function res = fun3(r1,r2,deltaplus,IBLplus,loop,Hist,NonVar)
% streamwise momentum equation
% E58 : equation (3.1)
% FTBL, FTBL-Blend: equation (4.11)


% load parameters & constants
Condi = NonVar.Condi;
Const = NonVar.Const;
opt = NonVar.opt;
Bparam = NonVar.Bparam;

kappa = Const.kappa;
A = Const.A;
B = Const.B;
p1 = Const.p1;
p2 = Const.p2;

ks1plus = Condi.ks1plus;
ks2plus = Condi.ks2plus;
Uinftyplus = Condi.Uinftplus;

G1 = Hist.G1;
G2 = Hist.G2;
G3 = Hist.G3;
G4 = Hist.G4;
Ui = Hist.Ui;
shear1 = Hist.shear1;
shear2 = Hist.shear2;
Cf2 = Hist.Cf2;
thetaplus = Hist.thetaplus;


DeltaUplus1 = roughness_function(ks1plus*r1, kappa, A, B);
DeltaUplus2 = roughness_function(ks2plus*r2, kappa, A, B);

Bparam.DIBL = Bparam.DIBL*r1;
[zplus,Uplusf,~,~] = NonD_VeloProf(deltaplus*r1,IBLplus*r1,r2/r1,DeltaUplus1,DeltaUplus2,Const,opt,Bparam);


% compute integrals (3.2) & (4.12)
n = numel(zplus)/2;
G1(loop) = trapz(zplus(1:n)/r1,Uplusf(1:n)*r1);   
G2(loop) = trapz(zplus(1:n)/r1,(Uplusf(1:n)*r1).^2);
G3(loop) = trapz(zplus(n:end)/r1,Uplusf(n:end)*r1);
G4(loop) = trapz(zplus(n:end)/r1,(Uplusf(n:end)*r1).^2);
Ui(loop) = Uplusf(n)*r1;
if opt.ShearCorr
    % shear stress correction, (5.10) & (5.8)
    shear1(loop) = r1^2*(p1*(IBLplus/deltaplus)^3+p2*(IBLplus/deltaplus)^2+(-1-p1-p2)*(IBLplus/deltaplus)+1);
    shear2(loop) = r1^2*(p1*(IBLplus/deltaplus)^3+p2*(IBLplus/deltaplus)^2+(-1-p1-p2)*(IBLplus/deltaplus)+1)-r2^2;
elseif ~opt.ShearCorr
    % Elliott original
    shear1(loop) = r1^2; 
    shear2(loop) = r1^2-r2^2; 
end
thetaplus(loop) = trapz(zplus/r1,Uplusf*r1.*(Uinftyplus-Uplusf*r1)/Uinftyplus^2);
Cf2(loop) = 2*(r2/Uinftyplus)^2;

if opt.DeltaGrow
    % with outer-layer growth (4.11)
    res = trapz(G4(1:loop),-1./shear1(1:loop))+...
            trapz(G1(1:loop),(Uinftyplus-Ui(1:loop))./shear1(1:loop))+...
            trapz(G3(1:loop),Uinftyplus./shear1(1:loop))-trapz(thetaplus(1:loop),2./Cf2(1:loop));
else
    % without outer-layer growth (3.1)
    res = trapz(G2(1:loop),1./shear2(1:loop))-...
        trapz(G1(1:loop),Ui(1:loop)./shear2(1:loop))-trapz(thetaplus(1:loop),2./Cf2(1:loop));
end