(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    335202,       7484]
NotebookOptionsPosition[    314695,       7160]
NotebookOutlinePosition[    315032,       7175]
CellTagsIndexPosition[    314989,       7172]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Implementation", " ", "of", " ", "the", " ", "FTBL", " ", "model", " ", 
   "with", " ", "a", " ", "piecewise", " ", "logarithmic", " ", "velocity", 
   " ", 
   RowBox[{"profile", ".", " ", "This"}], " ", "version", " ", "does", " ", 
   "not", " ", "differentiate", " ", "matching", " ", 
   RowBox[{"equation", ".", " ", "Instead"}], " ", "it", " ", "makes", " ", 
   "a", " ", "direct", " ", "substitution"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851856047524442*^9, 3.851856060353113*^9}, {
  3.8519643633270335`*^9, 3.8519643939384303`*^9}, {3.85197836415641*^9, 
  3.8519783771864986`*^9}, {3.8613864662538147`*^9, 3.861386470194346*^9}, {
  3.861386870607897*^9, 3.8613869244024363`*^9}},
 CellLabel->
  "In[939]:=",ExpressionUUID->"cb21c7c6-dc94-4bc3-9476-b0b5d034bbb4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "U1", ",", "U2", ",", "S1", ",", "K", ",", "z", ",", "z01", ",", "z02", 
    ",", "ks", ",", "A", ",", "B", ",", "S", ",", "d0", ",", "ksh"}], "]"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
   "Region", " ", "1", " ", "is", " ", "upstream", " ", "rough", " ", "wall", 
    " ", "Region", " ", "2", " ", "is", " ", "downstream", " ", "smooth", " ",
     "wall"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
    "Length", " ", "and", " ", "velocity", " ", "constants", " ", "are", " ", 
     "UI"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"velocity", " ", "at", " ", "infiniyy", " ", "and", " ", "dc0"}],
      " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\\", "delta"}], 
       RowBox[{"(", "0", ")"}], " ", "which", " ", "is", " ", "outer", " ", 
       "BL", " ", "thickness", " ", "at", " ", "x"}], " ", "=", " ", 
      "0"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Unknowns", " ", "are", " ", "S1"}], " ", "=", " ", 
     RowBox[{"UI", "/", "ut1"}]}], ",", " ", 
    RowBox[{"S2", " ", "=", " ", 
     RowBox[{"UI", "/", "ut2"}]}], ",", " ", 
    RowBox[{"dc", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\\", "delta"}], 
       RowBox[{"(", "x", ")"}], "  ", "and", " ", "di"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"delta_i", ".", "  ", 
        RowBox[{"Nondimensional", ":", " ", "dch"}]}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"\\", "delta"}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", "x", ")"}], "/"}], "\\", "delta"}], 
         RowBox[{"(", "0", ")"}], "  ", "and", " ", "dih"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"delta_i", "/", "delta"}], 
         RowBox[{"(", "0", ")"}]}]}]}]}]}]}], "  ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.730467711316572*^9, 3.7304677472340693`*^9}, {
  3.730473159840771*^9, 3.730473164837319*^9}, {3.8518559861540403`*^9, 
  3.8518560153344374`*^9}, {3.851859020912593*^9, 3.851859237043853*^9}, {
  3.8522203712375093`*^9, 3.852220429809493*^9}, {3.852222175338683*^9, 
  3.8522222764123263`*^9}},
 CellLabel->
  "In[940]:=",ExpressionUUID->"ea60df7e-34a6-4c5b-b260-4c0ba7449a99"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Velocity", " ", "profiles"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518592492400336`*^9, 3.8518592813813877`*^9}, {
  3.851860722972407*^9, 3.8518607448625355`*^9}, {3.8522203879921856`*^9, 
  3.852220393091872*^9}},
 CellLabel->
  "In[941]:=",ExpressionUUID->"82978fa8-6d69-43f3-b12c-ab4efd7c3ce1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U1", " ", "=", " ", 
  RowBox[{"ut1", "*", 
   RowBox[{"1", "/", "K"}], "*", 
   RowBox[{"Log", "[", 
    RowBox[{"z", "/", "z01"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7293497272938147`*^9, 3.729349754252965*^9}, {
  3.851856025135623*^9, 3.8518560420383825`*^9}, {3.851856948911482*^9, 
  3.8518569503617287`*^9}, {3.8518607638367047`*^9, 3.8518607645387115`*^9}},
 CellLabel->
  "In[942]:=",ExpressionUUID->"f6965048-5747-4dd7-8f85-b3a359a09027"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"Log", "[", 
    FractionBox["z", "z01"], "]"}]}], "K"]], "Output",
 CellChangeTimes->{3.729349756851776*^9, 3.729353704512504*^9, 
  3.730467757239176*^9, 3.7305564474550467`*^9, 3.7312596507464066`*^9, 
  3.851856066718689*^9, 3.8518569552524166`*^9, 3.851860766914606*^9, 
  3.851861390635028*^9, 3.851955388201799*^9, 3.8519644308964458`*^9, 
  3.851966213523812*^9, 3.8519783841786394`*^9, 3.852049271307126*^9, 
  3.8520716265975804`*^9, 3.8520716983451996`*^9, 3.852115463262934*^9, 
  3.852220439908625*^9, 3.8613864920674353`*^9, 3.861386840715555*^9, 
  3.8613875309697933`*^9},
 CellLabel->
  "Out[942]=",ExpressionUUID->"eef3f92d-861c-4e4d-81e5-083d288488f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U2", " ", "=", " ", 
  RowBox[{"ut2", "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "K"}], "*", 
      RowBox[{"Log", "[", 
       RowBox[{"z", "*", 
        RowBox[{"ut2", "/", "nu"}]}], "]"}]}], " ", "+", "A"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.8518562769203167`*^9, 3.8518563013255043`*^9}, {
  3.851856960120079*^9, 3.8518569611618805`*^9}, {3.851860777499856*^9, 
  3.851860778567809*^9}, {3.851861397096198*^9, 3.851861421642493*^9}, {
  3.851873227640999*^9, 3.8518732282349253`*^9}},
 CellLabel->
  "In[943]:=",ExpressionUUID->"4fa0517e-dfa6-42e8-ae35-99614f1d0edc"],

Cell[BoxData[
 RowBox[{"ut2", " ", 
  RowBox[{"(", 
   RowBox[{"A", "+", 
    FractionBox[
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"ut2", " ", "z"}], "nu"], "]"}], "K"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.85185630613315*^9, 3.8518569619884515`*^9, 
  3.851860780612847*^9, 3.8518614676370487`*^9, 3.851873229644766*^9, 
  3.8519553990303173`*^9, 3.8519644380696993`*^9, 3.851966217453807*^9, 
  3.851978398612624*^9, 3.852049271399274*^9, 3.852071626666689*^9, 
  3.852071698417595*^9, 3.85211546850134*^9, 3.852220444802431*^9, 
  3.8613864920750227`*^9, 3.8613868407238503`*^9, 3.861387530977777*^9},
 CellLabel->
  "Out[943]=",ExpressionUUID->"388dacf6-a1da-4c6a-ac1b-71699e942ec7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Eq", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], ".", "  ", "Velocity"}], " ", "matching", 
    " ", "at", " ", "z"}], " ", "=", " ", "di"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518565282158995`*^9, 3.8518565766461725`*^9}, {
  3.8521154769061017`*^9, 3.852115478041054*^9}},
 CellLabel->
  "In[944]:=",ExpressionUUID->"d5d7d418-6488-4e43-8ad8-d7b6e2cb5566"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQm1", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ut1", "/", "K"}], "*", 
    RowBox[{"Log", "[", 
     RowBox[{"di", "/", "z01"}], "]"}]}], "-", " ", 
   RowBox[{"ut2", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "K"}], "*", 
       RowBox[{"Log", "[", 
        RowBox[{"di", "*", 
         RowBox[{"ut2", "/", "nu"}]}], "]"}]}], " ", "+", "A"}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.851856595530841*^9, 3.8518566549562473`*^9}, {
   3.851856782130268*^9, 3.85185678282686*^9}, {3.851856968914916*^9, 
   3.8518569900861063`*^9}, {3.851860796822938*^9, 3.8518608261062565`*^9}, 
   3.8518614847090755`*^9, {3.851863887086609*^9, 3.8518638893146057`*^9}, {
   3.851864079595587*^9, 3.851864081219633*^9}, {3.8519554242982416`*^9, 
   3.851955425050208*^9}},
 CellLabel->
  "In[945]:=",ExpressionUUID->"25fb845c-9afe-4214-9316-c4d7ec15a13d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "ut2"}], " ", 
   RowBox[{"(", 
    RowBox[{"A", "+", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut2"}], "nu"], "]"}], "K"]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"Log", "[", 
     FractionBox["di", "z01"], "]"}]}], "K"]}]], "Output",
 CellChangeTimes->{{3.8518566400206356`*^9, 3.8518566593221865`*^9}, 
   3.851856783957985*^9, 3.851856996588332*^9, 3.8518608298372297`*^9, 
   3.85186148717063*^9, 3.8518638969429235`*^9, 3.851864082765283*^9, 
   3.8518642072726665`*^9, 3.851864334072564*^9, 3.8518669610890956`*^9, 
   3.8518732611790957`*^9, 3.8519554396240435`*^9, 3.8519622415934396`*^9, 
   3.8519662234810004`*^9, 3.851978426371771*^9, 3.8520492715123873`*^9, 
   3.8520716267476435`*^9, 3.852071698502036*^9, 3.8521154905547695`*^9, 
   3.8522204750312862`*^9, 3.861386492124401*^9, 3.861386840773349*^9, 
   3.8613875310249023`*^9},
 CellLabel->
  "Out[945]=",ExpressionUUID->"33178230-0457-475d-aeae-12f4e03bb31f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Eq", " ", 
    RowBox[{
     RowBox[{"(", "0", ")"}], ".", "  ", "velocity"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"UI", " ", "at", " ", "z"}], "=", " ", 
    RowBox[{"dc", " ", 
     RowBox[{"(", 
      RowBox[{"outer", " ", "BL"}], ")"}]}]}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851856885491148*^9, 3.8518569106649237`*^9}, 
   3.851860898508426*^9, {3.852220482240957*^9, 3.8522204843722687`*^9}},
 CellLabel->
  "In[946]:=",ExpressionUUID->"671d1813-c94e-4f5c-8a63-6b76fadcdda2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ0", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ut1", "/", "K"}], "*", 
    RowBox[{"Log", "[", 
     RowBox[{"dc", "/", "z01"}], "]"}]}], "-", "1"}]}]], "Input",
 CellChangeTimes->{{3.8518567878111296`*^9, 3.8518568356448374`*^9}, {
   3.8518570101376753`*^9, 3.8518570162570553`*^9}, {3.851860849458492*^9, 
   3.851860893700107*^9}, 3.852220499397125*^9},
 CellLabel->
  "In[947]:=",ExpressionUUID->"e79b034f-0f7f-420c-afd4-b76835fa6bc6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"Log", "[", 
     FractionBox["dc", "z01"], "]"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.851860908418703*^9, 3.851861503564375*^9, 
  3.851864088604856*^9, 3.851864340771022*^9, 3.851866966585204*^9, 
  3.8518732728890934`*^9, 3.851955446310946*^9, 3.851962251608975*^9, 
  3.8519662303716555`*^9, 3.8519784442983575`*^9, 3.852049271611267*^9, 
  3.85207162681991*^9, 3.8520716985754547`*^9, 3.852115508916393*^9, 
  3.8521155840507975`*^9, 3.8522205043915377`*^9, 3.8613864921735363`*^9, 
  3.861386840821966*^9, 3.861387531071336*^9},
 CellLabel->
  "Out[947]=",ExpressionUUID->"f476a396-7a60-48c3-897e-cfdcef6b0f24"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"EQ0", "\[Equal]", "0"}], ",", "ut1"}], "]"}]], "Input",
 CellChangeTimes->{{3.8518643633312273`*^9, 3.8518643757209153`*^9}},
 CellLabel->
  "In[948]:=",ExpressionUUID->"c1a895c8-3ec0-4572-b629-9474bce95644"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"ut1", "\[Rule]", 
    FractionBox["K", 
     RowBox[{"Log", "[", 
      FractionBox["dc", "z01"], "]"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.851864377042094*^9, 3.851866978671404*^9, 
  3.8519554545783777`*^9, 3.851962257823409*^9, 3.8519662351035957`*^9, 
  3.8519784497971053`*^9, 3.8520492717060013`*^9, 3.852071626882744*^9, 
  3.852071698640461*^9, 3.8521156461127195`*^9, 3.8522205094608955`*^9, 
  3.861386492219769*^9, 3.861386840860569*^9, 3.861387531112945*^9},
 CellLabel->
  "Out[948]=",ExpressionUUID->"42135b03-fae7-43b2-aef5-9e7a306a0943"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Put", " ", "UI"}], " ", "=", 
   RowBox[{
   "1.", " ", "Express", " ", "in", " ", "terms", " ", "of", " ", "S1"}]}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.85197798823536*^9, 3.8519779939853983`*^9}, {
  3.8519784763755064`*^9, 3.8519784856755385`*^9}},
 CellLabel->
  "In[949]:=",ExpressionUUID->"7ac1198f-a464-4ae9-b60a-0fa9abb193ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S1Sol", "[", "x_", "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "/", "K"}]}]], "Input",
 CellChangeTimes->{{3.85196791711742*^9, 3.851967981994134*^9}},
 CellLabel->
  "In[950]:=",ExpressionUUID->"c062a907-3048-4101-b550-1a602178787e"],

Cell[BoxData[
 RowBox[{"(*", " ", "Example", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8522205208895116`*^9, 3.852220525832639*^9}},
 CellLabel->
  "In[951]:=",ExpressionUUID->"c005581f-effa-4770-8ce6-b2584c9744c6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S1Sol", "[", "x", "]"}], "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{"z01h", "\[Rule]", "0.000373"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.851968013039324*^9, 3.851968064594179*^9}, {
   3.8519785151314507`*^9, 3.851978516123498*^9}, 3.861387523630535*^9},
 CellLabel->
  "In[952]:=",ExpressionUUID->"0b10577e-4069-4410-aff5-a67f7fe22f40"],

Cell[BoxData["20.55711494354286`"], "Output",
 CellChangeTimes->{{3.851968054037552*^9, 3.8519680678507977`*^9}, 
   3.851978006709188*^9, {3.8519785093628464`*^9, 3.851978517962041*^9}, 
   3.852049271802162*^9, 3.8520716269548335`*^9, 3.852071698713501*^9, 
   3.8521156685170565`*^9, 3.852220536553387*^9, 3.861386492313586*^9, 
   3.8613868409252787`*^9, 3.861387531172701*^9},
 CellLabel->
  "Out[952]=",ExpressionUUID->"9bd92276-bb46-4c42-8e52-f23ef09eecbe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQm1A", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"EQm1", "/.", " ", 
    RowBox[{"ut1", "\[Rule]", 
     RowBox[{"UI", "/", 
      RowBox[{"S1Sol", "[", "x", "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8518643825551414`*^9, 3.851864424603493*^9}, {
  3.851867037511719*^9, 3.851867040749667*^9}, {3.851967577964449*^9, 
  3.851967578165701*^9}, {3.8519785426241035`*^9, 3.8519785487585154`*^9}, {
  3.851978628864283*^9, 3.8519786315590363`*^9}},
 CellLabel->
  "In[953]:=",ExpressionUUID->"a0d4e923-9af5-45a9-b31e-aaa7daa6c5a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "ut2"}], " ", 
   RowBox[{"(", 
    RowBox[{"A", "+", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut2"}], "nu"], "]"}], "K"]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"UI", " ", 
    RowBox[{"Log", "[", 
     FractionBox["di", "z01"], "]"}]}], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]}]], "Output",
 CellChangeTimes->{{3.851864409395501*^9, 3.851864425729066*^9}, 
   3.851867005282336*^9, 3.851867044964031*^9, 3.851873287291603*^9, 
   3.8519554701029615`*^9, 3.851962270395913*^9, 3.851966254197507*^9, 
   3.851967579894915*^9, 3.851978024540492*^9, 3.8519785516626306`*^9, 
   3.851978632852002*^9, 3.8520492720062866`*^9, 3.8520716271523747`*^9, 
   3.8520716987765846`*^9, 3.8521157027376432`*^9, 3.861386492397249*^9, 
   3.861386840978074*^9, 3.861387531225548*^9},
 CellLabel->
  "Out[953]=",ExpressionUUID->"fef884b0-b34f-4676-a4bc-576ed861cba0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Put", " ", "UI"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
    "1.", " ", "Express", " ", "ut2", " ", "in", " ", "terms", " ", "of", " ",
      "S2"}], "=", " ", 
    RowBox[{"UI", "/", "ut2"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519780332117386`*^9, 3.851978048905177*^9}, {
  3.8519785642242594`*^9, 3.851978611596676*^9}, {3.8519787423577905`*^9, 
  3.8519787465258255`*^9}},
 CellLabel->
  "In[954]:=",ExpressionUUID->"2e68a52b-abef-4976-95f3-7cbbc6b3163d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQm1B", " ", "=", " ", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"(", 
     RowBox[{"A", "+", 
      FractionBox[
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"dih", "[", "x", "]"}], "*", 
         RowBox[{"Rec", "/", "S2S"}]}], "]"}], "K"]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"S2S", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]}]}]], "Input",
 CellChangeTimes->{{3.8519664015054827`*^9, 3.851966428406844*^9}, {
   3.851966517912634*^9, 3.8519665938272815`*^9}, 3.8519778794833965`*^9, 
   3.851977932264804*^9},
 CellLabel->
  "In[955]:=",ExpressionUUID->"e8854b6a-f3b4-41a8-94d0-aaf9ba596d2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "A"}], "+", 
  FractionBox[
   RowBox[{"S1S", " ", 
    RowBox[{"Log", "[", 
     FractionBox["di", "z02"], "]"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "Rec"}], "S1S"], "]"}]}], ")"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}]], "-", 
  FractionBox[
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"Rec", " ", 
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"di", " ", "Rec"}], "S1S"], "]"}]}], ")"}]}], 
     RowBox[{"S1S", " ", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z02"], "]"}]}]], "]"}], "K"]}]], "Output",
 CellChangeTimes->{
  3.851966600632086*^9, 3.8519675922791595`*^9, {3.85197786583988*^9, 
   3.851977881151085*^9}, 3.85197793335854*^9, 3.8519780766990824`*^9, 
   3.851978671494949*^9, 3.852049272101186*^9, 3.8520716272260914`*^9, 
   3.8520716988417673`*^9, 3.8521157138822393`*^9, 3.852220542224517*^9, 
   3.8613864924425173`*^9, 3.8613868410266323`*^9, 3.861387531274624*^9},
 CellLabel->
  "Out[955]=",ExpressionUUID->"8b6a0007-4cde-466d-9090-7c58f3d47611"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"EQm1B", "\[Equal]", "0"}], ",", "S2S"}], "]"}]], "Input",
 CellChangeTimes->{{3.8519662757525206`*^9, 3.85196629271659*^9}, {
   3.8519666076383176`*^9, 3.851966616519412*^9}, 3.8519778882533455`*^9},
 CellLabel->
  "In[956]:=",ExpressionUUID->"b2ce0246-5b7f-4125-bf12-35eadd073cc9"],

Cell[BoxData[
 TemplateBox[{
  "Solve","ivar",
   "\"\\!\\(\\*FractionBox[RowBox[{\\\"S1S\\\", \\\" \\\", \
RowBox[{\\\"Log\\\", \\\"[\\\", FractionBox[\\\"di\\\", \\\"z02\\\"], \\\"]\\\
\"}]}], RowBox[{RowBox[{\\\"A\\\", \\\" \\\", \\\"K\\\"}], \\\"+\\\", \
RowBox[{\\\"Log\\\", \\\"[\\\", FractionBox[RowBox[{\\\"di\\\", \\\" \\\", \\\
\"Rec\\\"}], \\\"S1S\\\"], \\\"]\\\"}]}]]\\) is not a valid variable.\"",2,
   956,7,32075551143242373313,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8519779381274548`*^9, 3.8519781047887897`*^9, 
  3.851978675365596*^9, 3.8520492721895075`*^9, 3.852071627290261*^9, 
  3.852071698901246*^9, 3.852115844779356*^9, 3.852220548182645*^9, 
  3.861386492499278*^9, 3.861386841040061*^9, 3.861387531287034*^9},
 CellLabel->
  "During evaluation of \
In[956]:=",ExpressionUUID->"c8121407-62e7-4420-bf93-8e030e89ceb5"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "A"}], "+", 
     FractionBox[
      RowBox[{"S1S", " ", 
       RowBox[{"Log", "[", 
        FractionBox["di", "z02"], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"di", " ", "Rec"}], "S1S"], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}]], "-", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A", " ", "K"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"di", " ", "Rec"}], "S1S"], "]"}]}], ")"}]}], 
        RowBox[{"S1S", " ", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z02"], "]"}]}]], "]"}], "K"]}], "\[Equal]", 
    "0"}], ",", 
   FractionBox[
    RowBox[{"S1S", " ", 
     RowBox[{"Log", "[", 
      FractionBox["di", "z02"], "]"}]}], 
    RowBox[{
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"di", " ", "Rec"}], "S1S"], "]"}]}]]}], "]"}]], "Output",
 CellChangeTimes->{3.851966296211296*^9, 3.8519666178970313`*^9, 
  3.8519675962718086`*^9, 3.851977889412921*^9, 3.851977938138426*^9, 
  3.851978104800753*^9, 3.8519786753805532`*^9, 3.8520492722026477`*^9, 
  3.852071627301119*^9, 3.8520716989106493`*^9, 3.8521158447965364`*^9, 
  3.8522205482023573`*^9, 3.861386492515761*^9, 3.861386841046462*^9, 
  3.861387531293833*^9},
 CellLabel->
  "Out[956]=",ExpressionUUID->"3b3299a1-45d6-488f-a8ca-a945b669bf5b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Define", " ", 
   RowBox[{"S2Sol", "[", "x", "]"}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.85197868075179*^9, 3.851978690664279*^9}},
 CellLabel->
  "In[957]:=",ExpressionUUID->"805c3821-37d7-49b9-bdb9-a1c60a885047"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2Sol", "[", "x", "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
    RowBox[{"ProductLog", "[", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}], 
   RowBox[{"K", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]]}]], "Input",
 CellChangeTimes->{{3.851966624093649*^9, 3.8519666564522066`*^9}},
 CellLabel->
  "In[958]:=",ExpressionUUID->"6b6a3c9d-80fe-43d8-a75e-5ed70e950bf4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "limits"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519787818486085`*^9, 3.851978795815835*^9}, 
   3.8522205716250815`*^9},
 CellLabel->
  "In[959]:=",ExpressionUUID->"ae5e87e3-a211-48e1-ac8e-f272ddc6e215"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"S2Sol", "[", "x", "]"}], ",", 
   RowBox[{
    RowBox[{"dih", "[", "x", "]"}], "\[Rule]", "z01h"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.851967109510713*^9, 3.8519671556429462`*^9}},
 CellLabel->
  "In[960]:=",ExpressionUUID->"3b1ad960-ab22-46de-acf5-78f5e65366ae"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"A", " ", "K"}]], " ", "Rec", " ", "z01h"}]], "Output",
 CellChangeTimes->{{3.851967146879403*^9, 3.8519671569661245`*^9}, 
   3.851977774706279*^9, 3.8519781232205667`*^9, 3.851980987182784*^9, 
   3.852049272958606*^9, 3.852071627968254*^9, 3.8520716991325827`*^9, 
   3.8521158863578367`*^9, 3.852220579039532*^9, 3.861386492789166*^9, 
   3.861386841281513*^9, 3.861387531530229*^9},
 CellLabel->
  "Out[960]=",ExpressionUUID->"64851964-1c97-4702-8c06-ef194163aa38"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"A", " ", "K"}]], " ", "Rec", " ", "z01h"}], "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"z01h", " ", "->", " ", "0.000373"}], ",", 
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]], "Input",
 CellChangeTimes->{{3.8519781418747644`*^9, 3.85197815682195*^9}, {
   3.851978192232061*^9, 3.8519782031130695`*^9}, 3.8519782567114706`*^9, {
   3.8519810445696926`*^9, 3.851981055946413*^9}, {3.852220600632513*^9, 
   3.8522206011342974`*^9}, 3.852222344662367*^9},
 CellLabel->
  "In[961]:=",ExpressionUUID->"6708e53a-58db-4623-b5fa-f57c3899c4ae"],

Cell[BoxData["619.082874528912`"], "Output",
 CellChangeTimes->{
  3.851978159037389*^9, 3.8519782051722174`*^9, 3.8519782579123106`*^9, {
   3.8519809947955527`*^9, 3.851981061787868*^9}, 3.852049273081563*^9, 
   3.8520716281194134`*^9, 3.852071699189242*^9, 3.8521158981887493`*^9, {
   3.8522205964747047`*^9, 3.8522206029887733`*^9}, 3.8522223469612136`*^9, 
   3.861386492796989*^9, 3.861386841289723*^9, 3.861387531538731*^9},
 CellLabel->
  "Out[961]=",ExpressionUUID->"162b5561-3067-4443-bba6-f5bff1f53c6e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Summary", " ", "to", " ", "date"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.852220645586186*^9, 3.8522206519048395`*^9}},
 CellLabel->
  "In[962]:=",ExpressionUUID->"e9c47dca-ddfe-4817-aef0-bd185b9b4ec3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"S1Sol", "[", "x", "]"}], ",", 
   RowBox[{"S2Sol", "[", "x", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.851967608136874*^9, 3.8519676218091016`*^9}, {
  3.85196809029003*^9, 3.8519680915302763`*^9}},
 CellLabel->
  "In[963]:=",ExpressionUUID->"4f29be76-7bab-497d-827d-76d6240fd6d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "K"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.851967624222247*^9, 3.851968093122267*^9, 
  3.85198108885706*^9, 3.852049281403226*^9, 3.852071628511261*^9, 
  3.8520716994101424`*^9, 3.8522206585956125`*^9, 3.8613864928508987`*^9, 
  3.861386841338854*^9, 3.861387531586842*^9},
 CellLabel->
  "Out[963]=",ExpressionUUID->"6eb95c91-0039-4c93-8ef7-939714e94ac3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Equ", 
   RowBox[{
    RowBox[{"(", "2", ")"}], ".", " ", "Outerlayer"}], " ", 
   RowBox[{"momentum", ".", " ", "First"}], " ", "construct", " ", "Three", 
   " ", "integral", " ", "terms", " ", "terms"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851856873098802*^9, 3.851856880068634*^9}, {
  3.851856919042452*^9, 3.851856938970237*^9}, {3.8518609377820053`*^9, 
  3.851860945353352*^9}, {3.851872852724075*^9, 3.8518728580144577`*^9}},
 CellLabel->
  "In[964]:=",ExpressionUUID->"292642b2-b58d-4450-805b-067cbe7fdb10"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1T", " ", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U1", "^", "2"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851860954975442*^9, 3.851861011427848*^9}, {
   3.851861054090987*^9, 3.851861111136257*^9}, 3.8518615197823687`*^9, {
   3.8518616174389577`*^9, 3.8518616407833185`*^9}, {3.85186168553551*^9, 
   3.851861695718727*^9}, {3.8518617654400682`*^9, 3.851861766048193*^9}, {
   3.851861821582517*^9, 3.8518618285886765`*^9}, 3.8518631652039003`*^9},
 CellLabel->
  "In[965]:=",ExpressionUUID->"28dc1692-73b7-4e17-b0dc-6228604e3cb4"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "z"}], "-", 
     RowBox[{"2", " ", "z", " ", 
      RowBox[{"Log", "[", 
       FractionBox["z", "z01"], "]"}]}], "+", 
     RowBox[{"z", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox["z", "z01"], "]"}], "2"]}]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{
  3.8518610180570145`*^9, {3.851861102575753*^9, 3.8518611150209*^9}, 
   3.8518615542770557`*^9, {3.85186167562362*^9, 3.8518616977320533`*^9}, {
   3.851861752805217*^9, 3.851861767527998*^9}, {3.851861822720601*^9, 
   3.851861831200296*^9}, 3.851861963539211*^9, 3.8518631699672422`*^9, 
   3.8519554889579687`*^9, 3.851962290270302*^9, 3.8519676301079016`*^9, 
   3.8519681026536646`*^9, 3.8519811154161577`*^9, 3.8519822605125184`*^9, 
   3.851982353722365*^9, 3.8520492930634656`*^9, 3.8520716286552663`*^9, 
   3.852071729597657*^9, 3.8522206783129983`*^9, 3.861386492957123*^9, 
   3.861386841392234*^9, 3.86138753163496*^9},
 CellLabel->
  "Out[965]=",ExpressionUUID->"bc00b9f6-5540-4db1-94c4-62ab9b5913d9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I1T", "/.", " ", 
      RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], " ", "-", 
    RowBox[{"(", 
     RowBox[{"I1T", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851861132006254*^9, 3.8518611456974487`*^9}, {
  3.8518617743306465`*^9, 3.851861862352995*^9}, {3.8518618975592804`*^9, 
  3.8518619224417996`*^9}, {3.8518619693128676`*^9, 3.851862003058215*^9}},
 CellLabel->
  "In[966]:=",ExpressionUUID->"2a769c66-0636-43c8-bfb0-1e906775d018"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"dc", "-", "di"}], ")"}]}], "+", 
     RowBox[{"dc", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["dc", "z01"], "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox["dc", "z01"], "]"}]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["di", "z01"], "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z01"], "]"}]}]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{
  3.851861801227013*^9, {3.8518618474006815`*^9, 3.851861866380803*^9}, {
   3.8518619025470767`*^9, 3.851861925316579*^9}, {3.8518619857744637`*^9, 
   3.8518620056876807`*^9}, 3.851863183728162*^9, 3.851955495442132*^9, 
   3.851962323535138*^9, 3.85196763466755*^9, 3.8519681127275715`*^9, 
   3.8519823674640336`*^9, 3.852049299724189*^9, 3.852071628775427*^9, 
   3.8520717296890955`*^9, 3.8522206838642917`*^9, 3.8613864930340233`*^9, 
   3.8613868414431143`*^9, 3.8613875316737328`*^9},
 CellLabel->
  "Out[966]=",ExpressionUUID->"c75b0754-daba-4cc3-b55a-363dbeb906d5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"define", " ", "interface", " ", "velocity"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8518735578976774`*^9, 3.851873568063842*^9}},
 CellLabel->
  "In[967]:=",ExpressionUUID->"074ea169-89cd-43eb-930f-f08e8ba96b09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ui", " ", "=", "  ", 
  RowBox[{"ut1", "*", 
   RowBox[{"1", "/", "K"}], "*", 
   RowBox[{"Log", "[", 
    RowBox[{"di", "/", "z01"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8518613155245695`*^9, 3.8518613277874904`*^9}, 
   3.851861363287326*^9, {3.8518735793378925`*^9, 3.8518735865978756`*^9}},
 CellLabel->
  "In[968]:=",ExpressionUUID->"eb92df4c-5651-4f54-b289-ba4f93144542"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"Log", "[", 
    FractionBox["di", "z01"], "]"}]}], "K"]], "Output",
 CellChangeTimes->{3.8518620583238506`*^9, 3.8518632036341195`*^9, 
  3.851873589662359*^9, 3.8519623360089674`*^9, 3.8519676462245655`*^9, 
  3.8519681191993876`*^9, 3.8519823812641954`*^9, 3.852049305590852*^9, 
  3.852049343351277*^9, 3.8520716287971663`*^9, 3.852071729803253*^9, 
  3.852220697054631*^9, 3.8613864930866547`*^9, 3.8613868414950647`*^9, 
  3.861387531722617*^9},
 CellLabel->
  "Out[968]=",ExpressionUUID->"4edc3b95-1dc4-4b67-8f86-fd36fd7ed473"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "Ui", "]"}]], "Input",
 CellChangeTimes->{{3.851968140839637*^9, 3.851968147524536*^9}},
 CellLabel->
  "In[969]:=",ExpressionUUID->"afcb4998-50d5-4bea-a001-d20ddb8ba456"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Express", " ", "in", " ", "terms", " ", "of", " ", 
    RowBox[{"S1", ".", " ", "Put"}], " ", "UI"}], " ", "=", "1"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8519823947702723`*^9, 3.851982408400963*^9}, {
  3.8519824533795557`*^9, 3.8519824617043505`*^9}},
 CellLabel->
  "In[970]:=",ExpressionUUID->"d5c1f21f-9406-4b4f-b671-45c4e6dfe44c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ui", "[", "x", "]"}], ":=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], "K"], "/", 
   RowBox[{"S1Sol", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.851968128582387*^9, 3.851968202055013*^9}, {
  3.8519824676993575`*^9, 3.8519824683311033`*^9}},
 CellLabel->
  "In[971]:=",ExpressionUUID->"b5b2af8a-821f-4296-9e42-5068ea68075d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ui", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.851968207081113*^9, 3.8519682102446136`*^9}},
 CellLabel->
  "In[972]:=",ExpressionUUID->"636dc89e-5e09-4596-9bee-2cf1480dd0b2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], 
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]], "Output",
 CellChangeTimes->{3.8519682111851993`*^9, 3.851982472659141*^9, 
  3.852049355788468*^9, 3.8520716288291273`*^9, 3.8520717299583406`*^9, 
  3.8522207194485707`*^9, 3.861386493189212*^9, 3.86138684157789*^9, 
  3.861387531787381*^9},
 CellLabel->
  "Out[972]=",ExpressionUUID->"2583f018-dd3b-4f4d-9a29-e5276da861b9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
   "Note", " ", "that", " ", "second", " ", "term", " ", "involves", " ", 
    "lower", " ", "layer"}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
   "Lower", " ", "limit", " ", "of", " ", "integration", " ", "set", " ", 
    "to", " ", 
    RowBox[{"zero", ".", " ", "This"}], " ", "will", " ", "hav", " ", 
    "minimal", " ", "effect", " ", "on", " ", "results", " ", "at", " ", 
    "large", " ", "Rec", " ", "because", " ", "integrals", " ", "converge"}], 
   "  ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.851872939447791*^9, 3.8518729568504906`*^9}, {
  3.852220730791543*^9, 3.8522208137297153`*^9}},
 CellLabel->
  "In[973]:=",ExpressionUUID->"04528a2a-0bcd-4ced-ac52-3de6bf03cbde"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U2", ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "di"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8518621577204556`*^9, 3.851862209432994*^9}},
 CellLabel->
  "In[974]:=",ExpressionUUID->"51f2c909-ae6e-404a-929c-62767e7d10ef"],

Cell[BoxData[
 FractionBox[
  RowBox[{"di", " ", "ut2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"di", " ", "ut2"}], "nu"], "]"}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.851862214799238*^9, 3.8518632173137083`*^9, 
  3.851872987675748*^9, 3.8518733403775697`*^9, 3.851962369753043*^9, 
  3.8519676524714155`*^9, 3.8519682269803243`*^9, 3.851982489028068*^9, 
  3.8520493727803545`*^9, 3.8520716321845665`*^9, 3.8520717498887954`*^9, 
  3.852220821916092*^9, 3.86138649504811*^9, 3.861386843029193*^9, 
  3.8613875332021027`*^9},
 CellLabel->
  "Out[974]=",ExpressionUUID->"f61bc30f-0554-4c98-b107-5e08c880b4ee"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Third", " ", "term", " ", "is", " ", "upper", " ", "layer"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8519825216288705`*^9, 3.8519825309378767`*^9}},
 CellLabel->
  "In[975]:=",ExpressionUUID->"0df6fc1e-990f-4881-943e-716347f3716f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I31", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U1", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851862237043108*^9, 3.8518622627339783`*^9}, {
  3.8518622954038053`*^9, 3.8518622993655844`*^9}},
 CellLabel->
  "In[976]:=",ExpressionUUID->"0afed7a9-81cf-437a-b834-71056bde53af"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "z"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"Log", "[", 
       FractionBox["z", "z01"], "]"}]}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{{3.8518622870144343`*^9, 3.8518623021132355`*^9}, 
   3.8518632466120443`*^9, 3.851873010013199*^9, 3.851873354037224*^9, 
   3.8519623901074195`*^9, 3.8519676558130517`*^9, 3.851968229700569*^9, 
   3.851982535643815*^9, 3.852049394881694*^9, 3.852071632310727*^9, 
   3.8520717500217247`*^9, 3.852220826944914*^9, 3.8613864951226463`*^9, 
   3.861386843103651*^9, 3.861387533276531*^9},
 CellLabel->
  "Out[976]=",ExpressionUUID->"0a26ee99-906b-4224-add4-c6a1ee4f46b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I31", "/.", " ", 
      RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], " ", "-", " ", 
    RowBox[{"(", 
     RowBox[{"I31", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8518623057712517`*^9, 3.851862314279415*^9}, {
  3.851862347218445*^9, 3.851862431466671*^9}},
 CellLabel->
  "In[977]:=",ExpressionUUID->"00a7e422-fee2-438c-b3dd-5698e61a2cf6"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "dc"}], "+", "di", "+", 
     RowBox[{"dc", " ", 
      RowBox[{"Log", "[", 
       FractionBox["dc", "z01"], "]"}]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z01"], "]"}]}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{{3.8518623852175736`*^9, 3.8518624325504746`*^9}, 
   3.8518632544026065`*^9, 3.8518730158875947`*^9, 3.8518733588743944`*^9, 
   3.8519624010812516`*^9, 3.851967661426421*^9, 3.851968233117422*^9, 
   3.8519825453731537`*^9, 3.852049398690322*^9, 3.852071632375409*^9, 
   3.8520717501056128`*^9, 3.85222083544865*^9, 3.861386495158682*^9, 
   3.861386843112409*^9, 3.861387533320344*^9},
 CellLabel->
  "Out[977]=",ExpressionUUID->"a6fbf833-2637-4e8e-9449-cb937af97b84"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
   "**"}], "******)"}]], "Input",
 CellChangeTimes->{{3.851982555987455*^9, 3.851982558707167*^9}},
 CellLabel->
  "In[978]:=",ExpressionUUID->"b4ffaa2d-74a5-4ef8-b19d-807a8c4870b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
   "Full", " ", "equation", " ", "to", " ", "be", " ", "processed", " ", 
    "later"}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"Eq", 
     RowBox[{"(", "3", ")"}]}], ":", " ", 
    RowBox[{"Karman", " ", "integral", " ", "equation"}]}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.851862443320953*^9, 3.851862457583795*^9}, {
  3.8518628756655493`*^9, 3.8518628982435637`*^9}, {3.8522208431409082`*^9, 
  3.852220843980531*^9}},
 CellLabel->
  "In[979]:=",ExpressionUUID->"392de634-aa3b-48db-b7c4-df97c481f97c"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"First", " ", "Integral", " ", "term"}], ",", " ", 
   RowBox[{"prior", " ", "to", " ", "differentiation"}]}], "   ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.851863583180588*^9, 3.8518636128465567`*^9}},
 CellLabel->
  "In[980]:=",ExpressionUUID->"cc0d0b27-1416-4008-9a0d-e11081ce93a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J11", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U1", "^", "2"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851862911343463*^9, 3.8518629370352592`*^9}, {
  3.851863322668552*^9, 3.8518633281143985`*^9}},
 CellLabel->
  "In[981]:=",ExpressionUUID->"efa3b49a-cede-4628-8036-e6f750c5a2ef"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "z"}], "-", 
     RowBox[{"2", " ", "z", " ", 
      RowBox[{"Log", "[", 
       FractionBox["z", "z01"], "]"}]}], "+", 
     RowBox[{"z", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox["z", "z01"], "]"}], "2"]}]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{3.851863337185335*^9, 3.851876355028816*^9, 
  3.851876829591784*^9, 3.851962412542983*^9, 3.8519676693454924`*^9, 
  3.851968239623691*^9, 3.8519825678987923`*^9, 3.852049406423622*^9, 
  3.852071632402411*^9, 3.8520717502374125`*^9, 3.852220849816868*^9, 
  3.861386495212594*^9, 3.861386843188674*^9, 3.861387533396819*^9},
 CellLabel->
  "Out[981]=",ExpressionUUID->"accd8a8f-6d68-4888-9725-dbea6ea82ccb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J12", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U2", "^", "2"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851863342917837*^9, 3.851863357167018*^9}},
 CellLabel->
  "In[982]:=",ExpressionUUID->"5f6834f1-12c7-469e-84ad-5dd9e22e3453"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut2", "2"], " ", "z", " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", 
     RowBox[{"2", " ", "A", " ", "K"}], "+", 
     RowBox[{
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox["K", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"ut2", " ", "z"}], "nu"], "]"}]}], "+", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"ut2", " ", "z"}], "nu"], "]"}], "2"]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{3.8518633664085073`*^9, 3.8518763588942585`*^9, 
  3.851876835762397*^9, 3.8519624168197308`*^9, 3.8519676739686127`*^9, 
  3.8519682433167686`*^9, 3.8519825723034067`*^9, 3.8520494097597017`*^9, 
  3.8520716324590387`*^9, 3.852071750320991*^9, 3.8522208547207346`*^9, 
  3.861386495248547*^9, 3.861386843227635*^9, 3.861387533406085*^9},
 CellLabel->
  "Out[982]=",ExpressionUUID->"05820ce9-7128-4cd8-adf7-7b61397701da"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Again", " ", "lower", " ", "limit", " ", "of", " ", "integration", " ", 
   "set", " ", "to", " ", "zero"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.852220868620609*^9, 3.8522208850427947`*^9}},
 CellLabel->
  "In[983]:=",ExpressionUUID->"38f723f9-e208-4147-9ffb-ce9f7df8b1a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"J12", ",", 
   RowBox[{"z", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.852220893673297*^9, 3.852220900421302*^9}},
 CellLabel->
  "In[984]:=",ExpressionUUID->"13b1e7e0-59e9-4c40-903a-4b9703aab0e8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8522209053239574`*^9, 3.8613864986711473`*^9, 
  3.861386843276626*^9, 3.861387533477387*^9},
 CellLabel->
  "Out[984]=",ExpressionUUID->"45a5fbe0-5b7d-44c6-9d7d-e5cde8afbb4c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1", " ", "=", " ", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"(", 
     RowBox[{"J12", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}], "]"}], " ", "+", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J11", "/.", " ", 
       RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"J11", "/.", " ", 
       RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.851863379643095*^9, 3.851863450552127*^9}, {
  3.8518635054423733`*^9, 3.851863561338069*^9}, {3.8519595710078983`*^9, 
  3.8519595767942*^9}},
 CellLabel->
  "In[985]:=",ExpressionUUID->"c5ba50b8-bb4b-4070-804b-f40c11217fb4"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"di", " ", 
    SuperscriptBox["ut2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"A", " ", "K", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"di", " ", "ut2"}], "nu"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", "A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"di", " ", "ut2"}], "nu"], "]"}]}], ")"}]}]}], ")"}]}], 
   SuperscriptBox["K", "2"]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["ut1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"dc", "-", "di"}], ")"}]}], "+", 
      RowBox[{"dc", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox["dc", "z01"], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox["dc", "z01"], "]"}]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z01"], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox["di", "z01"], "]"}]}]}], ")"}]}], 
   SuperscriptBox["K", "2"]]}]], "Output",
 CellChangeTimes->{3.8518634523402596`*^9, 3.8518635672715197`*^9, 
  3.8518763698029804`*^9, 3.851876845637937*^9, 3.8519595846097946`*^9, 
  3.851962452931127*^9, 3.8519676819957504`*^9, 3.8519682491536655`*^9, 
  3.8519826062099123`*^9, 3.8520494357037363`*^9, 3.8520716357471666`*^9, 
  3.852071750474209*^9, 3.85222091091893*^9, 3.8613864987812147`*^9, 
  3.86138684329158*^9, 3.861387533487628*^9},
 CellLabel->
  "Out[985]=",ExpressionUUID->"1be3a1a4-ffd8-4c18-b39a-9557f5ac4000"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Second", " ", "Integral", " ", "term"}], ",", " ", 
   RowBox[{"prior", " ", "to", " ", "differentiation"}]}], "   ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.851863583180588*^9, 3.851863640351836*^9}},
 CellLabel->
  "In[986]:=",ExpressionUUID->"d566285f-0c7b-45e8-bc0d-327bb776fd15"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J21", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U1", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851862911343463*^9, 3.8518629370352592`*^9}, {
  3.851863322668552*^9, 3.8518633281143985`*^9}, {3.8518636744158683`*^9, 
  3.8518636798872204`*^9}, {3.8519594581739235`*^9, 3.8519594586186748`*^9}, {
  3.851959523544786*^9, 3.8519595241135197`*^9}},
 CellLabel->
  "In[987]:=",ExpressionUUID->"e5629228-dd94-46e0-824b-e9b97a37aafd"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "z"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"Log", "[", 
       FractionBox["z", "z01"], "]"}]}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.851863337185335*^9, 3.8518636825563602`*^9, 
  3.8518763408204985`*^9, 3.8518763755702004`*^9, 3.851876853868067*^9, 
  3.851959460380392*^9, 3.8519595251723967`*^9, 3.851967737452882*^9, 
  3.8519682548182116`*^9, 3.8519826124210405`*^9, 3.852049662391616*^9, 
  3.8520716371786337`*^9, 3.8520717734812174`*^9, 3.852220940453972*^9, 
  3.8613864988212757`*^9, 3.861386843336885*^9, 3.86138753353443*^9},
 CellLabel->
  "Out[987]=",ExpressionUUID->"3ca05ba4-79ab-41ac-af01-55b3932359cb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J22", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U2", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851863342917837*^9, 3.851863357167018*^9}, {
  3.8518636981931148`*^9, 3.851863703343354*^9}},
 CellLabel->
  "In[988]:=",ExpressionUUID->"b4e6d041-c22c-43c1-aa22-dd6036712378"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", "ut2", " ", "z"}], "-", 
  FractionBox[
   RowBox[{"ut2", " ", "z"}], "K"], "+", 
  FractionBox[
   RowBox[{"ut2", " ", "z", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"ut2", " ", "z"}], "nu"], "]"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.8518633664085073`*^9, 3.85186370586018*^9, 
  3.8518763871021123`*^9, 3.851876858233985*^9, 3.8519595360518265`*^9, 
  3.8519677418282967`*^9, 3.8519682589994593`*^9, 3.8519826180274878`*^9, 
  3.8520496666684327`*^9, 3.852071637233844*^9, 3.8520717735638895`*^9, 
  3.85222094593009*^9, 3.86138649882969*^9, 3.861386843382209*^9, 
  3.861387533573346*^9},
 CellLabel->
  "Out[988]=",ExpressionUUID->"ed9163f4-22b6-4814-9174-baa49423d82d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"J22", ",", 
   RowBox[{"z", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8518634800687704`*^9, 3.851863490490794*^9}, {
  3.8518637157494073`*^9, 3.851863716207532*^9}},
 CellLabel->
  "In[989]:=",ExpressionUUID->"f6ba5116-ef24-409d-a965-9410a080fa50"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.851863495260802*^9, 3.8518637185943727`*^9, 
  3.851968265411643*^9, 3.8520716379547596`*^9, 3.8520717736319575`*^9, 
  3.8522209517507973`*^9, 3.861386499258198*^9, 3.861386843422751*^9, 
  3.8613875336152678`*^9},
 CellLabel->
  "Out[989]=",ExpressionUUID->"3175ec85-0758-4e56-80a4-35de2909fe4f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J2", " ", "=", " ", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"(", 
     RowBox[{"J22", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}], "]"}], " ", "+", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J21", "/.", " ", 
       RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"J21", "/.", " ", 
       RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.851863379643095*^9, 3.851863450552127*^9}, {
  3.8518635054423733`*^9, 3.851863561338069*^9}, {3.851863740732732*^9, 
  3.8518637760119085`*^9}, {3.851876396004256*^9, 3.8518763967422247`*^9}, {
  3.851959591651163*^9, 3.851959592597556*^9}},
 CellLabel->
  "In[990]:=",ExpressionUUID->"32960b91-ff19-4920-b5f4-1eed50d60a48"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"di", " ", "ut2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut2"}], "nu"], "]"}]}], ")"}]}], "K"], "+", 
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "dc"}], "+", "di", "+", 
      RowBox[{"dc", " ", 
       RowBox[{"Log", "[", 
        FractionBox["dc", "z01"], "]"}]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"Log", "[", 
        FractionBox["di", "z01"], "]"}]}]}], ")"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.8518634523402596`*^9, 3.8518635672715197`*^9, 
  3.851863789337105*^9, 3.851876397979389*^9, 3.8519595992681475`*^9, 
  3.8519677460197096`*^9, 3.8519682680173235`*^9, 3.851982648206269*^9, 
  3.852049670854443*^9, 3.8520716380129585`*^9, 3.8520717737047305`*^9, 
  3.8522209546936836`*^9, 3.861386499269807*^9, 3.861386843436129*^9, 
  3.861387533624053*^9},
 CellLabel->
  "Out[990]=",ExpressionUUID->"8e38503b-5304-4107-ae7d-00e70c1ef9c0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
    "Now", " ", "try", " ", "to", " ", "derive", " ", "two", " ", "ODEs", " ",
      "for", "  ", "di"}], ",", " ", "dc"}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{"First", " ", "construct", " ", "two", " ", "ODEs"}], "  ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.851867195448493*^9, 3.851867225824218*^9}, {
  3.8518730363919783`*^9, 3.8518730636333923`*^9}, {3.8519677705412045`*^9, 
  3.8519677923525577`*^9}},
 CellLabel->
  "In[991]:=",ExpressionUUID->"3c7ea884-fcde-4a7e-86d0-941f0be15b46"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Equation", " ", "2", " ", "of", " ", 
   RowBox[{"Morgan", "'"}], "s", " ", "notes"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518686327324305`*^9, 3.851868638932539*^9}, {
   3.851869296628148*^9, 3.851869309399314*^9}, 3.8519678432599*^9, {
   3.8522209795123067`*^9, 3.8522209882883253`*^9}},
 CellLabel->
  "In[992]:=",ExpressionUUID->"879748e4-4d70-4dca-9eaf-ed67e218c967"],

Cell[CellGroupData[{

Cell[BoxData["I1"], "Input",
 CellChangeTimes->{{3.8518686872649393`*^9, 3.851868687884019*^9}},
 CellLabel->
  "In[993]:=",ExpressionUUID->"cddcc760-fb28-4f7b-a9d9-ff3675855cb5"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"dc", "-", "di"}], ")"}]}], "+", 
     RowBox[{"dc", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["dc", "z01"], "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox["dc", "z01"], "]"}]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["di", "z01"], "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z01"], "]"}]}]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{3.851868690594057*^9, 3.851873117446684*^9, 
  3.8518733752652187`*^9, 3.8519596532662992`*^9, 3.8519678479979515`*^9, 
  3.851968273794633*^9, 3.851982655997951*^9, 3.852049709670113*^9, 
  3.852071638501611*^9, 3.852071800283456*^9, 3.8521223862992215`*^9, 
  3.852220993987797*^9, 3.861386499345862*^9, 3.861386843497443*^9, 
  3.8613875336769667`*^9},
 CellLabel->
  "Out[993]=",ExpressionUUID->"486f37a2-82c1-4d4f-8fb6-455f550d4e3a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"I1", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ut1", " ", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S1Sol", "[", "x", "]"}]}]}], ",", 
      RowBox[{"di", "\[Rule]", "dih"}], ",", 
      RowBox[{"dc", "\[Rule]", "dch"}], ",", 
      RowBox[{"z01", "->", "z01h"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851868717155259*^9, 3.8518687424664288`*^9}, {
  3.8518688228991323`*^9, 3.8518688325261197`*^9}, {3.8518693396886034`*^9, 
  3.8518693458437333`*^9}, {3.851967865856931*^9, 3.8519678668512273`*^9}, {
  3.8519682910183706`*^9, 3.851968297390774*^9}, {3.85222100047936*^9, 
  3.852221012657399*^9}},
 CellLabel->
  "In[994]:=",ExpressionUUID->"594fdd82-c597-4243-80ec-1c64eb5ff193"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"dch", "-", "dih"}], ")"}]}], "+", 
   RowBox[{"dch", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox["dch", "z01h"], "]"}]}], ")"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox["dch", "z01h"], "]"}]}], "-", 
   RowBox[{"dih", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox["dih", "z01h"], "]"}]}], ")"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox["dih", "z01h"], "]"}]}]}], 
  SuperscriptBox[
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]]], "Output",
 CellChangeTimes->{3.8518687477873125`*^9, 3.8518688343076706`*^9, 
  3.8518692684774084`*^9, 3.8518693498756423`*^9, 3.85187313171556*^9, 
  3.851873379406382*^9, 3.8519596586178665`*^9, 3.8519683062024403`*^9, 
  3.851982666360055*^9, 3.8520497761196456`*^9, 3.8520716385631895`*^9, 
  3.852071800377556*^9, 3.852221016050145*^9, 3.8613864993589354`*^9, 
  3.86138684350581*^9, 3.861387533724821*^9},
 CellLabel->
  "Out[994]=",ExpressionUUID->"1d46c940-f585-4d6e-b3ee-db9a3a5fabaf"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Adjust", " ", "to", " ", "make", " ", "dih"}], ",", " ", 
   RowBox[{"dch", " ", "functions", " ", "of", " ", "x"}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.851973071831476*^9, 3.851973076950673*^9}, {
  3.851982735290635*^9, 3.851982748497865*^9}},
 CellLabel->
  "In[995]:=",ExpressionUUID->"6ec93d16-8bdc-4ae6-9e7a-a766203f2f5f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1B", " ", "=", " ", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "-", 
       RowBox[{"dih", "[", "x", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]}], 
   SuperscriptBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]]}]], "Input",
 CellChangeTimes->{{3.851973081370751*^9, 3.851973099689826*^9}},
 CellLabel->
  "In[996]:=",ExpressionUUID->"18196df7-6b8b-4941-9fcb-6392536d611a"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"dch", "[", "x", "]"}], "-", 
      RowBox[{"dih", "[", "x", "]"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"dch", "[", "x", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
   RowBox[{
    RowBox[{"dih", "[", "x", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]}], 
  SuperscriptBox[
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]]], "Output",
 CellChangeTimes->{3.8519731030280313`*^9, 3.851982758080703*^9, 
  3.8520497855438547`*^9, 3.8520716386845036`*^9, 3.8520718005576134`*^9, 
  3.852221055800748*^9, 3.861386499407812*^9, 3.861386843553*^9, 
  3.8613875337888603`*^9},
 CellLabel->
  "Out[996]=",ExpressionUUID->"baefc91b-4ec4-4fb4-842e-8e0463f1b211"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"I1B", " ", "will", " ", "be", " ", "used"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519828323189635`*^9, 3.851982840340386*^9}},
 CellLabel->
  "In[997]:=",ExpressionUUID->"f5cab13b-2fbf-450c-b2f9-bc30c515c4d8"],

Cell[CellGroupData[{

Cell[BoxData["I2"], "Input",
 CellChangeTimes->{{3.85186958875992*^9, 3.8518696088669724`*^9}},
 CellLabel->
  "In[998]:=",ExpressionUUID->"9aac8e5a-2bfd-415e-8190-8b01498c086b"],

Cell[BoxData[
 FractionBox[
  RowBox[{"di", " ", "ut2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"di", " ", "ut2"}], "nu"], "]"}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.851869591344499*^9, 3.8518731705913267`*^9, 
  3.8518733942597685`*^9, 3.8519596745768504`*^9, 3.8519683947406783`*^9, 
  3.851982771963188*^9, 3.8519828459846044`*^9, 3.852049794717268*^9, 
  3.8520716387452245`*^9, 3.8520718006892333`*^9, 3.852221062282993*^9, 
  3.861386499447597*^9, 3.861386843597834*^9, 3.861387533837399*^9},
 CellLabel->
  "Out[998]=",ExpressionUUID->"722a60e9-06ab-407d-aedd-0dfb413edb37"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Convert", " ", "to", " ", "non"}], "-", 
   RowBox[{"dimensional", " ", "notation"}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.852221082556062*^9, 3.8522210998217697`*^9}},
 CellLabel->
  "In[999]:=",ExpressionUUID->"c0ce7030-2752-40fa-b1c0-c0fe02ce3023"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2A", " ", "=", " ", 
  RowBox[{"I2", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ut2", " ", "\[Rule]", 
      RowBox[{"1", "/", 
       RowBox[{"S2Sol", "[", "x", "]"}]}]}], ",", 
     RowBox[{"di", "\[Rule]", "dih"}], ",", 
     RowBox[{"dc", "\[Rule]", "dch"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.8518686969770727`*^9, 3.8518686976339703`*^9}, {
   3.8518696218402395`*^9, 3.8518696645607367`*^9}, {3.8519596785797267`*^9, 
   3.8519596800504417`*^9}, {3.8519684062431507`*^9, 3.8519684086157513`*^9}, 
   3.851982852295695*^9, {3.852221074464197*^9, 3.852221078842895*^9}},
 CellLabel->
  "In[1000]:=",ExpressionUUID->"7484bbc1-6f60-429b-b7f3-a25db1349d38"],

Cell[BoxData[
 FractionBox[
  RowBox[{"dih", " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", " ", "K", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
       RowBox[{"nu", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
        RowBox[{"ProductLog", "[", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dih", "[", "x", "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
      "]"}]}], ")"}]}], 
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]]], "Output",
 CellChangeTimes->{3.8518686992203655`*^9, 3.851873405139983*^9, 
  3.8519596809006586`*^9, 3.851968410932632*^9, 3.8519828566540847`*^9, 
  3.8520497990619974`*^9, 3.852071638802611*^9, 3.85207180076334*^9, 
  3.852221106570006*^9, 3.861386499489183*^9, 3.861386843644288*^9, 
  3.861387533888495*^9},
 CellLabel->
  "Out[1000]=",ExpressionUUID->"2ad39d94-4800-4113-abe9-df19ed345057"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"Adjust", " ", "so", " ", "that", " ", "dih"}], "\[Rule]", 
    RowBox[{"dih", "[", "x", "]"}]}], ",", 
   RowBox[{"dch", "\[Rule]", 
    RowBox[{"dch", "[", "x", "]"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851874363871391*^9, 3.8518743826949196`*^9}, {
   3.851982907224916*^9, 3.8519829173151207`*^9}, 3.851983582422181*^9, {
   3.8522211174288087`*^9, 3.8522211393627815`*^9}},
 CellLabel->
  "In[1001]:=",ExpressionUUID->"6d01b5e6-b6c3-4c4b-ab47-5d07f12bb74a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2B", " ", "=", 
  RowBox[{
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"dih", "[", "x", "]"}], "  ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dc0", " ", 
           RowBox[{"dih", "[", "x", "]"}], " ", "K", " ", "UI", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
          RowBox[{"nu", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
           RowBox[{"ProductLog", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
              RowBox[{"dih", "[", "x", "]"}], " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
             RowBox[{"Log", "[", 
              FractionBox[
               RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
         "]"}]}], ")"}]}]}], 
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], "/.", " ", 
   RowBox[{"nu", " ", "\[Rule]", 
    RowBox[{"UI", "*", 
     RowBox[{"dc0", "/", "Rec"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.8518743858589535`*^9, 3.8518744030670843`*^9}, {
   3.8518749190034704`*^9, 3.851874928702654*^9}, {3.851968427554838*^9, 
   3.8519684388302097`*^9}, {3.851968479771678*^9, 3.8519684807923326`*^9}, {
   3.8519686661709166`*^9, 3.8519687436127305`*^9}, 3.8519828977752333`*^9, {
   3.851983571539045*^9, 3.8519835736940126`*^9}},
 CellLabel->
  "In[1002]:=",ExpressionUUID->"1cc34603-e108-48bd-a8c5-255884ae4863"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"dih", "[", "x", "]"}], " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
       RowBox[{
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
        RowBox[{"ProductLog", "[", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dih", "[", "x", "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
      "]"}]}], ")"}]}], 
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]]], "Output",
 CellChangeTimes->{
  3.851874405115312*^9, 3.851874965961562*^9, 3.8519596927165666`*^9, 
   3.8519687504146805`*^9, 3.85197213121214*^9, 3.8519829003136463`*^9, 
   3.851982933947114*^9, 3.8519835752753296`*^9, {3.852049815760975*^9, 
   3.8520498219986115`*^9}, 3.852071638867882*^9, 3.852071800840109*^9, 
   3.8522211501935644`*^9, 3.861386499528358*^9, 3.861386843694117*^9, 
   3.861387533940263*^9},
 CellLabel->
  "Out[1002]=",ExpressionUUID->"06a7cd09-7d37-4575-abf4-b26b24a9a11d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ui", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.851968811323039*^9, 3.8519688141217504`*^9}},
 CellLabel->
  "In[1003]:=",ExpressionUUID->"a8412832-c458-46a6-9719-912ca37fa949"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], 
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]], "Output",
 CellChangeTimes->{3.851968815040558*^9, 3.851982942237903*^9, 
  3.8520498336044946`*^9, 3.8520716389222746`*^9, 3.852071816611922*^9, 
  3.852221157251979*^9, 3.8613864995674057`*^9, 3.861386843737885*^9, 
  3.861387533951124*^9},
 CellLabel->
  "Out[1003]=",ExpressionUUID->"195cc64c-1461-4714-9f58-062a565ddcff"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "UFact", "]"}]], "Input",
 CellChangeTimes->{{3.8519688538805056`*^9, 3.8519688643879414`*^9}},
 CellLabel->
  "In[1004]:=",ExpressionUUID->"9f219e7c-97a5-4e45-acfa-eeada032eee7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"UFact", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.851873606961873*^9, 3.851873662625697*^9}, {
  3.851968832800237*^9, 3.851968841538314*^9}, {3.8519721444856396`*^9, 
  3.8519721449036493`*^9}},
 CellLabel->
  "In[1005]:=",ExpressionUUID->"7cad23fe-7166-4ce7-9e12-20e5cd1a83a2"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "I3"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519829681507883`*^9, 3.851982973709914*^9}},
 CellLabel->
  "In[1006]:=",ExpressionUUID->"6aa609ae-0de0-41ee-a6fe-9dc700108989"],

Cell[CellGroupData[{

Cell[BoxData["I3"], "Input",
 CellChangeTimes->{{3.8518687010913725`*^9, 3.8518687018911824`*^9}},
 CellLabel->
  "In[1007]:=",ExpressionUUID->"1cf35150-ebc7-4172-8780-f027f5a055c2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "dc"}], "+", "di", "+", 
     RowBox[{"dc", " ", 
      RowBox[{"Log", "[", 
       FractionBox["dc", "z01"], "]"}]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z01"], "]"}]}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.851868703174698*^9, 3.85187392657395*^9, 
  3.851959737248172*^9, 3.8519688731145616`*^9, 3.8519722440763426`*^9, 
  3.851982979169679*^9, 3.852049852310047*^9, 3.8520716390599766`*^9, 
  3.8520718168130045`*^9, 3.85222118986828*^9, 3.861386499623*^9, 
  3.861386843803459*^9, 3.86138753401145*^9},
 CellLabel->
  "Out[1007]=",ExpressionUUID->"8a1ed67e-c5c9-4260-af5c-0502cc1bc3b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"I3", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ut2", " ", "\[Rule]", 
       RowBox[{"1", "/", "S2"}]}], ",", 
      RowBox[{"di", "\[Rule]", "dih"}], ",", 
      RowBox[{"dc", "\[Rule]", "dch"}], ",", 
      RowBox[{"ut1", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S1Sol", "[", "x", "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8518739294475145`*^9, 3.851874008035644*^9}, {
  3.851968884210758*^9, 3.8519688927639327`*^9}, {3.8522212047222233`*^9, 
  3.852221214594689*^9}},
 CellLabel->
  "In[1008]:=",ExpressionUUID->"af5e8ca6-a929-44f6-a4ab-51c2b843138f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "dch"}], "+", "dih", "+", 
   RowBox[{"dch", " ", 
    RowBox[{"Log", "[", 
     FractionBox["dch", "z01"], "]"}]}], "-", 
   RowBox[{"dih", " ", 
    RowBox[{"Log", "[", 
     FractionBox["dih", "z01"], "]"}]}]}], 
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]], "Output",
 CellChangeTimes->{{3.851873962550318*^9, 3.851874009234546*^9}, 
   3.8519597492003927`*^9, 3.851968896077718*^9, 3.851972249056758*^9, 
   3.8519829913571177`*^9, 3.8520498590994205`*^9, 3.852071639118292*^9, 
   3.8520718168900166`*^9, {3.8522211955727997`*^9, 3.852221216316015*^9}, 
   3.861386499656807*^9, 3.861386843811838*^9, 3.861387534051468*^9},
 CellLabel->
  "Out[1008]=",ExpressionUUID->"15c7783c-8f67-4864-b01d-db52424bd8cf"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Convert", " ", 
   RowBox[{"to", " ", "[", "x", "]"}], " ", "notation"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8518740317777863`*^9, 3.8518740493156047`*^9}, {
  3.851874133113291*^9, 3.851874136754738*^9}, {3.851972253702067*^9, 
  3.851972259733642*^9}, {3.851983011841034*^9, 3.851983012355293*^9}, {
  3.8522212254077883`*^9, 3.852221234962725*^9}},
 CellLabel->
  "In[1009]:=",ExpressionUUID->"26a33294-6f31-4464-9388-4ec5eecb5f9a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3B", " ", "=", " ", 
  FractionBox[
   RowBox[{" ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"dch", "[", "x", "]"}]}], "+", 
      RowBox[{"dih", "[", "x", "]"}], "+", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{"dch", "[", "x", "]"}]}], "z01h"], "]"}]}], "-", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{"dih", "[", "x", "]"}]}], "z01h"], "]"}]}]}], ")"}]}], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]}]], "Input",
 CellChangeTimes->{{3.8518740144865522`*^9, 3.851874027789448*^9}, {
   3.8518740581849847`*^9, 3.8518740775321608`*^9}, {3.8518741515294356`*^9, 
   3.851874180219778*^9}, {3.851874210697683*^9, 3.8518742251961083`*^9}, {
   3.851952238106142*^9, 3.8519522390955067`*^9}, {3.8519689127598534`*^9, 
   3.851968977136852*^9}, 3.851972266917652*^9},
 CellLabel->
  "In[1010]:=",ExpressionUUID->"63bf9988-dc69-4d36-8a4a-201c574d52ba"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"dch", "[", "x", "]"}]}], "+", 
   RowBox[{"dih", "[", "x", "]"}], "+", 
   RowBox[{
    RowBox[{"dch", "[", "x", "]"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
   RowBox[{
    RowBox[{"dih", "[", "x", "]"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]}], 
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]], "Output",
 CellChangeTimes->{3.8518742278235455`*^9, 3.8519521860927114`*^9, 
  3.8519522439054375`*^9, 3.851959761789217*^9, 3.8519689822511697`*^9, 
  3.851972270204645*^9, 3.851983016234437*^9, 3.852049871841676*^9, 
  3.8520716391834764`*^9, 3.852071816979814*^9, 3.852221241595162*^9, 
  3.861386499702868*^9, 3.8613868438591337`*^9, 3.861387534098773*^9},
 CellLabel->
  "Out[1010]=",ExpressionUUID->"682a8959-8f03-4062-b1c5-d1d5b8d9faef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"I1B", ",", 
   RowBox[{
    RowBox[{"UFact", "[", "x", "]"}], "*", "I2B"}], ",", "I3B"}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.851874245714177*^9, 3.8518742649258432`*^9}, {
   3.8518743086831913`*^9, 3.851874332371498*^9}, 3.85187441971628*^9, {
   3.8518745603210945`*^9, 3.8518745951423907`*^9}, 3.8518752119274535`*^9, {
   3.8519690035287404`*^9, 3.851969004244796*^9}, 3.8519690769143143`*^9, {
   3.8519722814197288`*^9, 3.851972294741745*^9}},
 CellLabel->
  "In[1011]:=",ExpressionUUID->"985cae73-98cc-4d60-8226-9856fe03dfab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dch", "[", "x", "]"}], "-", 
        RowBox[{"dih", "[", "x", "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"dch", "[", "x", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
     RowBox[{
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]}], 
    SuperscriptBox[
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
         RowBox[{
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
          RowBox[{"ProductLog", "[", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dih", "[", "x", "]"}], " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
        "]"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"dch", "[", "x", "]"}]}], "+", 
     RowBox[{"dih", "[", "x", "]"}], "+", 
     RowBox[{
      RowBox[{"dch", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
     RowBox[{
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]}], 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.851874266158955*^9, 3.8518743366364098`*^9, 3.851874420932742*^9, {
   3.851874588320595*^9, 3.851874596316755*^9}, 3.851875214064713*^9, 
   3.851875278795478*^9, 3.851875343256854*^9, 3.851881265409589*^9, 
   3.8518813788513994`*^9, 3.8518815397323523`*^9, 3.8519522520748415`*^9, 
   3.8519597687606325`*^9, {3.851968995300458*^9, 3.851969005676625*^9}, 
   3.851969085326335*^9, 3.851969167686038*^9, 3.851972011721018*^9, 
   3.851972297347554*^9, 3.8519731170995736`*^9, 3.8519830285762444`*^9, 
   3.8519836098417673`*^9, 3.8520498847127466`*^9, 3.8520716392409787`*^9, 
   3.852071816993045*^9, 3.8522212511860495`*^9, 3.8613864997560377`*^9, 
   3.861386843902691*^9, 3.861387534108245*^9},
 CellLabel->
  "Out[1011]=",ExpressionUUID->"69cbca0c-f671-48c3-ac6b-0a14a9162a1d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Now", " ", "define", " ", "terms"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851874602489704*^9, 3.85187462134516*^9}},
 CellLabel->
  "In[1012]:=",ExpressionUUID->"056ce359-ff69-4d5d-bcbc-b80d003f7526"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQB1", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{"I1B", ",", "x"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"UFact", "[", "x", "]"}], "*", 
     RowBox[{"D", "[", 
      RowBox[{"I2B", ",", "x"}], "]"}]}], "+", 
    RowBox[{"D", "[", 
     RowBox[{"I3B", ",", "x"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.852122662057003*^9},
 CellLabel->
  "In[1013]:=",ExpressionUUID->"fe37d8ca-e77a-4a84-83f2-d0b75799e18d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CEQB1i", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"EQB1", ",", 
     RowBox[{
      RowBox[{"dih", "'"}], "[", "x", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.851874624237014*^9, 3.8518748023871026`*^9}, 
   3.8518752290512304`*^9, {3.8518753947895184`*^9, 3.8518754315189185`*^9}, {
   3.8519690197400007`*^9, 3.851969020810835*^9}, {3.851969218923568*^9, 
   3.851969289396138*^9}, {3.8519694352294917`*^9, 3.8519694383893604`*^9}, {
   3.8519723194941006`*^9, 3.851972331682291*^9}, {3.852122452177862*^9, 
   3.8521224756039624`*^9}, {3.8521225134011536`*^9, 3.852122517152302*^9}, {
   3.8521225577614937`*^9, 3.8521225888619184`*^9}, {3.8521226707108345`*^9, 
   3.8521227741469116`*^9}, {3.852122856027833*^9, 3.8521228588039966`*^9}},
 CellLabel->
  "In[1014]:=",ExpressionUUID->"30e2088e-d8ae-41f0-bc4f-6fa17c792ab4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CEQB1c", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"EQB1", ",", 
     RowBox[{
      RowBox[{"dch", "'"}], "[", "x", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.851874624237014*^9, 3.8518748023871026`*^9}, 
   3.8518752290512304`*^9, {3.8518753947895184`*^9, 3.8518754315189185`*^9}, {
   3.8519690197400007`*^9, 3.851969020810835*^9}, {3.851969218923568*^9, 
   3.851969289396138*^9}, {3.8519694352294917`*^9, 3.8519694383893604`*^9}, {
   3.8519723194941006`*^9, 3.851972331682291*^9}, {3.852122452177862*^9, 
   3.8521224756039624`*^9}, {3.8521225134011536`*^9, 3.852122517152302*^9}, {
   3.8521225577614937`*^9, 3.8521225888619184`*^9}, {3.8521226707108345`*^9, 
   3.8521227741469116`*^9}, {3.852122848649332*^9, 3.8521228490432177`*^9}},
 CellLabel->
  "In[1015]:=",ExpressionUUID->"58df71e1-5df5-43b8-9eb6-00b4569c1413"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CEQB1i", "/.", " ", 
  RowBox[{
   RowBox[{"dch", "[", "x", "]"}], "\[Rule]", 
   RowBox[{"dih", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.852122761762965*^9, 3.852122813751099*^9}},
 CellLabel->
  "In[1016]:=",ExpressionUUID->"e84b0a42-4850-4df6-86dd-085c4eb76363"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.852122815601313*^9, 3.852122869899265*^9, 
  3.852221296162546*^9, 3.861386499868264*^9, 3.861386843986134*^9, 
  3.861387534189116*^9},
 CellLabel->
  "Out[1016]=",ExpressionUUID->"d8a6b396-4da8-40d3-acfd-7fe31463032b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CEQB1c", "/.", " ", 
  RowBox[{
   RowBox[{"dch", "[", "x", "]"}], "\[Rule]", 
   RowBox[{"dih", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.852122761762965*^9, 3.852122813751099*^9}, {
  3.852122887939437*^9, 3.8521228886412163`*^9}},
 CellLabel->
  "In[1017]:=",ExpressionUUID->"8d6336bb-d203-459f-8c41-f8fb5dd44314"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8521228905446625`*^9, 3.8522212986228127`*^9, 
  3.861386499875711*^9, 3.861386843993885*^9, 3.861387534196739*^9},
 CellLabel->
  "Out[1017]=",ExpressionUUID->"6e6ee26d-4f71-4edc-aa1a-bd0efbbb08eb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "RHS"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851877380292621*^9, 3.8518773865457864`*^9}},
 CellLabel->
  "In[1018]:=",ExpressionUUID->"4ce40572-576e-4635-802f-19c9a666085d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S1Sol", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8518773901545916`*^9, 3.8518773939097004`*^9}, {
  3.851969468340542*^9, 3.851969472064191*^9}},
 CellLabel->
  "In[1019]:=",ExpressionUUID->"78ec0ff8-9783-4d91-ace8-52a076747571"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "K"]], "Output",
 CellChangeTimes->{
  3.851877400543622*^9, 3.851881296575392*^9, 3.8519522917296324`*^9, 
   3.851953904762218*^9, 3.8519597942033014`*^9, {3.8519694531723523`*^9, 
   3.8519694735325346`*^9}, 3.8519830663052187`*^9, 3.8520716394273047`*^9, 
   3.852071861289564*^9, 3.852221303861885*^9, 3.861386499922908*^9, 
   3.861386844043655*^9, 3.861387534289854*^9},
 CellLabel->
  "Out[1019]=",ExpressionUUID->"dfd5eab9-fef5-46fb-8a47-8476b7e52d92"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Corrected", " ", "shear", " ", "stress", " ", "profile"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8522213106646843`*^9, 3.8522213245698214`*^9}},
 CellLabel->
  "In[1020]:=",ExpressionUUID->"212af77f-2ae5-42b9-8364-e9c5211f2918"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", " ", "=", " ", "1.9971"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", " ", "=", " ", 
   RowBox[{"-", "3.0789"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"RHS", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"S1Sol", "[", "x", "]"}]}], ")"}], "^", "2"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p1", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dih", "[", "x", "]"}], "/", 
         RowBox[{"dch", "[", "x", "]"}]}], ")"}], "^", "3"}]}], "+", 
     RowBox[{"p2", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dih", "[", "x", "]"}], "/", 
          RowBox[{"dch", "[", "x", "]"}]}], ")"}], ")"}], "^", "2"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "p1", "+", "p2"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dih", "[", "x", "]"}], "/", 
        RowBox[{"dch", "[", "x", "]"}]}], ")"}]}], "+", "1"}], 
    ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.8518774092188787`*^9, 3.8518774683683825`*^9}, {
   3.851969495837837*^9, 3.8519695017834826`*^9}, {3.852123819420309*^9, 
   3.8521238859284735`*^9}, {3.8521285195600414`*^9, 3.85212852318195*^9}, {
   3.8521285791278296`*^9, 3.8521285811838126`*^9}, 3.8521294108153977`*^9, {
   3.8521346807674227`*^9, 3.8521346861725435`*^9}, {3.8522219909690742`*^9, 
   3.8522219936819134`*^9}, {3.861386827807949*^9, 3.8613868287225533`*^9}},
 CellLabel->
  "In[1021]:=",ExpressionUUID->"f1a19301-5a44-4882-9273-52dadb4d26e1"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["K", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"0.08179999999999987`", " ", 
       RowBox[{"dih", "[", "x", "]"}]}], 
      RowBox[{"dch", "[", "x", "]"}]], "-", 
     FractionBox[
      RowBox[{"3.0789`", " ", 
       SuperscriptBox[
        RowBox[{"dih", "[", "x", "]"}], "2"]}], 
      SuperscriptBox[
       RowBox[{"dch", "[", "x", "]"}], "2"]], "+", 
     FractionBox[
      RowBox[{"1.9971`", " ", 
       SuperscriptBox[
        RowBox[{"dih", "[", "x", "]"}], "3"]}], 
      SuperscriptBox[
       RowBox[{"dch", "[", "x", "]"}], "3"]]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]]], "Output",
 CellChangeTimes->{3.8518774700267987`*^9, 3.8518813006478653`*^9, 
  3.851881577084176*^9, 3.8519522955458813`*^9, 3.8519539118080473`*^9, 
  3.851959798526639*^9, 3.851969509194504*^9, 3.8519723666097918`*^9, 
  3.851973128416898*^9, 3.851983071699252*^9, 3.8520499341647034`*^9, 
  3.852071639505766*^9, 3.852071861377211*^9, 3.8521238585200663`*^9, 
  3.852123888534499*^9, 3.852128531920142*^9, 3.8521285841553464`*^9, 
  3.852129414897439*^9, 3.8521294591169863`*^9, 3.8521346894177866`*^9, 
  3.8522214037008085`*^9, 3.8522219971860995`*^9, 3.8613864999632893`*^9, 
  3.861386844107832*^9, 3.8613875343401957`*^9},
 CellLabel->
  "Out[1023]=",ExpressionUUID->"74eb48e2-18bf-48c4-8979-e50697e78040"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"So", " ", "if", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "=", 
    RowBox[{"dih", "[", "x", "]"}]}], ",", "  ", 
   RowBox[{
   "equation", " ", "cannot", " ", "be", " ", "satisfied", " ", "This", " ", 
    "seems", " ", "nonphysical"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8521229137541914`*^9, 3.852122972380724*^9}},
 CellLabel->
  "In[1024]:=",ExpressionUUID->"df91d49f-9158-446f-bdb2-f34103ca6cb8"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Form", " ", "EQB"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851875571700697*^9, 3.8518756062393427`*^9}, {
   3.8518773178590827`*^9, 3.8518773211900396`*^9}, 3.8519695542562656`*^9},
 CellLabel->
  "In[1025]:=",ExpressionUUID->"28844915-54e3-4422-a22a-c3d9fbb0fa9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQB", " ", "=", " ", 
   RowBox[{"EQB1", "-", "RHS"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8518784786888294`*^9, 3.8518785268044167`*^9}, {
   3.8518785932858458`*^9, 3.851878613330866*^9}, 3.8518816059186444`*^9, {
   3.8519520992953196`*^9, 3.85195210129722*^9}, {3.8519539499965687`*^9, 
   3.851953968503289*^9}, 3.85195400295744*^9, {3.851969527590869*^9, 
   3.8519695396461782`*^9}, 3.8519695791804967`*^9, 3.8519834929355936`*^9, 
   3.8519836243116455`*^9},
 CellLabel->
  "In[1026]:=",ExpressionUUID->"cb4d3267-2341-444e-a694-c5987824ab9e"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Equation", " ", "EQB", " ", "complete"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518757218813744`*^9, 3.8518757365865045`*^9}},
 CellLabel->
  "In[1027]:=",ExpressionUUID->"21a3f675-fce1-4a89-a041-c1fcdfd47ff8"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "Karman", " ", "Integral", " ", "equation"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.851875788388176*^9, 3.8518758074173203`*^9}, {
  3.851969588291605*^9, 3.851969594056013*^9}},
 CellLabel->
  "In[1028]:=",ExpressionUUID->"d4f7e667-d918-4a6b-aa14-a56c199dafa2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"J1", ",", "J2"}], "}"}]], "Input",
 CellChangeTimes->{{3.8518764307454715`*^9, 3.8518764348004403`*^9}},
 CellLabel->
  "In[1029]:=",ExpressionUUID->"2dc65262-3214-427d-a0af-0503579834d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"di", " ", 
      SuperscriptBox["ut2", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"A", " ", "K", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"di", " ", "ut2"}], "nu"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"2", " ", "A", " ", "K"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"di", " ", "ut2"}], "nu"], "]"}]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox["K", "2"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["ut1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"dc", "-", "di"}], ")"}]}], "+", 
        RowBox[{"dc", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox["dc", "z01"], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox["dc", "z01"], "]"}]}], "-", 
        RowBox[{"di", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox["di", "z01"], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z01"], "]"}]}]}], ")"}]}], 
     SuperscriptBox["K", "2"]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"di", " ", "ut2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"di", " ", "ut2"}], "nu"], "]"}]}], ")"}]}], "K"], "+", 
    FractionBox[
     RowBox[{"ut1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "dc"}], "+", "di", "+", 
        RowBox[{"dc", " ", 
         RowBox[{"Log", "[", 
          FractionBox["dc", "z01"], "]"}]}], "-", 
        RowBox[{"di", " ", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z01"], "]"}]}]}], ")"}]}], "K"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.851876435676431*^9, 3.8518786199626245`*^9, 
  3.851881724711501*^9, 3.8519598160748844`*^9, 3.85196054562786*^9, 
  3.8519696005154357`*^9, 3.851972385089383*^9, 3.851983082090807*^9, 
  3.8520499431166525`*^9, 3.852071639589748*^9, 3.8520718615080624`*^9, 
  3.852221440856552*^9, 3.852221484657837*^9, 3.861386500057119*^9, 
  3.861386844207304*^9, 3.8613875344765377`*^9},
 CellLabel->
  "Out[1029]=",ExpressionUUID->"97da32e1-5e1f-4150-a0cd-22384e88eec1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"**", "**", "**", "**", "**", "**"}], "*****)"}]], "Input",
 CellChangeTimes->{{3.8519697627148647`*^9, 3.8519697753461246`*^9}, {
  3.8519830907047987`*^9, 3.8519830984377985`*^9}, {3.852221458948633*^9, 
  3.852221465841339*^9}},
 CellLabel->
  "In[1030]:=",ExpressionUUID->"02d0c4fc-a834-42ad-bdb4-2fa1cdf1324b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"J1", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ut1", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S1Sol", "[", "x", "]"}]}]}], ",", 
      RowBox[{"ut2", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S2Sol", "[", "x", "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851876463955768*^9, 3.8518765003354015`*^9}, {
  3.851876547054245*^9, 3.851876555817399*^9}, {3.851876741544276*^9, 
  3.8518767643252335`*^9}, {3.8518768007396574`*^9, 3.8518768013403845`*^9}, {
  3.8518769001733603`*^9, 3.85187695011794*^9}, {3.8518770094748898`*^9, 
  3.8518770431541643`*^9}, {3.851881753158047*^9, 3.8518817540640736`*^9}, {
  3.8519606302347345`*^9, 3.8519606377239943`*^9}, {3.851969620295534*^9, 
  3.851969754108821*^9}, {3.851972391397232*^9, 3.8519723974306645`*^9}},
 CellLabel->
  "In[1031]:=",ExpressionUUID->"9a7f0b89-d7ac-4cac-9789-069bf3908070"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"dc", "-", "di"}], ")"}]}], "+", 
    RowBox[{"dc", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox["dc", "z01"], "]"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["dc", "z01"], "]"}]}], "-", 
    RowBox[{"di", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox["di", "z01"], "]"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["di", "z01"], "]"}]}], "+", 
    FractionBox[
     RowBox[{"di", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"A", " ", "K", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"di", " ", "K", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
           RowBox[{"nu", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
            RowBox[{"ProductLog", "[", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
               RowBox[{"dih", "[", "x", "]"}], " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
          "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"2", " ", "A", " ", "K"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"di", " ", "K", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
             RowBox[{"nu", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
              RowBox[{"ProductLog", "[", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
                 RowBox[{"dih", "[", "x", "]"}], " ", 
                 RowBox[{"Log", "[", 
                  FractionBox[
                   RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
                RowBox[{"Log", "[", 
                 FractionBox[
                  RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
            "]"}]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"ProductLog", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}], "2"]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8519696811945953`*^9, {3.85196972965854*^9, 3.85196975820535*^9}, 
   3.8519698555772285`*^9, 3.851972401863599*^9, 3.8519831054432507`*^9, 
   3.851983673749881*^9, 3.85204997264355*^9, 3.8520716396765337`*^9, {
   3.852071861595768*^9, 3.852071867693768*^9}, 3.8522214717756033`*^9, 
   3.8613865001071053`*^9, 3.8613868442851677`*^9, 3.861387534529624*^9},
 CellLabel->
  "Out[1031]=",ExpressionUUID->"18b03ecf-ac23-4aa4-ba82-5f9edc1c4014"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"J1A", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"di", "\[Rule]", "dih"}], ",", 
      RowBox[{"dc", "\[Rule]", "dch"}], ",", 
      RowBox[{"z01", "\[Rule]", "z01h"}], ",", 
      RowBox[{"nu", " ", "\[Rule]", 
       RowBox[{"1", "/", "Rec"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851876463955768*^9, 3.8518765003354015`*^9}, {
   3.851876547054245*^9, 3.851876555817399*^9}, {3.851876741544276*^9, 
   3.8518767643252335`*^9}, {3.8518768007396574`*^9, 
   3.8518768013403845`*^9}, {3.8518769001733603`*^9, 3.85187695011794*^9}, {
   3.8518770094748898`*^9, 3.8518770431541643`*^9}, {3.851881753158047*^9, 
   3.8518817540640736`*^9}, 3.8519606577829742`*^9, 3.851960782181884*^9, {
   3.8519697921114845`*^9, 3.851969810856394*^9}, {3.8519698454184713`*^9, 
   3.851969878675971*^9}, 3.851983654943867*^9, {3.8522215104299107`*^9, 
   3.8522215210672274`*^9}},
 CellLabel->
  "In[1032]:=",ExpressionUUID->"00857a12-a045-43a5-a092-3f2841f3738c"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"dch", "-", "dih"}], ")"}]}], "+", 
    RowBox[{"dch", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox["dch", "z01h"], "]"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["dch", "z01h"], "]"}]}], "-", 
    RowBox[{"dih", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox["dih", "z01h"], "]"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["dih", "z01h"], "]"}]}], "+", 
    FractionBox[
     RowBox[{"dih", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"A", " ", "K", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", " ", "K", " ", "Rec", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
            RowBox[{"ProductLog", "[", 
             FractionBox[
              RowBox[{
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
               RowBox[{"dih", "[", "x", "]"}], " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
          "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"2", " ", "A", " ", "K"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dih", " ", "K", " ", "Rec", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
             RowBox[{
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
              RowBox[{"ProductLog", "[", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
                 RowBox[{"dih", "[", "x", "]"}], " ", 
                 RowBox[{"Log", "[", 
                  FractionBox[
                   RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
                RowBox[{"Log", "[", 
                 FractionBox[
                  RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
            "]"}]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"ProductLog", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}], "2"]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8519606654081163`*^9, {3.8519607586809616`*^9, 3.851960784824711*^9}, {
   3.851960829326198*^9, 3.851960840774742*^9}, 3.851969823391592*^9, 
   3.851969883428046*^9, 3.851972413363412*^9, 3.8519831180224967`*^9, 
   3.8519836573185234`*^9, 3.8519836972908144`*^9, {3.8520499634965897`*^9, 
   3.8520499773559747`*^9}, 3.852071639745261*^9, 3.8520718721740074`*^9, 
   3.8522215225079193`*^9, 3.861386500150379*^9, 3.861386844299408*^9, 
   3.861387534579718*^9},
 CellLabel->
  "Out[1032]=",ExpressionUUID->"32d8d018-24af-449f-b592-aabeeb125e40"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"dih", "\[Rule]", 
    RowBox[{"dih", "[", "x", "]"}]}], ",", " ", 
   RowBox[{"dch", "\[Rule]", 
    RowBox[{"dch", "[", "x", "]"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.85197021378288*^9, 3.8519702214057007`*^9}, {
  3.851983123385825*^9, 3.8519831296771536`*^9}, {3.8522215385524087`*^9, 
  3.852221553888317*^9}},
 CellLabel->
  "In[1033]:=",ExpressionUUID->"e2c0fdc3-2818-46e3-90bb-ea9a4a772f83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"J1B", "=", " ", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dch", "[", "x", "]"}], "-", 
         RowBox[{"dih", "[", "x", "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dih", "[", "x", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"A", " ", "K", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"dih", "[", "x", "]"}], " ", "K", " ", "Rec", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
              RowBox[{
               RowBox[{"Log", "[", 
                FractionBox[
                 RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
               RowBox[{"ProductLog", "[", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
                  RowBox[{"dih", "[", "x", "]"}], " ", 
                  RowBox[{"Log", "[", 
                   FractionBox[
                    RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
                 RowBox[{"Log", "[", 
                  FractionBox[
                   RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
             "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"2", " ", "A", " ", "K"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{
                 RowBox[{"dih", "[", "x", "]"}], " ", "K", " ", "Rec", " ", 
                 RowBox[{"Log", "[", 
                  FractionBox[
                   RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
                RowBox[{
                 RowBox[{"Log", "[", 
                  FractionBox[
                   RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
                 RowBox[{"ProductLog", "[", 
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
                    RowBox[{"dih", "[", "x", "]"}], " ", 
                    RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]],
                "]"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       SuperscriptBox[
        RowBox[{"ProductLog", "[", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dih", "[", "x", "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}], "2"]}]}], 
     ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.851970183554661*^9, 3.851970186677454*^9}, {
   3.851970338250389*^9, 3.8519704477517786`*^9}, {3.8519724745813847`*^9, 
   3.8519724880334773`*^9}, 3.851972524677884*^9, 3.8519837294038877`*^9, {
   3.8519841049755125`*^9, 3.8519841127612*^9}, {3.851984146215929*^9, 
   3.851984147071603*^9}},
 CellLabel->
  "In[1034]:=",ExpressionUUID->"ebfcc9d9-9090-4e00-95dd-85b5e8e45fe4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"We", " ", "will", " ", "use", " ", "J1B"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851983154768263*^9, 3.8519831620233393`*^9}},
 CellLabel->
  "In[1035]:=",ExpressionUUID->"e8074448-2c86-419b-885a-6854976bf757"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Now", " ", "J2"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519704882569785`*^9, 3.8519704928649797`*^9}},
 CellLabel->
  "In[1036]:=",ExpressionUUID->"dd73e1b8-d1ca-4d08-bb15-4a706c3ef535"],

Cell[CellGroupData[{

Cell[BoxData["J2"], "Input",
 CellChangeTimes->{{3.851961170821271*^9, 3.851961171335213*^9}},
 CellLabel->
  "In[1037]:=",ExpressionUUID->"fbc0ea47-5dc4-4154-baf0-b92b90320538"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"di", " ", "ut2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut2"}], "nu"], "]"}]}], ")"}]}], "K"], "+", 
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "dc"}], "+", "di", "+", 
      RowBox[{"dc", " ", 
       RowBox[{"Log", "[", 
        FractionBox["dc", "z01"], "]"}]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"Log", "[", 
        FractionBox["di", "z01"], "]"}]}]}], ")"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.8519611728962045`*^9, 3.851970498788004*^9, 
  3.851970863737213*^9, 3.8519725428978353`*^9, 3.8519831681729474`*^9, 
  3.852050026265853*^9, 3.852071639844364*^9, 3.852071887762667*^9, 
  3.852221585811021*^9, 3.8613865002592287`*^9, 3.8613868443983593`*^9, 
  3.861387534687285*^9},
 CellLabel->
  "Out[1037]=",ExpressionUUID->"2901070c-3ead-4afb-96d4-890a60da4481"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Adjust", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"di", "*", 
      RowBox[{"ut2", "/", "nu"}]}], "]"}], " ", "term", " ", "di", "*", 
    RowBox[{"ut2", "/", "nu"}]}], " ", "=", " ", 
   RowBox[{"Rec", "*", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "/", 
     RowBox[{"S2", "[", "x", "]"}]}]}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.85197098182688*^9, 3.8519710017168145`*^9}, 
   3.851972551053116*^9, {3.8519831848856277`*^9, 3.851983226182047*^9}},
 CellLabel->
  "In[1038]:=",ExpressionUUID->"1f26f63b-cdbd-4d83-945b-ed978fe57cb0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J21", " ", "=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"di", " ", "ut2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"dih", "[", "x", "]"}], "*", 
         RowBox[{"Rec", "/", "S2"}]}], "]"}]}], ")"}]}], "K"], "+", 
   FractionBox[
    RowBox[{"ut1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "dc"}], "+", "di", "+", 
       RowBox[{"dc", " ", 
        RowBox[{"Log", "[", 
         FractionBox["dc", "z01"], "]"}]}], "-", 
       RowBox[{"di", " ", 
        RowBox[{"Log", "[", 
         FractionBox["di", "z01"], "]"}]}]}], ")"}]}], "K"]}]}]], "Input",
 CellChangeTimes->{{3.8519709609128146`*^9, 3.8519709747506304`*^9}, {
  3.851971080346883*^9, 3.8519710978855095`*^9}, {3.8519725600641804`*^9, 
  3.851972561866007*^9}},
 CellLabel->
  "In[1039]:=",ExpressionUUID->"cd3114b4-7f25-4238-ab30-f1bd94376e00"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "dc"}], "+", "di", "+", 
      RowBox[{"dc", " ", 
       RowBox[{"Log", "[", 
        FractionBox["dc", "z01"], "]"}]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"Log", "[", 
        FractionBox["di", "z01"], "]"}]}]}], ")"}]}], "K"], "+", 
  FractionBox[
   RowBox[{"di", " ", "ut2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}]}], "S2"], "]"}]}], ")"}]}], 
   "K"]}]], "Output",
 CellChangeTimes->{3.851971101049986*^9, 3.85197258151836*^9, 
  3.8519832526561527`*^9, 3.852050053494605*^9, 3.852071639910965*^9, 
  3.852071892051317*^9, 3.8522216232856855`*^9, 3.861386500311701*^9, 
  3.861386844434634*^9, 3.861387534739455*^9},
 CellLabel->
  "Out[1039]=",ExpressionUUID->"f32c682e-91d6-4e99-a250-52d16ec7675d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J2A", " ", "=", " ", 
  RowBox[{"J21", "/.", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ut1", "\[Rule]", 
      RowBox[{"1", "/", 
       RowBox[{"S1Sol", "[", "x", "]"}]}]}], ",", 
     RowBox[{"ut2", "\[Rule]", 
      RowBox[{"1", "/", 
       RowBox[{"S2Sol", "[", "x", "]"}]}]}], ",", 
     RowBox[{"S2", "\[Rule]", 
      RowBox[{"S2Sol", "[", "x", "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.851878680862157*^9, 3.8518787478077745`*^9}, {
   3.851878778978977*^9, 3.851878779650845*^9}, {3.8518818261586885`*^9, 
   3.8518818269180517`*^9}, 3.8519609341812134`*^9, {3.8519612329566455`*^9, 
   3.8519612382158113`*^9}, {3.851970518061519*^9, 3.8519705595682907`*^9}, {
   3.8519711124476023`*^9, 3.851971120287111*^9}, 3.851971213396578*^9},
 CellLabel->
  "In[1040]:=",ExpressionUUID->"806ac099-ab93-495c-8edb-4df002ee52a4"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", "dc"}], "+", "di", "+", 
    RowBox[{"dc", " ", 
     RowBox[{"Log", "[", 
      FractionBox["dc", "z01"], "]"}]}], "-", 
    RowBox[{"di", " ", 
     RowBox[{"Log", "[", 
      FractionBox["di", "z01"], "]"}]}]}], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "+", 
  FractionBox[
   RowBox[{"di", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
         RowBox[{"ProductLog", "[", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dih", "[", "x", "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
       "]"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
    RowBox[{"ProductLog", "[", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]]}]], "Output",
 CellChangeTimes->{3.8519612404391336`*^9, 3.8519705607858152`*^9, 
  3.851970882131359*^9, 3.85197093359356*^9, 3.851971122107637*^9, 
  3.8519712145171933`*^9, 3.8519725911596217`*^9, 3.851983279831046*^9, 
  3.8520500568251762`*^9, 3.8520716399694986`*^9, 3.852071906087782*^9, 
  3.8522216281095915`*^9, 3.861386500356421*^9, 3.861386844443166*^9, 
  3.861387534779626*^9},
 CellLabel->
  "Out[1040]=",ExpressionUUID->"837127e7-a9b7-4f8a-a8b5-a42a3503f567"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Make", " ", "further", " ", "nondimensionalized", " ", "adjustments"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851970668123923*^9, 3.8519706830575304`*^9}, {
  3.852221633445648*^9, 3.8522216371690845`*^9}},
 CellLabel->
  "In[1041]:=",ExpressionUUID->"e7366cdf-3ef7-4a5c-a1f9-d1b8648ed9fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J2B", " ", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       RowBox[{"dch", "[", "x", "]"}]}], "+", 
      RowBox[{"dih", "[", "x", "]"}], "+", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]}], 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"dih", "[", "x", "]"}], " ", "*", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"K", " ", "Rec", " ", 
           RowBox[{"dih", "[", "x", "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
          RowBox[{
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
           RowBox[{"ProductLog", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
              RowBox[{"dih", "[", "x", "]"}], " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
             RowBox[{"Log", "[", 
              FractionBox[
               RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
         "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
      RowBox[{"ProductLog", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]]}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.8518787831440067`*^9, 3.8518788864088416`*^9}, {
   3.85187892558517*^9, 3.8518789486933765`*^9}, {3.8518792561998687`*^9, 
   3.851879256429002*^9}, {3.8518818429677987`*^9, 3.8518818437308254`*^9}, {
   3.8519599561548624`*^9, 3.851959970782219*^9}, {3.851960210718092*^9, 
   3.851960240400384*^9}, {3.851961047785406*^9, 3.851961064934393*^9}, {
   3.851961302199791*^9, 3.85196135717471*^9}, 3.8519706996926737`*^9, {
   3.8519708002889442`*^9, 3.851970827924198*^9}, {3.8519712500612726`*^9, 
   3.8519713253444448`*^9}, {3.8519726509946337`*^9, 
   3.8519726576469975`*^9}, {3.851984027669241*^9, 3.8519840490273046`*^9}},
 CellLabel->
  "In[1042]:=",ExpressionUUID->"633d12df-963c-4d2e-9eea-701ba6efdf89"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"dch", "[", "x", "]"}]}], "+", 
    RowBox[{"dih", "[", "x", "]"}], "+", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]}], "-", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]}], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"dih", "[", "x", "]"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
         RowBox[{"ProductLog", "[", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dih", "[", "x", "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]], 
       "]"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
    RowBox[{"ProductLog", "[", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}]]}]], "Output",
 CellChangeTimes->{3.85196136004714*^9, 3.8519713316323156`*^9, 
  3.851972674433832*^9, 3.851983318529382*^9, 3.851983427516421*^9, 
  3.8519840551208906`*^9, 3.852050080434457*^9, 3.8520716400419903`*^9, 
  3.852071912377369*^9, 3.8522216415205164`*^9, 3.861386500410104*^9, 
  3.861386844491067*^9, 3.8613875348316793`*^9},
 CellLabel->
  "Out[1042]=",ExpressionUUID->"37e251df-ddfb-43bb-8b4e-45b9fc2f246a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQC", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{"J1B", ",", "x"}], "]"}]}], "+", 
    RowBox[{"D", "[", 
     RowBox[{"J2B", ",", "x"}], "]"}], "-", 
    RowBox[{"1", "/", 
     RowBox[{
      RowBox[{"S2Sol", "[", "x", "]"}], "^", "2"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8518789883045187`*^9, 3.851879066015366*^9}, {
  3.8518791118763485`*^9, 3.85187912686547*^9}, {3.8519620216925507`*^9, 
  3.8519620612786245`*^9}, {3.851971367636671*^9, 3.8519713896531143`*^9}, {
  3.8519726865191517`*^9, 3.8519726873677015`*^9}},
 CellLabel->
  "In[1043]:=",ExpressionUUID->"4bec4fca-4865-40a8-8188-40bcb53269c1"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{
   "We", " ", "now", " ", "have", " ", "two", " ", "equations", " ", "for", 
    " ", 
    RowBox[{"dch", "[", "x", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dic", "[", "x", "]"}], " ", ".", "  ", "Parameters"}], " ", 
    "are", " ", "z01h", " ", "and", " ", 
    RowBox[{"Rec", ".", " ", "These"}], " ", "need", " ", "to", " ", "be", 
    " ", 
    RowBox[{"calculated", ".", " ", "Also"}], " ", "need", " ", "ICs"}]}], 
  "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851879599018918*^9, 3.8518796864826736`*^9}, {
  3.8518819265966196`*^9, 3.8518819275480814`*^9}, {3.851971397707412*^9, 
  3.8519714047975936`*^9}},
 CellLabel->
  "In[1044]:=",ExpressionUUID->"e87d97c2-fbc4-4eb0-8192-fea5eaf9f7ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S2Sol", "[", "x", "]"}], "/.", "  ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"z01h", " ", "->", " ", "0.000371"}], ",", 
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}], " ", ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", 
     RowBox[{"2", "*", "0.000371"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.851966715660026*^9, 3.8519667246294994`*^9}, {
   3.8519667691619716`*^9, 3.851966774358142*^9}, {3.8519670399149747`*^9, 
   3.85196707070533*^9}, {3.851967331720683*^9, 3.851967332475976*^9}, 
   3.8520715958571806`*^9, {3.852129579318751*^9, 3.852129596345292*^9}},
 CellLabel->
  "In[1045]:=",ExpressionUUID->"a8f3c2d3-5e47-4a9b-86ba-5cbc25b56c89"],

Cell[BoxData["80.83176821541788`"], "Output",
 CellChangeTimes->{
  3.8519673351460533`*^9, 3.851971514789234*^9, 3.8519833670750003`*^9, 
   3.851984171924302*^9, 3.8520501031055565`*^9, 3.8520715991354656`*^9, 
   3.852071934420907*^9, {3.852129599044181*^9, 3.8521296274259863`*^9}, 
   3.8522216753680577`*^9, 3.86138650046972*^9, 3.861386844564151*^9, 
   3.861387534887566*^9},
 CellLabel->
  "Out[1045]=",ExpressionUUID->"637d6699-7762-4dc7-9a77-e0a84c91ee1d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2Sol", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.852071947090707*^9, 3.852071951414809*^9}},
 CellLabel->
  "In[1046]:=",ExpressionUUID->"2bc6352f-e6b0-40ef-a270-19de324aac46"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}], 
  RowBox[{"K", " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]]], "Output",
 CellChangeTimes->{
  3.852071953414957*^9, {3.8521296149911847`*^9, 3.8521296353806057`*^9}, 
   3.8522216790831494`*^9, 3.861386500507534*^9, 3.861386844573498*^9, 
   3.861387534927479*^9},
 CellLabel->
  "Out[1046]=",ExpressionUUID->"8249d876-a1a4-40b5-acf7-3323eafa1bc8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**"}], "******)"}]}]], "Input",
 CellChangeTimes->{{3.8518794241757245`*^9, 3.8518794424436684`*^9}},
 CellLabel->
  "In[1047]:=",ExpressionUUID->"fe134c15-9aa3-47f8-95ac-006c9c717992"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Try", " ", "solution", " ", "of", " ", "ODEs"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7304701661584663`*^9, 3.730470167776614*^9}, {
  3.730470332073261*^9, 3.7304703419922733`*^9}, {3.85198438149617*^9, 
  3.8519843874641542`*^9}, {3.8521296808459167`*^9, 3.8521296862090564`*^9}},
 CellLabel->
  "In[1048]:=",ExpressionUUID->"03d66728-b880-4634-8cfd-481b246a523b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQBN", " ", "=", 
   RowBox[{"EQB", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z01h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, {3.85197601541241*^9, 
   3.8519760263560867`*^9}, {3.851976151846327*^9, 3.8519761540388584`*^9}, {
   3.851978280184795*^9, 3.8519782818348255`*^9}, {3.8519843947572317`*^9, 
   3.851984395835679*^9}, 3.8519844730078897`*^9},
 CellLabel->
  "In[1049]:=",ExpressionUUID->"8ae65aef-7dd1-4f36-aff8-3f748abfe610"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQCN", " ", "=", " ", 
   RowBox[{"EQC", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z01h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, 3.8519754443209496`*^9, {
   3.851976037160728*^9, 3.8519760468379583`*^9}, {3.8519761617038784`*^9, 
   3.8519761639038644`*^9}, {3.8519782909715233`*^9, 
   3.8519782921539507`*^9}, {3.851984403144809*^9, 3.851984403944397*^9}},
 CellLabel->
  "In[1050]:=",ExpressionUUID->"2f36a8fc-cdce-4cbf-bad1-7619c056acc3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EQBN", "\[Equal]", "0"}], ",", 
      RowBox[{"EQCN", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"dch", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"dih", "[", "0", "]"}], "\[Equal]", 
       RowBox[{"1.1", "*", "0.000371"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"dch", ",", "dih"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "300"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7304707264222374`*^9, 3.7304707626209087`*^9}, {
   3.730471150076991*^9, 3.730471192732275*^9}, {3.7304712331930275`*^9, 
   3.730471241200686*^9}, {3.7304728856991377`*^9, 3.7304729120458727`*^9}, {
   3.730472984840526*^9, 3.73047299254502*^9}, {3.7305566873513727`*^9, 
   3.7305567308952975`*^9}, {3.730556886927088*^9, 3.7305569131106553`*^9}, {
   3.730557242621592*^9, 3.7305573606363783`*^9}, {3.73055771430449*^9, 
   3.7305577251351695`*^9}, {3.7305581383665457`*^9, 3.730558152935896*^9}, {
   3.7312602620864716`*^9, 3.7312602825580025`*^9}, {3.731261789181636*^9, 
   3.731261791263114*^9}, {3.731261841258609*^9, 3.7312618424734917`*^9}, {
   3.731261876069353*^9, 3.731261877143103*^9}, 3.7312619427736893`*^9, 
   3.7312622845083046`*^9, {3.851951304211819*^9, 3.8519513854604645`*^9}, {
   3.8519514325748835`*^9, 3.851951573326021*^9}, 3.851951750495144*^9, 
   3.8519517868927164`*^9, 3.8519518211241455`*^9, {3.8519518904364605`*^9, 
   3.851951929163808*^9}, {3.851954184356408*^9, 3.851954186600216*^9}, 
   3.8519545520593014`*^9, {3.851955685562499*^9, 3.851955686589571*^9}, {
   3.851955804082919*^9, 3.8519558044788003`*^9}, {3.8519577154585085`*^9, 
   3.851957729652563*^9}, {3.8519641362793827`*^9, 3.8519641651884627`*^9}, {
   3.85196594916074*^9, 3.851965963635912*^9}, {3.85196687697763*^9, 
   3.851966877659809*^9}, 3.8519669317683754`*^9, {3.851973321742544*^9, 
   3.851973342814912*^9}, {3.851973438888547*^9, 3.85197344222373*^9}, {
   3.8519739080027285`*^9, 3.851973917196357*^9}, {3.8519752368984528`*^9, 
   3.85197524325529*^9}, 3.85197551237716*^9, 3.8519755476779995`*^9, {
   3.851975656873122*^9, 3.851975675602148*^9}, 3.8519759905299845`*^9, {
   3.8519760562328253`*^9, 3.8519760689900723`*^9}, {3.8519761322865453`*^9, 
   3.8519761334904423`*^9}, {3.851976181015073*^9, 3.8519761819541464`*^9}, 
   3.8519762263364277`*^9, 3.851976263770647*^9, {3.851978306172095*^9, 
   3.8519783111176233`*^9}, {3.851984419797775*^9, 3.851984420756149*^9}, 
   3.8519845512146025`*^9, {3.8519845958819304`*^9, 3.851984596430002*^9}, {
   3.8519846265771866`*^9, 3.8519846740034294`*^9}, {3.851984704465914*^9, 
   3.8519847064302616`*^9}, {3.8519847453704987`*^9, 3.8519847458878365`*^9}, 
   3.85198477633648*^9, {3.851984821901883*^9, 3.851984822456086*^9}, 
   3.851984853266609*^9, 3.851984886115674*^9, {3.8519849166319323`*^9, 
   3.8519849172646947`*^9}, {3.8519849493404436`*^9, 3.8519849827257023`*^9}, 
   3.8519850187434587`*^9, {3.851985197683219*^9, 3.851985204612754*^9}, {
   3.8520530265694456`*^9, 3.8520530269888067`*^9}, {3.8521293855265307`*^9, 
   3.8521293866389184`*^9}, 3.8521315889329834`*^9, 3.852136732172714*^9, {
   3.8521367628391895`*^9, 3.8521368040561953`*^9}, 3.8521368552556696`*^9, 
   3.85213691123707*^9, {3.852221733119483*^9, 3.8522217339329185`*^9}},
 CellLabel->
  "In[1051]:=",ExpressionUUID->"0b482a0a-ab45-49e3-9071-03ce1698f691"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dch", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T5Zc9sa5v/vP/RcJVHn
jxNAaev/Lyt+8T/FyyIHhWIkQJt76hX1bfM/Hy7qmjJJLkCECsXjVhr1Pxdi
2uMT/zNAe1god1Wc9j+fNY2q3UI5QFjPie/fIfg/r6vbi7UsPkAdvufX6nn5
Px/Vu07uv0FAROiVUwrg+j9Tocq9E11EQLPHtXc6Nfw/yz4nOkDNRkAcAIjv
4Wz9P4Ogqk4UcklAFLKt1ZK5/j9/03tw7+lLQKyfxFdw7P8/aNONeFxVTkAU
hrozSIsAQMlLY4y4elBAHAeqe84rAUCAliZjRrRRQEN881mowAFAVkP9BSgI
U0CbN8PDJ2ECQKNW9JvSVVRA3xkXU/r9AkCSUpK4AI1VQJWl+9amjwNAobBD
oYLeVkARA/KNFS0EQFL3mxCIGVhAFjYhU4u/BEAjoAdM4W5ZQLIdeZXCXQVA
aq+TegO+WkDT6XbSo/gFQFOnxi+p9ltAHTXuJb+IBkBcAQ2xokldQFDsBYSY
JAdAB0T6uB+GXkBsJzGKwbUHQCntB7RlvF9Acub8gcBDCEA2fJS9f4ZgQPBH
0bp13QhAKHZ4ZI4jYUBddbRzmGwJQCohZvHGzWFAmdbxpWgHCkBn/+P343Ri
QHpHOn8VnwpA9VG1wcIQY0AN/pwKSSwLQJNVkHHLuWNA885ocCDFC0CCzb7k
lVdkQFSN89iKUwxArHh90UTyZEB/94Kt6t4MQObURaQdmmVAOx/S3OR1DUBx
pWE6uDZmQAp8aLeFAg5ADCeHtnzgZkCMdHCNuJoOQPgcAPYCf2dARi0/PJwo
D0AgRgmvbRpoQKAdvBOCsw9AWCAcTgLDaEAqv81l+CQQQOFugrBYYGlA4Twm
kBBrEEB5bvL42ApqQBJIL0PpthBATaHyuj2yakCB0j2bQwERQHJIRkBkTmtA
bKFpnIZGEUCnoKOrtPdrQJ4n58iFkRFALW1U2saVbEBIoD6bcdcRQO5slYK9
MG1AT3V5EOcbEkC/HeAQ3thtQKElOpQUZhJA4UJ+YsB1bkCy1eB7NasSQBMZ
JprMH29AEajR+gr2EkCAIl5LvcZvQDAWiT9qPxNAH9D03zcxcEDOiZhXw4MT
QIZnPw2mhXBAdUxjGM3NE0AWuTMcddRwQIUsM/TTEhRALuMsHtkpcUDwvrk7
iF0UQOMm7lyvfXFAtUupRMqmFEDBJFl95stxQAdXcjoP6xRAJ/vIkLIgckAg
mzrq/TQVQLWL4oXfb3JAJ3JagPJ5FUDvEqv6/79yQMX7NmqovxVANLKvuw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$124813#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0.9999876522593737}, 
                  FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.9999876522593737}, DisplayFunction :> 
                  Identity, Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0.9999876522593737, 
                   5.437165889364171}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T5Zc9sa5v/vP/RcJVHn
jxNAaev/Lyt+8T/FyyIHhWIkQJt76hX1bfM/Hy7qmjJJLkCECsXjVhr1Pxdi
2uMT/zNAe1god1Wc9j+fNY2q3UI5QFjPie/fIfg/r6vbi7UsPkAdvufX6nn5
Px/Vu07uv0FAROiVUwrg+j9Tocq9E11EQLPHtXc6Nfw/yz4nOkDNRkAcAIjv
4Wz9P4Ogqk4UcklAFLKt1ZK5/j9/03tw7+lLQKyfxFdw7P8/aNONeFxVTkAU
hrozSIsAQMlLY4y4elBAHAeqe84rAUCAliZjRrRRQEN881mowAFAVkP9BSgI
U0CbN8PDJ2ECQKNW9JvSVVRA3xkXU/r9AkCSUpK4AI1VQJWl+9amjwNAobBD
oYLeVkARA/KNFS0EQFL3mxCIGVhAFjYhU4u/BEAjoAdM4W5ZQLIdeZXCXQVA
aq+TegO+WkDT6XbSo/gFQFOnxi+p9ltAHTXuJb+IBkBcAQ2xokldQFDsBYSY
JAdAB0T6uB+GXkBsJzGKwbUHQCntB7RlvF9Acub8gcBDCEA2fJS9f4ZgQPBH
0bp13QhAKHZ4ZI4jYUBddbRzmGwJQCohZvHGzWFAmdbxpWgHCkBn/+P343Ri
QHpHOn8VnwpA9VG1wcIQY0AN/pwKSSwLQJNVkHHLuWNA885ocCDFC0CCzb7k
lVdkQFSN89iKUwxArHh90UTyZEB/94Kt6t4MQObURaQdmmVAOx/S3OR1DUBx
pWE6uDZmQAp8aLeFAg5ADCeHtnzgZkCMdHCNuJoOQPgcAPYCf2dARi0/PJwo
D0AgRgmvbRpoQKAdvBOCsw9AWCAcTgLDaEAqv81l+CQQQOFugrBYYGlA4Twm
kBBrEEB5bvL42ApqQBJIL0PpthBATaHyuj2yakCB0j2bQwERQHJIRkBkTmtA
bKFpnIZGEUCnoKOrtPdrQJ4n58iFkRFALW1U2saVbEBIoD6bcdcRQO5slYK9
MG1AT3V5EOcbEkC/HeAQ3thtQKElOpQUZhJA4UJ+YsB1bkCy1eB7NasSQBMZ
JprMH29AEajR+gr2EkCAIl5LvcZvQDAWiT9qPxNAH9D03zcxcEDOiZhXw4MT
QIZnPw2mhXBAdUxjGM3NE0AWuTMcddRwQIUsM/TTEhRALuMsHtkpcUDwvrk7
iF0UQOMm7lyvfXFAtUupRMqmFEDBJFl95stxQAdXcjoP6xRAJ/vIkLIgckAg
mzrq/TQVQLWL4oXfb3JAJ3JagPJ5FUDvEqv6/79yQMX7NmqovxVANLKvuw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$124813#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0.9999876522593737}, 
                  FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.9999876522593737}, DisplayFunction :> 
                  Identity, Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0.9999876522593737, 
                   5.437165889364171}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 300.}}, {
       5, 7, 1, {253}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlXk01YsahtlkOhLFbpNjykyOsY34fZ95iIidZIxkiAol6iZSmcsQHZQx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       "], {Developer`PackedArrayForm, CompressedData["
1:eJwt0oFGHgAAhdF/SZIkSZKkJUmSJEmSZCZJkiRJkiRJS5JkkswkmUySJEmS
JEmSJEmSJEmSJEmSJEmSzOzMdjlPcL+PDV8q2j4EAoHfgX8LIpgQQgkjnAgi
iSKaGGKJI54EEkkimRRSSSOdDDLJIpsccskjnwIKKeITnymmhFLKKKeCSqqo
poZa6qingUaaaKaFVtpop4NOuuimh6/00kc/3/jOAIMM8YNhfjLCKGOMM8Ek
U0wzwyxzzLPAIksss8Iqa6yzwSZbbLPDLnvsc8AhRxxzwilnnHPBJVdcc8Mt
d9zzwCNPPPPCK2+88yvw/38hBBFMCKGEEU4EkUQRTQyxxBFPAokkkUwKqaSR
TgaZZJFNDrnkkU8BhRTxic8UU0IpZZRTQSVVVFNDLXXU00AjTTTTQit/I2+n
g0666KaHr/TSRz/f+M4Agwzxg2F+MsIoY4wzwSRTTDPDLHPMs8AiSyyzwipr
rLPBJltss8Mue+xzwCFHHHPCKWecc8ElV1xzwy133PPAI08888Irb7zzB7Hs
gDY=
        "], CompressedData["
1:eJwd1nc8lW0YB3AzKyNlvDKKvA3Jaipdz5vRIqPIDmUlIykjlJF9Dsc6qaSQ
UCoilNyHQkmirBRFVsR5jj2i99bzx/P5fD+f+4/7vq7ffT3PegdPE0d2Nja2
+eXX34eEaYmeK9wSXIwV9p1//vxhgqbV7y4ubMHq4r/+Oim8b9niCvF/LV6/
9gYn9rpw17/m+iI3y4Gt1K/91882SpstW+f+7NKyc30WV7Fj27sW/HVdKnr/
R5yLEabk8Nc+eQ7RS9hdVecXlh2YIdbOwl5jGTK77M16eZL92JsnE6b+evW6
Yx3Yb+2VO5ZdW1jQYIpdQ6t/vmwzs4AbjWJcjIkYl/Rlhx7jrTqAPWVU57uE
bdwXfqpFiIsRYpFgsoitf8yPrWIFF+Me9xfl39g5ztvc1y5yMmKdXd1Y2AoE
o17KlZPhtDmCdxBbsZ1Q18jgYNQcTpPowvYmSfWGOnZGnPfEZCP2ValHXH7x
bIyMTXM1VdjDBrWnMplLyCv4sUcJtnqjfcXoikVUsUOkLBvbkPGmarpgHq36
gfRSsF0Vha/boVlE/2+2L2L5vLKue7rlZ1Cq5jZnf+xvF9IExWunkNhb9e9O
2JnTxRYLaycRjwerwBQ7zyexug6NI9WL/6XoLp+P0qqqlM5C/LQi153YCVx+
MWY5JLq4bofKemz3g/tGgvvHULqEn6Mg9sn1ES8fjPxCwe1OjfNLTHCqt2e2
HRhBNt+37/2J/XPaQ/dz+0+U8ivfqQmbj39es1pwCMnk0FTLsRkd7EKtiQNo
r/Fq0yzssrEJrwGTfuS1Fd2hYu/Tr9+sR/ShyNam5PPY3R4rpccGetG97N3W
ZtgSzr0ydnU9KOd208N92LwRqbnEp+9oqIBpsAG7UIjbtJztO6pV2ebFgV2d
sFFtYbwLyTtvuNu7yIQ1IsbDT/Z8RQ0fhuJfY7NHmVewVXUiYXPFpfvYPQ+6
3+cFfEZ71qwvvYrtEHyjx6G/HeVHKzKssOs6cy0vxLehB8SOqt3YbR+Mu9jO
tiKuwamLEthJrQ8HM8+2IK9qG7Xh30x4Ltz0rULlE8rcNRiGsDkbTWOtN3xE
58UPCNGxz+5xaSzSakZhtXXXvLBf5MnvE/dpQqv9JA32YXt6SbPqphvR0mlN
LgHs1KsG/1gce484eo0OfF3A+0uFkeLud6hQouHpY+xzHi6d+2/Vo1/sfOLX
sDfQtDU9g98i91P2bfuwbbJfJAnW1iG/7OEdc/NMkCx6LXjItBaxZwYHlWP/
zBo/myVVgz5teLMuCFvskbvEav7XSFbGt1Ab+6lVQ9dvqVfIsTJNhDmH8/i9
9oxcZxX6x92/LAM7NM2afF3PQBGXvvWcwJ7YmPy+uhqhlLUHxgWxz+rxEiVK
lYgwb/aon8X54Wd9yXxdgQbeMTScsaV+/Eld+v4csd2IVePHzkmwbDDRLUfy
z59dK5phAu38gJFlTymaFxC4cgr71RrzwKi8Z2jkQ2G8CPajwplk15QSpHnS
7MbtaVzvzefbKxSLEb3X5acGdov1XqWi4SJkaCMb/GEK70/JN6SuoxA93nYi
3gs76FKhY9ngEyT1pStAHNuOOqbvsuoJEvgSl5Y6ieeXTeE5q9ECpDfBVJbD
fmp63I3B/RCdHHeWejzBBOIM8SzaKh/d3ki9rIst6JHewejNRRXZpdd7xplw
+qrnS9/E++hjNZ+NGXY03enf/s57qH3QnNXCYsKuiRjrUJtslOVYIW6NvWS7
hXlWKAvJ6Ki9HyaZcDsNjvf03UWH2ay1r2I3PzMEw847yPGm15sxJhOuKUn3
/WDPQE6lDvdcsMtb73asvH8LsRwdfX+N4fxw2xm+TLyBOD5ayfljd1SPnhIu
u464dHufCGKvrzHx0hCko6PvvuQEj+L74mxe3z+UjGSteh79/sWE/qWJezk8
SehYYxREYAvUsr3Ns6ahqP1LElLYOdIRETkV8chYz2Zb6Qjuz2kR7gh+Cqqv
4926G9sh74GN7c1opLVdS/nNMM631sVxalIEChyQvuKIbTF20Zrvexg6YGdf
IYQdcNjHzsI7BM1mCb6o/onznDa//VZwMFLfy+p1xm61LeoLYvqhkrHQfbLY
NTleTGV2HxQte3XoxxD+fvxUfC+wzROJSJlblmL7Mr6e2bTTGXH+S+jSsbeG
6md3kqcQp7DP0SBsLYk7ksHUo8imlGfyEnZ0Vum85hEFuHznoGoo9qLz24uP
ZoxAXsXpcDp2wbSctNpGW+j2m2uoxW5cSTltI+4IEaGZ7mJ4PwoVCaViiedg
ti33bAB2d3OXSlfmeQiffRk6gT1k4nXuaJ4PaAzXNAfj84pWi7KMXX3BQrO2
QgrX66aXKVNr1B+iRlSf8eD6vtnZuNGcLwiuyelKCOH+qLPVO4W0XoFRJsNF
CfdPQKt+4ohKCByUnE+xwf3Pb1TosjgZCiXfdDoycV425585P+sUBltcDVov
4vwlaqiVvCsOh/0z4fmOOM/B/3mM2fReA/L+gyxPfF+4zLw2F09GgHVluy8N
30czTxHJt8xIaJ+7rPoWz4O+SJ/7TW1RcHbaREoMzz8ny/wzzg+jQTFANCIK
/z8E7lvZvooZA27CIwnpHCTsdTF4t0Y4DuxXBB+p4yLBf8PXRUdRCvDa7Cjh
5CHhjwVDOWORAvp36PLGfCQc6g8wsm2hwrDzF/lHAiQ8bbAVjkyLBz5qjICa
MAkMRqXTpEECyN7uL2sUJcFCgCQWqxKA/fFoVLg4CVJyek/ZlWhQFkvVNpIi
od9NdqQghgYpmjpcqrIkrCh/fNyslwb+zPOb5eVJeLiYEyOokQhzNz9aTG8k
wTP7KsMqPRH27JfwHVYmoe2p1b8Ci4lgYdXnuqBBgrBU5EnG8STglN5A+1eT
hNbNu8jazCQQP1Kf50qQMNSyirJpJAncaLcrqvVIsCcLBiuUkwF1MOhzhiRo
C3Yf2hOeDIp3FSmmFiTobQphdDcnw+6bm35+dCBB8JJe74RECnRXygR6nCPh
lNvii8CTKWB8Uv+q4iUSgu6n047SUuCe146IqSskzDSLPVtZmwL8H22kOKkk
8IePntzBlwrXXu7atecWCWtbTk3e1kkFzrx1+5LySTBx1xQy8k8F/YEGOcFy
EjRPyz2Vzk2F6OeqJ7LqcD1qcpuKmlPBL4uj0KSNhE5VW66s6VTQoolySo2Q
0MRzeCJZgQ6s0/0xK9hYwCaC6mwP04GXJgyiYiy4oKL98IcLHUbMdzXt2sIC
qfIzNt9C6TCoxx3jDSwQUVC2ZtLpcCeXe2/lCRY4ECfj03Lp8JCj5ADFmwU2
kQwFi3I6LITKironsIBXhqbi+YoO8ibn2k0fsaBtO39PeR0dbp5bXU00sMBj
Pur6VC0dTJzFuzYOs6DvR9rcqyo6MMTekty843DF3kCysIwOiyoectfVxuFD
ua6Wdw4d5koP6nNbjQNXkZfNEyodykbrs3XCx+GeiFuHtTcdHi2ZdB0rGAfD
3ZWyuiZ0KM3nmJVpG4eXnE8E/lGhQ5DLYbGCpXHImSt77clHh2FHYo3/7glI
v9/StvAhFayYI25Pzk+ARuZpy6KkVJhTzjMwyJ+Ar8fpL9JMUyGwRB30eyfg
0Bl3rwjxVOiQSMp98M8keEyEzii0p0DIIHHJzWgSeMqlhH7TU2Dr1u8LkD4J
YV9l5swhBcKTLew6hybhwpnr/lNDySCa2kdqa0xBMZuFq29KMsQPivdHBk6B
t1UVh4FuMjiIxD0pej0FUcx55eezSWDmbhTcLDANQ7ubm3sfJ8HqrWNdivbT
sNF58aimdRKkhZ1CkiXTsK68XGudUBLc7V2xrppnBmReEB/P1SRCtMxD+T0W
M1B2xun5QEgiwNm1bUl5M2AcbT5yWDsRfO49XzU4OwOXnwb76vMlgoNA8Gm9
g7PgOVDCm/mJBvNmkzvNymZBlRogbhhHA3q99tbSjXMQFStpUqRPg/AC74/0
lDmQ2vaocXw1DfjVNl1bzzEPKQMdxod7EqBOM7DXz30e5mwPhbEXY3d+0K5s
n4f6neH1/rEJcHu3mIbQfwsw2qzsLO+cALYJmf9M/lqA2dQhQ36NBMhmU9zW
k/objqrcKJbjSQAXFxEzBViEParFas9e4XlTUDQ1178I9CM3oznC48FX4kfN
9dglGJPJP7PZIB5+HU+T3qL6B3QYxs2JMvGgmuVc1fTpD+SI82yanqDCrm+5
267tZyMmkPAm8j0VIle4czAS2QhV1fxdRg+poG5h0541wEZETozMnaBSwe9R
5bs9muyEZob1DocLVDjN9+ZyNIWd+JbeAHOWVGjZKXUk7Ts78TtKkeOpDhXC
9DLTPDQ4iOAXQdp7VangfWdLx6s7HER44tqDlyTw+ldbLF8JchIeC8H5P9io
kNvLZ+UTwElwlY37y/2igPlXl5avA5zE8fuHTb50UEB9oKma/TgXoWTsd/xz
LQX2fzC3HKzkIsRiDx0aKqHArfOiKrQt3ESRXljd93sU8BI2WF/znJvYJnns
WxKNAsUKx5TTjqwgFA/4FVwKpkBUgE62aOcKIuFYw1PLcxQYY9gK73TlIQa0
+ZrWWlFAtDHQimeWh/jc/x89/QgFij59nIuO4CVmVTpPvdWkAI8gMctYw0dw
vjX4EqdEAR3tmYUdzXyEFKmuvV6SAp0X2qVVKfzE6yCB5hhuClzyPehdfEiA
UDuU8btoIg5a+XUT6jhXEk0dHJcje+NA95lWhnvlSkJpL1NtrjkOPrxa65Hv
J0gEzPR4LlTFwQW/n1dC1IUIu/wku7CiODjhmHifqixMBAXST5jejoNEsQXj
mdUiRGqIwtWZmDgIDUrY0JIgQiQb3mCZ+8UBL+8N0k5wFUFrj1nh5hQHPbnb
M+5EryLk5tbOrTONg0jBib4UblFCdno4xFMnDuiDWoxYhighzGt3d+/WOPjU
ce3f/oDVxEWfxBwVsTgoPGfsnLd9DaGRIeSo9icWMrpvqX4bXUOEZkUobhmO
BSNW58HPZmJEklqk4e3uWAjt/OyRi8QI59133cw/xcL/RYwk8g==
        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], ",", 
    RowBox[{"dih", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T5hpXN6Feg7P/RcJVHn
jxNA7wkIk0lR0z/FyyIHhWIkQKZ73bs7VuE/Hy7qmjJJLkBwbaoy+d7mPxdi
2uMT/zNAe1hwKa8i6z+fNY2q3UI5QDaGVboJ2u4/r6vbi7UsPkAgvW17mN7w
Px/Vu07uv0FA1kd92Ow48j9Tocq9E11EQIko8k/2Z/M/yz4nOkDNRkD3MQ4+
GGz0P4Ogqk4UcklAOb8m7xZ19T9/03tw7+lLQKqcHY4OYfY/aNONeFxVTkCH
XY0EoED3P8lLY4y4elBAanPSycQs+D+AliZjRrRRQHj/zW2OBPk/VkP9BSgI
U0CX0LSkq+r5P6NW9JvSVVRAKr8dopTJ+j+SUpK4AI1VQEH0UgZWl/s/obBD
oYLeVkBMt+BtmnT8P1L3mxCIGVhAa/9IpaRB/T8joAdM4W5ZQA4OsAhzHv4/
aq+TegO+WkDifMFLCvb+P1Onxi+p9ltA2Rbdyzq+/z9cAQ2xokldQPFPDQIv
SwBAB0T6uB+GXkA5V6uBsq8AQCntB7RlvF9A8N8a4+cRAUA2fJS9f4ZgQE70
x8YafAFAKHZ4ZI4jYUBosgKk6N4BQCohZvHGzWFAX7Z09a9JAkBn/+P343Ri
QCjp7j85sgJA9VG1wcIQY0CLBXOGehMDQJNVkHHLuWNAkSaLUbB8A0CCzb7k
lVdkQORQ9ySr3gNArHh90UTyZEBzl9digj4EQObURaQdmmVACPHitkemBEBx
pWE6uDZmQL4frBTlBgVADCeHtnzgZkDeQoQTam8FQPgcAPYCf2dAhq3Kl9DQ
BUAgRgmvbRpoQD2m92EgMAZAWCAcTgLDaECCCWPHUJcGQOFugrBYYGlA5572
pXH3BkB5bvL42ApqQK2Ez9hsXwdATaHyuj2yakDlaCv0UsUHQHJIRkBkTmtA
ZTqNLTckCECnoKOrtPdrQHE1DbvuighALW1U2saVbEAlLiJCq+oIQO5slYK9
MG1AZY5zc2BICUC/HeAQ3thtQFkV1E7irQlA4UJ+YsB1bkCJ0IqSdAwKQBMZ
JprMH29AP9g+1c1yCkCAIl5LvcZvQFcUui8g1wpAH9D03zcxcEDJlXjFjTQL
QIZnPw2mhXBAAlVJ77uZC0AWuTMcddRwQIfKMdQK+AtALuMsHtkpcUD/mgT+
FF4MQOMm7lyvfXFAdoZNAx/CDEDBJFl95stxQEgzKnhTHw1AJ/vIkLIgckCw
LiwnPYQNQLWL4oXfb3JAYfKzOVbiDUDvEqv6/79yQIsaPsJxQQ5A4oyy9A==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$124870#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 3.7819552588655987`}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T5hpXN6Feg7P/RcJVHn
jxNA7wkIk0lR0z/FyyIHhWIkQKZ73bs7VuE/Hy7qmjJJLkBwbaoy+d7mPxdi
2uMT/zNAe1hwKa8i6z+fNY2q3UI5QDaGVboJ2u4/r6vbi7UsPkAgvW17mN7w
Px/Vu07uv0FA1kd92Ow48j9Tocq9E11EQIko8k/2Z/M/yz4nOkDNRkD3MQ4+
GGz0P4Ogqk4UcklAOb8m7xZ19T9/03tw7+lLQKqcHY4OYfY/aNONeFxVTkCH
XY0EoED3P8lLY4y4elBAanPSycQs+D+AliZjRrRRQHj/zW2OBPk/VkP9BSgI
U0CX0LSkq+r5P6NW9JvSVVRAKr8dopTJ+j+SUpK4AI1VQEH0UgZWl/s/obBD
oYLeVkBMt+BtmnT8P1L3mxCIGVhAa/9IpaRB/T8joAdM4W5ZQA4OsAhzHv4/
aq+TegO+WkDifMFLCvb+P1Onxi+p9ltA2Rbdyzq+/z9cAQ2xokldQPFPDQIv
SwBAB0T6uB+GXkA5V6uBsq8AQCntB7RlvF9A8N8a4+cRAUA2fJS9f4ZgQE70
x8YafAFAKHZ4ZI4jYUBosgKk6N4BQCohZvHGzWFAX7Z09a9JAkBn/+P343Ri
QCjp7j85sgJA9VG1wcIQY0CLBXOGehMDQJNVkHHLuWNAkSaLUbB8A0CCzb7k
lVdkQORQ9ySr3gNArHh90UTyZEBzl9digj4EQObURaQdmmVACPHitkemBEBx
pWE6uDZmQL4frBTlBgVADCeHtnzgZkDeQoQTam8FQPgcAPYCf2dAhq3Kl9DQ
BUAgRgmvbRpoQD2m92EgMAZAWCAcTgLDaECCCWPHUJcGQOFugrBYYGlA5572
pXH3BkB5bvL42ApqQK2Ez9hsXwdATaHyuj2yakDlaCv0UsUHQHJIRkBkTmtA
ZTqNLTckCECnoKOrtPdrQHE1DbvuighALW1U2saVbEAlLiJCq+oIQO5slYK9
MG1AZY5zc2BICUC/HeAQ3thtQFkV1E7irQlA4UJ+YsB1bkCJ0IqSdAwKQBMZ
JprMH29AP9g+1c1yCkCAIl5LvcZvQFcUui8g1wpAH9D03zcxcEDJlXjFjTQL
QIZnPw2mhXBAAlVJ77uZC0AWuTMcddRwQIfKMdQK+AtALuMsHtkpcUD/mgT+
FF4MQOMm7lyvfXFAdoZNAx/CDEDBJFl95stxQEgzKnhTHw1AJ/vIkLIgckCw
LiwnPYQNQLWL4oXfb3JAYfKzOVbiDUDvEqv6/79yQIsaPsJxQQ5A4oyy9A==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$124870#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 3.7819552588655987`}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 300.}}, {
       5, 7, 1, {253}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlXk01YsahtlkOhLFbpNjykyOsY34fZ95iIidZIxkiAol6iZSmcsQHZQx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       "], {Developer`PackedArrayForm, CompressedData["
1:eJwt0oFGHgAAhdF/SZIkSZKkJUmSJEmSZCZJkiRJkiRJS5JkkswkmUySJEmS
JEmSJEmSJEmSJEmSJEmSzOzMdjlPcL+PDV8q2j4EAoHfgX8LIpgQQgkjnAgi
iSKaGGKJI54EEkkimRRSSSOdDDLJIpsccskjnwIKKeITnymmhFLKKKeCSqqo
poZa6qingUaaaKaFVtpop4NOuuimh6/00kc/3/jOAIMM8YNhfjLCKGOMM8Ek
U0wzwyxzzLPAIksss8Iqa6yzwSZbbLPDLnvsc8AhRxxzwilnnHPBJVdcc8Mt
d9zzwCNPPPPCK2+88yvw/38hBBFMCKGEEU4EkUQRTQyxxBFPAokkkUwKqaSR
TgaZZJFNDrnkkU8BhRTxic8UU0IpZZRTQSVVVFNDLXXU00AjTTTTQit/I2+n
g0666KaHr/TSRz/f+M4Agwzxg2F+MsIoY4wzwSRTTDPDLHPMs8AiSyyzwipr
rLPBJltss8Mue+xzwCFHHHPCKWecc8ElV1xzwy133PPAI08888Irb7zzB7Hs
gDY=
        "], CompressedData["
1:eJwN1Wc81Q0UB/CbPRtuIaRhlcQjZFW/v5FRykpWiJCSimRLdS+hRRRZWdlk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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8521289733573065`*^9, 3.8521293904665227`*^9, 3.8521294959956727`*^9, 
   3.8521297046089582`*^9, 3.852131592226951*^9, 3.8521347061846323`*^9, {
   3.8521367474139876`*^9, 3.852136806273043*^9}, 3.8521368568819723`*^9, 
   3.8521369154516397`*^9, 3.8522216997833233`*^9, 3.8522217376262693`*^9, 
   3.8522220206487255`*^9, 3.8613865011584797`*^9, 3.86138684537608*^9, 
   3.861387535718444*^9},
 CellLabel->
  "Out[1051]=",ExpressionUUID->"de227476-bbb4-43fb-bb41-9faa846e0b89"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"delta_c", ",", "delta_i"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "delta"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, 
   3.8521288666663456`*^9, {3.852130762064339*^9, 3.8521308332363777`*^9}, {
   3.852130896147086*^9, 3.8521310938494043`*^9}, {3.8521367558250923`*^9, 
   3.8521368397526817`*^9}, 3.8521369198904943`*^9},
 CellLabel->
  "In[1052]:=",ExpressionUUID->"b3beead8-1d69-4713-8ecd-b83d036903b3"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVz3s41XcAx/HjziG5nB8148kkrS2K2UPo+yklaiMquSaUEDnn11Zu4UkY
OqeLI9NFSaWOyDoucwld5FKMNpMcj7U0zgnnd5qQLNv+eD+vv9/mYXE++5VZ
LFbQf/2v2Hf+3UT5wPoHwgXTlwtykv14T7+3oJbUWFgXPx+Tk9MvjieZCdpI
2lXn8VGpnEyuLFPLEfWSkJRlpR5yORGOCLtUBf2kXe8Ae35aTtZdSclP5Q2R
ASOrvKUshjCrq6yPiV6Su60FazeqMeSc9NL0DH+UDGblPnykx5CotrMB1aky
Uha/M3bOiCHO17OaaN4EkfaWFMaaMoRX6fDwiEhBpoTN4eOrGGIc81mugj9D
sr8y6KvdwhDW4KcuPervCd/cpNjeiyEyD2N5ReocEfx4zvKpL0MarXR2xPD+
IcGJ9TFOEQz5SZHIPyxSgmnu8mfTGQzZXb5v1yRfAz7i4QhpG0OejoRWBG/V
hLFRnWhHD0PwaYhGl7oWRh8HXG99zpBVuf51Zals7Luyrr5JypD5SE/TKN4i
zD9JbZvVVhBvg4tveSJ9iA51ch29FWSmK6N+nG8Ml+OcYIMhBRFzehdl5q5E
KXvEOH/FFOF+8VXPPSdbBDrlmwkMp4nRlhlhh6EDTDR/lsQ9nSF/3zOOvhq9
Hm7BlQGJOe9JRojZkoJVG6G+X8VezfgDuc0PSXcN2YxX4kybrpp5YpIQFDN7
wh0BKyeX8zd/JKW3Brsyv9uG3aNrFt0QL5DurOzapBJPPL7/rSuriIWcPomO
Zfd2VAaWXjy2Qwk9rc+S9Vx98PCHzdE2qsoY0fljzZ3+HbCb0pa0PlBG1hHr
4nXeu1CiLmyvPqyCma+FuxJkvjjmfie/1FYV2r/3uzsn+2FYekvDb0IVFQVB
s2/e+kOlyKao77wazCpn33hmB8LK9YlbmK86TN/0XShSDUakl3fOa1UNyJI7
TxVf3gPuCxsJ974Gyo94hgqX7oX9L6k66omaWI3nft19e+EuuStrtdSCYXXs
25fFobCoabx3YlgLGxosZAf3hqH3VcedjJNs3K90V3IwCYdpxAVWi702Sr0T
6odeh2Prbx9bJsa10Zfe2fv+6j6kn4zXTSvQQXSoVa48bj+U/YMi57wWwdv6
73ArxwjUZG4crFLVRerJ4fN9UxFIkH8/r7itC865/sPBLQfQH8P5kx2+GMwa
RhSYEom8DWPiAHU9mDUcVbroEIUwt9XqIf56EDPsuWrlaAzltfpsE+vhVG3T
drfmaCjcgpJ1NPTx7PMUj8rcg1hxWZZQGaqPoNV7rpzeGgMri5FCmxp9OCwr
NxKrxWKZtbzotaYBkpo0bO70xEKyxGE0PswAapPHr5sLDsFku+FNRbUBptu1
mmID46BY0B3bqGeIix0Lc8cMuNjWbtD9JNIQoTNstzQuFyU1VcOuDYYYmDMJ
i/udi84+V/NTHA7eubmUF9rzsH0gKLH7AAf1bCPN12d5+HjDzs+rjgPba1N2
prM8xGsIIov0KXhmvhKc9qWx7UDjsDScwpatgm++9qMh91f7xH8/Beg6siX+
NC4IN/i0R1BYe06QYRVMo00gbLwRRYFzwzG5KZzGba9b8eFxFAZbT0WNc2nY
dokFkkQKkWrOm9xzaXSoJNl1naEQ2vGX0uRJGkklaV8651EI4J9pzhPQsFSk
WJQJKXxDja4bPkPD3DVCO7uAgo3l2bVHfqQxljjyYNMlCtObxsyuXafhptLa
03CTglwzT+JRSuNRS9StVSIKY09dzstv0rAb1korLKMwsDOPcrpN4/IbZ6uj
FRQa963XeXaXhuwDHWxbRaF6pbTjaBWNZYkzlsXVFCrG87JMa2g8uBs/vriW
wpXvpMpRdTTYLPrwRB2FQgdhi24DjcUHZXZBDRTOzq9PqWqkQVz2vu1spJDT
InUKaPrvt/jXCscmCuknhO8XmmkMPdwUdbOZwr+br67N
          "]]}, Annotation[#, "Charting`Private`Tag$124931#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVk2k81IsagG1jGUwpJ4dQWZpwZ5KMkLyvRKhIUVmzRpbG/OvqKFuRJWYq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          "]]}, Annotation[#, "Charting`Private`Tag$124931#2"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {Automatic, Automatic}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox["x", HoldForm], TraditionalForm], 
       FormBox["delta", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"delta_c", "delta_i"}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.852130989856325*^9, {3.852131022693478*^9, 3.852131040583562*^9}, {
   3.8521310737532277`*^9, 3.852131096094097*^9}, 3.852131597225279*^9, 
   3.85213470996019*^9, {3.8521367513295164`*^9, 3.852136861485786*^9}, 
   3.8521369207794785`*^9, 3.8522217069364758`*^9, 3.8522217414115486`*^9, 
   3.852222025102398*^9, 3.861386501280718*^9, 3.861386845483177*^9, 
   3.861387535821679*^9},
 CellLabel->
  "Out[1052]=",ExpressionUUID->"8f49c5ac-b5e6-4073-99fe-88adda09a272"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}], "/", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "300"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.0"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "delta_ratio"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, {
   3.852124125642785*^9, 3.852124141635003*^9}, {3.8521311140173144`*^9, 
   3.8521311358455563`*^9}, {3.852136793087507*^9, 3.8521368167286*^9}, {
   3.852137159884965*^9, 3.852137179240376*^9}},
 CellLabel->
  "In[1053]:=",ExpressionUUID->"4be731d4-ecc6-48c2-baf0-f0afbc57742d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd13c81d8bAHCkSJJI024gJdkK58ku617uvTYJZWRdMpKUkb1HIqOI+Ga2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       "]]},
     Annotation[#, "Charting`Private`Tag$125012#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["x", HoldForm], TraditionalForm], 
    FormBox["delta_ratio", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 300}, {0, 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8521241496341267`*^9, 3.8521288800069914`*^9, 3.8521295058238277`*^9, 
   3.8521297161720333`*^9, 3.8521311399580317`*^9, 3.852131601893999*^9, 
   3.8521347148755445`*^9, {3.852136794543645*^9, 3.852136818676442*^9}, 
   3.85213692588529*^9, 3.8521371837472353`*^9, {3.8522217208660555`*^9, 
   3.8522217463102713`*^9}, 3.8522220305434732`*^9, 3.861386501340452*^9, 
   3.861386845531646*^9, 3.8613875358791943`*^9},
 CellLabel->
  "Out[1053]=",ExpressionUUID->"f7813102-090f-49c9-a331-8df024468c75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"S1Sol", "[", "x", "]"}], ",", 
   RowBox[{"S2Sol", "[", "x", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.852129834464188*^9, 3.85212986212484*^9}},
 CellLabel->
  "In[1054]:=",ExpressionUUID->"8e3dc439-6ea5-45b9-80b5-6403274be7e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "K"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.852129864630492*^9, 3.861386501350635*^9, 
  3.861386845541601*^9, 3.861387535890864*^9},
 CellLabel->
  "Out[1054]=",ExpressionUUID->"aa105d61-652a-46c0-a313-ccf6bb89c825"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Plot", " ", "Shear", " ", "stress"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8522220411679087`*^9, 3.852222047805437*^9}},
 CellLabel->
  "In[1055]:=",ExpressionUUID->"e0e47356-187a-407f-a06b-5ea278e1441b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S1SolN", "[", "x_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], "K"], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z01h", " ", "->", " ", "0.000371"}], ",", 
     RowBox[{"K", "\[Rule]", "0.384"}]}], " ", "}"}]}]}]], "Input",
 CellChangeTimes->{{3.852129900314182*^9, 3.852129945731001*^9}, 
   3.8521299946526856`*^9},
 CellLabel->
  "In[1056]:=",ExpressionUUID->"01b3c087-c389-4a55-890f-c3af83944273"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S1SolN", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8521300006387076`*^9, 3.8521300287581463`*^9}},
 CellLabel->
  "In[1057]:=",ExpressionUUID->"d94e3c06-3958-4f1e-8bc0-7742642a8eca"],

Cell[BoxData[
 RowBox[{"2.6041666666666665`", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"2695.4177897574123`", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.8521300297560835`*^9, 3.8522220565816183`*^9, 
  3.8613865014331293`*^9, 3.861386845609457*^9, 3.8613875359762793`*^9},
 CellLabel->
  "Out[1057]=",ExpressionUUID->"6335df96-6dba-4509-b2e2-297ad578695c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2SolN", "[", "x_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}], 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dch", "[", "x", "]"}], "z01h"], "]"}]], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z01h"], "]"}]}]], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z01h", " ", "->", " ", "0.000371"}], ",", 
     RowBox[{"K", "\[Rule]", "0.384"}], ",", 
     RowBox[{"A", "\[Rule]", "4.17"}], ",", 
     RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.852129900314182*^9, 3.852129945731001*^9}, {
  3.852130043049155*^9, 3.8521300740164013`*^9}},
 CellLabel->
  "In[1058]:=",ExpressionUUID->"0d642e2e-a729-4b36-9035-7b16345170b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2SolN", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8521300828358326`*^9, 3.852130087574032*^9}},
 CellLabel->
  "In[1059]:=",ExpressionUUID->"de1b85e0-bc45-422c-920b-c02f233be7c5"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2.6041666666666665`", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"2695.4177897574123`", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    FractionBox[
     RowBox[{"637340.01023888`", " ", 
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"2695.4177897574123`", " ", 
        RowBox[{"dih", "[", "x", "]"}]}], "]"}]}], 
     RowBox[{"Log", "[", 
      RowBox[{"2695.4177897574123`", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
  RowBox[{"Log", "[", 
   RowBox[{"2695.4177897574123`", " ", 
    RowBox[{"dih", "[", "x", "]"}]}], "]"}]]], "Output",
 CellChangeTimes->{3.8521300885465574`*^9, 3.8522217952040496`*^9, 
  3.85222206609501*^9, 3.861386501486487*^9, 3.861386845660623*^9, 
  3.861387536031342*^9},
 CellLabel->
  "Out[1059]=",ExpressionUUID->"5a9a35bd-ac3f-4d7d-bdf3-d7204be38178"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1", " ", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{
          RowBox[{"S1SolN", "[", "x", "]"}], "^", "2"}]}], "/.", "s"}], "]"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "Cf1", "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Cf"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, {
   3.852124125642785*^9, 3.852124141635003*^9}, {3.85213011619508*^9, 
   3.8521301430047703`*^9}, {3.852130217573925*^9, 3.852130225014469*^9}, 
   3.852130336873315*^9, {3.8521313538860645`*^9, 3.852131392479273*^9}, {
   3.8521314540560384`*^9, 3.852131455947811*^9}, {3.852131496570117*^9, 
   3.85213151320859*^9}, {3.852137295378949*^9, 3.852137306004427*^9}},
 CellLabel->
  "In[1060]:=",ExpressionUUID->"4fc82e74-e2e0-4285-ab3d-cdf61f719fd1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{
          RowBox[{"S2SolN", "[", "x", "]"}], "^", "2"}]}], "/.", "s"}], "]"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Orange"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "Cf2", "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8521302425391626`*^9, 3.852130282037215*^9}, 
   3.85213034376534*^9, {3.8521311848524218`*^9, 3.852131268789968*^9}, {
   3.8521313785130234`*^9, 3.8521314486244793`*^9}, 3.8521315072282715`*^9},
 CellLabel->
  "In[1061]:=",ExpressionUUID->"59f641ce-2afd-4c64-8b60-426b9c8fc54f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P1pt5", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"P1", ",", "P2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8521302981332645`*^9, 3.8521303070806866`*^9}, {
   3.8521304328913984`*^9, 3.852130438397482*^9}, {3.8521312504548655`*^9, 
   3.852131285765663*^9}, 3.852131325225462*^9, 3.8521313639917946`*^9, 
   3.8521314322379427`*^9},
 CellLabel->
  "In[1062]:=",ExpressionUUID->"bb3d0b36-a536-46c0-b760-e0cb2a65072b"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV03k01fkbB3BrYvBDlkpUV9n6WSLmVnge+5IxIQpZo/i6173fzzcaU1FZ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           "]]}, 
         Annotation[#, "Charting`Private`Tag$125063#1"]& ]}}, {}}, {{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0.5, 0]], 
          LineBox[CompressedData["
1:eJwV1nk0VfsXAHD1EBFlCKEyXq4hROFh75AQQrkZ773nGDLGvQ14SZoM4VKU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           "]]}, Annotation[#, "Charting`Private`Tag$125124#1"]& ]}}, {}}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {Automatic, Automatic}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox["x", HoldForm], TraditionalForm], 
       FormBox["Cf", TraditionalForm]}, 
     AxesOrigin -> {0, 0.0032049614675305612`}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"Cf1"}, "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"Cf2"}, "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8521303080785627`*^9, 3.852130439439432*^9, 3.852131230002668*^9, {
   3.8521312747462187`*^9, 3.8521312878332644`*^9}, 3.8521313263882775`*^9, 
   3.8521314332169776`*^9, 3.8521314659240513`*^9, 3.8521315272034454`*^9, 
   3.852131621708188*^9, 3.8521347285753293`*^9, 3.852137028149008*^9, 
   3.852137319304658*^9, {3.852221762807136*^9, 3.8522218052238207`*^9}, 
   3.8522220809582167`*^9, 3.8613865017332087`*^9, 3.861386845803377*^9, 
   3.8613875362162647`*^9},
 CellLabel->
  "Out[1062]=",ExpressionUUID->"1d476378-89e1-4248-a787-0eda55df95b2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Try", " ", "a", " ", "different", " ", "calue", " ", "of", " ", 
   RowBox[{"dih", "[", 
    RowBox[{"x", "=", "0"}], "]"}], " ", "to", " ", "check", " ", "for", " ", 
   "sensitivity"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8521303818677998`*^9, 3.8521304101583805`*^9}},
 CellLabel->
  "In[1063]:=",ExpressionUUID->"1f189524-69d2-4394-a465-29d5f788593d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQBN", " ", "=", 
   RowBox[{"EQB", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z01h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, {3.85197601541241*^9, 
   3.8519760263560867`*^9}, {3.851976151846327*^9, 3.8519761540388584`*^9}, {
   3.851978280184795*^9, 3.8519782818348255`*^9}, {3.8519843947572317`*^9, 
   3.851984395835679*^9}, 3.8519844730078897`*^9},
 CellLabel->
  "In[1064]:=",ExpressionUUID->"c3d26102-728d-46c7-b3da-5a54caccb392"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQCN", " ", "=", " ", 
   RowBox[{"EQC", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z01h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, 3.8519754443209496`*^9, {
   3.851976037160728*^9, 3.8519760468379583`*^9}, {3.8519761617038784`*^9, 
   3.8519761639038644`*^9}, {3.8519782909715233`*^9, 
   3.8519782921539507`*^9}, {3.851984403144809*^9, 3.851984403944397*^9}},
 CellLabel->
  "In[1065]:=",ExpressionUUID->"e2721dbf-011a-4e4d-a9f7-cc4a594565b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EQBN", "\[Equal]", "0"}], ",", 
      RowBox[{"EQCN", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"dch", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"dih", "[", "0", "]"}], "\[Equal]", 
       RowBox[{"5.0", "*", "0.000371"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"dch", ",", "dih"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "300"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7304707264222374`*^9, 3.7304707626209087`*^9}, {
   3.730471150076991*^9, 3.730471192732275*^9}, {3.7304712331930275`*^9, 
   3.730471241200686*^9}, {3.7304728856991377`*^9, 3.7304729120458727`*^9}, {
   3.730472984840526*^9, 3.73047299254502*^9}, {3.7305566873513727`*^9, 
   3.7305567308952975`*^9}, {3.730556886927088*^9, 3.7305569131106553`*^9}, {
   3.730557242621592*^9, 3.7305573606363783`*^9}, {3.73055771430449*^9, 
   3.7305577251351695`*^9}, {3.7305581383665457`*^9, 3.730558152935896*^9}, {
   3.7312602620864716`*^9, 3.7312602825580025`*^9}, {3.731261789181636*^9, 
   3.731261791263114*^9}, {3.731261841258609*^9, 3.7312618424734917`*^9}, {
   3.731261876069353*^9, 3.731261877143103*^9}, 3.7312619427736893`*^9, 
   3.7312622845083046`*^9, {3.851951304211819*^9, 3.8519513854604645`*^9}, {
   3.8519514325748835`*^9, 3.851951573326021*^9}, 3.851951750495144*^9, 
   3.8519517868927164`*^9, 3.8519518211241455`*^9, {3.8519518904364605`*^9, 
   3.851951929163808*^9}, {3.851954184356408*^9, 3.851954186600216*^9}, 
   3.8519545520593014`*^9, {3.851955685562499*^9, 3.851955686589571*^9}, {
   3.851955804082919*^9, 3.8519558044788003`*^9}, {3.8519577154585085`*^9, 
   3.851957729652563*^9}, {3.8519641362793827`*^9, 3.8519641651884627`*^9}, {
   3.85196594916074*^9, 3.851965963635912*^9}, {3.85196687697763*^9, 
   3.851966877659809*^9}, 3.8519669317683754`*^9, {3.851973321742544*^9, 
   3.851973342814912*^9}, {3.851973438888547*^9, 3.85197344222373*^9}, {
   3.8519739080027285`*^9, 3.851973917196357*^9}, {3.8519752368984528`*^9, 
   3.85197524325529*^9}, 3.85197551237716*^9, 3.8519755476779995`*^9, {
   3.851975656873122*^9, 3.851975675602148*^9}, 3.8519759905299845`*^9, {
   3.8519760562328253`*^9, 3.8519760689900723`*^9}, {3.8519761322865453`*^9, 
   3.8519761334904423`*^9}, {3.851976181015073*^9, 3.8519761819541464`*^9}, 
   3.8519762263364277`*^9, 3.851976263770647*^9, {3.851978306172095*^9, 
   3.8519783111176233`*^9}, {3.851984419797775*^9, 3.851984420756149*^9}, 
   3.8519845512146025`*^9, {3.8519845958819304`*^9, 3.851984596430002*^9}, {
   3.8519846265771866`*^9, 3.8519846740034294`*^9}, {3.851984704465914*^9, 
   3.8519847064302616`*^9}, {3.8519847453704987`*^9, 3.8519847458878365`*^9}, 
   3.85198477633648*^9, {3.851984821901883*^9, 3.851984822456086*^9}, 
   3.851984853266609*^9, 3.851984886115674*^9, {3.8519849166319323`*^9, 
   3.8519849172646947`*^9}, {3.8519849493404436`*^9, 3.8519849827257023`*^9}, 
   3.8519850187434587`*^9, {3.851985197683219*^9, 3.851985204612754*^9}, {
   3.8520530265694456`*^9, 3.8520530269888067`*^9}, {3.8521293855265307`*^9, 
   3.8521293866389184`*^9}, {3.8521304771636677`*^9, 3.852130478162436*^9}},
 CellLabel->
  "In[1066]:=",ExpressionUUID->"5e701952-f3ca-44f7-a507-2c146ccceee0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dch", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T4PvdnE/v/vP/RcJVHn
jxNAyVdA7u2B8T/FyyIHhWIkQNKqxSmwcfM/Hy7qmjJJLkC8paxsFx71Pxdi
2uMT/zNACjpx6CCg9j+fNY2q3UI5QBMbFvW3Jfg/r6vbi7UsPkAH3Z/+zH35
Px/Vu07uv0FAcfi0+vTj+j9Tocq9E11EQFszs/0qOfw/yz4nOkDNRkDvbN4t
1nD9P4Ogqk4UcklAwJhKhYm9/j9/03tw7+lLQMSXXilo8P8/aNONeFxVTkDq
UBNBRI0AQMlLY4y4elBAG1m6WcotAUCAliZjRrRRQOQpVM6jwgFAVkP9BSgI
U0B9OyeWImMCQKNW9JvSVVRALtlZZPT/AkCSUpK4AI1VQMbA0h6gkQNAobBD
oYLeVkBY+jfqDS8EQFL3mxCIGVhASOOLyoLBBEAjoAdM4W5ZQJrQ4Ay5XwVA
aq+TegO+WkDg2mJLmfoFQFOnxi+p9ltAjqv2sLOKBkBcAQ2xokldQMaH8g2M
JgdAB0T6uB+GXkCi4sAltLcHQCntB7RlvF9AR5ytNrJFCEA2fJS9f4ZgQE6/
+3dm3whAKHZ4ZI4jYUCuABFNiG4JQCohZvHGzWFAnYNcjVcJCkBn/+P343Ri
QHVGuH0DoQpA9VG1wcIQY0CyadUzNi4LQJNVkHHLuWNAYoTbtgzHC0CCzb7k
lVdkQMxPHlB2VQxArHh90UTyZEB6RsNd1eAMQObURaQdmmVAnB8Suc53DUBx
pWE6uDZmQH+bNNJuBA5ADCeHtnzgZkC3BT/aoJwOQPgcAPYCf2dAegQ1zYMq
D0AgRgmvbRpoQN238u9otQ9AWCAcTgLDaEBurQ906yUQQOFugrBYYGlA6ROG
RgNsEEB5bvL42ApqQCerb5zbtxBATaHyuj2yakDzfgCbNQIRQHJIRkBkTmtA
zHM4SnhHEUCnoKOrtPdrQGebHB93khFALW1U2saVbECg29ihYtgRQO5slYK9
MG1Ae2vkydccEkC/HeAQ3thtQIAchvsEZxJA4UJ+YsB1bkCsAbKYJawSQBMZ
JprMH29AqL1cx/r2EkCAIl5LvcZvQOhdXb9ZQBNAH9D03zcxcEBEQe2QsoQT
QIZnPw2mhXBAlkdsBrzOE0AWuTMcddRwQJfGZZ3CExRALuMsHtkpcUCB+3Wb
dl4UQOMm7lyvfXFAR1ZzXbinFEDBJFl95stxQOceVhL96xRAJ/vIkLIgckDf
eLd86zUVQLWL4oXfb3JAQvkc0996FUDvEqv6/79yQM+kdH2VwBVAvEu3Kw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$125296#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0.999999412988389}, 
                  FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.999999412988389}, DisplayFunction :> 
                  Identity, Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0.999999412988389, 
                   5.438070259327289}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T4PvdnE/v/vP/RcJVHn
jxNAyVdA7u2B8T/FyyIHhWIkQNKqxSmwcfM/Hy7qmjJJLkC8paxsFx71Pxdi
2uMT/zNACjpx6CCg9j+fNY2q3UI5QBMbFvW3Jfg/r6vbi7UsPkAH3Z/+zH35
Px/Vu07uv0FAcfi0+vTj+j9Tocq9E11EQFszs/0qOfw/yz4nOkDNRkDvbN4t
1nD9P4Ogqk4UcklAwJhKhYm9/j9/03tw7+lLQMSXXilo8P8/aNONeFxVTkDq
UBNBRI0AQMlLY4y4elBAG1m6WcotAUCAliZjRrRRQOQpVM6jwgFAVkP9BSgI
U0B9OyeWImMCQKNW9JvSVVRALtlZZPT/AkCSUpK4AI1VQMbA0h6gkQNAobBD
oYLeVkBY+jfqDS8EQFL3mxCIGVhASOOLyoLBBEAjoAdM4W5ZQJrQ4Ay5XwVA
aq+TegO+WkDg2mJLmfoFQFOnxi+p9ltAjqv2sLOKBkBcAQ2xokldQMaH8g2M
JgdAB0T6uB+GXkCi4sAltLcHQCntB7RlvF9AR5ytNrJFCEA2fJS9f4ZgQE6/
+3dm3whAKHZ4ZI4jYUCuABFNiG4JQCohZvHGzWFAnYNcjVcJCkBn/+P343Ri
QHVGuH0DoQpA9VG1wcIQY0CyadUzNi4LQJNVkHHLuWNAYoTbtgzHC0CCzb7k
lVdkQMxPHlB2VQxArHh90UTyZEB6RsNd1eAMQObURaQdmmVAnB8Suc53DUBx
pWE6uDZmQH+bNNJuBA5ADCeHtnzgZkC3BT/aoJwOQPgcAPYCf2dAegQ1zYMq
D0AgRgmvbRpoQN238u9otQ9AWCAcTgLDaEBurQ906yUQQOFugrBYYGlA6ROG
RgNsEEB5bvL42ApqQCerb5zbtxBATaHyuj2yakDzfgCbNQIRQHJIRkBkTmtA
zHM4SnhHEUCnoKOrtPdrQGebHB93khFALW1U2saVbECg29ihYtgRQO5slYK9
MG1Ae2vkydccEkC/HeAQ3thtQIAchvsEZxJA4UJ+YsB1bkCsAbKYJawSQBMZ
JprMH29AqL1cx/r2EkCAIl5LvcZvQOhdXb9ZQBNAH9D03zcxcEBEQe2QsoQT
QIZnPw2mhXBAlkdsBrzOE0AWuTMcddRwQJfGZZ3CExRALuMsHtkpcUCB+3Wb
dl4UQOMm7lyvfXFAR1ZzXbinFEDBJFl95stxQOceVhL96xRAJ/vIkLIgckDf
eLd86zUVQLWL4oXfb3JAQvkc0996FUDvEqv6/79yQM+kdH2VwBVAvEu3Kw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$125296#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0.999999412988389}, 
                  FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0.999999412988389}, DisplayFunction :> 
                  Identity, Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0.999999412988389, 
                   5.438070259327289}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 300.}}, {
       5, 7, 1, {190}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlGk0FAoYhjWoUCjKkGJEUSJLw4yT78uSIkRMEZE9YowUyQmF0kQroUxC
t0KW0k2qMSGyNkOLSDSj7PsSpdzO7Z5z33Pe85zn1/vvJXnQ7b0JQkJCC36X
LfR/nkXZ2HiR5o3/UAr+UAkaO8uoEk7r/3NtKNEsUpbvNoGIJw2bPsxbg3J2
aEZDogOc6iPk5K9yBqNTcaqOZgeh5ILYt5YIb9DKSKy1Lz4Ed3KX3eD1BIL0
R0sDdSkG5FvLpXWnh8KOcsH3zHXh0L25yMX1wQmIzopkyxtHgeQ5VekBrxh4
5TwhUiESCzEbK2ZTc+KBOndxmG6WAJMNboLt3Uy4n6HVujo2Cex2ZRes0b0E
9Tu1GVoqV8Dc4qme8fJkKDezmLYmXAOKSUup63gqvCNns4lV1yFk45GqlmQW
LL5I8q55mAm0c2K9OYpZkBM75n8qLvv3bq9zDfM2DGzutFxy+Q5ILXpHtUu9
B7odDRtSWHlAe1ip0J5zHyi9y/iD24qgZvoF+XBxMTiKhjAHlB+CQEaly/9i
CTBUmvX75x+B9r7rV3mEUhhO9JosFS2D/MpNDpmLn4H/7PTDMxJsuCrXlWCw
iAP175vqqwNeACH1+VIatwIo+/Jtv+hXQTDx+qXQtJdwpzWhRfhXNYg6L3Dy
/voKPNrDP1U31QHHZdRT/XEDrPnk25dwswnYhfTHU6ZceLz7dN1AEg+KxlI6
Pn9ohruXc0ffq76BW3ps4Sb6W0h/w1tZVfYO8rtP7PY63grlk2rnRAzbgCfC
rcyZbodu2YifZo86YFpV1eDLkU6IVfAtNUnrgiWi/PoxcT5cGXHpzIwUgELb
+3Hb4W64VWW/cN7tK2gUNsoX8HqgKG3HJlfTPuBIHvONpg0A93T2rexDQ/B5
htteHTkCM+R58amaUYgZW3E3njcGYvma5sT2cUh3jK3MdJoEzfn2bRqtU/D8
rh6nmPYNbOyZxtS3M9D1g/+sYs93YNymGlk1/wCvDQuDBOM/Ie+9H/e5mBCq
pTf1iSksQJaLvjBtAwHllNIVs6jCeOnz/JZhSxFsU7eJ1K4XRZXgGxXBVosw
4HH/4gf1i7Hkl6HthJU4zpmfSdZvkEDzxLftR3ctxfj+CetkHykUrBVzd+ZI
42l7orx/4zJcG7O++XjbcqwsJDMTemTQ85O5WdqkLJ4s6A2MDViJaSeZ1+h8
OSyx0Xrh7CSPr9fw+s25Ctg/fERWx0IRRctXGiuyV6N6Gzc3o0EJ/4p4ybww
pIyGZ1VMuJMkrEuOmpGeU8H92R8L7IRVcaiI4n1ZXA0dJvoHzS+vw7ItN0Jn
5dWRFG49l39LA8+U/TrtrrERh+cKJWSLNdEBDl6pMdTCwJtjBQLSZtS+qXvV
c70OjrOOHBdo6mIJq+SAp64ehrGmTAUG+khhkTU8t27BuYwwSYEJGauW3a/R
uW+A5+P40dFyFNwzK0d9HUPFVYHWE6sHjVDQdSr/MG0r5jmUej/lGCOl+5hU
3ArEJCElJ9eV25CvWJO1Rc4EDSj0waVEU2Q6ypG/Es2wi1EexZY3R/0k39oU
he14NldKhr7KAp90GH30D9mBfdJ+t31qd6KC2dUgD2UrtAzjGBwI24URuYNC
zk3WmNdBrHNUs8Wgs1m16sa7MSm2fyZY0g4LonXVn3yyw6bIiL0LCu1xOLwi
fmfUHpQ8Kv73JVsH1GLYf/mg5Ii2gemyKqOOSD/EN/Xn0NCDQNg6UL0XHa6T
yIcb96GF/jbtoRYnpDa6qwe1OeMmn2jSSNd+VJ6/qRDc44IyqeUyY0OuuFCn
c0nI5AF0pI0v3UV2x/WyR1e4jbvjLO+bYkjBQay/EKEa5++BLOufG1PXeWKw
RLReHt8TTWoJRmyWF9rJRr7OSfFGd7cpT2aSD9Jzg2YY8b54cqrn/L6TfpiE
B0lw7BBmMNseqQX5Y6j29sOjIwFo2VKs8pQRiKSw1R/iJoIwMrHK4i41GP3c
vmcl/gjGPTqbf4U8Y+A9IjGKYhyC/548JwT/AbWGwBU=
       "], {Developer`PackedArrayForm, CompressedData["
1:eJwl0gFHnAEAgOGvJEmSJElSSZIkOUmSJEmSnCRJcpKcU0mSnCRJkswkmZlJ
kpkkycxsM5MkyczMJEkyMzMzM5P0ZC/PP3gLIyPh4YQgCN4E/0skiWRSSCWN
dDLIJItscsglj3wKKKKYEkopo5wKKqkiRDU11FJHPQ000kQzLbTSRjsdhOmk
i2566KWPfiIMMMgQUWIMM8oY40wwyRRxpplhljnmWWCRJZZ5wENWWGWNRzzm
CU9ZZ4NNtnjGc7bZYZc99nnBS17xmre84z0HHHLEMSec8oGPfOIzXzjjnAsu
ueKar3zjOz/4yS9+84e//OOGWwIjJJJEMimkkkY6GWSSRTY55JJHPgUUUUwJ
pZRRTgWVVBGimhpqqaOeBhppopkWWmmjnQ7CdNJFNz300kc/EQYYZIgoMe4n
H2WMcSaYZIo4d8x9UXQ=
        "], CompressedData["
1:eJwd1Xk0lN//APDB2CVkK/lIyVayRKL0flQqlaxZWrVQ+hCSEtl3ZjVjJipZ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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], ",", 
    RowBox[{"dih", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T5d7c3F0GleP/RcJVHn
jxNA5nwtV11U0z/FyyIHhWIkQAl5XUbzV+E/Hy7qmjJJLkB7GwJwLeHmPxdi
2uMT/zNA6RTWTXQl6z+fNY2q3UI5QOogxONi3e4/r6vbi7UsPkDje1mkf+Dw
Px/Vu07uv0FAUnDe/wY78j9Tocq9E11EQFR2bec2avM/yz4nOkDNRkBC9xCW
dG70P4Ogqk4UcklAVfg1Gop39T9/03tw7+lLQAPF+7qRY/Y/aNONeFxVTkBs
fAcDL0P3P8lLY4y4elBAPw3cUV0v+D+AliZjRrRRQP85uXQtB/k/VkP9BSgI
U0CgFyjBT+35P6NW9JvSVVRAiwsmOzzM+j+SUpK4AI1VQBAlSNn/mfs/obBD
oYLeVkB6fyDGRXf8P1L3mxCIGVhAhgDjz1BE/T8joAdM4W5ZQLLtz4YfIf4/
aq+TegO+WkBZEx+2tvj+P1Onxi+p9ltANibx3+bA/z9cAQ2xokldQJis+b+E
TABAB0T6uB+GXkBYBcLiB7EAQCntB7RlvF9At4ba2jwTAUA2fJS9f4ZgQDDr
1D1vfQFAKHZ4ZI4jYUBtLbSYPOABQCohZvHGzWFA4favVwNLAkBn/+P343Ri
QOVXeA2MswJA9VG1wcIQY0CLrNLFzBQDQJNVkHHLuWNAi6CV9AF+A0CCzb7k
lVdkQH7KXDX83wNArHh90UTyZEC7bdbj0j8EQObURaQdmmVAxpmUm5enBEBx
pWE6uDZmQMAbmmg0CAVADCeHtnzgZkCcjqHKuHAFQPgcAPYCf2dAoIuwvh7S
BUAgRgmvbRpoQFC1Bf1tMQZAWCAcTgLDaEB5uTrNnZgGQOFugrBYYGlA+yrP
Ib74BkB5bvL42ApqQETMrsG4YAdATaHyuj2yakBSwQVPnsYHQHJIRkBkTmtA
GM5cBYIlCECnoKOrtPdrQEPbLAY5jAhALW1U2saVbEDZz5gN9esIQO5slYK9
MG1AFIF1wqlJCUC/HeAQ3thtQO9smxkrrwlA4UJ+YsB1bkDj+V3lvA0KQBMZ
JprMH29AYZTWpRV0CkCAIl5LvcZvQL0S4INn2ApAH9D03zcxcEAIyuqm1DUL
QIZnPw2mhXBAsRUZVgKbC0AWuTMcddRwQK5K3spQ+QtALuMsHtkpcUCwMuB8
Wl8MQOMm7lyvfXFAmKBjDmTDDEDBJFl95stxQHlBUBmYIA1AJ/vIkLIgckBR
i9tWgYUNQLWL4oXfb3JATvcyAZrjDUDvEqv6/79yQPwC4SG1Qg5AFa+3mw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$125353#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 3.7825720450204}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T5d7c3F0GleP/RcJVHn
jxNA5nwtV11U0z/FyyIHhWIkQAl5XUbzV+E/Hy7qmjJJLkB7GwJwLeHmPxdi
2uMT/zNA6RTWTXQl6z+fNY2q3UI5QOogxONi3e4/r6vbi7UsPkDje1mkf+Dw
Px/Vu07uv0FAUnDe/wY78j9Tocq9E11EQFR2bec2avM/yz4nOkDNRkBC9xCW
dG70P4Ogqk4UcklAVfg1Gop39T9/03tw7+lLQAPF+7qRY/Y/aNONeFxVTkBs
fAcDL0P3P8lLY4y4elBAPw3cUV0v+D+AliZjRrRRQP85uXQtB/k/VkP9BSgI
U0CgFyjBT+35P6NW9JvSVVRAiwsmOzzM+j+SUpK4AI1VQBAlSNn/mfs/obBD
oYLeVkB6fyDGRXf8P1L3mxCIGVhAhgDjz1BE/T8joAdM4W5ZQLLtz4YfIf4/
aq+TegO+WkBZEx+2tvj+P1Onxi+p9ltANibx3+bA/z9cAQ2xokldQJis+b+E
TABAB0T6uB+GXkBYBcLiB7EAQCntB7RlvF9At4ba2jwTAUA2fJS9f4ZgQDDr
1D1vfQFAKHZ4ZI4jYUBtLbSYPOABQCohZvHGzWFA4favVwNLAkBn/+P343Ri
QOVXeA2MswJA9VG1wcIQY0CLrNLFzBQDQJNVkHHLuWNAi6CV9AF+A0CCzb7k
lVdkQH7KXDX83wNArHh90UTyZEC7bdbj0j8EQObURaQdmmVAxpmUm5enBEBx
pWE6uDZmQMAbmmg0CAVADCeHtnzgZkCcjqHKuHAFQPgcAPYCf2dAoIuwvh7S
BUAgRgmvbRpoQFC1Bf1tMQZAWCAcTgLDaEB5uTrNnZgGQOFugrBYYGlA+yrP
Ib74BkB5bvL42ApqQETMrsG4YAdATaHyuj2yakBSwQVPnsYHQHJIRkBkTmtA
GM5cBYIlCECnoKOrtPdrQEPbLAY5jAhALW1U2saVbEDZz5gN9esIQO5slYK9
MG1AFIF1wqlJCUC/HeAQ3thtQO9smxkrrwlA4UJ+YsB1bkDj+V3lvA0KQBMZ
JprMH29AYZTWpRV0CkCAIl5LvcZvQL0S4INn2ApAH9D03zcxcEAIyuqm1DUL
QIZnPw2mhXBAsRUZVgKbC0AWuTMcddRwQK5K3spQ+QtALuMsHtkpcUCwMuB8
Wl8MQOMm7lyvfXFAmKBjDmTDDEDBJFl95stxQHlBUBmYIA1AJ/vIkLIgckBR
i9tWgYUNQLWL4oXfb3JATvcyAZrjDUDvEqv6/79yQPwC4SG1Qg5AFa+3mw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$125353#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 3.7825720450204}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 300.}}, {
       5, 7, 1, {190}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlGk0FAoYhjWoUCjKkGJEUSJLw4yT78uSIkRMEZE9YowUyQmF0kQroUxC
t0KW0k2qMSGyNkOLSDSj7PsSpdzO7Z5z33Pe85zn1/vvJXnQ7b0JQkJCC36X
LfR/nkXZ2HiR5o3/UAr+UAkaO8uoEk7r/3NtKNEsUpbvNoGIJw2bPsxbg3J2
aEZDogOc6iPk5K9yBqNTcaqOZgeh5ILYt5YIb9DKSKy1Lz4Ed3KX3eD1BIL0
R0sDdSkG5FvLpXWnh8KOcsH3zHXh0L25yMX1wQmIzopkyxtHgeQ5VekBrxh4
5TwhUiESCzEbK2ZTc+KBOndxmG6WAJMNboLt3Uy4n6HVujo2Cex2ZRes0b0E
9Tu1GVoqV8Dc4qme8fJkKDezmLYmXAOKSUup63gqvCNns4lV1yFk45GqlmQW
LL5I8q55mAm0c2K9OYpZkBM75n8qLvv3bq9zDfM2DGzutFxy+Q5ILXpHtUu9
B7odDRtSWHlAe1ip0J5zHyi9y/iD24qgZvoF+XBxMTiKhjAHlB+CQEaly/9i
CTBUmvX75x+B9r7rV3mEUhhO9JosFS2D/MpNDpmLn4H/7PTDMxJsuCrXlWCw
iAP175vqqwNeACH1+VIatwIo+/Jtv+hXQTDx+qXQtJdwpzWhRfhXNYg6L3Dy
/voKPNrDP1U31QHHZdRT/XEDrPnk25dwswnYhfTHU6ZceLz7dN1AEg+KxlI6
Pn9ohruXc0ffq76BW3ps4Sb6W0h/w1tZVfYO8rtP7PY63grlk2rnRAzbgCfC
rcyZbodu2YifZo86YFpV1eDLkU6IVfAtNUnrgiWi/PoxcT5cGXHpzIwUgELb
+3Hb4W64VWW/cN7tK2gUNsoX8HqgKG3HJlfTPuBIHvONpg0A93T2rexDQ/B5
htteHTkCM+R58amaUYgZW3E3njcGYvma5sT2cUh3jK3MdJoEzfn2bRqtU/D8
rh6nmPYNbOyZxtS3M9D1g/+sYs93YNymGlk1/wCvDQuDBOM/Ie+9H/e5mBCq
pTf1iSksQJaLvjBtAwHllNIVs6jCeOnz/JZhSxFsU7eJ1K4XRZXgGxXBVosw
4HH/4gf1i7Hkl6HthJU4zpmfSdZvkEDzxLftR3ctxfj+CetkHykUrBVzd+ZI
42l7orx/4zJcG7O++XjbcqwsJDMTemTQ85O5WdqkLJ4s6A2MDViJaSeZ1+h8
OSyx0Xrh7CSPr9fw+s25Ctg/fERWx0IRRctXGiuyV6N6Gzc3o0EJ/4p4ybww
pIyGZ1VMuJMkrEuOmpGeU8H92R8L7IRVcaiI4n1ZXA0dJvoHzS+vw7ItN0Jn
5dWRFG49l39LA8+U/TrtrrERh+cKJWSLNdEBDl6pMdTCwJtjBQLSZtS+qXvV
c70OjrOOHBdo6mIJq+SAp64ehrGmTAUG+khhkTU8t27BuYwwSYEJGauW3a/R
uW+A5+P40dFyFNwzK0d9HUPFVYHWE6sHjVDQdSr/MG0r5jmUej/lGCOl+5hU
3ArEJCElJ9eV25CvWJO1Rc4EDSj0waVEU2Q6ypG/Es2wi1EexZY3R/0k39oU
he14NldKhr7KAp90GH30D9mBfdJ+t31qd6KC2dUgD2UrtAzjGBwI24URuYNC
zk3WmNdBrHNUs8Wgs1m16sa7MSm2fyZY0g4LonXVn3yyw6bIiL0LCu1xOLwi
fmfUHpQ8Kv73JVsH1GLYf/mg5Ii2gemyKqOOSD/EN/Xn0NCDQNg6UL0XHa6T
yIcb96GF/jbtoRYnpDa6qwe1OeMmn2jSSNd+VJ6/qRDc44IyqeUyY0OuuFCn
c0nI5AF0pI0v3UV2x/WyR1e4jbvjLO+bYkjBQay/EKEa5++BLOufG1PXeWKw
RLReHt8TTWoJRmyWF9rJRr7OSfFGd7cpT2aSD9Jzg2YY8b54cqrn/L6TfpiE
B0lw7BBmMNseqQX5Y6j29sOjIwFo2VKs8pQRiKSw1R/iJoIwMrHK4i41GP3c
vmcl/gjGPTqbf4U8Y+A9IjGKYhyC/548JwT/AbWGwBU=
       "], {Developer`PackedArrayForm, CompressedData["
1:eJwl0gFHnAEAgOGvJEmSJElSSZIkOUmSJEmSnCRJcpKcU0mSnCRJkswkmZlJ
kpkkycxsM5MkyczMJEkyMzMzM5P0ZC/PP3gLIyPh4YQgCN4E/0skiWRSSCWN
dDLIJItscsglj3wKKKKYEkopo5wKKqkiRDU11FJHPQ000kQzLbTSRjsdhOmk
i2566KWPfiIMMMgQUWIMM8oY40wwyRRxpplhljnmWWCRJZZ5wENWWGWNRzzm
CU9ZZ4NNtnjGc7bZYZc99nnBS17xmre84z0HHHLEMSec8oGPfOIzXzjjnAsu
ueKar3zjOz/4yS9+84e//OOGWwIjJJJEMimkkkY6GWSSRTY55JJHPgUUUUwJ
pZRRTgWVVBGimhpqqaOeBhppopkWWmmjnQ7CdNJFNz300kc/EQYYZIgoMe4n
H2WMcSaYZIo4d8x9UXQ=
        "], CompressedData["
1:eJwN1fcjFAoAB3CRjEIkElFRSgrJqB7fK4QyciorlS0yLsqql9wZZStb5tEZ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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8521289733573065`*^9, 3.8521293904665227`*^9, 3.8521294959956727`*^9, 
   3.8521297046089582`*^9, {3.8521304808077693`*^9, 3.8521304937170334`*^9}, 
   3.8522218314475174`*^9, 3.852222096692867*^9, 3.861386502212418*^9, 
   3.861386846419856*^9, 3.861387536864065*^9},
 CellLabel->
  "Out[1066]=",ExpressionUUID->"298d6290-95d5-48a7-aa61-608c0c1e3601"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, 
   3.8521288666663456`*^9},
 CellLabel->
  "In[1067]:=",ExpressionUUID->"952d9f66-ccde-4559-8961-287a66e4cbda"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVj3k41HkAh1EMQ3L9aBPLdig9STcV38+m5Cg1ophcg8oomfmJHutqyxEy
hal0oWIr5SiM3DabqNHiaZKOp9q0RTE/lCux7R/v8/7z/vOa+oe67lFSUFDw
+sH/Lt058bWvsMuW5OfFT07JSXKTTydHVEHSd/4dK5XLyannR6OMRQ8In+82
a9aAnPQvvKmcUtBOwrq34PSwnIi7xa3TRZ2kpadUz2NSTtbmxp6OE74iJM/B
snUaQ5glZRYxBW/JtuiV/4ypMuRMz6XhkbQPhH1Nc9pRPYbwH2Rwy+N6yQo+
72rlbIasz0+qo4V9ZE7c42ALU4YIS6waIwoGiEjrcG6xBUMMDvySOpA2QlSK
ffpinBmi8GKOTZvKGJGwt5pPuDKk19FAXhQ3TmTkhXomlyE1Zho7Dgi/E6Vv
3s+Vghlye+C3tLACRSiMtkjqkhmyqzDQvT+NhXhZZFPJI4ZIu3lF3k6quCez
7J79hCGY48tqVVHD2BC//MRLhpinelbejGOjZUznYEIfQyaCXIz4whko5rFv
1M0cIBydi4PCAm1IeR3C724DZKQ1oepzmgGaVZLFHW8GSKle+4zE1IV4Zt7H
4Zh/IYLFK9tq1y3HnutPXN0Nhon+5hFxi64Vim6uN9/UNkKGag2CrwTbgmTu
G/ISjZEEX+NZZ803wPO3qH5m9jdyK833mJ3vJpgLVoXXV00Qw0ivA6PxDoio
ajQ+5jhJrt140Zp4yBm/H+dWXqqYIo+TkiuirrqA62+1bSJHASmylxrzH2/H
tx0VAZHuimi73xGtZecKcXh4rrmKEro13lgWd+5Ao0Rq3fCXEpIiLC6v5bjD
JCfSqjh8GkZWi90je3eCdjnek7NyOtSfdjqsj/ZAXNmRVdvk01F01mv006An
rFefvf3oojKMS0Y/uSTvhmd73vxdHiow+iS7kD3dG0YbYxy6VFjojX548nKO
D14rXA0MaGShMMKFJ/7JD4nNm/gjUapYgmcej2V+mByIWikxU4Nuecjg28s8
FJo4vwt7q4Zfq+f27vfzx4Z12Q/DRGz8WeKgaGUYgMMziwwL16jjGiey6tX7
AGzzsWzt6leH7NjD9rErgTjSrjRv/zkNBPPMUuWhe3DE7WBkN2cGOBZDAWbW
e9GUoTt0SUUTcSden5d92YtF0X2Wz4s0oXemM8y7YR/Um7MXDAbOBGPJFOyO
DUKClPm4laUF4+rDihet+Ni8J62Dw9VCKcMeL1cKRq1AWGJTpoWTFXXb7euD
0WyzKXySpY2ORbGOJan7Yat/n3XFXxteS3xyTzkdQHHewiaTCm1YmRTqlyqH
QDZNGvJUTQdRdaylxW0hcBsKdeUH6EC5/2i+qeggaBNu5VuJDoab1epCdoci
xnA8a7m2Li62TI3H6AiwuGnp3Gq+LngjbPsjAgG++B58s7xGF13jhv6hTwVw
76pvjqH08NXepvDcKiEueOi21QTpoYqtr/o+Q4jta+x8bar0sDzvywqjUSHu
e5vOOaFDwSXxnejUThra8+7ZdwZS2Owk2rLag4ab5G6c/V4K0LRmv/SkYVJw
RVK+j8KyM6IEM28aNgEcY3EwBb0/rKPrAmhMyYxl2wUUXtw/yf8soKGbnvOm
JYpCkPL6jQ6pNGaP7RVUZVDgtfyr2H+Cxv5Yo6BFYgrctPT6TBGNbKnUO+s0
hS3Uh7Wv02lkCfTtIrIoLJ2fsSwii8bmdO7XZdkUhjd+NM7Lp8FWk45ev0FB
rpr50vEaDX2/uW0GNyl8lNqcl1+ncWdFRH7iLQpdbpnUuls04r9rOgUWU6gJ
tNXouENjUqYd9XM5hfKFPS2Hy2gMP3LcIJJQKPqcmWQk+fGfFcv6XkEh91CP
Er+SxhLe69TnVRTOWYkbNKtpGJWpOzvWUMiYsI0tq6Hhm7JK9W4thZSGnnXc
uh/9TO/GBfUUjsWLx6bqadwLORp9uoHCf37PqP4=
       "]]},
     Annotation[#, "Charting`Private`Tag$125414#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVlHk41Ykeh+3rcYikstxQY8tadEK+37GTTKZR9qxlOeL8aqxZkuVK51TW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       "]]},
     Annotation[#, "Charting`Private`Tag$125414#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.852221844157041*^9, 3.852222096788887*^9, 
  3.86138650228757*^9, 3.861386846485487*^9, 3.861387536991946*^9},
 CellLabel->
  "Out[1067]=",ExpressionUUID->"04305653-30d5-4a7a-877c-c107db995d26"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}], "/", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3000"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, {
   3.852124125642785*^9, 3.852124141635003*^9}},
 CellLabel->
  "In[1068]:=",ExpressionUUID->"362943a4-e2b0-49c8-80d5-2561877610a3"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13k4VG0UAHBaiIjsFYVQ1mQN6T3WUPa1rJGl7EuyVNaxzphBUZKtrEmF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       "]]},
     Annotation[#, "Charting`Private`Tag$125463#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8521241496341267`*^9, 3.8521288800069914`*^9, 
  3.8521295058238277`*^9, 3.8521297161720333`*^9, 3.8521305058280315`*^9, 
  3.852221855699004*^9, 3.852222109355008*^9, 3.861386502348812*^9, 
  3.861386846540291*^9, 3.861387537073636*^9},
 CellLabel->
  "Out[1068]=",ExpressionUUID->"fd553d32-dc92-43f2-85a8-e92be96d1323"]
}, Open  ]]
},
WindowSize->{1243, 770},
WindowMargins->{{49, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 838, 15, 52, "Input",ExpressionUUID->"cb21c7c6-dc94-4bc3-9476-b0b5d034bbb4"],
Cell[1398, 37, 2343, 58, 115, "Input",ExpressionUUID->"ea60df7e-34a6-4c5b-b260-4c0ba7449a99"],
Cell[3744, 97, 354, 7, 30, "Input",ExpressionUUID->"82978fa8-6d69-43f3-b12c-ab4efd7c3ce1"],
Cell[CellGroupData[{
Cell[4123, 108, 480, 10, 30, "Input",ExpressionUUID->"f6965048-5747-4dd7-8f85-b3a359a09027"],
Cell[4606, 120, 733, 14, 57, "Output",ExpressionUUID->"eef3f92d-861c-4e4d-81e5-083d288488f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5376, 139, 641, 16, 30, "Input",ExpressionUUID->"4fa0517e-dfa6-42e8-ae35-99614f1d0edc"],
Cell[6020, 157, 713, 15, 64, "Output",ExpressionUUID->"388dacf6-a1da-4c6a-ac1b-71699e942ec7"]
}, Open  ]],
Cell[6748, 175, 455, 11, 30, "Input",ExpressionUUID->"d5d7d418-6488-4e43-8ad8-d7b6e2cb5566"],
Cell[CellGroupData[{
Cell[7228, 190, 916, 23, 30, "Input",ExpressionUUID->"25fb845c-9afe-4214-9316-c4d7ec15a13d"],
Cell[8147, 215, 1060, 24, 66, "Output",ExpressionUUID->"33178230-0457-475d-aeae-12f4e03bb31f"]
}, Open  ]],
Cell[9222, 242, 560, 14, 30, "Input",ExpressionUUID->"671d1813-c94e-4f5c-8a63-6b76fadcdda2"],
Cell[CellGroupData[{
Cell[9807, 260, 475, 11, 30, "Input",ExpressionUUID->"e79b034f-0f7f-420c-afd4-b76835fa6bc6"],
Cell[10285, 273, 726, 15, 58, "Output",ExpressionUUID->"f476a396-7a60-48c3-897e-cfdcef6b0f24"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11048, 293, 269, 6, 30, "Input",ExpressionUUID->"c1a895c8-3ec0-4572-b629-9474bce95644"],
Cell[11320, 301, 624, 13, 59, "Output",ExpressionUUID->"42135b03-fae7-43b2-aef5-9e7a306a0943"]
}, Open  ]],
Cell[11959, 317, 404, 10, 30, "Input",ExpressionUUID->"7ac1198f-a464-4ae9-b60a-0fa9abb193ba"],
Cell[12366, 329, 350, 9, 49, "Input",ExpressionUUID->"c062a907-3048-4101-b550-1a602178787e"],
Cell[12719, 340, 218, 4, 30, "Input",ExpressionUUID->"c005581f-effa-4770-8ce6-b2584c9744c6"],
Cell[CellGroupData[{
Cell[12962, 348, 507, 12, 30, "Input",ExpressionUUID->"0b10577e-4069-4410-aff5-a67f7fe22f40"],
Cell[13472, 362, 464, 7, 34, "Output",ExpressionUUID->"9bd92276-bb46-4c42-8e52-f23ef09eecbe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13973, 374, 581, 12, 30, "Input",ExpressionUUID->"a0d4e923-9af5-45a9-b31e-aaa7daa6c5a5"],
Cell[14557, 388, 1014, 25, 68, "Output",ExpressionUUID->"fef884b0-b34f-4676-a4bc-576ed861cba0"]
}, Open  ]],
Cell[15586, 416, 536, 13, 30, "Input",ExpressionUUID->"2e68a52b-abef-4976-95f3-7cbbc6b3163d"],
Cell[CellGroupData[{
Cell[16147, 433, 812, 23, 66, "Input",ExpressionUUID->"e8854b6a-f3b4-41a8-94d0-aaf9ba596d2b"],
Cell[16962, 458, 1464, 41, 87, "Output",ExpressionUUID->"8b6a0007-4cde-466d-9090-7c58f3d47611"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18463, 504, 344, 7, 30, "Input",ExpressionUUID->"b2ce0246-5b7f-4125-bf12-35eadd073cc9"],
Cell[18810, 513, 877, 16, 60, "Message",ExpressionUUID->"c8121407-62e7-4420-bf93-8e030e89ceb5"],
Cell[19690, 531, 1901, 54, 87, "Output",ExpressionUUID->"3b3299a1-45d6-488f-a8ca-a945b669bf5b"]
}, Open  ]],
Cell[21606, 588, 271, 6, 30, "Input",ExpressionUUID->"805c3821-37d7-49b9-bdb9-a1c60a885047"],
Cell[21880, 596, 918, 26, 85, "Input",ExpressionUUID->"6b6a3c9d-80fe-43d8-a75e-5ed70e950bf4"],
Cell[22801, 624, 273, 6, 30, "Input",ExpressionUUID->"ae5e87e3-a211-48e1-ac8e-f272ddc6e215"],
Cell[CellGroupData[{
Cell[23099, 634, 330, 8, 30, "Input",ExpressionUUID->"3b1ad960-ab22-46de-acf5-78f5e65366ae"],
Cell[23432, 644, 542, 10, 34, "Output",ExpressionUUID->"64851964-1c97-4702-8c06-ef194163aa38"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24011, 659, 734, 16, 30, "Input",ExpressionUUID->"6708e53a-58db-4623-b5fa-f57c3899c4ae"],
Cell[24748, 677, 516, 8, 34, "Output",ExpressionUUID->"162b5561-3067-4443-bba6-f5bff1f53c6e"]
}, Open  ]],
Cell[25279, 688, 257, 5, 30, "Input",ExpressionUUID->"e9c47dca-ddfe-4817-aef0-bd185b9b4ec3"],
Cell[CellGroupData[{
Cell[25561, 697, 339, 8, 30, "Input",ExpressionUUID->"4f29be76-7bab-497d-827d-76d6240fd6d8"],
Cell[25903, 707, 1231, 33, 88, "Output",ExpressionUUID->"6eb95c91-0039-4c93-8ef7-939714e94ac3"]
}, Open  ]],
Cell[27149, 743, 574, 11, 30, "Input",ExpressionUUID->"292642b2-b58d-4450-805b-067cbe7fdb10"],
Cell[CellGroupData[{
Cell[27748, 758, 592, 11, 30, "Input",ExpressionUUID->"28dc1692-73b7-4e17-b0dc-6228604e3cb4"],
Cell[28343, 771, 1161, 26, 61, "Output",ExpressionUUID->"bc00b9f6-5540-4db1-94c4-62ab9b5913d9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29541, 802, 612, 14, 30, "Input",ExpressionUUID->"2a769c66-0636-43c8-bfb0-1e906775d018"],
Cell[30156, 818, 1353, 35, 59, "Output",ExpressionUUID->"c75b0754-daba-4cc3-b55a-363dbeb906d5"]
}, Open  ]],
Cell[31524, 856, 270, 6, 30, "Input",ExpressionUUID->"074ea169-89cd-43eb-930f-f08e8ba96b09"],
Cell[CellGroupData[{
Cell[31819, 866, 408, 9, 30, "Input",ExpressionUUID->"eb92df4c-5651-4f54-b289-ba4f93144542"],
Cell[32230, 877, 596, 12, 58, "Output",ExpressionUUID->"4edc3b95-1dc4-4b67-8f86-fd36fd7ed473"]
}, Open  ]],
Cell[32841, 892, 208, 4, 30, "Input",ExpressionUUID->"afcb4998-50d5-4bea-a001-d20ddb8ba456"],
Cell[33052, 898, 407, 9, 30, "Input",ExpressionUUID->"d5c1f21f-9406-4b4f-b671-45c4e6dfe44c"],
Cell[33462, 909, 457, 12, 55, "Input",ExpressionUUID->"b5b2af8a-821f-4296-9e42-5068ea68075d"],
Cell[CellGroupData[{
Cell[33944, 925, 206, 4, 30, "Input",ExpressionUUID->"636dc89e-5e09-4596-9bee-2cf1480dd0b2"],
Cell[34153, 931, 539, 13, 69, "Output",ExpressionUUID->"2583f018-dd3b-4f4d-9a29-e5276da861b9"]
}, Open  ]],
Cell[34707, 947, 781, 17, 52, "Input",ExpressionUUID->"04528a2a-0bcd-4ced-ac52-3de6bf03cbde"],
Cell[CellGroupData[{
Cell[35513, 968, 334, 8, 30, "Input",ExpressionUUID->"51f2c909-ae6e-404a-929c-62767e7d10ef"],
Cell[35850, 978, 743, 17, 58, "Output",ExpressionUUID->"f61bc30f-0554-4c98-b107-5e08c880b4ee"]
}, Open  ]],
Cell[36608, 998, 287, 6, 30, "Input",ExpressionUUID->"0df6fc1e-990f-4881-943e-716347f3716f"],
Cell[CellGroupData[{
Cell[36920, 1008, 326, 7, 30, "Input",ExpressionUUID->"0afed7a9-81cf-437a-b834-71056bde53af"],
Cell[37249, 1017, 722, 16, 57, "Output",ExpressionUUID->"0a26ee99-906b-4224-add4-c6a1ee4f46b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38008, 1038, 519, 13, 30, "Input",ExpressionUUID->"00a7e422-fee2-438c-b3dd-5698e61a2cf6"],
Cell[38530, 1053, 837, 19, 58, "Output",ExpressionUUID->"a6fbf833-2637-4e8e-9449-cb937af97b84"]
}, Open  ]],
Cell[39382, 1075, 298, 7, 30, "Input",ExpressionUUID->"b4ffaa2d-74a5-4ef8-b19d-807a8c4870b4"],
Cell[39683, 1084, 624, 16, 52, "Input",ExpressionUUID->"392de634-aa3b-48db-b7c4-df97c481f97c"],
Cell[40310, 1102, 347, 8, 30, "Input",ExpressionUUID->"cc0d0b27-1416-4008-9a0d-e11081ce93a4"],
Cell[CellGroupData[{
Cell[40682, 1114, 349, 8, 30, "Input",ExpressionUUID->"efa3b49a-cede-4628-8036-e6f750c5a2ef"],
Cell[41034, 1124, 852, 21, 61, "Output",ExpressionUUID->"accd8a8f-6d68-4888-9725-dbea6ea82ccb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41923, 1150, 296, 7, 30, "Input",ExpressionUUID->"5f6834f1-12c7-469e-84ad-5dd9e22e3453"],
Cell[42222, 1159, 1125, 29, 61, "Output",ExpressionUUID->"05820ce9-7128-4cd8-adf7-7b61397701da"]
}, Open  ]],
Cell[43362, 1191, 333, 7, 30, "Input",ExpressionUUID->"38f723f9-e208-4147-9ffb-ce9f7df8b1a7"],
Cell[CellGroupData[{
Cell[43720, 1202, 262, 6, 30, "Input",ExpressionUUID->"13b1e7e0-59e9-4c40-903a-4b9703aab0e8"],
Cell[43985, 1210, 226, 4, 34, "Output",ExpressionUUID->"45a5fbe0-5b7d-44c6-9d7d-e5cde8afbb4c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44248, 1219, 727, 19, 30, "Input",ExpressionUUID->"c5ba50b8-bb4b-4070-804b-f40c11217fb4"],
Cell[44978, 1240, 1967, 56, 59, "Output",ExpressionUUID->"1be3a1a4-ffd8-4c18-b39a-9557f5ac4000"]
}, Open  ]],
Cell[46960, 1299, 346, 8, 30, "Input",ExpressionUUID->"d566285f-0c7b-45e8-bc0d-327bb776fd15"],
Cell[CellGroupData[{
Cell[47331, 1311, 478, 9, 30, "Input",ExpressionUUID->"e5629228-dd94-46e0-824b-e9b97a37aafd"],
Cell[47812, 1322, 740, 16, 57, "Output",ExpressionUUID->"3ca05ba4-79ab-41ac-af01-55b3932359cb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48589, 1343, 322, 7, 30, "Input",ExpressionUUID->"b4e6d041-c22c-43c1-aa22-dd6036712378"],
Cell[48914, 1352, 746, 17, 57, "Output",ExpressionUUID->"ed9163f4-22b6-4814-9174-baa49423d82d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49697, 1374, 315, 7, 30, "Input",ExpressionUUID->"f6ba5116-ef24-409d-a965-9410a080fa50"],
Cell[50015, 1383, 348, 6, 34, "Output",ExpressionUUID->"3175ec85-0758-4e56-80a4-35de2909fe4f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50400, 1394, 826, 20, 30, "Input",ExpressionUUID->"32960b91-ff19-4920-b5f4-1eed50d60a48"],
Cell[51229, 1416, 1103, 29, 58, "Output",ExpressionUUID->"8e38503b-5304-4107-ae7d-00e70c1ef9c0"]
}, Open  ]],
Cell[52347, 1448, 609, 15, 52, "Input",ExpressionUUID->"3c7ea884-fcde-4a7e-86d0-941f0be15b46"],
Cell[52959, 1465, 432, 8, 30, "Input",ExpressionUUID->"879748e4-4d70-4dca-9eaf-ed67e218c967"],
Cell[CellGroupData[{
Cell[53416, 1477, 179, 3, 30, "Input",ExpressionUUID->"cddcc760-fb28-4f7b-a9d9-ff3675855cb5"],
Cell[53598, 1482, 1214, 33, 59, "Output",ExpressionUUID->"486f37a2-82c1-4d4f-8fb6-455f550d4e3a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54849, 1520, 813, 18, 30, "Input",ExpressionUUID->"594fdd82-c597-4243-80ec-1c64eb5ff193"],
Cell[55665, 1540, 1230, 33, 69, "Output",ExpressionUUID->"1d46c940-f585-4d6e-b3ee-db9a3a5fabaf"]
}, Open  ]],
Cell[56910, 1576, 400, 9, 30, "Input",ExpressionUUID->"6ec93d16-8bdc-4ae6-9e7a-a766203f2f5f"],
Cell[CellGroupData[{
Cell[57335, 1589, 1215, 37, 67, "Input",ExpressionUUID->"18196df7-6b8b-4941-9fcb-6392536d611a"],
Cell[58553, 1628, 1317, 39, 70, "Output",ExpressionUUID->"baefc91b-4ec4-4fb4-842e-8e0463f1b211"]
}, Open  ]],
Cell[59885, 1670, 265, 5, 30, "Input",ExpressionUUID->"f5cab13b-2fbf-450c-b2f9-bc30c515c4d8"],
Cell[CellGroupData[{
Cell[60175, 1679, 178, 3, 30, "Input",ExpressionUUID->"9aac8e5a-2bfd-415e-8190-8b01498c086b"],
Cell[60356, 1684, 717, 16, 58, "Output",ExpressionUUID->"722a60e9-06ab-407d-aedd-0dfb413edb37"]
}, Open  ]],
Cell[61088, 1703, 321, 7, 30, "Input",ExpressionUUID->"c0ce7030-2752-40fa-b1c0-c0fe02ce3023"],
Cell[CellGroupData[{
Cell[61434, 1714, 707, 15, 30, "Input",ExpressionUUID->"7484bbc1-6f60-429b-b7f3-a25db1349d38"],
Cell[62144, 1731, 2029, 55, 149, "Output",ExpressionUUID->"2ad39d94-4800-4113-abe9-df19ed345057"]
}, Open  ]],
Cell[64188, 1789, 547, 12, 30, "Input",ExpressionUUID->"6d01b5e6-b6c3-4c4b-ab47-5d07f12bb74a"],
Cell[CellGroupData[{
Cell[64760, 1805, 2467, 63, 147, "Input",ExpressionUUID->"1cc34603-e108-48bd-a8c5-255884ae4863"],
Cell[67230, 1870, 2198, 59, 149, "Output",ExpressionUUID->"06a7cd09-7d37-4575-abf4-b26b24a9a11d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69465, 1934, 207, 4, 30, "Input",ExpressionUUID->"a8412832-c458-46a6-9719-912ca37fa949"],
Cell[69675, 1940, 539, 13, 69, "Output",ExpressionUUID->"195cc64c-1461-4714-9f58-062a565ddcff"]
}, Open  ]],
Cell[70229, 1956, 216, 4, 30, "Input",ExpressionUUID->"9f219e7c-97a5-4e45-acfa-eeada032eee7"],
Cell[70448, 1962, 631, 17, 66, "Input",ExpressionUUID->"7cad23fe-7166-4ce7-9e12-20e5cd1a83a2"],
Cell[71082, 1981, 241, 5, 30, "Input",ExpressionUUID->"6aa609ae-0de0-41ee-a6fe-9dc700108989"],
Cell[CellGroupData[{
Cell[71348, 1990, 182, 3, 30, "Input",ExpressionUUID->"1cf35150-ebc7-4172-8780-f027f5a055c2"],
Cell[71533, 1995, 749, 18, 58, "Output",ExpressionUUID->"8a1ed67e-c5c9-4260-af5c-0502cc1bc3b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72319, 2018, 694, 17, 30, "Input",ExpressionUUID->"af5e8ca6-a929-44f6-a4ab-51c2b843138f"],
Cell[73016, 2037, 815, 19, 68, "Output",ExpressionUUID->"15c7783c-8f67-4864-b01d-db52424bd8cf"]
}, Open  ]],
Cell[73846, 2059, 495, 10, 30, "Input",ExpressionUUID->"26a33294-6f31-4464-9388-4ec5eecb5f9a"],
Cell[CellGroupData[{
Cell[74366, 2073, 1160, 30, 66, "Input",ExpressionUUID->"63bf9988-dc69-4d36-8a4a-201c574d52ba"],
Cell[75529, 2105, 994, 25, 69, "Output",ExpressionUUID->"682a8959-8f03-4062-b1c5-d1d5b8d9faef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76560, 2135, 580, 12, 30, "Input",ExpressionUUID->"985cae73-98cc-4d60-8226-9856fe03dfab"],
Cell[77143, 2149, 4573, 125, 222, "Output",ExpressionUUID->"69cbca0c-f671-48c3-ac6b-0a14a9162a1d"]
}, Open  ]],
Cell[81731, 2277, 254, 5, 30, "Input",ExpressionUUID->"056ce359-ff69-4d5d-bcbc-b80d003f7526"],
Cell[81988, 2284, 498, 15, 30, "Input",ExpressionUUID->"fe37d8ca-e77a-4a84-83f2-d0b75799e18d"],
Cell[82489, 2301, 889, 16, 30, "Input",ExpressionUUID->"30e2088e-d8ae-41f0-bc4f-6fa17c792ab4"],
Cell[83381, 2319, 889, 16, 30, "Input",ExpressionUUID->"58df71e1-5df5-43b8-9eb6-00b4569c1413"],
Cell[CellGroupData[{
Cell[84295, 2339, 301, 7, 30, "Input",ExpressionUUID->"e84b0a42-4850-4df6-86dd-085c4eb76363"],
Cell[84599, 2348, 270, 5, 34, "Output",ExpressionUUID->"d8a6b396-4da8-40d3-acfd-7fe31463032b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84906, 2358, 352, 8, 30, "Input",ExpressionUUID->"8d6336bb-d203-459f-8c41-f8fb5dd44314"],
Cell[85261, 2368, 249, 4, 34, "Output",ExpressionUUID->"6e6ee26d-4f71-4edc-aa1a-bd0efbbb08eb"]
}, Open  ]],
Cell[85525, 2375, 242, 5, 30, "Input",ExpressionUUID->"4ce40572-576e-4635-802f-19c9a666085d"],
Cell[CellGroupData[{
Cell[85792, 2384, 261, 5, 30, "Input",ExpressionUUID->"78ec0ff8-9783-4d91-ace8-52a076747571"],
Cell[86056, 2391, 580, 12, 58, "Output",ExpressionUUID->"dfd5eab9-fef5-46fb-8a47-8476b7e52d92"]
}, Open  ]],
Cell[86651, 2406, 286, 6, 30, "Input",ExpressionUUID->"212af77f-2ae5-42b9-8364-e9c5211f2918"],
Cell[CellGroupData[{
Cell[86962, 2416, 1619, 42, 73, "Input",ExpressionUUID->"f1a19301-5a44-4882-9273-52dadb4d26e1"],
Cell[88584, 2460, 1494, 36, 76, "Output",ExpressionUUID->"74eb48e2-18bf-48c4-8979-e50697e78040"]
}, Open  ]],
Cell[90093, 2499, 490, 12, 30, "Input",ExpressionUUID->"df91d49f-9158-446f-bdb2-f34103ca6cb8"],
Cell[90586, 2513, 320, 6, 30, "Input",ExpressionUUID->"28844915-54e3-4422-a22a-c3d9fbb0fa9b"],
Cell[90909, 2521, 590, 11, 30, "Input",ExpressionUUID->"cb4d3267-2341-444e-a694-c5987824ab9e"],
Cell[91502, 2534, 266, 5, 30, "Input",ExpressionUUID->"21a3f675-fce1-4a89-a041-c1fcdfd47ff8"],
Cell[91771, 2541, 330, 7, 30, "Input",ExpressionUUID->"d4f7e667-d918-4a6b-aa14-a56c199dafa2"],
Cell[CellGroupData[{
Cell[92126, 2552, 228, 5, 30, "Input",ExpressionUUID->"2dc65262-3214-427d-a0af-0503579834d3"],
Cell[92357, 2559, 2758, 80, 108, "Output",ExpressionUUID->"97da32e1-5e1f-4150-a0cd-22384e88eec1"]
}, Open  ]],
Cell[95130, 2642, 355, 7, 30, "Input",ExpressionUUID->"02d0c4fc-a834-42ad-bdb4-2fa1cdf1324b"],
Cell[CellGroupData[{
Cell[95510, 2653, 983, 20, 30, "Input",ExpressionUUID->"9a7f0b89-d7ac-4cac-9789-069bf3908070"],
Cell[96496, 2675, 4235, 113, 389, "Output",ExpressionUUID->"18b03ecf-ac23-4aa4-ba82-5f9edc1c4014"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100768, 2793, 1065, 21, 30, "Input",ExpressionUUID->"00857a12-a045-43a5-a092-3f2841f3738c"],
Cell[101836, 2816, 4357, 115, 389, "Output",ExpressionUUID->"32d8d018-24af-449f-b592-aabeeb125e40"]
}, Open  ]],
Cell[106208, 2934, 471, 11, 30, "Input",ExpressionUUID->"e2c0fdc3-2818-46e3-90bb-ea9a4a772f83"],
Cell[106682, 2947, 4929, 126, 457, "Input",ExpressionUUID->"ebfcc9d9-9090-4e00-95dd-85b5e8e45fe4"],
Cell[111614, 3075, 265, 5, 30, "Input",ExpressionUUID->"e8074448-2c86-419b-885a-6854976bf757"],
Cell[111882, 3082, 241, 5, 30, "Input",ExpressionUUID->"dd73e1b8-d1ca-4d08-bb15-4a706c3ef535"],
Cell[CellGroupData[{
Cell[112148, 3091, 178, 3, 30, "Input",ExpressionUUID->"fbc0ea47-5dc4-4154-baf0-b92b90320538"],
Cell[112329, 3096, 1029, 28, 58, "Output",ExpressionUUID->"2901070c-3ead-4afb-96d4-890a60da4481"]
}, Open  ]],
Cell[113373, 3127, 616, 15, 30, "Input",ExpressionUUID->"1f26f63b-cdbd-4d83-945b-ed978fe57cb0"],
Cell[CellGroupData[{
Cell[114014, 3146, 987, 28, 55, "Input",ExpressionUUID->"cd3114b4-7f25-4238-ab30-f1bd94376e00"],
Cell[115004, 3176, 1015, 29, 58, "Output",ExpressionUUID->"f32c682e-91d6-4e99-a250-52d16ec7675d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116056, 3210, 873, 19, 30, "Input",ExpressionUUID->"806ac099-ab93-495c-8edb-4df002ee52a4"],
Cell[116932, 3231, 2560, 70, 149, "Output",ExpressionUUID->"837127e7-a9b7-4f8a-a8b5-a42a3503f567"]
}, Open  ]],
Cell[119507, 3304, 349, 8, 30, "Input",ExpressionUUID->"e7366cdf-3ef7-4a5c-a1f9-d1b8648ed9fc"],
Cell[CellGroupData[{
Cell[119881, 3316, 3272, 83, 183, "Input",ExpressionUUID->"633d12df-963c-4d2e-9eea-701ba6efdf89"],
Cell[123156, 3401, 2737, 76, 149, "Output",ExpressionUUID->"37e251df-ddfb-43bb-8b4e-45b9fc2f246a"]
}, Open  ]],
Cell[125908, 3480, 689, 17, 30, "Input",ExpressionUUID->"4bec4fca-4865-40a8-8188-40bcb53269c1"],
Cell[126600, 3499, 775, 19, 52, "Input",ExpressionUUID->"e87d97c2-fbc4-4eb0-8192-fea5eaf9f7ed"],
Cell[CellGroupData[{
Cell[127400, 3522, 869, 19, 30, "Input",ExpressionUUID->"a8f3c2d3-5e47-4a9b-86ba-5cbc25b56c89"],
Cell[128272, 3543, 467, 8, 34, "Output",ExpressionUUID->"637d6699-7762-4dc7-9a77-e0a84c91ee1d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128776, 3556, 208, 4, 30, "Input",ExpressionUUID->"2bc6352f-e6b0-40ef-a270-19de324aac46"],
Cell[128987, 3562, 969, 27, 88, "Output",ExpressionUUID->"8249d876-a1a4-40b5-acf7-3323eafa1bc8"]
}, Open  ]],
Cell[129971, 3592, 984, 19, 73, "Input",ExpressionUUID->"fe134c15-9aa3-47f8-95ac-006c9c717992"],
Cell[130958, 3613, 424, 8, 30, "Input",ExpressionUUID->"03d66728-b880-4634-8cfd-481b246a523b"],
Cell[131385, 3623, 775, 16, 30, "Input",ExpressionUUID->"8ae65aef-7dd1-4f36-aff8-3f748abfe610"],
Cell[132163, 3641, 783, 16, 30, "Input",ExpressionUUID->"2f36a8fc-cdce-4cbf-bad1-7619c056acc3"],
Cell[CellGroupData[{
Cell[132971, 3661, 3494, 56, 30, "Input",ExpressionUUID->"0b482a0a-ab45-49e3-9071-03ce1698f691"],
Cell[136468, 3719, 45586, 841, 62, "Output",ExpressionUUID->"de227476-bbb4-43fb-bb41-9faa846e0b89"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182091, 4565, 2791, 49, 30, "Input",ExpressionUUID->"b3beead8-1d69-4713-8ecd-b83d036903b3"],
Cell[184885, 4616, 17425, 343, 256, "Output",ExpressionUUID->"8f49c5ac-b5e6-4073-99fe-88adda09a272"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202347, 4964, 2839, 52, 30, "Input",ExpressionUUID->"4be731d4-ecc6-48c2-baf0-f0afbc57742d"],
Cell[205189, 5018, 9907, 181, 253, "Output",ExpressionUUID->"f7813102-090f-49c9-a331-8df024468c75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215133, 5204, 287, 7, 30, "Input",ExpressionUUID->"8e3dc439-6ea5-45b9-80b5-6403274be7e4"],
Cell[215423, 5213, 1089, 31, 88, "Output",ExpressionUUID->"aa105d61-652a-46c0-a313-ccf6bb89c825"]
}, Open  ]],
Cell[216527, 5247, 259, 5, 30, "Input",ExpressionUUID->"e0e47356-187a-407f-a06b-5ea278e1441b"],
Cell[216789, 5254, 543, 15, 55, "Input",ExpressionUUID->"01b3c087-c389-4a55-890f-c3af83944273"],
Cell[CellGroupData[{
Cell[217357, 5273, 213, 4, 30, "Input",ExpressionUUID->"d94e3c06-3958-4f1e-8bc0-7742642a8eca"],
Cell[217573, 5279, 397, 8, 34, "Output",ExpressionUUID->"6335df96-6dba-4509-b2e2-297ad578695c"]
}, Open  ]],
Cell[217985, 5290, 1246, 34, 85, "Input",ExpressionUUID->"0d642e2e-a729-4b36-9035-7b16345170b3"],
Cell[CellGroupData[{
Cell[219256, 5328, 211, 4, 30, "Input",ExpressionUUID->"de1b85e0-bc45-422c-920b-c02f233be7c5"],
Cell[219470, 5334, 930, 23, 64, "Output",ExpressionUUID->"5a9a35bd-ac3f-4d7d-bdf3-d7204be38178"]
}, Open  ]],
Cell[220415, 5360, 2930, 51, 30, "Input",ExpressionUUID->"4fc82e74-e2e0-4285-ab3d-cdf61f719fd1"],
Cell[223348, 5413, 892, 22, 30, "Input",ExpressionUUID->"59f641ce-2afd-4c64-8b60-426b9c8fc54f"],
Cell[CellGroupData[{
Cell[224265, 5439, 452, 9, 30, "Input",ExpressionUUID->"bb3d0b36-a536-46c0-b760-e0cb2a65072b"],
Cell[224720, 5450, 21554, 415, 248, "Output",ExpressionUUID->"1d476378-89e1-4248-a787-0eda55df95b2"]
}, Open  ]],
Cell[246289, 5868, 412, 8, 30, "Input",ExpressionUUID->"1f189524-69d2-4394-a465-29d5f788593d"],
Cell[246704, 5878, 775, 16, 30, "Input",ExpressionUUID->"c3d26102-728d-46c7-b3da-5a54caccb392"],
Cell[247482, 5896, 783, 16, 30, "Input",ExpressionUUID->"e2721dbf-011a-4e4d-a9f7-cc4a594565b1"],
Cell[CellGroupData[{
Cell[248290, 5916, 3345, 54, 30, "Input",ExpressionUUID->"5e701952-f3ca-44f7-a507-2c146ccceee0"],
Cell[251638, 5972, 41463, 773, 62, "Output",ExpressionUUID->"298d6290-95d5-48a7-aa61-608c0c1e3601"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293138, 6750, 2397, 41, 30, "Input",ExpressionUUID->"952d9f66-ccde-4559-8961-287a66e4cbda"],
Cell[295538, 6793, 6809, 134, 243, "Output",ExpressionUUID->"04305653-30d5-4a7a-877c-c107db995d26"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302384, 6932, 2420, 41, 30, "Input",ExpressionUUID->"362943a4-e2b0-49c8-80d5-2561877610a3"],
Cell[304807, 6975, 9872, 182, 272, "Output",ExpressionUUID->"fd553d32-dc92-43f2-85a8-e92be96d1323"]
}, Open  ]]
}
]
*)

