(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    407876,       9127]
NotebookOptionsPosition[    381601,       8717]
NotebookOutlinePosition[    381937,       8732]
CellTagsIndexPosition[    381894,       8729]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{
   "Implementation", " ", "of", " ", "the", " ", "FTBL", " ", "model", " ", 
    "with", " ", "a", " ", "piecewise", " ", "logarithmic", " ", "velocity", 
    " ", 
    RowBox[{"profile", ".", " ", "This"}], " ", "version", " ", "is", " ", 
    "for", " ", "smooth"}], "-", 
   RowBox[{"rough", "."}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851856047524442*^9, 3.851856060353113*^9}, {
   3.8519643633270335`*^9, 3.8519643939384303`*^9}, {3.85197836415641*^9, 
   3.8519783771864986`*^9}, {3.8521384700212536`*^9, 
   3.8521384763675747`*^9}, {3.852391831974824*^9, 3.8523918360281343`*^9}, 
   3.861320234928773*^9, {3.861320282709454*^9, 3.86132032267003*^9}, {
   3.861320372149871*^9, 3.861320372321889*^9}, {3.861386476171879*^9, 
   3.861386476749628*^9}, 3.861386938692766*^9},
 CellLabel->
  "In[771]:=",ExpressionUUID->"cb21c7c6-dc94-4bc3-9476-b0b5d034bbb4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "U1", ",", "U2", ",", "S1", ",", "K", ",", "z", ",", "z01", ",", "z02", 
    ",", "ks", ",", "A", ",", "B", ",", "S", ",", "d0", ",", "ksh", ",", 
    "ut1", ",", "ut2", ",", "dic", ",", "dih"}], "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
   "Region", " ", "1", " ", "is", " ", "upstream", " ", "rough", " ", "wall", 
    " ", "Region", " ", "2", " ", "is", " ", "downstream", " ", "smooth", " ",
     "wall"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
    "Length", " ", "and", " ", "velocity", " ", "constants", " ", "are", " ", 
     "UI"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"velocity", " ", "at", " ", "infinity", " ", "and", " ", "dc0"}],
      " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\\", "delta"}], 
       RowBox[{"(", "0", ")"}], " ", "which", " ", "is", " ", "outer", " ", 
       "BL", " ", "thickness", " ", "at", " ", "x"}], " ", "=", " ", 
      "0"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"Unknowns", " ", "are", " ", "S1"}], " ", "=", " ", 
     RowBox[{"UI", "/", "ut1"}]}], ",", " ", 
    RowBox[{"S2", " ", "=", " ", 
     RowBox[{"UI", "/", "ut2"}]}], ",", " ", 
    RowBox[{"dc", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\\", "delta"}], 
       RowBox[{"(", "x", ")"}], "  ", "and", " ", "di"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"delta_i", ".", "  ", 
        RowBox[{"Nondimensional", ":", " ", "dch"}]}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"\\", "delta"}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", "x", ")"}], "/"}], "\\", "delta"}], 
         RowBox[{"(", "0", ")"}], "  ", "and", " ", "dih"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"delta_i", "/", "delta"}], 
         RowBox[{"(", "0", ")"}]}]}]}]}]}]}], "  ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.730467711316572*^9, 3.7304677472340693`*^9}, {
   3.730473159840771*^9, 3.730473164837319*^9}, {3.8518559861540403`*^9, 
   3.8518560153344374`*^9}, {3.851859020912593*^9, 3.851859237043853*^9}, {
   3.852139515552419*^9, 3.852139527948711*^9}, {3.8523918666439548`*^9, 
   3.8523918727979097`*^9}, 3.852391925334406*^9, 3.861320329995994*^9},
 CellLabel->
  "In[772]:=",ExpressionUUID->"ea60df7e-34a6-4c5b-b260-4c0ba7449a99"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Velocity", " ", "profiles"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518592492400336`*^9, 3.8518592813813877`*^9}, {
  3.851860722972407*^9, 3.8518607448625355`*^9}, {3.852391933059099*^9, 
  3.852391938213058*^9}},
 CellLabel->
  "In[773]:=",ExpressionUUID->"82978fa8-6d69-43f3-b12c-ab4efd7c3ce1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U2", " ", "=", " ", 
  RowBox[{"ut2", "*", 
   RowBox[{"1", "/", "K"}], "*", 
   RowBox[{"Log", "[", 
    RowBox[{"z", "/", "z02"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7293497272938147`*^9, 3.729349754252965*^9}, {
   3.851856025135623*^9, 3.8518560420383825`*^9}, {3.851856948911482*^9, 
   3.8518569503617287`*^9}, {3.8518607638367047`*^9, 
   3.8518607645387115`*^9}, {3.8521384893114405`*^9, 3.85213849883141*^9}, 
   3.861387259259042*^9, 3.86138732676081*^9},
 CellLabel->
  "In[774]:=",ExpressionUUID->"f6965048-5747-4dd7-8f85-b3a359a09027"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut2", " ", 
   RowBox[{"Log", "[", 
    FractionBox["z", "z02"], "]"}]}], "K"]], "Output",
 CellChangeTimes->{3.861387502422524*^9},
 CellLabel->
  "Out[774]=",ExpressionUUID->"dc798ac1-555d-4cdb-9cef-e592915bd5f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U1", " ", "=", " ", 
  RowBox[{"ut1", "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "K"}], "*", 
      RowBox[{"Log", "[", 
       RowBox[{"z", "*", 
        RowBox[{"ut1", "/", "nu"}]}], "]"}]}], " ", "+", "A"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.8518562769203167`*^9, 3.8518563013255043`*^9}, {
   3.851856960120079*^9, 3.8518569611618805`*^9}, {3.851860777499856*^9, 
   3.851860778567809*^9}, {3.851861397096198*^9, 3.851861421642493*^9}, {
   3.851873227640999*^9, 3.8518732282349253`*^9}, {3.8521385073923016`*^9, 
   3.852138518624138*^9}, 3.861387261143417*^9, 3.8613873283975143`*^9, 
   3.861387467342772*^9},
 CellLabel->
  "In[775]:=",ExpressionUUID->"4fa0517e-dfa6-42e8-ae35-99614f1d0edc"],

Cell[BoxData[
 RowBox[{"ut1", " ", 
  RowBox[{"(", 
   RowBox[{"A", "+", 
    FractionBox[
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"ut1", " ", "z"}], "nu"], "]"}], "K"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.861387502432816*^9},
 CellLabel->
  "Out[775]=",ExpressionUUID->"21c13acf-8582-4ba6-a3ae-fffe571526a2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Eq", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], ".", "  ", "Velocity"}], " ", "matching", 
    " ", "at", " ", "z"}], " ", "=", " ", "di"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518565282158995`*^9, 3.8518565766461725`*^9}, {
  3.8521154769061017`*^9, 3.852115478041054*^9}, {3.8613204131681223`*^9, 
  3.861320414680435*^9}},
 CellLabel->
  "In[776]:=",ExpressionUUID->"d5d7d418-6488-4e43-8ad8-d7b6e2cb5566"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQm1", " ", "=", 
   RowBox[{
    RowBox[{"U2", "-", "U1"}], "/.", " ", 
    RowBox[{"z", "\[Rule]", "di"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.851856595530841*^9, 3.8518566549562473`*^9}, {
   3.851856782130268*^9, 3.85185678282686*^9}, {3.851856968914916*^9, 
   3.8518569900861063`*^9}, {3.851860796822938*^9, 3.8518608261062565`*^9}, 
   3.8518614847090755`*^9, {3.851863887086609*^9, 3.8518638893146057`*^9}, {
   3.851864079595587*^9, 3.851864081219633*^9}, {3.8519554242982416`*^9, 
   3.851955425050208*^9}, {3.8521385390299225`*^9, 3.8521385499139786`*^9}, 
   3.8613872694919863`*^9, 3.8613873299499807`*^9},
 CellLabel->
  "In[777]:=",ExpressionUUID->"25fb845c-9afe-4214-9316-c4d7ec15a13d"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Eq", " ", 
    RowBox[{
     RowBox[{"(", "0", ")"}], ".", "  ", "velocity"}], " ", "at", " ", "z"}], 
   "=", " ", 
   RowBox[{
    RowBox[{"dc", " ", 
     RowBox[{"(", 
      RowBox[{"outer", " ", "BL"}], ")"}]}], " ", "=", " ", "UI"}]}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.851856885491148*^9, 3.8518569106649237`*^9}, 
   3.851860898508426*^9, {3.8521635952898507`*^9, 3.852163598444501*^9}},
 CellLabel->
  "In[778]:=",ExpressionUUID->"671d1813-c94e-4f5c-8a63-6b76fadcdda2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ0", " ", "=", " ", 
  RowBox[{
   RowBox[{"ut1", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "K"}], "*", 
       RowBox[{"Log", "[", 
        RowBox[{"dc", "*", 
         RowBox[{"ut1", "/", "nu"}]}], "]"}]}], " ", "+", "A"}], ")"}]}], "-",
    "1"}]}]], "Input",
 CellChangeTimes->{{3.8518567878111296`*^9, 3.8518568356448374`*^9}, {
   3.8518570101376753`*^9, 3.8518570162570553`*^9}, {3.851860849458492*^9, 
   3.851860893700107*^9}, 3.852138582598691*^9, {3.8521388779333267`*^9, 
   3.85213887843682*^9}, 3.852391966038568*^9, {3.8613872724091682`*^9, 
   3.86138729454216*^9}},
 CellLabel->
  "In[779]:=",ExpressionUUID->"e79b034f-0f7f-420c-afd4-b76835fa6bc6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{"A", "+", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "K"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.851860908418703*^9, 3.851861503564375*^9, 
  3.851864088604856*^9, 3.851864340771022*^9, 3.851866966585204*^9, 
  3.8518732728890934`*^9, 3.851955446310946*^9, 3.851962251608975*^9, 
  3.8519662303716555`*^9, 3.8519784442983575`*^9, 3.852049271611267*^9, 
  3.85207162681991*^9, 3.8520716985754547`*^9, 3.852115508916393*^9, 
  3.8521155840507975`*^9, 3.852138590652437*^9, 3.8521388802308645`*^9, 
  3.852139560820015*^9, 3.8521515842461042`*^9, 3.8521636189043283`*^9, 
  3.852391971930048*^9, 3.854465534996582*^9, 3.854470386386156*^9, 
  3.8545108362327137`*^9, 3.861320182850588*^9, 3.861387108151976*^9, 
  3.8613873054717627`*^9, 3.861387502494012*^9},
 CellLabel->
  "Out[779]=",ExpressionUUID->"21535c37-4bfc-4a2f-92e7-d72af02ed3b6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Explore", " ", "consequences", " ", "if", " ", "di"}], " ", "=", 
   " ", "dc"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.852163468319272*^9, 3.852163486133277*^9}},
 CellLabel->
  "In[780]:=",ExpressionUUID->"1624ab0b-1fa2-43b1-9025-174591d960c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQm1A", " ", "=", 
  RowBox[{"EQm1", "/.", " ", 
   RowBox[{"di", "\[Rule]", "dc"}]}]}]], "Input",
 CellChangeTimes->{{3.852163023659977*^9, 3.852163043861575*^9}, {
  3.852163080812905*^9, 3.8521630850849466`*^9}},
 CellLabel->
  "In[781]:=",ExpressionUUID->"739a9663-a7f8-4d16-9c6b-6869524a3ed2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "ut1"}], " ", 
   RowBox[{"(", 
    RowBox[{"A", "+", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "K"]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"ut2", " ", 
    RowBox[{"Log", "[", 
     FractionBox["dc", "z02"], "]"}]}], "K"]}]], "Output",
 CellChangeTimes->{
  3.8521630475082846`*^9, 3.8521630863710575`*^9, 3.85216362601725*^9, {
   3.852391981104305*^9, 3.8523920027323465`*^9}, 3.854465542372451*^9, 
   3.854470386457925*^9, 3.854510836281539*^9, 3.861320182898134*^9, 
   3.861387108190329*^9, 3.861387305521036*^9, 3.861387502538147*^9},
 CellLabel->
  "Out[781]=",ExpressionUUID->"8cf319ae-20f9-4d6b-9237-d17e6b0fe733"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Sovle", " ", "for", " ", "ut2"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8521636352378473`*^9, 3.852163643014718*^9}, 
   3.8523920090840087`*^9},
 CellLabel->
  "In[782]:=",ExpressionUUID->"32d29f4e-9225-4db2-ae76-12b73b64b183"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox[
      RowBox[{"ut2", " ", 
       RowBox[{"Log", "[", 
        FractionBox["dc", "z02"], "]"}]}], "K"]}], "\[Equal]", "0"}], ",", 
   "ut2"}], "]"}]], "Input",
 CellChangeTimes->{{3.8521631298937626`*^9, 3.852163184635747*^9}, 
   3.852392056278097*^9},
 CellLabel->
  "In[783]:=",ExpressionUUID->"56cf7adb-e33b-4068-9a7f-c9e8eb9dedf2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"ut2", "\[Rule]", 
    FractionBox["K", 
     RowBox[{"Log", "[", 
      FractionBox["dc", "z02"], "]"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.852163150362074*^9, 3.8521631867269707`*^9}, 
   3.852392064947735*^9, 3.854470386528415*^9, 3.854510836332129*^9, 
   3.861320182944989*^9, 3.8613871082368193`*^9, 3.861387305568128*^9, 
   3.861387502556472*^9},
 CellLabel->
  "Out[783]=",ExpressionUUID->"13de4b48-621e-42cb-99b0-268b1db91212"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ut2S", " ", "=", " ", 
  FractionBox["K", 
   RowBox[{"Log", "[", 
    FractionBox["dc", "z02"], "]"}]]}]], "Input",
 CellChangeTimes->{{3.8521636632858467`*^9, 3.8521636807769833`*^9}, {
  3.852392072321083*^9, 3.8523920727679234`*^9}},
 CellLabel->
  "In[784]:=",ExpressionUUID->"c73886e4-bc1f-4e87-9361-0ab56b188bc1"],

Cell[BoxData[
 FractionBox["K", 
  RowBox[{"Log", "[", 
   FractionBox["dc", "z02"], "]"}]]], "Output",
 CellChangeTimes->{3.8521636845039525`*^9, 3.8523920738023186`*^9, 
  3.85446555543157*^9, 3.854470386590201*^9, 3.854510836344*^9, 
  3.861320182955558*^9, 3.861387108273315*^9, 3.861387305605521*^9, 
  3.861387502591256*^9},
 CellLabel->
  "Out[784]=",ExpressionUUID->"f01ca4ae-62b1-4f46-9629-b3fd35e634ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "EQm1A"}], "/.", " ", 
  RowBox[{"ut2", "\[Rule]", 
   FractionBox[
    RowBox[{"K", " "}], 
    RowBox[{"Log", "[", 
     FractionBox["dc", "z02"], "]"}]]}]}]], "Input",
 CellChangeTimes->{{3.8521632454786696`*^9, 3.8521632545530195`*^9}, {
  3.8521633050006657`*^9, 3.852163343259855*^9}, {3.8523920797227907`*^9, 
  3.8523920799271755`*^9}},
 CellLabel->
  "In[785]:=",ExpressionUUID->"cecdd245-3829-4177-b408-81318d0e9dc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{"A", "+", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "K"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.85216332297792*^9, 3.852163344211985*^9}, 
   3.8521636987235546`*^9, 3.8523920816720057`*^9, 3.8544655628312426`*^9, 
   3.8544703866489234`*^9, 3.85451083638521*^9, 3.861320182992404*^9, 
   3.861387108287017*^9, 3.86138730561516*^9, 3.8613875026041183`*^9},
 CellLabel->
  "Out[785]=",ExpressionUUID->"d267be12-39b0-4951-bd1d-e34b5d031332"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["EQ0"], "Input",
 CellChangeTimes->{{3.8521633274906273`*^9, 3.8521633286422353`*^9}},
 CellLabel->
  "In[786]:=",ExpressionUUID->"852e83f0-b591-4995-accb-64d77e1fed5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{"A", "+", 
     FractionBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "K"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.852163329976219*^9, 3.8521633496786237`*^9}, 
   3.852392089113466*^9, 3.854465568220498*^9, 3.854470386708702*^9, 
   3.8545108363949547`*^9, 3.861320183001711*^9, 3.861387108328535*^9, 
   3.8613873056604967`*^9, 3.86138750263962*^9},
 CellLabel->
  "Out[786]=",ExpressionUUID->"c0761641-a3ff-480a-ac8d-dafd2468b4e4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Same", " ", 
   RowBox[{"equation", ".", "  ", "Solve"}], " ", "for", " ", "ut1"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8521637032801104`*^9, 3.852163718518647*^9}},
 CellLabel->
  "In[787]:=",ExpressionUUID->"791a9e83-929d-49bb-9336-e8da1d5c1adc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"EQ0", "\[Equal]", "0"}], ",", "ut1"}], "]"}]], "Input",
 CellChangeTimes->{{3.852163358626604*^9, 3.852163369053439*^9}},
 CellLabel->
  "In[788]:=",ExpressionUUID->"81561a9f-1ada-481b-8487-c87cd1193c15"],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,788,6,32075551143242373313,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8521633708732114`*^9, 3.8523920955091686`*^9, 
  3.8544655732193*^9, 3.854470386776244*^9, 3.85451083647215*^9, 
  3.861320183081148*^9, 3.861387108372813*^9, 3.861387305710601*^9, 
  3.861387502685813*^9},
 CellLabel->
  "During evaluation of \
In[788]:=",ExpressionUUID->"a25247d4-434e-4232-8ee0-b0a8268ba94f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"ut1", "\[Rule]", 
    FractionBox["K", 
     RowBox[{"ProductLog", "[", 
      FractionBox[
       RowBox[{"dc", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K"}], "nu"], "]"}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8521633708919115`*^9, 3.852392095527482*^9, 
  3.8544655732335596`*^9, 3.8544703867878623`*^9, 3.854510836501478*^9, 
  3.861320183086344*^9, 3.861387108379942*^9, 3.861387305722857*^9, 
  3.861387502695691*^9},
 CellLabel->
  "Out[788]=",ExpressionUUID->"60010109-79ec-4ab9-a9eb-95ca420654f7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ut1S", " ", "=", " ", 
   FractionBox[
    RowBox[{"K", " "}], 
    RowBox[{"ProductLog", "[", 
     FractionBox[
      RowBox[{"dc", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "UI"}], "nu"], "]"}]]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.852163725348589*^9, 3.8521637387240367`*^9}, 
   3.8521638426873646`*^9, {3.852392100432269*^9, 3.852392118403737*^9}},
 CellLabel->
  "In[789]:=",ExpressionUUID->"0b78b01e-d955-43e7-ad0b-88c866000b29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"EQm1", "\[Equal]", "0"}], ",", "ut2"}], "]"}]], "Input",
 CellChangeTimes->{{3.8518643633312273`*^9, 3.8518643757209153`*^9}, {
  3.8521386111852508`*^9, 3.85213861779924*^9}, {3.8523921447380676`*^9, 
  3.8523921473524227`*^9}},
 CellLabel->
  "In[790]:=",ExpressionUUID->"c1a895c8-3ec0-4572-b629-9474bce95644"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"ut2", "\[Rule]", 
    FractionBox[
     RowBox[{"ut1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}], ")"}]}], 
     RowBox[{"Log", "[", 
      FractionBox["di", "z02"], "]"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.851864377042094*^9, 3.851866978671404*^9, 
  3.8519554545783777`*^9, 3.851962257823409*^9, 3.8519662351035957`*^9, 
  3.8519784497971053`*^9, 3.8520492717060013`*^9, 3.852071626882744*^9, 
  3.852071698640461*^9, 3.8521156461127195`*^9, 3.8521386199077015`*^9, 
  3.8521388889304934`*^9, 3.8521395656341343`*^9, 3.8521515970195065`*^9, 
  3.8523921488289547`*^9, 3.8544655921356106`*^9, 3.854470386856489*^9, 
  3.8545108365432453`*^9, 3.861320183124422*^9, 3.861387108423027*^9, 
  3.861387305775856*^9, 3.861387502742454*^9},
 CellLabel->
  "Out[790]=",ExpressionUUID->"7ba1a34c-93be-455b-8aab-953c69c3bce1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Express", " ", "in", " ", "terms", " ", "of", " ", "S1"}], ",", 
   "S2"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.852139091961993*^9, 3.8521391056997557`*^9}},
 CellLabel->
  "In[791]:=",ExpressionUUID->"f2727e6a-3e68-4649-80cf-8e21138e53ca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2S", " ", "=", " ", 
  RowBox[{"S1S", " ", "*", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"di", "/", "z02"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A", "*", "K"}], "+", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", "*", "Rec", " "}], "S1S"], "]"}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.852139071833421*^9, 3.852139086436539*^9}, {
  3.8521391231813526`*^9, 3.8521392269859433`*^9}, {3.8521392826383185`*^9, 
  3.8521392835148373`*^9}},
 CellLabel->
  "In[792]:=",ExpressionUUID->"4110c549-54c6-4c26-b4a3-ef900572dfb7"],

Cell[BoxData[
 FractionBox[
  RowBox[{"S1S", " ", 
   RowBox[{"Log", "[", 
    FractionBox["di", "z02"], "]"}]}], 
  RowBox[{
   RowBox[{"A", " ", "K"}], "+", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"di", " ", "Rec"}], "S1S"], "]"}]}]]], "Output",
 CellChangeTimes->{3.852139230177854*^9, 3.8521392860435834`*^9, 
  3.8521395805524178`*^9, 3.8521516184330745`*^9, 3.8523921860846567`*^9, 
  3.854465606041945*^9, 3.854470386923503*^9, 3.854510836588646*^9, 
  3.8613201831672792`*^9, 3.861387108479557*^9, 3.861387305823209*^9, 
  3.861387502798118*^9},
 CellLabel->
  "Out[792]=",ExpressionUUID->"304598f0-87ef-42de-ae8a-e63eb55a6a34"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"S1Sol", ",", "S2Sol"}], "]"}]], "Input",
 CellChangeTimes->{{3.8521397192128735`*^9, 3.852139734341127*^9}},
 CellLabel->
  "In[793]:=",ExpressionUUID->"ab54f21e-2941-49ed-91f2-568487038381"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Put", " ", "UI"}], " ", "=", 
   RowBox[{
   "1.", " ", "Express", " ", "in", " ", "terms", " ", "of", " ", "S1"}]}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.85197798823536*^9, 3.8519779939853983`*^9}, {
  3.8519784763755064`*^9, 3.8519784856755385`*^9}},
 CellLabel->
  "In[794]:=",ExpressionUUID->"7ac1198f-a464-4ae9-b60a-0fa9abb193ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S1Sol", "[", "x_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"ProductLog", "[", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "*", "Rec", " ", "*", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K"}], " ", "]"}], "/", "K"}]}]], "Input",
 CellChangeTimes->{{3.85196791711742*^9, 3.851967981994134*^9}, {
   3.8521389203616686`*^9, 3.85213897659912*^9}, {3.8521394481635313`*^9, 
   3.8521394503275404`*^9}, 3.852139600189209*^9},
 CellLabel->
  "In[795]:=",ExpressionUUID->"c062a907-3048-4101-b550-1a602178787e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S1Sol", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8521396475783443`*^9, 3.8521396513181915`*^9}},
 CellLabel->
  "In[796]:=",ExpressionUUID->"fa47fa05-ec70-4bcf-adaf-4f08f4288ea7"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ProductLog", "[", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}], "K"]], "Output",
 CellChangeTimes->{3.852139652166758*^9, 3.8521397529320908`*^9, 
  3.852151666974637*^9, 3.852392227836587*^9, 3.8544656192198086`*^9, 
  3.8544703870075235`*^9, 3.854510836677887*^9, 3.861320183221294*^9, 
  3.8613871085300827`*^9, 3.861387305927349*^9, 3.861387502875443*^9},
 CellLabel->
  "Out[796]=",ExpressionUUID->"91cfffbc-b63c-445c-9e7d-53704a639644"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "S2Sol"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.852139318286334*^9, 3.8521393277420444`*^9}},
 CellLabel->
  "In[797]:=",ExpressionUUID->"19102964-597c-4a97-a3dd-ec5c7adcb088"],

Cell[CellGroupData[{

Cell[BoxData["S2S"], "Input",
 CellChangeTimes->{{3.852151705977497*^9, 3.852151706718783*^9}},
 CellLabel->
  "In[798]:=",ExpressionUUID->"f7a660d9-1fa9-465b-84b4-9135ee0aa205"],

Cell[BoxData[
 FractionBox[
  RowBox[{"S1S", " ", 
   RowBox[{"Log", "[", 
    FractionBox["di", "z02"], "]"}]}], 
  RowBox[{
   RowBox[{"A", " ", "K"}], "+", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"di", " ", "Rec"}], "S1S"], "]"}]}]]], "Output",
 CellChangeTimes->{3.8521517078162193`*^9, 3.852392236291259*^9, 
  3.854465625494689*^9, 3.854470387074998*^9, 3.854510836724827*^9, 
  3.861320183261508*^9, 3.861387108573599*^9, 3.861387305976122*^9, 
  3.861387502935005*^9},
 CellLabel->
  "Out[798]=",ExpressionUUID->"58b909ca-bd08-4dab-82e1-3db70ef846f2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2Sol", "[", "x_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"S1Sol", "[", "x", "]"}], "*", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"dih", "[", "x", "]"}], "/", "z02"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A", "*", "K"}], "+", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"dih", "[", "x", "]"}], "*", "Rec", " "}], 
        RowBox[{"S1Sol", "[", "x", "]"}]], "]"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8521393505380774`*^9, 3.8521393982124186`*^9}, {
  3.85213943098645*^9, 3.8521394399587708`*^9}},
 CellLabel->
  "In[799]:=",ExpressionUUID->"34d944d9-3719-4b8d-8940-c858fbcfb91c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2Sol", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.852139406237505*^9, 3.8521394100600133`*^9}},
 CellLabel->
  "In[800]:=",ExpressionUUID->"f25969f8-5e8d-4b0a-9069-be4ed7c7f2c8"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dih", "[", "x", "]"}], "z02"], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
  RowBox[{"K", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}]}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
    ")"}]}]]], "Output",
 CellChangeTimes->{3.852139411171114*^9, 3.8521396307867346`*^9, 
  3.8521397638238416`*^9, 3.8521516775349503`*^9, 3.85215174099129*^9, 
  3.8523922470273275`*^9, 3.8544656335744286`*^9, 3.854470387170339*^9, 
  3.854510836768793*^9, 3.861320183306858*^9, 3.86138710861244*^9, 
  3.861387306024304*^9, 3.861387502998302*^9},
 CellLabel->
  "Out[800]=",ExpressionUUID->"36078014-3b2b-4609-97f0-ba6de85e8854"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Define", " ", "unambiguously"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.852151756277585*^9, 3.852151768588276*^9}, 
   3.852392253014464*^9},
 CellLabel->
  "In[801]:=",ExpressionUUID->"c03a0ec9-4f52-4dbc-bb8d-cf909ec33d7b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2Sol", "[", "x_", "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
   RowBox[{"K", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}]}], 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
     ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.852142379766706*^9, 3.852142399492524*^9}},
 CellLabel->
  "In[802]:=",ExpressionUUID->"440c160d-5182-4656-9d8f-ed2e976269c7"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Look", " ", "at", " ", "some", " ", "numbers"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.852392265664749*^9, 3.8523922730016675`*^9}},
 CellLabel->
  "In[803]:=",ExpressionUUID->"8a2531e4-a929-4184-a325-dc3396178401"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S1Sol", "[", "x", "]"}], "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.851968013039324*^9, 3.851968064594179*^9}, {
   3.8519785151314507`*^9, 3.851978516123498*^9}, {3.8521390066615*^9, 
   3.85213903764532*^9}, {3.8521398218105555`*^9, 3.852139823400921*^9}, 
   3.861387369883848*^9, 3.8613874888289337`*^9},
 CellLabel->
  "In[804]:=",ExpressionUUID->"0b10577e-4069-4410-aff5-a67f7fe22f40"],

Cell[BoxData["28.567456035215283`"], "Output",
 CellChangeTimes->{{3.851968054037552*^9, 3.8519680678507977`*^9}, 
   3.851978006709188*^9, {3.8519785093628464`*^9, 3.851978517962041*^9}, 
   3.852049271802162*^9, 3.8520716269548335`*^9, 3.852071698713501*^9, 
   3.8521156685170565`*^9, {3.852139023847169*^9, 3.8521390399951477`*^9}, 
   3.8521397921396666`*^9, 3.8521398249814806`*^9, 3.852142417867764*^9, 
   3.852151786904657*^9, 3.852392277537938*^9, 3.854465644455842*^9, 
   3.8544703872873583`*^9, 3.854510836853953*^9, 3.861320183363575*^9, 
   3.861387108668829*^9, 3.8613873060882607`*^9, 3.861387503057425*^9},
 CellLabel->
  "Out[804]=",ExpressionUUID->"49d681c9-d6de-4e84-b2c0-a232806c3876"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S2Sol", "[", "x", "]"}], "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", 
     RowBox[{"2", "*", "0.000371"}]}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}], ",", 
    RowBox[{"z02h", "\[Rule]", "0.000371"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.851968013039324*^9, 3.851968064594179*^9}, {
   3.8519785151314507`*^9, 3.851978516123498*^9}, {3.8521390066615*^9, 
   3.85213903764532*^9}, {3.852139806316631*^9, 3.8521398068706813`*^9}, {
   3.8521398427978535`*^9, 3.852139908470538*^9}, {3.852139966033787*^9, 
   3.852139990497094*^9}, {3.8521424251980543`*^9, 3.8521424339961505`*^9}, {
   3.8521517947597976`*^9, 3.852151821208374*^9}, 3.8613873919653807`*^9, 
   3.861387488831821*^9},
 CellLabel->
  "In[805]:=",ExpressionUUID->"40524fd0-6eab-439f-a425-d9dc2a2cdc82"],

Cell[BoxData["5.261107866708356`"], "Output",
 CellChangeTimes->{{3.8521398710152445`*^9, 3.852139910119914*^9}, {
   3.8521399670863886`*^9, 3.8521399914515944`*^9}, {3.8521424272671695`*^9, 
   3.852142435359683*^9}, {3.852151797131198*^9, 3.852151822748698*^9}, 
   3.852392284239437*^9, 3.854465647783863*^9, 3.8544703873454485`*^9, 
   3.854510836862289*^9, 3.861320183399023*^9, 3.8613871087014837`*^9, 
   3.861387306126647*^9, 3.861387503067418*^9},
 CellLabel->
  "Out[805]=",ExpressionUUID->"05db6b8f-7b47-4104-9f01-3cc4be6fadf9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"S1Sol", "[", "x", "]"}], ",", 
   RowBox[{"S2Sol", "[", "x", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.851967608136874*^9, 3.8519676218091016`*^9}, {
   3.85196809029003*^9, 3.8519680915302763`*^9}, 3.861387397829854*^9},
 CellLabel->
  "In[806]:=",ExpressionUUID->"4f29be76-7bab-497d-827d-76d6240fd6d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "K"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.851967624222247*^9, 3.851968093122267*^9, 
  3.85198108885706*^9, 3.852049281403226*^9, 3.852071628511261*^9, 
  3.8520716994101424`*^9, 3.852140039325818*^9, 3.8521518760234804`*^9, 
  3.8521625417143817`*^9, 3.852392306574128*^9, 3.854465652271782*^9, 
  3.8544703874078436`*^9, 3.854510836902343*^9, 3.861320183407139*^9, 
  3.861387108710124*^9, 3.861387306139073*^9, 3.861387503110738*^9},
 CellLabel->
  "Out[806]=",ExpressionUUID->"fe780e16-6ee2-4ed0-aa09-ba3eaf1a3d4a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Now", " ", "construct", " ", "two", " ", "momentum", " ", "equations"}], 
  "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8523923451679173`*^9, 3.8523923578745174`*^9}},
 CellLabel->
  "In[807]:=",ExpressionUUID->"d4fbf5f9-1dc1-4e1b-a0ce-980765611ee2"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Equ", 
   RowBox[{
    RowBox[{"(", "2", ")"}], ".", " ", "Outerlayer"}], " ", 
   RowBox[{"momentum", ".", " ", "First"}], " ", "construct", " ", "Three", 
   " ", "integral", " ", "terms"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851856873098802*^9, 3.851856880068634*^9}, {
  3.851856919042452*^9, 3.851856938970237*^9}, {3.8518609377820053`*^9, 
  3.851860945353352*^9}, {3.851872852724075*^9, 3.8518728580144577`*^9}, {
  3.861320462343315*^9, 3.861320463021935*^9}},
 CellLabel->
  "In[808]:=",ExpressionUUID->"292642b2-b58d-4450-805b-067cbe7fdb10"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1T", " ", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U1", "^", "2"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851860954975442*^9, 3.851861011427848*^9}, {
   3.851861054090987*^9, 3.851861111136257*^9}, 3.8518615197823687`*^9, {
   3.8518616174389577`*^9, 3.8518616407833185`*^9}, {3.85186168553551*^9, 
   3.851861695718727*^9}, {3.8518617654400682`*^9, 3.851861766048193*^9}, {
   3.851861821582517*^9, 3.8518618285886765`*^9}, 3.8518631652039003`*^9},
 CellLabel->
  "In[809]:=",ExpressionUUID->"28dc1692-73b7-4e17-b0dc-6228604e3cb4"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", "z", " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", 
     RowBox[{"2", " ", "A", " ", "K"}], "+", 
     RowBox[{
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox["K", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"ut1", " ", "z"}], "nu"], "]"}]}], "+", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"ut1", " ", "z"}], "nu"], "]"}], "2"]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{
  3.8518610180570145`*^9, {3.851861102575753*^9, 3.8518611150209*^9}, 
   3.8518615542770557`*^9, {3.85186167562362*^9, 3.8518616977320533`*^9}, {
   3.851861752805217*^9, 3.851861767527998*^9}, {3.851861822720601*^9, 
   3.851861831200296*^9}, 3.851861963539211*^9, 3.8518631699672422`*^9, 
   3.8519554889579687`*^9, 3.851962290270302*^9, 3.8519676301079016`*^9, 
   3.8519681026536646`*^9, 3.8519811154161577`*^9, 3.8519822605125184`*^9, 
   3.851982353722365*^9, 3.8520492930634656`*^9, 3.8520716286552663`*^9, 
   3.852071729597657*^9, 3.8521400655906963`*^9, 3.852140106509019*^9, 
   3.8521519136493807`*^9, 3.8523923984444027`*^9, 3.8544656600869875`*^9, 
   3.854470387488737*^9, 3.854510836987094*^9, 3.861320183487362*^9, 
   3.8613871087855387`*^9, 3.861387306227585*^9, 3.861387503168975*^9},
 CellLabel->
  "Out[809]=",ExpressionUUID->"ef36533b-7c9f-406f-8626-a82bec44c76c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I1T", "/.", " ", 
      RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], " ", "-", 
    RowBox[{"(", 
     RowBox[{"I1T", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851861132006254*^9, 3.8518611456974487`*^9}, {
  3.8518617743306465`*^9, 3.851861862352995*^9}, {3.8518618975592804`*^9, 
  3.8518619224417996`*^9}, {3.8518619693128676`*^9, 3.851862003058215*^9}},
 CellLabel->
  "In[810]:=",ExpressionUUID->"2a769c66-0636-43c8-bfb0-1e906775d018"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"dc", "-", "di"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"A", " ", "K", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "dc", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "+", 
     RowBox[{"dc", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "2"]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut1"}], "nu"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"2", " ", "A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}], ")"}]}]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{
  3.851861801227013*^9, {3.8518618474006815`*^9, 3.851861866380803*^9}, {
   3.8518619025470767`*^9, 3.851861925316579*^9}, {3.8518619857744637`*^9, 
   3.8518620056876807`*^9}, 3.851863183728162*^9, 3.851955495442132*^9, 
   3.851962323535138*^9, 3.85196763466755*^9, 3.8519681127275715`*^9, 
   3.8519823674640336`*^9, 3.852049299724189*^9, 3.852071628775427*^9, 
   3.8520717296890955`*^9, 3.852140128449229*^9, 3.8521519224067287`*^9, 
   3.8523924028099823`*^9, 3.8544656654077168`*^9, 3.8544703875502605`*^9, 
   3.8545108372124434`*^9, 3.861320183657154*^9, 3.861387108825726*^9, 
   3.861387306240238*^9, 3.861387503177046*^9},
 CellLabel->
  "Out[810]=",ExpressionUUID->"52a0ca4e-b533-444e-9cc4-3eac2eabc168"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"define", " ", "interface", " ", "velocity"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8518735578976774`*^9, 3.851873568063842*^9}},
 CellLabel->
  "In[811]:=",ExpressionUUID->"074ea169-89cd-43eb-930f-f08e8ba96b09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ui", " ", "=", "  ", 
  RowBox[{"ut2", "*", 
   RowBox[{"1", "/", "K"}], "*", 
   RowBox[{"Log", "[", 
    RowBox[{"di", "/", "z02"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8518613155245695`*^9, 3.8518613277874904`*^9}, 
   3.851861363287326*^9, {3.8518735793378925`*^9, 3.8518735865978756`*^9}, {
   3.852140154927758*^9, 3.8521401616319785`*^9}},
 CellLabel->
  "In[812]:=",ExpressionUUID->"eb92df4c-5651-4f54-b289-ba4f93144542"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut2", " ", 
   RowBox[{"Log", "[", 
    FractionBox["di", "z02"], "]"}]}], "K"]], "Output",
 CellChangeTimes->{3.8518620583238506`*^9, 3.8518632036341195`*^9, 
  3.851873589662359*^9, 3.8519623360089674`*^9, 3.8519676462245655`*^9, 
  3.8519681191993876`*^9, 3.8519823812641954`*^9, 3.852049305590852*^9, 
  3.852049343351277*^9, 3.8520716287971663`*^9, 3.852071729803253*^9, 
  3.8521401633874435`*^9, 3.852151930553437*^9, 3.8523924126849337`*^9, 
  3.8544656775255513`*^9, 3.8544703876213603`*^9, 3.854510837255229*^9, 
  3.861320183745672*^9, 3.8613871088687267`*^9, 3.861387306290785*^9, 
  3.861387503220419*^9},
 CellLabel->
  "Out[812]=",ExpressionUUID->"931a3f4f-403d-408d-ae9b-8df0f6ffa5c7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "Ui", "]"}]], "Input",
 CellChangeTimes->{{3.851968140839637*^9, 3.851968147524536*^9}},
 CellLabel->
  "In[813]:=",ExpressionUUID->"afcb4998-50d5-4bea-a001-d20ddb8ba456"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Express", " ", "in", " ", "terms", " ", "of", " ", 
    RowBox[{"S1", ".", " ", "Put"}], " ", "UI"}], " ", "=", "1"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8519823947702723`*^9, 3.851982408400963*^9}, {
  3.8519824533795557`*^9, 3.8519824617043505`*^9}},
 CellLabel->
  "In[814]:=",ExpressionUUID->"d5c1f21f-9406-4b4f-b671-45c4e6dfe44c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ui", "[", "x_", "]"}], ":=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], "K"], "/", 
   RowBox[{"S2Sol", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.851968128582387*^9, 3.851968202055013*^9}, {
   3.8519824676993575`*^9, 3.8519824683311033`*^9}, {3.852140178897902*^9, 
   3.8521401875814934`*^9}, 3.8523924263143077`*^9},
 CellLabel->
  "In[815]:=",ExpressionUUID->"b5b2af8a-821f-4296-9e42-5068ea68075d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2Sol", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.852151967051796*^9, 3.8521519717579145`*^9}},
 CellLabel->
  "In[816]:=",ExpressionUUID->"035835b1-ba77-4b28-beac-3e6729f12875"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
  RowBox[{"K", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}]}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
    ")"}]}]]], "Output",
 CellChangeTimes->{3.852151972649026*^9, 3.852152194334025*^9, 
  3.8523924460732036`*^9, 3.854465696888929*^9, 3.854470387708092*^9, 
  3.854510837345978*^9, 3.861320183826078*^9, 3.8613871089282417`*^9, 
  3.861387306397053*^9, 3.861387503276367*^9},
 CellLabel->
  "Out[816]=",ExpressionUUID->"f409aff8-6b2c-4319-8524-ab1703c101da"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ui", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.851968207081113*^9, 3.8519682102446136`*^9}},
 CellLabel->
  "In[817]:=",ExpressionUUID->"636dc89e-5e09-4596-9bee-2cf1480dd0b2"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"A", " ", "K"}], "+", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"K", " ", "Rec", " ", 
      RowBox[{"dih", "[", "x", "]"}]}], 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
  RowBox[{"ProductLog", "[", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}]]], "Output",
 CellChangeTimes->{3.8519682111851993`*^9, 3.851982472659141*^9, 
  3.852049355788468*^9, 3.8520716288291273`*^9, 3.8520717299583406`*^9, 
  3.8521401985928245`*^9, 3.8521519483491583`*^9, 3.8521519972474394`*^9, 
  3.8523924500782413`*^9, 3.854465701478036*^9, 3.8544703877708235`*^9, 
  3.854510837358634*^9, 3.861320183865211*^9, 3.8613871089384403`*^9, 
  3.8613873064378777`*^9, 3.861387503313655*^9},
 CellLabel->
  "Out[817]=",ExpressionUUID->"dc088538-078a-4f99-8311-9ed83be3b4bd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Note", " ", "that", " ", "second", " ", "term", " ", "involves", " ", 
   "lower", " ", "layer"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851872939447791*^9, 3.8518729568504906`*^9}},
 CellLabel->
  "In[818]:=",ExpressionUUID->"04528a2a-0bcd-4ced-ac52-3de6bf03cbde"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U2", ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "di"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8518621577204556`*^9, 3.851862209432994*^9}},
 CellLabel->
  "In[819]:=",ExpressionUUID->"51f2c909-ae6e-404a-929c-62767e7d10ef"],

Cell[BoxData[
 FractionBox[
  RowBox[{"di", " ", "ut2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox["di", "z02"], "]"}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.851862214799238*^9, 3.8518632173137083`*^9, 
  3.851872987675748*^9, 3.8518733403775697`*^9, 3.851962369753043*^9, 
  3.8519676524714155`*^9, 3.8519682269803243`*^9, 3.851982489028068*^9, 
  3.8520493727803545`*^9, 3.8520716321845665`*^9, 3.8520717498887954`*^9, 
  3.8521402099434795`*^9, 3.8521520069350877`*^9, 3.852392478031231*^9, 
  3.854465711775834*^9, 3.8544703888476734`*^9, 3.8545108385688972`*^9, 
  3.8613201870251217`*^9, 3.861387109677167*^9, 3.861387307107211*^9, 
  3.861387504035736*^9},
 CellLabel->
  "Out[819]=",ExpressionUUID->"66b5d26e-5ba1-4eab-8477-acc5ba07c768"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Third", " ", "term", " ", "is", " ", "upper", " ", "layer"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8519825216288705`*^9, 3.8519825309378767`*^9}},
 CellLabel->
  "In[820]:=",ExpressionUUID->"0df6fc1e-990f-4881-943e-716347f3716f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I31", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U1", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851862237043108*^9, 3.8518622627339783`*^9}, {
  3.8518622954038053`*^9, 3.8518622993655844`*^9}},
 CellLabel->
  "In[821]:=",ExpressionUUID->"0afed7a9-81cf-437a-b834-71056bde53af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", "ut1", " ", "z"}], "-", 
  FractionBox[
   RowBox[{"ut1", " ", "z"}], "K"], "+", 
  FractionBox[
   RowBox[{"ut1", " ", "z", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"ut1", " ", "z"}], "nu"], "]"}]}], "K"]}]], "Output",
 CellChangeTimes->{{3.8518622870144343`*^9, 3.8518623021132355`*^9}, 
   3.8518632466120443`*^9, 3.851873010013199*^9, 3.851873354037224*^9, 
   3.8519623901074195`*^9, 3.8519676558130517`*^9, 3.851968229700569*^9, 
   3.851982535643815*^9, 3.852049394881694*^9, 3.852071632310727*^9, 
   3.8520717500217247`*^9, 3.8521402204626536`*^9, 3.8521520139297953`*^9, 
   3.8523924841751537`*^9, 3.854465713011818*^9, 3.8544703889207544`*^9, 
   3.8545108386962357`*^9, 3.861320187130074*^9, 3.861387109779181*^9, 
   3.861387307164852*^9, 3.861387504105002*^9},
 CellLabel->
  "Out[821]=",ExpressionUUID->"5688ff29-b20f-46c2-8fc1-e1d70b508649"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"I31", "/.", " ", 
      RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], " ", "-", " ", 
    RowBox[{"(", 
     RowBox[{"I31", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8518623057712517`*^9, 3.851862314279415*^9}, {
  3.851862347218445*^9, 3.851862431466671*^9}},
 CellLabel->
  "In[822]:=",ExpressionUUID->"00a7e422-fee2-438c-b3dd-5698e61a2cf6"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"dc", "-", "di"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
     RowBox[{"dc", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{{3.8518623852175736`*^9, 3.8518624325504746`*^9}, 
   3.8518632544026065`*^9, 3.8518730158875947`*^9, 3.8518733588743944`*^9, 
   3.8519624010812516`*^9, 3.851967661426421*^9, 3.851968233117422*^9, 
   3.8519825453731537`*^9, 3.852049398690322*^9, 3.852071632375409*^9, 
   3.8520717501056128`*^9, 3.852140226396554*^9, 3.8521520203951645`*^9, 
   3.8523924887929535`*^9, 3.8544657221376286`*^9, 3.85447038897571*^9, 
   3.854510838742167*^9, 3.861320187189732*^9, 3.86138710979536*^9, 
   3.861387307173892*^9, 3.861387504113627*^9},
 CellLabel->
  "Out[822]=",ExpressionUUID->"83d7c898-3dae-48cd-88ed-549c0e750212"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
   "**"}], "******)"}]], "Input",
 CellChangeTimes->{{3.851982555987455*^9, 3.851982558707167*^9}},
 CellLabel->
  "In[823]:=",ExpressionUUID->"b4ffaa2d-74a5-4ef8-b19d-807a8c4870b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
   "Full", " ", "equation", " ", "to", " ", "be", " ", "processed", " ", 
    "later"}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{"Now", " ", "Eq", 
    RowBox[{
     RowBox[{"(", "3", ")"}], ".", " ", "Karman"}], " ", "integral", " ", 
    "equation"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.851862443320953*^9, 3.851862457583795*^9}, {
  3.8518628756655493`*^9, 3.8518628982435637`*^9}, {3.8523924981849604`*^9, 
  3.852392499088547*^9}},
 CellLabel->
  "In[824]:=",ExpressionUUID->"392de634-aa3b-48db-b7c4-df97c481f97c"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"First", " ", "Integral", " ", "term"}], ",", " ", 
   RowBox[{"prior", " ", "to", " ", "differentiation"}]}], "   ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.851863583180588*^9, 3.8518636128465567`*^9}},
 CellLabel->
  "In[825]:=",ExpressionUUID->"cc0d0b27-1416-4008-9a0d-e11081ce93a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J11", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U1", "^", "2"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851862911343463*^9, 3.8518629370352592`*^9}, {
  3.851863322668552*^9, 3.8518633281143985`*^9}},
 CellLabel->
  "In[826]:=",ExpressionUUID->"efa3b49a-cede-4628-8036-e6f750c5a2ef"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", "z", " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", 
     RowBox[{"2", " ", "A", " ", "K"}], "+", 
     RowBox[{
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox["K", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"ut1", " ", "z"}], "nu"], "]"}]}], "+", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"ut1", " ", "z"}], "nu"], "]"}], "2"]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{3.851863337185335*^9, 3.851876355028816*^9, 
  3.851876829591784*^9, 3.851962412542983*^9, 3.8519676693454924`*^9, 
  3.851968239623691*^9, 3.8519825678987923`*^9, 3.852049406423622*^9, 
  3.852071632402411*^9, 3.8520717502374125`*^9, 3.852140236476647*^9, 
  3.8521520301177216`*^9, 3.8523925053675623`*^9, 3.8544657298949995`*^9, 
  3.854470389061325*^9, 3.854510838846673*^9, 3.861320187246272*^9, 
  3.861387109880906*^9, 3.861387307289504*^9, 3.861387504175212*^9},
 CellLabel->
  "Out[826]=",ExpressionUUID->"2ed06b69-edcf-4a4b-a380-877f3b0e8b58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J12", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U2", "^", "2"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851863342917837*^9, 3.851863357167018*^9}},
 CellLabel->
  "In[827]:=",ExpressionUUID->"5f6834f1-12c7-469e-84ad-5dd9e22e3453"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut2", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "z"}], "-", 
     RowBox[{"2", " ", "z", " ", 
      RowBox[{"Log", "[", 
       FractionBox["z", "z02"], "]"}]}], "+", 
     RowBox[{"z", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox["z", "z02"], "]"}], "2"]}]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{3.8518633664085073`*^9, 3.8518763588942585`*^9, 
  3.851876835762397*^9, 3.8519624168197308`*^9, 3.8519676739686127`*^9, 
  3.8519682433167686`*^9, 3.8519825723034067`*^9, 3.8520494097597017`*^9, 
  3.8520716324590387`*^9, 3.852071750320991*^9, 3.852140246239304*^9, 
  3.85215203527379*^9, 3.8523925092050686`*^9, 3.854465736323962*^9, 
  3.854470389119422*^9, 3.854510838894889*^9, 3.861320187282193*^9, 
  3.861387109921131*^9, 3.861387307329397*^9, 3.861387504223061*^9},
 CellLabel->
  "Out[827]=",ExpressionUUID->"9bcdeffe-27d5-4c85-9b0e-22be60f8d06a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"J12", ",", 
   RowBox[{"z", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8518634800687704`*^9, 3.851863490490794*^9}},
 CellLabel->
  "In[828]:=",ExpressionUUID->"4a9785f5-599d-4826-9263-94a6031e1d07"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.851863495260802*^9, 3.8518763660862722`*^9, 
  3.8519624231020527`*^9, 3.852049417670433*^9, 3.852071635582966*^9, 
  3.852071750390554*^9, 3.852140253612059*^9, 3.852392513571086*^9, 
  3.8544657414987197`*^9, 3.854470389175696*^9, 3.85451083928054*^9, 
  3.861320187586152*^9, 3.8613871099674673`*^9, 3.86138730737083*^9, 
  3.861387504263011*^9},
 CellLabel->
  "Out[828]=",ExpressionUUID->"6481e303-0526-420a-ac06-ebaa8eced435"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1", " ", "=", " ", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"(", 
     RowBox[{"J12", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}], "]"}], " ", "+", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J11", "/.", " ", 
       RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"J11", "/.", " ", 
       RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.851863379643095*^9, 3.851863450552127*^9}, {
  3.8518635054423733`*^9, 3.851863561338069*^9}, {3.8519595710078983`*^9, 
  3.8519595767942*^9}},
 CellLabel->
  "In[829]:=",ExpressionUUID->"c5ba50b8-bb4b-4070-804b-f40c11217fb4"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["ut1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dc", "-", "di"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"A", " ", "K", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "dc", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "+", 
      RowBox[{"dc", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "2"]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"di", " ", "ut1"}], "nu"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", "A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}], ")"}]}]}], ")"}]}], 
   SuperscriptBox["K", "2"]], "+", 
  FractionBox[
   RowBox[{"di", " ", 
    SuperscriptBox["ut2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z02"], "]"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox["di", "z02"], "]"}]}]}], ")"}]}], 
   SuperscriptBox["K", "2"]]}]], "Output",
 CellChangeTimes->{3.8518634523402596`*^9, 3.8518635672715197`*^9, 
  3.8518763698029804`*^9, 3.851876845637937*^9, 3.8519595846097946`*^9, 
  3.851962452931127*^9, 3.8519676819957504`*^9, 3.8519682491536655`*^9, 
  3.8519826062099123`*^9, 3.8520494357037363`*^9, 3.8520716357471666`*^9, 
  3.852071750474209*^9, 3.8521403135191813`*^9, 3.852152040812127*^9, 
  3.8523925172877655`*^9, 3.854465746070969*^9, 3.8544703892338295`*^9, 
  3.8545108393248453`*^9, 3.861320187622675*^9, 3.861387109980977*^9, 
  3.861387307429784*^9, 3.861387504271954*^9},
 CellLabel->
  "Out[829]=",ExpressionUUID->"609c566d-81f3-4ec3-8318-7f7d2d560d91"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Second", " ", "integral", " ", "involves", " ", "lower", " ", "layer"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.852140357174863*^9, 3.852140373790316*^9}},
 CellLabel->
  "In[830]:=",ExpressionUUID->"e8f80b15-c250-4072-9fe8-f3b30801a04b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J21", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U1", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851862911343463*^9, 3.8518629370352592`*^9}, {
  3.851863322668552*^9, 3.8518633281143985`*^9}, {3.8518636744158683`*^9, 
  3.8518636798872204`*^9}, {3.8519594581739235`*^9, 3.8519594586186748`*^9}, {
  3.851959523544786*^9, 3.8519595241135197`*^9}},
 CellLabel->
  "In[831]:=",ExpressionUUID->"e5629228-dd94-46e0-824b-e9b97a37aafd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", "ut1", " ", "z"}], "-", 
  FractionBox[
   RowBox[{"ut1", " ", "z"}], "K"], "+", 
  FractionBox[
   RowBox[{"ut1", " ", "z", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"ut1", " ", "z"}], "nu"], "]"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.851863337185335*^9, 3.8518636825563602`*^9, 
  3.8518763408204985`*^9, 3.8518763755702004`*^9, 3.851876853868067*^9, 
  3.851959460380392*^9, 3.8519595251723967`*^9, 3.851967737452882*^9, 
  3.8519682548182116`*^9, 3.8519826124210405`*^9, 3.852049662391616*^9, 
  3.8520716371786337`*^9, 3.8520717734812174`*^9, 3.8521403858829727`*^9, 
  3.852152047460039*^9, 3.8523925315651875`*^9, 3.854465768997645*^9, 
  3.854470389303074*^9, 3.85451083937475*^9, 3.86132018766577*^9, 
  3.8613871100273333`*^9, 3.861387307475607*^9, 3.8613875043260117`*^9},
 CellLabel->
  "Out[831]=",ExpressionUUID->"cf7836f7-d636-4d07-8d7e-840f825813fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J22", " ", "=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{"U2", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851863342917837*^9, 3.851863357167018*^9}, {
  3.8518636981931148`*^9, 3.851863703343354*^9}},
 CellLabel->
  "In[832]:=",ExpressionUUID->"b4e6d041-c22c-43c1-aa22-dd6036712378"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "z"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"Log", "[", 
       FractionBox["z", "z02"], "]"}]}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.8518633664085073`*^9, 3.85186370586018*^9, 
  3.8518763871021123`*^9, 3.851876858233985*^9, 3.8519595360518265`*^9, 
  3.8519677418282967`*^9, 3.8519682589994593`*^9, 3.8519826180274878`*^9, 
  3.8520496666684327`*^9, 3.852071637233844*^9, 3.8520717735638895`*^9, 
  3.8521403908493466`*^9, 3.8521520526347322`*^9, 3.8523925356460876`*^9, 
  3.854465772886114*^9, 3.8544703893642063`*^9, 3.854510839384899*^9, 
  3.861320187673326*^9, 3.861387110072001*^9, 3.861387307518731*^9, 
  3.86138750437313*^9},
 CellLabel->
  "Out[832]=",ExpressionUUID->"200fbfb9-8282-46d5-9373-5f51d0cc449d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"J22", ",", 
   RowBox[{"z", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8518634800687704`*^9, 3.851863490490794*^9}, {
  3.8518637157494073`*^9, 3.851863716207532*^9}},
 CellLabel->
  "In[833]:=",ExpressionUUID->"f6ba5116-ef24-409d-a965-9410a080fa50"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.851863495260802*^9, 3.8518637185943727`*^9, 
  3.851968265411643*^9, 3.8520716379547596`*^9, 3.8520717736319575`*^9, 
  3.8521403979107676`*^9, 3.852392539037809*^9, 3.854465778520689*^9, 
  3.854470389415353*^9, 3.854510839430373*^9, 3.8613201877092876`*^9, 
  3.861387110115687*^9, 3.861387307564879*^9, 3.861387504412516*^9},
 CellLabel->
  "Out[833]=",ExpressionUUID->"17228a99-0c3c-4ed2-8d5a-eeb68dbe4ab4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J2", " ", "=", " ", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"(", 
     RowBox[{"J22", "/.", " ", 
      RowBox[{"z", "\[Rule]", "di"}]}], ")"}], "]"}], " ", "+", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J21", "/.", " ", 
       RowBox[{"z", "\[Rule]", "dc"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"J21", "/.", " ", 
       RowBox[{"z", "\[Rule]", "di"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.851863379643095*^9, 3.851863450552127*^9}, {
  3.8518635054423733`*^9, 3.851863561338069*^9}, {3.851863740732732*^9, 
  3.8518637760119085`*^9}, {3.851876396004256*^9, 3.8518763967422247`*^9}, {
  3.851959591651163*^9, 3.851959592597556*^9}},
 CellLabel->
  "In[834]:=",ExpressionUUID->"32960b91-ff19-4920-b5f4-1eed50d60a48"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dc", "-", "di"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
      RowBox[{"dc", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}]}], ")"}]}], "K"], "+", 
  FractionBox[
   RowBox[{"di", " ", "ut2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z02"], "]"}]}], ")"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.8518634523402596`*^9, 3.8518635672715197`*^9, 
  3.851863789337105*^9, 3.851876397979389*^9, 3.8519595992681475`*^9, 
  3.8519677460197096`*^9, 3.8519682680173235`*^9, 3.851982648206269*^9, 
  3.852049670854443*^9, 3.8520716380129585`*^9, 3.8520717737047305`*^9, 
  3.85214040247393*^9, 3.852152058790392*^9, 3.8523925426755114`*^9, 
  3.854465782888959*^9, 3.854470389473745*^9, 3.854510839442725*^9, 
  3.8613201877219133`*^9, 3.861387110124509*^9, 3.8613873075731564`*^9, 
  3.861387504422947*^9},
 CellLabel->
  "Out[834]=",ExpressionUUID->"f334f745-cb27-44c9-b789-7889fb7b26ef"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
    "Now", " ", "try", " ", "to", " ", "derive", " ", "two", " ", "ODEs", " ",
      "for", "  ", "di"}], ",", " ", "dc"}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{"First", " ", "construct", " ", "two", " ", "ODEs"}], "  ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.851867195448493*^9, 3.851867225824218*^9}, {
  3.8518730363919783`*^9, 3.8518730636333923`*^9}, {3.8519677705412045`*^9, 
  3.8519677923525577`*^9}},
 CellLabel->
  "In[835]:=",ExpressionUUID->"3c7ea884-fcde-4a7e-86d0-941f0be15b46"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "equation", " ", "2", " ", "of", " ", "notes"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8518686327324305`*^9, 3.851868638932539*^9}, {
   3.851869296628148*^9, 3.851869309399314*^9}, 3.8519678432599*^9},
 CellLabel->
  "In[836]:=",ExpressionUUID->"879748e4-4d70-4dca-9eaf-ed67e218c967"],

Cell[CellGroupData[{

Cell[BoxData["I1"], "Input",
 CellChangeTimes->{{3.8518686872649393`*^9, 3.851868687884019*^9}},
 CellLabel->
  "In[837]:=",ExpressionUUID->"cddcc760-fb28-4f7b-a9d9-ff3675855cb5"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ut1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"dc", "-", "di"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"A", " ", "K", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "dc", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "+", 
     RowBox[{"dc", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "2"]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut1"}], "nu"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"2", " ", "A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}], ")"}]}]}], ")"}]}], 
  SuperscriptBox["K", "2"]]], "Output",
 CellChangeTimes->{3.851868690594057*^9, 3.851873117446684*^9, 
  3.8518733752652187`*^9, 3.8519596532662992`*^9, 3.8519678479979515`*^9, 
  3.851968273794633*^9, 3.851982655997951*^9, 3.852049709670113*^9, 
  3.852071638501611*^9, 3.852071800283456*^9, 3.8521223862992215`*^9, 
  3.852140448061983*^9, 3.852152074388217*^9, 3.8523925553649216`*^9, 
  3.8544657886480665`*^9, 3.8544703895471325`*^9, 3.8545108395255203`*^9, 
  3.861320187769148*^9, 3.861387110179512*^9, 3.861387307656629*^9, 
  3.861387504484613*^9},
 CellLabel->
  "Out[837]=",ExpressionUUID->"24bad9a6-441f-4f63-8d55-ce7e55b8ed5a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Add", " ", 
    RowBox[{"S1Sol", "[", "x", "]"}], " ", "and", " ", "transform"}], 
   "\[Rule]", " ", "nondimensional"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8521404707599726`*^9, 3.8521404789259605`*^9}, {
  3.852392575013794*^9, 3.8523926069608445`*^9}},
 CellLabel->
  "In[838]:=",ExpressionUUID->"ccded802-49e4-4be2-83cb-ef9acdff1953"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"I1", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ut1", " ", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S1Sol", "[", "x", "]"}]}]}], ",", 
      RowBox[{"di", "\[Rule]", "dih"}], ",", 
      RowBox[{"dc", "\[Rule]", "dch"}], ",", 
      RowBox[{"z02", "->", "z02h"}], ",", 
      RowBox[{"UI", "\[Rule]", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851868717155259*^9, 3.8518687424664288`*^9}, {
   3.8518688228991323`*^9, 3.8518688325261197`*^9}, {3.8518693396886034`*^9, 
   3.8518693458437333`*^9}, {3.851967865856931*^9, 3.8519678668512273`*^9}, {
   3.8519682910183706`*^9, 3.851968297390774*^9}, {3.8521404922785645`*^9, 
   3.8521405272191954`*^9}, 3.8521405678974867`*^9},
 CellLabel->
  "In[839]:=",ExpressionUUID->"e8fdf097-19b3-4d5b-a6b6-eb1a04629f89"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dch", "-", "dih"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"A", " ", "K", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "dch", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", " ", "K"}], 
       RowBox[{"nu", " ", 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], "+", 
    RowBox[{"dch", " ", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", " ", "K"}], 
        RowBox[{"nu", " ", 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], "2"]}], "-", 
    RowBox[{"dih", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", " ", "K"}], 
       RowBox[{"nu", " ", 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"2", " ", "A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", " ", "K"}], 
         RowBox[{"nu", " ", 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.8544658085964985`*^9, 3.854470389627632*^9, 
  3.854510839573565*^9, 3.8613201878103123`*^9, 3.86138711023446*^9, 
  3.861387307707204*^9, 3.861387504530854*^9},
 CellLabel->
  "Out[839]=",ExpressionUUID->"23e29179-92d9-49d7-962e-73c877f80593"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"I1", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ut1", " ", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S1Sol", "[", "x", "]"}]}]}], ",", 
      RowBox[{"di", "\[Rule]", "dih"}], ",", 
      RowBox[{"dc", "\[Rule]", "dch"}], ",", 
      RowBox[{"z02", "->", "z02h"}], ",", 
      RowBox[{"UI", "\[Rule]", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851868717155259*^9, 3.8518687424664288`*^9}, {
   3.8518688228991323`*^9, 3.8518688325261197`*^9}, {3.8518693396886034`*^9, 
   3.8518693458437333`*^9}, {3.851967865856931*^9, 3.8519678668512273`*^9}, {
   3.8519682910183706`*^9, 3.851968297390774*^9}, {3.8521404922785645`*^9, 
   3.8521405272191954`*^9}, 3.8521405678974867`*^9},
 CellLabel->
  "In[840]:=",ExpressionUUID->"594fdd82-c597-4243-80ec-1c64eb5ff193"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dch", "-", "dih"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"A", " ", "K", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "dch", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dch", " ", "K"}], 
       RowBox[{"nu", " ", 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], "+", 
    RowBox[{"dch", " ", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dch", " ", "K"}], 
        RowBox[{"nu", " ", 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], "2"]}], "-", 
    RowBox[{"dih", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", " ", "K"}], 
       RowBox[{"nu", " ", 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"2", " ", "A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", " ", "K"}], 
         RowBox[{"nu", " ", 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8518687477873125`*^9, 3.8518688343076706`*^9, 3.8518692684774084`*^9, 
   3.8518693498756423`*^9, 3.85187313171556*^9, 3.851873379406382*^9, 
   3.8519596586178665`*^9, 3.8519683062024403`*^9, 3.851982666360055*^9, 
   3.8520497761196456`*^9, 3.8520716385631895`*^9, 3.852071800377556*^9, {
   3.8521405169319057`*^9, 3.8521405402820115`*^9}, 3.852140572476573*^9, 
   3.85215208085205*^9, {3.852392612786271*^9, 3.85239263235083*^9}, 
   3.8544703896422243`*^9, 3.854510839583496*^9, 3.861320187822748*^9, 
   3.8613871102445517`*^9, 3.861387307720787*^9, 3.86138750454009*^9},
 CellLabel->
  "Out[840]=",ExpressionUUID->"b9bab27e-7e07-4a52-8433-bbc8b48c6486"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"adjust", " ", "for", " ", "functions", " ", "of", " ", 
    RowBox[{"x", " ", ".", " ", "Put"}], " ", "Rec"}], " ", "=", " ", 
   RowBox[{"UI", "*", 
    RowBox[{
     RowBox[{"dch", "[", "0", "]"}], "/", "nu"}], "  ", "wher", " ", "nu", 
    " ", 
    RowBox[{"appears", "."}]}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851869166507133*^9, 3.851869243471583*^9}, {
  3.851869416989169*^9, 3.851869450257578*^9}, {3.851869545065242*^9, 
  3.8518695719325333`*^9}, {3.85187452117701*^9, 3.8518745401578145`*^9}, {
  3.851972194260188*^9, 3.851972199982111*^9}, {3.852140589923499*^9, 
  3.85214059915621*^9}, {3.8521406944333506`*^9, 3.8521407100792274`*^9}, {
  3.8521408654593678`*^9, 3.8521408734255304`*^9}},
 CellLabel->
  "In[841]:=",ExpressionUUID->"52c36b3f-db34-4e37-8960-5294768c9f68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"I1B", " ", "=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dch", "[", "x", "]"}], "-", 
         RowBox[{"dih", "[", "x", "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"A", " ", "K", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"dch", "[", "x", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"dch", "[", "x", "]"}], " ", "K", "*", "Rec"}], 
         RowBox[{" ", 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], "+", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"dch", "[", "x", "]"}], " ", "K", "*", "Rec"}], 
          RowBox[{" ", 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"dih", "[", "x", "]"}], " ", "K", "*", "Rec"}], 
         RowBox[{" ", 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", "A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"dih", "[", "x", "]"}], " ", "K", "*", "Rec"}], 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}]}], 
     ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8518691969703236`*^9, 3.8518692099394836`*^9}, {
   3.8518694611917124`*^9, 3.851869536037734*^9}, {3.8518753216308737`*^9, 
   3.851875327947674*^9}, {3.8519683253657103`*^9, 3.8519683830765195`*^9}, {
   3.8519691443679247`*^9, 3.8519691457285748`*^9}, 3.8519722078023634`*^9, {
   3.852140615285508*^9, 3.852140688785886*^9}, {3.852140732411085*^9, 
   3.852140835281866*^9}},
 CellLabel->
  "In[842]:=",ExpressionUUID->"91f9d3ac-9ecc-4283-875b-a3575e02ef54"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", "this", " ", "makes", " ", "sense"}], 
  "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.852392653782132*^9, 3.8523926661653423`*^9}},
 CellLabel->
  "In[843]:=",ExpressionUUID->"419e9f84-50a1-4abb-a701-5c3258c4c039"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1B", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", 
     RowBox[{"2", "*", "0.000371"}]}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8521436748270426`*^9, 3.8521437056231403`*^9}, {
   3.852152099350381*^9, 3.8521521056689034`*^9}, 3.861387488834433*^9},
 CellLabel->
  "In[844]:=",ExpressionUUID->"7757e649-1ed4-4103-a35f-6c73de0af9ce"],

Cell[BoxData["0.8342494683977685`"], "Output",
 CellChangeTimes->{3.85214371505133*^9, 3.852152106885887*^9, 
  3.852392671079173*^9, 3.8523928787558613`*^9, 3.8544658484965715`*^9, 
  3.854470389682747*^9, 3.8545108397241287`*^9, 3.861320187873714*^9, 
  3.861387110308193*^9, 3.8613873078184433`*^9, 3.861387504620112*^9},
 CellLabel->
  "Out[844]=",ExpressionUUID->"43d106b4-d6a6-443d-b69e-4e8c5fe4c7cb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"I1B", " ", "will", " ", "be", " ", "used"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519828323189635`*^9, 3.851982840340386*^9}},
 CellLabel->
  "In[845]:=",ExpressionUUID->"f5cab13b-2fbf-450c-b2f9-bc30c515c4d8"],

Cell[CellGroupData[{

Cell[BoxData["I2"], "Input",
 CellChangeTimes->{{3.85186958875992*^9, 3.8518696088669724`*^9}},
 CellLabel->
  "In[846]:=",ExpressionUUID->"9aac8e5a-2bfd-415e-8190-8b01498c086b"],

Cell[BoxData[
 FractionBox[
  RowBox[{"di", " ", "ut2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox["di", "z02"], "]"}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.851869591344499*^9, 3.8518731705913267`*^9, 
  3.8518733942597685`*^9, 3.8519596745768504`*^9, 3.8519683947406783`*^9, 
  3.851982771963188*^9, 3.8519828459846044`*^9, 3.852049794717268*^9, 
  3.8520716387452245`*^9, 3.8520718006892333`*^9, 3.8521409013991613`*^9, 
  3.85215211159321*^9, 3.8523926794904275`*^9, 3.854470389704198*^9, 
  3.854510839767906*^9, 3.861320187913144*^9, 3.8613871103628473`*^9, 
  3.861387307863401*^9, 3.8613875046605043`*^9},
 CellLabel->
  "Out[846]=",ExpressionUUID->"96134cda-848c-473e-a2a4-42b9c6c385ac"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Add", " ", 
   RowBox[{"S2Sol", "[", "x", "]"}], " ", "and", " ", "define", " ", 
   "functions"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8523926860859475`*^9, 3.8523927113225546`*^9}},
 CellLabel->
  "In[847]:=",ExpressionUUID->"29f44626-c423-4b6d-a859-8cb2f4394fd4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2A", " ", "=", " ", 
  RowBox[{"I2", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ut2", " ", "\[Rule]", 
      RowBox[{"1", "/", 
       RowBox[{"S2Sol", "[", "x", "]"}]}]}], ",", 
     RowBox[{"di", "\[Rule]", 
      RowBox[{"dih", "[", "x", "]"}]}], ",", 
     RowBox[{"z02", "\[Rule]", "z02h"}], ",", 
     RowBox[{
      RowBox[{"1", "/", "z02"}], "\[Rule]", 
      RowBox[{"1", "/", "z02h"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.8518686969770727`*^9, 3.8518686976339703`*^9}, {
   3.8518696218402395`*^9, 3.8518696645607367`*^9}, {3.8519596785797267`*^9, 
   3.8519596800504417`*^9}, {3.8519684062431507`*^9, 3.8519684086157513`*^9}, 
   3.851982852295695*^9, {3.8521409159875727`*^9, 3.852140954409729*^9}, {
   3.8521410212803497`*^9, 3.852141028881285*^9}},
 CellLabel->
  "In[848]:=",ExpressionUUID->"7484bbc1-6f60-429b-b7f3-a25db1349d38"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"dih", "[", "x", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}]}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}], 
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]]], "Output",
 CellChangeTimes->{
  3.8518686992203655`*^9, 3.851873405139983*^9, 3.8519596809006586`*^9, 
   3.851968410932632*^9, 3.8519828566540847`*^9, 3.8520497990619974`*^9, 
   3.852071638802611*^9, 3.85207180076334*^9, {3.8521409389074364`*^9, 
   3.85214095624358*^9}, 3.852140997426197*^9, 3.8521410320328827`*^9, 
   3.8521521155873427`*^9, 3.852392715711542*^9, 3.8544658754269357`*^9, 
   3.854470389731779*^9, 3.854510839814397*^9, 3.86132018795297*^9, 
   3.861387110411656*^9, 3.861387307910033*^9, 3.861387504708321*^9},
 CellLabel->
  "Out[848]=",ExpressionUUID->"ced305a4-e563-4980-b4ea-9ca57d178764"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2B", " ", "=", " ", "I2A"}]], "Input",
 CellChangeTimes->{{3.852392761666613*^9, 3.8523927665253887`*^9}},
 CellLabel->
  "In[849]:=",ExpressionUUID->"b7f1c1ab-272c-4835-8fa8-4d9b087cf72e"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"dih", "[", "x", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"A", " ", "K"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"K", " ", "Rec", " ", 
        RowBox[{"dih", "[", "x", "]"}]}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}], 
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]]], "Output",
 CellChangeTimes->{3.852392767782757*^9, 3.8544658842015133`*^9, 
  3.854470389748752*^9, 3.854510839855138*^9, 3.8613201879606457`*^9, 
  3.861387110454949*^9, 3.861387307953208*^9, 3.861387504749487*^9},
 CellLabel->
  "Out[849]=",ExpressionUUID->"a2a8238a-7666-48ad-8f3a-f6cb13054962"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2B", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", 
     RowBox[{"2", "*", "0.000371"}]}], ",", 
    RowBox[{"z02h", "\[Rule]", "0.000371"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8521437398045626`*^9, 3.8521437998028994`*^9}, 
   3.861387488837756*^9},
 CellLabel->
  "In[850]:=",ExpressionUUID->"a83bb409-ad98-4f59-be4e-5c0fcc4f4917"],

Cell[BoxData[
 RowBox[{"-", "0.00011270043514012928`"}]], "Output",
 CellChangeTimes->{
  3.852143741965277*^9, {3.852143780145385*^9, 3.8521438017850103`*^9}, 
   3.852152137238248*^9, 3.852392771967951*^9, 3.854465888507089*^9, 
   3.854470389766367*^9, 3.8545108398629*^9, 3.861320187997562*^9, 
   3.861387110463853*^9, 3.861387307962257*^9, 3.861387504757707*^9},
 CellLabel->
  "Out[850]=",ExpressionUUID->"fd6843b8-6661-4df1-9924-66a4173c7084"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ui", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.851968811323039*^9, 3.8519688141217504`*^9}},
 CellLabel->
  "In[851]:=",ExpressionUUID->"a8412832-c458-46a6-9719-912ca37fa949"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"A", " ", "K"}], "+", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"K", " ", "Rec", " ", 
      RowBox[{"dih", "[", "x", "]"}]}], 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
  RowBox[{"ProductLog", "[", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}]]], "Output",
 CellChangeTimes->{3.851968815040558*^9, 3.851982942237903*^9, 
  3.8520498336044946`*^9, 3.8520716389222746`*^9, 3.852071816611922*^9, 
  3.852141097556232*^9, 3.852152141177112*^9, 3.8523927760669365`*^9, 
  3.854465894008004*^9, 3.8544703897822323`*^9, 3.854510839902545*^9, 
  3.861320188005146*^9, 3.86138711050348*^9, 3.86138730800418*^9, 
  3.861387504796935*^9},
 CellLabel->
  "Out[851]=",ExpressionUUID->"496216b9-f8bc-413b-8a29-19600f003345"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"UFact", " ", "=", " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", 
    RowBox[{"Ui", "[", "x", "]"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8518734313937063`*^9, 3.85187348178078*^9}, {
   3.851968800539176*^9, 3.851968822617175*^9}, 3.8519829480024986`*^9},
 CellLabel->
  "In[852]:=",ExpressionUUID->"764c74de-05c2-44ad-b7fe-c5292f48b0b2"],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{
    RowBox[{"A", " ", "K"}], "+", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"K", " ", "Rec", " ", 
       RowBox[{"dih", "[", "x", "]"}]}], 
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]]}]], "Output",
 CellChangeTimes->{3.851873446759611*^9, 3.851873483663573*^9, 
  3.851873600261586*^9, 3.851881235063594*^9, 3.851959720870098*^9, 
  3.8519688241990156`*^9, 3.8519829489667587`*^9, 3.8520498368712807`*^9, 
  3.8520716389793425`*^9, 3.852071816700641*^9, 3.852141101863675*^9, 
  3.852152148584117*^9, 3.852392782920252*^9, 3.8544658991233015`*^9, 
  3.8544703897964954`*^9, 3.854510839912408*^9, 3.861320188037857*^9, 
  3.861387110511978*^9, 3.861387308012527*^9, 3.861387504805526*^9},
 CellLabel->
  "Out[852]=",ExpressionUUID->"4d9957ec-bcdf-4822-86d0-505da8d3b02a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "UFact", "]"}]], "Input",
 CellChangeTimes->{{3.8519688538805056`*^9, 3.8519688643879414`*^9}},
 CellLabel->
  "In[853]:=",ExpressionUUID->"9f219e7c-97a5-4e45-acfa-eeada032eee7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"ut", " ", "UI"}], "\[Rule]", "1"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851972153537933*^9, 3.851972164134797*^9}, {
  3.851972230330377*^9, 3.851972234516999*^9}},
 CellLabel->
  "In[854]:=",ExpressionUUID->"015937c6-0dab-432d-a6be-fa79e8e4e004"],

Cell[BoxData[
 RowBox[{
  RowBox[{"UFact", "[", "x_", "]"}], " ", ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"A", " ", "K"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"K", " ", "Rec", " ", 
           RowBox[{"dih", "[", "x", "]"}]}], 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851873606961873*^9, 3.851873662625697*^9}, {
   3.851968832800237*^9, 3.851968841538314*^9}, {3.8519721444856396`*^9, 
   3.8519721449036493`*^9}, 3.8521411218549953`*^9, 3.85214261796058*^9, {
   3.8521522330759964`*^9, 3.8521522408547106`*^9}},
 CellLabel->
  "In[855]:=",ExpressionUUID->"7cad23fe-7166-4ce7-9e12-20e5cd1a83a2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"UFact", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.852152254234887*^9, 3.8521522581786165`*^9}},
 CellLabel->
  "In[856]:=",ExpressionUUID->"457d3613-54e5-4784-9e11-b576e36eafa0"],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{
    RowBox[{"A", " ", "K"}], "+", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"K", " ", "Rec", " ", 
       RowBox[{"dih", "[", "x", "]"}]}], 
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]]}]], "Output",
 CellChangeTimes->{{3.8521522590532475`*^9, 3.8521522848927374`*^9}, 
   3.852392795558633*^9, 3.8544659151594076`*^9, 3.8544703898362856`*^9, 
   3.854510840002591*^9, 3.861320188107245*^9, 3.8613871105749207`*^9, 
   3.861387308106023*^9, 3.861387504901641*^9},
 CellLabel->
  "Out[856]=",ExpressionUUID->"94ae0adb-03f1-4e27-99c5-ed00e31ea7d7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "it", " ", "makes", " ", "sense"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8523927994073286`*^9, 3.8523928075114985`*^9}},
 CellLabel->
  "In[857]:=",ExpressionUUID->"086ef00e-ec76-4caa-956a-0da262b43879"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"UFact", "[", "x", "]"}], "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", "0.00371"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.852143815899584*^9, 3.8521438203679314`*^9}, 
   3.8613874888416853`*^9},
 CellLabel->
  "In[858]:=",ExpressionUUID->"c3ab5535-47b6-4a94-aa11-139206ee1ec2"],

Cell[BoxData["0.5101889544879318`"], "Output",
 CellChangeTimes->{3.8521438262998915`*^9, 3.8521522475290327`*^9, 
  3.852392812010749*^9, 3.854465919550476*^9, 3.8544703898562098`*^9, 
  3.8545108400474367`*^9, 3.861320188146351*^9, 3.86138711062009*^9, 
  3.86138730815394*^9, 3.861387504943241*^9},
 CellLabel->
  "Out[858]=",ExpressionUUID->"5173f54e-4ac0-47f6-88a9-56a88b368a96"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "I3"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519829681507883`*^9, 3.851982973709914*^9}},
 CellLabel->
  "In[859]:=",ExpressionUUID->"6aa609ae-0de0-41ee-a6fe-9dc700108989"],

Cell[CellGroupData[{

Cell[BoxData["I3"], "Input",
 CellChangeTimes->{{3.8518687010913725`*^9, 3.8518687018911824`*^9}},
 CellLabel->
  "In[860]:=",ExpressionUUID->"1cf35150-ebc7-4172-8780-f027f5a055c2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"ut1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"dc", "-", "di"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
     RowBox[{"dc", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "-", 
     RowBox[{"di", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}]}], ")"}]}], "K"]], "Output",
 CellChangeTimes->{3.8521522962052484`*^9, 3.852392820240578*^9, 
  3.8544659408561325`*^9, 3.8544703899463882`*^9, 3.854510840100361*^9, 
  3.8613201881914988`*^9, 3.861387110663989*^9, 3.861387308203209*^9, 
  3.861387504989081*^9},
 CellLabel->
  "Out[860]=",ExpressionUUID->"8481251d-d7d2-44c2-a80f-9bbebbba86ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"I3", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ut2", " ", "\[Rule]", 
       RowBox[{"1", "/", "S2"}]}], ",", 
      RowBox[{"di", "\[Rule]", 
       RowBox[{"1", "dih"}]}], ",", 
      RowBox[{"dc", "\[Rule]", 
       RowBox[{"1", "dch"}]}], ",", 
      RowBox[{"ut1", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S1Sol", "[", "x", "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8518739294475145`*^9, 3.851874008035644*^9}, {
  3.851968884210758*^9, 3.8519688927639327`*^9}, {3.8521411517052794`*^9, 
  3.852141165265723*^9}},
 CellLabel->
  "In[861]:=",ExpressionUUID->"af5e8ca6-a929-44f6-a4ab-51c2b843138f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"dch", "-", "dih"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
   RowBox[{"dch", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dch", " ", "K"}], 
      RowBox[{"nu", " ", 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], "-", 
   RowBox[{"dih", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", " ", "K"}], 
      RowBox[{"nu", " ", 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}]}], 
  RowBox[{"ProductLog", "[", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}]]], "Output",
 CellChangeTimes->{{3.851873962550318*^9, 3.851874009234546*^9}, 
   3.8519597492003927`*^9, 3.851968896077718*^9, 3.851972249056758*^9, 
   3.8519829913571177`*^9, 3.8520498590994205`*^9, 3.852071639118292*^9, 
   3.8520718168900166`*^9, 3.8521411682830257`*^9, 3.85214120185992*^9, 
   3.852141329025439*^9, 3.852152315525709*^9, 3.8523928280949745`*^9, 
   3.8544659437767286`*^9, 3.8544703900119033`*^9, 3.8545108401410303`*^9, 
   3.861320188201611*^9, 3.861387110704894*^9, 3.861387308211886*^9, 
   3.861387505030179*^9},
 CellLabel->
  "Out[861]=",ExpressionUUID->"a4759076-c398-477d-98a9-7635540c24f3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{"Put", " ", "nu"}], "\[Rule]", 
   RowBox[{"1", "/", "Rec"}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518740317777863`*^9, 3.8518740493156047`*^9}, {
  3.851874133113291*^9, 3.851874136754738*^9}, {3.851972253702067*^9, 
  3.851972259733642*^9}, {3.851983011841034*^9, 3.851983012355293*^9}, {
  3.8521411832115345`*^9, 3.8521411915733414`*^9}},
 CellLabel->
  "In[862]:=",ExpressionUUID->"26a33294-6f31-4464-9388-4ec5eecb5f9a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3B", " ", "=", " ", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "-", 
       RowBox[{"dih", "[", "x", "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"dch", "[", "x", "]"}], " ", "K", "*", "Rec"}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "-", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"dih", "[", "x", "]"}], " ", "K", "*", "Rec"}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}]}], 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]]}]], "Input",
 CellChangeTimes->{{3.8518740144865522`*^9, 3.851874027789448*^9}, {
   3.8518740581849847`*^9, 3.8518740775321608`*^9}, {3.8518741515294356`*^9, 
   3.851874180219778*^9}, {3.851874210697683*^9, 3.8518742251961083`*^9}, {
   3.851952238106142*^9, 3.8519522390955067`*^9}, {3.8519689127598534`*^9, 
   3.851968977136852*^9}, 3.851972266917652*^9, {3.8521412146861286`*^9, 
   3.8521412804785614`*^9}},
 CellLabel->
  "In[863]:=",ExpressionUUID->"63bf9988-dc69-4d36-8a4a-201c574d52ba"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"A", " ", "K"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"dch", "[", "x", "]"}], "-", 
      RowBox[{"dih", "[", "x", "]"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"dch", "[", "x", "]"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], 
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "-", 
   RowBox[{
    RowBox[{"dih", "[", "x", "]"}], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"K", " ", "Rec", " ", 
       RowBox[{"dih", "[", "x", "]"}]}], 
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}]}], 
  RowBox[{"ProductLog", "[", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}]]], "Output",
 CellChangeTimes->{3.8518742278235455`*^9, 3.8519521860927114`*^9, 
  3.8519522439054375`*^9, 3.851959761789217*^9, 3.8519689822511697`*^9, 
  3.851972270204645*^9, 3.851983016234437*^9, 3.852049871841676*^9, 
  3.8520716391834764`*^9, 3.852071816979814*^9, 3.8521412846163464`*^9, 
  3.8521413338011584`*^9, 3.8521523268041544`*^9, 3.852392835972479*^9, 
  3.8544659548274713`*^9, 3.8544703900346603`*^9, 3.854510840187284*^9, 
  3.861320188241685*^9, 3.861387110771307*^9, 3.861387308260912*^9, 
  3.86138750507195*^9},
 CellLabel->
  "Out[863]=",ExpressionUUID->"57b53b59-3739-47a0-808f-53f880ddbea1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3B", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", "0.000371"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8521438404230585`*^9, 3.852143851532708*^9}, 
   3.8613874888453407`*^9},
 CellLabel->
  "In[864]:=",ExpressionUUID->"5f811457-9063-4a6e-86a2-408ca1ec7d2b"],

Cell[BoxData["0.9087714649907657`"], "Output",
 CellChangeTimes->{{3.8521438463169866`*^9, 3.852143852511937*^9}, 
   3.852152441805235*^9, 3.8523928451893854`*^9, 3.8544659648924294`*^9, 
   3.8544685696396646`*^9, 3.854470390048682*^9, 3.854510840195793*^9, 
   3.861320188277875*^9, 3.861387110810248*^9, 3.861387308304652*^9, 
   3.861387505129389*^9},
 CellLabel->
  "Out[864]=",ExpressionUUID->"d072e8fc-0761-459b-b332-3a0caf1446f9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"I1B", ",", 
   RowBox[{
    RowBox[{"UFact", "[", "x", "]"}], "*", "I2B"}], ",", "I3B"}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.851874245714177*^9, 3.8518742649258432`*^9}, {
   3.8518743086831913`*^9, 3.851874332371498*^9}, 3.85187441971628*^9, {
   3.8518745603210945`*^9, 3.8518745951423907`*^9}, 3.8518752119274535`*^9, {
   3.8519690035287404`*^9, 3.851969004244796*^9}, 3.8519690769143143`*^9, {
   3.8519722814197288`*^9, 3.851972294741745*^9}},
 CellLabel->
  "In[865]:=",ExpressionUUID->"985cae73-98cc-4d60-8226-9856fe03dfab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"A", " ", "K", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dch", "[", "x", "]"}], "-", 
         RowBox[{"dih", "[", "x", "]"}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}], " ", 
       RowBox[{"dch", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "+", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", "A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"K", " ", "Rec", " ", 
            RowBox[{"dih", "[", "x", "]"}]}], 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}]}], 
     ")"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"K", " ", "Rec", " ", 
            RowBox[{"dih", "[", "x", "]"}]}], 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]]}], ")"}]}], 
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"A", " ", "K"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dch", "[", "x", "]"}], "-", 
        RowBox[{"dih", "[", "x", "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"dch", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "-", 
     RowBox[{
      RowBox[{"dih", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}]}], 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}]}], 
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.851874266158955*^9, 3.8518743366364098`*^9, 3.851874420932742*^9, {
   3.851874588320595*^9, 3.851874596316755*^9}, 3.851875214064713*^9, 
   3.851875278795478*^9, 3.851875343256854*^9, 3.851881265409589*^9, 
   3.8518813788513994`*^9, 3.8518815397323523`*^9, 3.8519522520748415`*^9, 
   3.8519597687606325`*^9, {3.851968995300458*^9, 3.851969005676625*^9}, 
   3.851969085326335*^9, 3.851969167686038*^9, 3.851972011721018*^9, 
   3.851972297347554*^9, 3.8519731170995736`*^9, 3.8519830285762444`*^9, 
   3.8519836098417673`*^9, 3.8520498847127466`*^9, 3.8520716392409787`*^9, 
   3.852071816993045*^9, 3.85214134106026*^9, 3.852152448473612*^9, 
   3.852392848852167*^9, 3.852392887817899*^9, 3.8544660116290092`*^9, 
   3.854470390065961*^9, 3.8545108402387733`*^9, 3.861320188289699*^9, 
   3.86138711082404*^9, 3.861387308313294*^9, 3.861387505141411*^9},
 CellLabel->
  "Out[865]=",ExpressionUUID->"23713782-d42a-4707-a4f7-ec5145090a50"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Now", " ", "define", " ", "terms"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851874602489704*^9, 3.85187462134516*^9}},
 CellLabel->
  "In[866]:=",ExpressionUUID->"056ce359-ff69-4d5d-bcbc-b80d003f7526"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQB1", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{"I1B", ",", "x"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"UFact", "[", "x", "]"}], "*", 
     RowBox[{"D", "[", 
      RowBox[{"I2B", ",", "x"}], "]"}]}], "+", 
    RowBox[{"D", "[", 
     RowBox[{"I3B", ",", "x"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.852122662057003*^9},
 CellLabel->
  "In[867]:=",ExpressionUUID->"fe37d8ca-e77a-4a84-83f2-d0b75799e18d"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Addition", " ", "of", " ", "RHS", "  ", "to", " ", "form", " ", "a", 
      " ", "complete", " ", "EQB", " ", "EQB1"}], "-", "RHS"}], ",", " ", 
    RowBox[{
     RowBox[{"which", " ", "is", " ", "the", " ", "shear"}], "-", 
     RowBox[{"stress", " ", "profile"}]}], ",", " ", 
    RowBox[{"is", " ", "deferred", " ", "until", " ", 
     RowBox[{"later", ".", " ", "The"}], " ", "RHS", " ", "is", " ", 
     "different", " ", "for", " ", "uncorrected", " ", "and", " ", 
     "corrected", " ", "profiles"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.851877380292621*^9, 3.8518773865457864`*^9}, {
  3.8523933085999193`*^9, 3.8523933848369446`*^9}, {3.8544667036947927`*^9, 
  3.854466708480936*^9}, {3.8544697626828237`*^9, 3.854469872601615*^9}, {
  3.854469950235433*^9, 3.854469970220912*^9}},
 CellLabel->
  "In[868]:=",ExpressionUUID->"4ce40572-576e-4635-802f-19c9a666085d"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "Karman", " ", "Integral", " ", 
   RowBox[{"equation", ".", " ", "The"}], " ", "following", " ", "is", " ", 
   "common", " ", "to", " ", "both", " ", "corrected", " ", "and", " ", 
   "uncorrected", " ", "shear", " ", "stress", " ", "profiles", " ", 
   "because", " ", "the", " ", "profile", " ", "does", " ", "not", " ", 
   "appear"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851875788388176*^9, 3.8518758074173203`*^9}, {
  3.851969588291605*^9, 3.851969594056013*^9}, {3.8544678251679583`*^9, 
  3.8544678432296915`*^9}, {3.854469911506604*^9, 3.8544699299622574`*^9}, {
  3.861320523413863*^9, 3.861320523899166*^9}},
 CellLabel->
  "In[869]:=",ExpressionUUID->"d4f7e667-d918-4a6b-aa14-a56c199dafa2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"J1", ",", "J2"}], "}"}]], "Input",
 CellChangeTimes->{{3.8518764307454715`*^9, 3.8518764348004403`*^9}},
 CellLabel->
  "In[870]:=",ExpressionUUID->"2dc65262-3214-427d-a0af-0503579834d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["ut1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dc", "-", "di"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"A", " ", "K", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "dc", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"A", " ", "K"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "+", 
        RowBox[{"dc", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"dc", " ", "ut1"}], "nu"], "]"}], "2"]}], "-", 
        RowBox[{"di", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"di", " ", "ut1"}], "nu"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"2", " ", "A", " ", "K"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox["K", "2"]], "+", 
    FractionBox[
     RowBox[{"di", " ", 
      SuperscriptBox["ut2", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox["di", "z02"], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z02"], "]"}]}]}], ")"}]}], 
     SuperscriptBox["K", "2"]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"ut1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dc", "-", "di"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
        RowBox[{"dc", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "-", 
        RowBox[{"di", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}]}], ")"}]}], "K"], "+", 
    FractionBox[
     RowBox[{"di", " ", "ut2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["di", "z02"], "]"}]}], ")"}]}], "K"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.851876435676431*^9, 3.8518786199626245`*^9, 
  3.851881724711501*^9, 3.8519598160748844`*^9, 3.85196054562786*^9, 
  3.8519696005154357`*^9, 3.851972385089383*^9, 3.851983082090807*^9, 
  3.8520499431166525`*^9, 3.852071639589748*^9, 3.8520718615080624`*^9, 
  3.8521415180546017`*^9, 3.852142777942891*^9, 3.852152551632982*^9, 
  3.852392985347225*^9, 3.854466061419239*^9, 3.8544666783296576`*^9, 
  3.8544670128791547`*^9, 3.8544703901231127`*^9, 3.854510840348196*^9, 
  3.861320188347687*^9, 3.861387110893608*^9, 3.861387308462141*^9, 
  3.861387505265258*^9},
 CellLabel->
  "Out[870]=",ExpressionUUID->"cd7c19c7-9aaf-4d10-8cda-b9333d9e75e6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{
   "From", " ", "here", " ", "on", " ", "we", " ", "eliminate", " ", "UI", 
    " ", "bu", " ", "putting", " ", "UI"}], " ", "=", "1"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8519697627148647`*^9, 3.8519697753461246`*^9}, {
  3.8519830907047987`*^9, 3.8519830984377985`*^9}},
 CellLabel->
  "In[871]:=",ExpressionUUID->"02d0c4fc-a834-42ad-bdb4-2fa1cdf1324b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"J1", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ut1", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S1Sol", "[", "x", "]"}]}]}], ",", 
      RowBox[{"ut2", "\[Rule]", 
       RowBox[{"1", "/", 
        RowBox[{"S2Sol", "[", "x", "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851876463955768*^9, 3.8518765003354015`*^9}, {
  3.851876547054245*^9, 3.851876555817399*^9}, {3.851876741544276*^9, 
  3.8518767643252335`*^9}, {3.8518768007396574`*^9, 3.8518768013403845`*^9}, {
  3.8518769001733603`*^9, 3.85187695011794*^9}, {3.8518770094748898`*^9, 
  3.8518770431541643`*^9}, {3.851881753158047*^9, 3.8518817540640736`*^9}, {
  3.8519606302347345`*^9, 3.8519606377239943`*^9}, {3.851969620295534*^9, 
  3.851969754108821*^9}, {3.851972391397232*^9, 3.8519723974306645`*^9}},
 CellLabel->
  "In[872]:=",ExpressionUUID->"9a7f0b89-d7ac-4cac-9789-069bf3908070"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dc", "-", "di"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"A", " ", "K", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "dc", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dc", " ", "K"}], 
       RowBox[{"nu", " ", 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], "+", 
    RowBox[{"dc", " ", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "K"}], 
        RowBox[{"nu", " ", 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], "2"]}], "-", 
    RowBox[{"di", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"di", " ", "K"}], 
       RowBox[{"nu", " ", 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"2", " ", "A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"di", " ", "K"}], 
         RowBox[{"nu", " ", 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "]"}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"di", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox["di", "z02"], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z02"], "]"}]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"K", " ", "Rec", " ", 
            RowBox[{"dih", "[", "x", "]"}]}], 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], "2"]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8519696811945953`*^9, {3.85196972965854*^9, 3.85196975820535*^9}, 
   3.8519698555772285`*^9, 3.851972401863599*^9, 3.8519831054432507`*^9, 
   3.851983673749881*^9, 3.85204997264355*^9, 3.8520716396765337`*^9, {
   3.852071861595768*^9, 3.852071867693768*^9}, 3.852141530494855*^9, 
   3.8521416609167037`*^9, 3.852141806399538*^9, 3.852142782510006*^9, 
   3.8521525586212945`*^9, 3.8523929967644196`*^9, 3.8544660678677106`*^9, 
   3.8544670194048147`*^9, 3.854470390199636*^9, 3.8545108404329557`*^9, 
   3.861320188386051*^9, 3.861387110943474*^9, 3.861387308509691*^9, 
   3.8613875053097897`*^9},
 CellLabel->
  "Out[872]=",ExpressionUUID->"f7344620-df60-4bc3-870f-d02084e61401"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1A", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"J1A", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z02", "\[Rule]", "z02h"}], ",", 
      RowBox[{"nu", " ", "\[Rule]", 
       RowBox[{"1", "/", "Rec"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.851876463955768*^9, 3.8518765003354015`*^9}, {
   3.851876547054245*^9, 3.851876555817399*^9}, {3.851876741544276*^9, 
   3.8518767643252335`*^9}, {3.8518768007396574`*^9, 
   3.8518768013403845`*^9}, {3.8518769001733603`*^9, 3.85187695011794*^9}, {
   3.8518770094748898`*^9, 3.8518770431541643`*^9}, {3.851881753158047*^9, 
   3.8518817540640736`*^9}, 3.8519606577829742`*^9, 3.851960782181884*^9, {
   3.8519697921114845`*^9, 3.851969810856394*^9}, {3.8519698454184713`*^9, 
   3.851969878675971*^9}, 3.851983654943867*^9, {3.8521415543563385`*^9, 
   3.852141649903392*^9}, {3.852141790602724*^9, 3.85214179151657*^9}},
 CellLabel->
  "In[873]:=",ExpressionUUID->"00857a12-a045-43a5-a092-3f2841f3738c"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dc", "-", "di"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"A", " ", "K", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "dc", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dc", " ", "K", " ", "Rec"}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "+", 
    RowBox[{"dc", " ", 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dc", " ", "K", " ", "Rec"}], 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}], "2"]}], "-", 
    RowBox[{"di", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"di", " ", "K", " ", "Rec"}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"2", " ", "A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"di", " ", "K", " ", "Rec"}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"di", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox["di", "z02h"], "]"}]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox["di", "z02h"], "]"}]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"K", " ", "Rec", " ", 
            RowBox[{"dih", "[", "x", "]"}]}], 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], "2"]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8519606654081163`*^9, {3.8519607586809616`*^9, 3.851960784824711*^9}, {
   3.851960829326198*^9, 3.851960840774742*^9}, 3.851969823391592*^9, 
   3.851969883428046*^9, 3.851972413363412*^9, 3.8519831180224967`*^9, 
   3.8519836573185234`*^9, 3.8519836972908144`*^9, {3.8520499634965897`*^9, 
   3.8520499773559747`*^9}, 3.852071639745261*^9, 3.8520718721740074`*^9, 
   3.852141576341968*^9, {3.8521416071081514`*^9, 3.852141665744903*^9}, {
   3.8521417935970826`*^9, 3.852141819007868*^9}, 3.85214279636878*^9, 
   3.8521525627194977`*^9, 3.8523930047055707`*^9, 3.8544660718510504`*^9, 
   3.854467022828782*^9, 3.854470390271916*^9, 3.854510840483261*^9, 
   3.8613201883993607`*^9, 3.861387110962166*^9, 3.861387308523561*^9, 
   3.861387505323395*^9},
 CellLabel->
  "Out[873]=",ExpressionUUID->"ff8136be-6dd3-424a-a02b-53f3bebb52cc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Further", " ", "correction", " ", "to", " ", "get", " ", "functions", " ", 
   RowBox[{"right", "."}]}], "   ", "*)"}]], "Input",
 CellChangeTimes->{{3.85197021378288*^9, 3.8519702214057007`*^9}, {
   3.851983123385825*^9, 3.8519831296771536`*^9}, 3.852141674076169*^9, {
   3.8523930147456846`*^9, 3.8523930255132427`*^9}},
 CellLabel->
  "In[874]:=",ExpressionUUID->"e2c0fdc3-2818-46e3-90bb-ea9a4a772f83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"J1B", "=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dch", "[", "x", "]"}], "-", 
         RowBox[{"dih", "[", "x", "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"A", " ", "K", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"A", " ", "K"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"dch", "[", "x", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"dch", "[", "x", "]"}], " ", "K", " ", "Rec"}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "+", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"dch", "[", "x", "]"}], " ", "K", " ", "Rec"}], 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"dih", "[", "x", "]"}], " ", "K", " ", "Rec"}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", "A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"dih", "[", "x", "]"}], " ", "K", " ", "Rec"}], 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"Log", "[", 
              FractionBox[
               RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A", " ", "K"}], "+", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"K", " ", "Rec", " ", 
              RowBox[{"dih", "[", "x", "]"}]}], 
             RowBox[{"ProductLog", "[", 
              RowBox[{
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
               RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}], 
         "2"]}], 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], "2"]]}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.851970183554661*^9, 3.851970186677454*^9}, {
   3.851970338250389*^9, 3.8519704477517786`*^9}, {3.8519724745813847`*^9, 
   3.8519724880334773`*^9}, 3.851972524677884*^9, 3.8519837294038877`*^9, {
   3.8519841049755125`*^9, 3.8519841127612*^9}, {3.851984146215929*^9, 
   3.851984147071603*^9}, {3.852141690261438*^9, 3.8521417597945385`*^9}, {
   3.852141829172304*^9, 3.852141829722912*^9}, {3.852141867585388*^9, 
   3.8521419686903453`*^9}, 3.85214283640197*^9, {3.8521434377637253`*^9, 
   3.8521435487812824`*^9}, 3.852143976709072*^9},
 CellLabel->
  "In[875]:=",ExpressionUUID->"ebfcc9d9-9090-4e00-95dd-85b5e8e45fe4"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", "it", " ", "evaluates"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8523930383702116`*^9, 3.852393059997882*^9}},
 CellLabel->
  "In[876]:=",ExpressionUUID->"e552149b-2708-43f3-acd8-8223cf18da2b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J1B", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", 
     RowBox[{"2", "*", "0.000371"}]}], ",", 
    RowBox[{"z02h", "\[Rule]", "0.000371"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.852143895644539*^9, 3.8521439298199396`*^9}, 
   3.861387488849436*^9},
 CellLabel->
  "In[877]:=",ExpressionUUID->"a001de08-d375-443f-93c3-16325548d64c"],

Cell[BoxData["0.8344483833104934`"], "Output",
 CellChangeTimes->{3.852143897102609*^9, 3.8521439329095097`*^9, 
  3.852143995877164*^9, 3.8521525852532463`*^9, 3.85239306762498*^9, 
  3.8544660844150176`*^9, 3.8544670407666283`*^9, 3.8544703903152475`*^9, 
  3.854510840580737*^9, 3.861320188453308*^9, 3.861387111024667*^9, 
  3.861387308618525*^9, 3.861387505420766*^9},
 CellLabel->
  "Out[877]=",ExpressionUUID->"a5424c61-d887-49e4-b89c-0304914c77bb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"We", " ", "will", " ", "use", " ", "J1B"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851983154768263*^9, 3.8519831620233393`*^9}},
 CellLabel->
  "In[878]:=",ExpressionUUID->"e8074448-2c86-419b-885a-6854976bf757"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Now", " ", "J2"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8519704882569785`*^9, 3.8519704928649797`*^9}},
 CellLabel->
  "In[879]:=",ExpressionUUID->"dd73e1b8-d1ca-4d08-bb15-4a706c3ef535"],

Cell[CellGroupData[{

Cell[BoxData["J2"], "Input",
 CellChangeTimes->{{3.851961170821271*^9, 3.851961171335213*^9}},
 CellLabel->
  "In[880]:=",ExpressionUUID->"fbc0ea47-5dc4-4154-baf0-b92b90320538"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dc", "-", "di"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
      RowBox[{"dc", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dc", " ", "ut1"}], "nu"], "]"}]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"di", " ", "ut1"}], "nu"], "]"}]}]}], ")"}]}], "K"], "+", 
  FractionBox[
   RowBox[{"di", " ", "ut2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z02"], "]"}]}], ")"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.8519611728962045`*^9, 3.851970498788004*^9, 
  3.851970863737213*^9, 3.8519725428978353`*^9, 3.8519831681729474`*^9, 
  3.852050026265853*^9, 3.852071639844364*^9, 3.852071887762667*^9, 
  3.8521420230854416`*^9, 3.852152596834594*^9, 3.8523930726453876`*^9, 
  3.8544660903422756`*^9, 3.854467049636589*^9, 3.8544703903439655`*^9, 
  3.854510840676931*^9, 3.861320188496086*^9, 3.8613871110858383`*^9, 
  3.861387308704266*^9, 3.86138750549899*^9},
 CellLabel->
  "Out[880]=",ExpressionUUID->"0177afee-d5d7-4135-be72-a7b668b3136e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Adjust", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"di", "*", 
      RowBox[{"ut2", "/", "nu"}]}], "]"}], " ", "term", " ", "di", "*", 
    RowBox[{"ut2", "/", "nu"}]}], " ", "=", " ", 
   RowBox[{"Rec", "*", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "/", 
     RowBox[{"S2", "[", "x", "]"}]}]}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.85197098182688*^9, 3.8519710017168145`*^9}, 
   3.851972551053116*^9, {3.8519831848856277`*^9, 3.851983226182047*^9}},
 CellLabel->
  "In[881]:=",ExpressionUUID->"1f26f63b-cdbd-4d83-945b-ed978fe57cb0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J21", " ", "=", " ", 
  RowBox[{"J2", "/.", " ", 
   RowBox[{"nu", "\[Rule]", 
    RowBox[{"1", "/", "Rec"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8519709609128146`*^9, 3.8519709747506304`*^9}, {
  3.851971080346883*^9, 3.8519710978855095`*^9}, {3.8519725600641804`*^9, 
  3.851972561866007*^9}, {3.8521420552057467`*^9, 3.852142063364721*^9}},
 CellLabel->
  "In[882]:=",ExpressionUUID->"cd3114b4-7f25-4238-ab30-f1bd94376e00"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"ut1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dc", "-", "di"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
      RowBox[{"dc", " ", 
       RowBox[{"Log", "[", 
        RowBox[{"dc", " ", "Rec", " ", "ut1"}], "]"}]}], "-", 
      RowBox[{"di", " ", 
       RowBox[{"Log", "[", 
        RowBox[{"di", " ", "Rec", " ", "ut1"}], "]"}]}]}], ")"}]}], "K"], "+", 
  FractionBox[
   RowBox[{"di", " ", "ut2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z02"], "]"}]}], ")"}]}], "K"]}]], "Output",
 CellChangeTimes->{3.851971101049986*^9, 3.85197258151836*^9, 
  3.8519832526561527`*^9, 3.852050053494605*^9, 3.852071639910965*^9, 
  3.852071892051317*^9, 3.8521420646769056`*^9, 3.8521526009752564`*^9, 
  3.8523930807335415`*^9, 3.854466093866799*^9, 3.854467055783673*^9, 
  3.8544703903693867`*^9, 3.8545108407240973`*^9, 3.861320188536316*^9, 
  3.8613871111357183`*^9, 3.8613873087529087`*^9, 3.86138750554039*^9},
 CellLabel->
  "Out[882]=",ExpressionUUID->"0a64d8ec-240d-440c-8ad3-11ee97a6a69e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J2A", " ", "=", " ", 
  RowBox[{"J21", "/.", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ut1", "\[Rule]", 
      RowBox[{"1", "/", 
       RowBox[{"S1Sol", "[", "x", "]"}]}]}], ",", 
     RowBox[{"ut2", "\[Rule]", 
      RowBox[{"1", "/", 
       RowBox[{"S2Sol", "[", "x", "]"}]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.851878680862157*^9, 3.8518787478077745`*^9}, {
   3.851878778978977*^9, 3.851878779650845*^9}, {3.8518818261586885`*^9, 
   3.8518818269180517`*^9}, 3.8519609341812134`*^9, {3.8519612329566455`*^9, 
   3.8519612382158113`*^9}, {3.851970518061519*^9, 3.8519705595682907`*^9}, {
   3.8519711124476023`*^9, 3.851971120287111*^9}, 3.851971213396578*^9, 
   3.852142077762748*^9},
 CellLabel->
  "In[883]:=",ExpressionUUID->"806ac099-ab93-495c-8edb-4df002ee52a4"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dc", "-", "di"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
    RowBox[{"dc", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dc", " ", "K", " ", "Rec"}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "-", 
    RowBox[{"di", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"di", " ", "K", " ", "Rec"}], 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}]}], 
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "+", 
  FractionBox[
   RowBox[{"di", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox["di", "z02"], "]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A", " ", "K"}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"K", " ", "Rec", " ", 
         RowBox[{"dih", "[", "x", "]"}]}], 
        RowBox[{"ProductLog", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
          RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]]}]], "Output",
 CellChangeTimes->{3.8519612404391336`*^9, 3.8519705607858152`*^9, 
  3.851970882131359*^9, 3.85197093359356*^9, 3.851971122107637*^9, 
  3.8519712145171933`*^9, 3.8519725911596217`*^9, 3.851983279831046*^9, 
  3.8520500568251762`*^9, 3.8520716399694986`*^9, 3.852071906087782*^9, 
  3.852142087934107*^9, 3.8521526089888773`*^9, 3.852393086314151*^9, 
  3.854466097147112*^9, 3.854467059450589*^9, 3.854470390385691*^9, 
  3.854510840733021*^9, 3.861320188544479*^9, 3.861387111177106*^9, 
  3.861387308761537*^9, 3.861387505554193*^9},
 CellLabel->
  "Out[883]=",ExpressionUUID->"93a1c67e-6d38-4f43-955d-2ddf260c36d2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Make", " ", "furthernondimensional", " ", "adjustments", "  ", "and", " ", 
   "correct", " ", "for", " ", 
   RowBox[{"functions", " ", "[", "x", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.851970668123923*^9, 3.8519706830575304`*^9}, {
  3.85239310162428*^9, 3.852393115154118*^9}},
 CellLabel->
  "In[884]:=",ExpressionUUID->"e7366cdf-3ef7-4a5c-a1f9-d1b8648ed9fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"J2B", " ", "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dch", "[", "x", "]"}], "-", 
          RowBox[{"dih", "[", "x", "]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"A", " ", "K"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"dch", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"dch", "[", "x", "]"}], " ", "K", " ", "Rec"}], 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], "-", 
       RowBox[{
        RowBox[{"dih", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"dih", "[", "x", "]"}], " ", "K", " ", "Rec"}], 
          RowBox[{"ProductLog", "[", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
            RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}]}], 
      RowBox[{"ProductLog", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
        RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", " ", "K"}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"K", " ", "Rec", " ", 
            RowBox[{"dih", "[", "x", "]"}]}], 
           RowBox[{"ProductLog", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
             RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
       RowBox[{"ProductLog", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
         RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]]}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.8518787831440067`*^9, 3.8518788864088416`*^9}, {
   3.85187892558517*^9, 3.8518789486933765`*^9}, {3.8518792561998687`*^9, 
   3.851879256429002*^9}, {3.8518818429677987`*^9, 3.8518818437308254`*^9}, {
   3.8519599561548624`*^9, 3.851959970782219*^9}, {3.851960210718092*^9, 
   3.851960240400384*^9}, {3.851961047785406*^9, 3.851961064934393*^9}, {
   3.851961302199791*^9, 3.85196135717471*^9}, 3.8519706996926737`*^9, {
   3.8519708002889442`*^9, 3.851970827924198*^9}, {3.8519712500612726`*^9, 
   3.8519713253444448`*^9}, {3.8519726509946337`*^9, 
   3.8519726576469975`*^9}, {3.851984027669241*^9, 3.8519840490273046`*^9}, {
   3.852142132132373*^9, 3.8521422402878456`*^9}, {3.852143277844816*^9, 
   3.8521433521208324`*^9}, 3.852144033681302*^9},
 CellLabel->
  "In[885]:=",ExpressionUUID->"633d12df-963c-4d2e-9eea-701ba6efdf89"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", "this", " ", "evaluates"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.852393126283609*^9, 3.852393135729591*^9}},
 CellLabel->
  "In[886]:=",ExpressionUUID->"5c538785-894d-4594-807a-f509a0f01d60"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"J2B", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", 
     RowBox[{"2", "*", "0.000371"}]}], ",", 
    RowBox[{"z02h", "\[Rule]", "0.000371"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8521440228053274`*^9, 3.8521440234858513`*^9}, 
   3.8613874888521757`*^9},
 CellLabel->
  "In[887]:=",ExpressionUUID->"7b263790-27ec-4789-8f6d-dd4ee6b7df76"],

Cell[BoxData["0.908541853239358`"], "Output",
 CellChangeTimes->{{3.852144025759506*^9, 3.85214403925729*^9}, 
   3.8521526229408283`*^9, 3.8523931836461143`*^9, 3.854466117736786*^9, 
   3.854467068895599*^9, 3.8544703904273195`*^9, 3.85451084082996*^9, 
   3.861320188597453*^9, 3.8613871112419653`*^9, 3.861387308855699*^9, 
   3.86138750564036*^9},
 CellLabel->
  "Out[887]=",ExpressionUUID->"0d92e991-4558-4ca5-85ce-c22c1c9b4e5a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQC", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{"J1B", ",", "x"}], "]"}]}], "+", 
    RowBox[{"D", "[", 
     RowBox[{"J2B", ",", "x"}], "]"}], "-", 
    RowBox[{"1", "/", 
     RowBox[{
      RowBox[{"S2Sol", "[", "x", "]"}], "^", "2"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8518789883045187`*^9, 3.851879066015366*^9}, {
  3.8518791118763485`*^9, 3.85187912686547*^9}, {3.8519620216925507`*^9, 
  3.8519620612786245`*^9}, {3.851971367636671*^9, 3.8519713896531143`*^9}, {
  3.8519726865191517`*^9, 3.8519726873677015`*^9}},
 CellLabel->
  "In[888]:=",ExpressionUUID->"4bec4fca-4865-40a8-8188-40bcb53269c1"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
   RowBox[{
   "We", " ", "now", " ", "have", " ", "two", " ", "equations", " ", "for", 
    " ", 
    RowBox[{"dch", "[", "x", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dic", "[", "x", "]"}], " ", ".", "  ", "Parameters"}], " ", 
    "are", " ", "z01h", " ", "and", " ", 
    RowBox[{"Rec", ".", " ", "These"}], " ", "need", " ", "to", " ", "be", 
    " ", 
    RowBox[{"calculated", ".", " ", "Also"}], " ", "need", " ", "ICs"}]}], 
  "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.851879599018918*^9, 3.8518796864826736`*^9}, {
  3.8518819265966196`*^9, 3.8518819275480814`*^9}, {3.851971397707412*^9, 
  3.8519714047975936`*^9}},
 CellLabel->
  "In[889]:=",ExpressionUUID->"e87d97c2-fbc4-4eb0-8192-fea5eaf9f7ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S2Sol", "[", "x", "]"}], "/.", "  ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"z02h", " ", "->", " ", "0.000371"}], ",", 
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}], " ", ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", 
     RowBox[{"2", "*", "0.000371"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.851966715660026*^9, 3.8519667246294994`*^9}, {
   3.8519667691619716`*^9, 3.851966774358142*^9}, {3.8519670399149747`*^9, 
   3.85196707070533*^9}, {3.851967331720683*^9, 3.851967332475976*^9}, 
   3.8520715958571806`*^9, {3.852129579318751*^9, 3.852129596345292*^9}, {
   3.852142302203098*^9, 3.852142332924719*^9}, 3.8521424690867805`*^9},
 CellLabel->
  "In[890]:=",ExpressionUUID->"a8f3c2d3-5e47-4a9b-86ba-5cbc25b56c89"],

Cell[BoxData["5.261107866708356`"], "Output",
 CellChangeTimes->{
  3.8519673351460533`*^9, 3.851971514789234*^9, 3.8519833670750003`*^9, 
   3.851984171924302*^9, 3.8520501031055565`*^9, 3.8520715991354656`*^9, 
   3.852071934420907*^9, {3.852129599044181*^9, 3.8521296274259863`*^9}, 
   3.852142334309019*^9, {3.8521424521186743`*^9, 3.852142472724807*^9}, 
   3.852142866185707*^9, 3.8521526345213985`*^9, 3.8523931987561865`*^9, 
   3.854466126798706*^9, 3.8544670769166346`*^9, 3.8544703904568124`*^9, 
   3.8545108409158916`*^9, 3.861320188643137*^9, 3.861387111294785*^9, 
   3.861387308941834*^9, 3.861387505722591*^9},
 CellLabel->
  "Out[890]=",ExpressionUUID->"167abe9e-2477-4d63-b10d-30bb6efdcde4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Before", " ", "ODEs", " ", "can", " ", "be", " ", "solved", " ", "we", " ",
    "must", " ", "define", " ", "the", " ", "shear", " ", "stress", " ", 
   RowBox[{"profile", ".", " ", "This"}], " ", "is", " ", "different", " ", 
   "for", " ", "uncorrected", " ", "and", " ", "corrected", " ", "profiles"}],
   "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.854470276124339*^9, 3.854470333747546*^9}},
 CellLabel->
  "In[891]:=",ExpressionUUID->"55040b67-3794-4ada-bb1d-6e41b6838669"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
   "Now", " ", "define", "  ", "RHS", " ", "for", " ", "uncorrected", " ", 
    "shear", " ", "stress", " ", "profile"}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"**", "**", "**", "**", "**", "**", "**", "**"}], 
   "*****)"}]}]], "Input",
 CellChangeTimes->{{3.852144430960307*^9, 3.8521444392208905`*^9}, {
  3.8544672523892813`*^9, 3.854467256841483*^9}, {3.85446961989559*^9, 
  3.854469663250821*^9}, {3.85447002221264*^9, 3.854470030117095*^9}},
 CellLabel->
  "In[892]:=",ExpressionUUID->"1c3b2305-8c6b-4458-813f-8dfe6ef6f3ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RHS", " ", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "/", 
     RowBox[{"S1Sol", "[", "x", "]"}]}], ")"}], "^", "2"}]}]], "Input",
 CellChangeTimes->{{3.8518774092188787`*^9, 3.8518774683683825`*^9}, {
   3.851969495837837*^9, 3.8519695017834826`*^9}, {3.852123819420309*^9, 
   3.8521238859284735`*^9}, {3.8521285195600414`*^9, 3.85212852318195*^9}, {
   3.8521285791278296`*^9, 3.8521285811838126`*^9}, 3.8521294108153977`*^9, {
   3.8521346807674227`*^9, 3.8521346861725435`*^9}, {3.852144424201386*^9, 
   3.8521444244973483`*^9}},
 CellLabel->
  "In[893]:=",ExpressionUUID->"e2e0a281-3aa7-4888-9662-e0b12131aed3"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["K", "2"], 
  SuperscriptBox[
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]]], "Output",
 CellChangeTimes->{{3.8544673232233725`*^9, 3.854467340563424*^9}, 
   3.854467380581951*^9, 3.8544676466261396`*^9, 3.85446789767551*^9, 
   3.8544689468534946`*^9, 3.854469670498966*^9, 3.854469723792582*^9, 
   3.854470034128768*^9, 3.8544703544334574`*^9, 3.854470390488143*^9, 
   3.8545108409695787`*^9, 3.8613201886901608`*^9, 3.8613871113529387`*^9, 
   3.861387308996355*^9, 3.8613875057747087`*^9},
 CellLabel->
  "Out[893]=",ExpressionUUID->"56f4b8a3-6b9d-478d-979e-09ef4975e4d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RHS", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", "0.00371"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.852143871972267*^9, 3.852143873253496*^9}, 
   3.86138748885483*^9},
 CellLabel->
  "In[894]:=",ExpressionUUID->"5abfcb77-b15b-44c7-b5fd-0918f11fd3f4"],

Cell[BoxData["0.0012253407160377496`"], "Output",
 CellChangeTimes->{
  3.852143879868354*^9, 3.8521525427750573`*^9, 3.85239297021323*^9, 
   3.8544660521141815`*^9, 3.854466563511475*^9, {3.854466654605558*^9, 
   3.854466663565705*^9}, 3.854466752911178*^9, 3.8544669208891125`*^9, 
   3.854466992167713*^9, 3.854467384139144*^9, 3.854467650199711*^9, 
   3.8544678977761784`*^9, 3.854468946943591*^9, 3.854469674772769*^9, 
   3.8544697238831635`*^9, 3.854470037932435*^9, 3.854470354494647*^9, 
   3.8544703905033493`*^9, 3.854510841008857*^9, 3.86132018869728*^9, 
   3.86138711136106*^9, 3.861387309036512*^9, 3.861387505814981*^9},
 CellLabel->
  "Out[894]=",ExpressionUUID->"9b0ae716-fbf8-49d6-9da7-0148edad22d3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Form", " ", "EQB", " ", "for", " ", "uncorrected", " ", "RHS"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.851875571700697*^9, 3.8518756062393427`*^9}, {
   3.8518773178590827`*^9, 3.8518773211900396`*^9}, 3.8519695542562656`*^9, {
   3.854467675132112*^9, 3.854467685118376*^9}},
 CellLabel->
  "In[895]:=",ExpressionUUID->"a756a48b-aa86-4571-8aef-9584603dccd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQB", " ", "=", " ", 
   RowBox[{"EQB1", "-", "RHS"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8518784786888294`*^9, 3.8518785268044167`*^9}, {
   3.8518785932858458`*^9, 3.851878613330866*^9}, 3.8518816059186444`*^9, {
   3.8519520992953196`*^9, 3.85195210129722*^9}, {3.8519539499965687`*^9, 
   3.851953968503289*^9}, 3.85195400295744*^9, {3.851969527590869*^9, 
   3.8519695396461782`*^9}, 3.8519695791804967`*^9, 3.8519834929355936`*^9, 
   3.8519836243116455`*^9},
 CellLabel->
  "In[896]:=",ExpressionUUID->"d10fbdd1-167d-42c2-a552-ed41575b821f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**"}], "******)"}]}]], "Input",
 CellChangeTimes->{{3.8518794241757245`*^9, 3.8518794424436684`*^9}, {
  3.854469695096008*^9, 3.85446969988043*^9}},
 CellLabel->
  "In[897]:=",ExpressionUUID->"fe134c15-9aa3-47f8-95ac-006c9c717992"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{"Try", " ", "solution", " ", "of", " ", "ODEs"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Results", " ", "below", " ", "are", " ", "with", " ", "uncorrected", 
      " ", "shear", " ", "stress", " ", 
      RowBox[{"profile", ".", " ", "Note"}], " ", "that", " ", "the", " ", 
      "x"}], "-", 
     RowBox[{"domain", " ", "is", " ", 
      RowBox[{"unbounded", ".", " ", "We"}], " ", "choose", " ", "x"}]}], " ",
     "=", " ", "300"}], "   ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7304701661584663`*^9, 3.730470167776614*^9}, {
  3.730470332073261*^9, 3.7304703419922733`*^9}, {3.85198438149617*^9, 
  3.8519843874641542`*^9}, {3.8521296808459167`*^9, 3.8521296862090564`*^9}, {
  3.852152942868363*^9, 3.8521529992862263`*^9}, {3.8544688202098866`*^9, 
  3.8544688805419536`*^9}},
 CellLabel->
  "In[898]:=",ExpressionUUID->"03d66728-b880-4634-8cfd-481b246a523b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQBN", " ", "=", 
   RowBox[{"EQB", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z02h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, {3.85197601541241*^9, 
   3.8519760263560867`*^9}, {3.851976151846327*^9, 3.8519761540388584`*^9}, {
   3.851978280184795*^9, 3.8519782818348255`*^9}, {3.8519843947572317`*^9, 
   3.851984395835679*^9}, 3.8519844730078897`*^9, {3.8521424847575073`*^9, 
   3.852142485298045*^9}},
 CellLabel->
  "In[899]:=",ExpressionUUID->"8ae65aef-7dd1-4f36-aff8-3f748abfe610"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQCN", " ", "=", " ", 
   RowBox[{"EQC", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z02h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, 3.8519754443209496`*^9, {
   3.851976037160728*^9, 3.8519760468379583`*^9}, {3.8519761617038784`*^9, 
   3.8519761639038644`*^9}, {3.8519782909715233`*^9, 
   3.8519782921539507`*^9}, {3.851984403144809*^9, 3.851984403944397*^9}, {
   3.8521424904753866`*^9, 3.8521424909305363`*^9}},
 CellLabel->
  "In[900]:=",ExpressionUUID->"2f36a8fc-cdce-4cbf-bad1-7619c056acc3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EQBN", "\[Equal]", "0"}], ",", 
      RowBox[{"EQCN", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"dch", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"dih", "[", "0", "]"}], "\[Equal]", 
       RowBox[{"5", "*", "0.000371"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"dch", ",", "dih"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "300"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7304707264222374`*^9, 3.7304707626209087`*^9}, {
   3.730471150076991*^9, 3.730471192732275*^9}, {3.7304712331930275`*^9, 
   3.730471241200686*^9}, {3.7304728856991377`*^9, 3.7304729120458727`*^9}, {
   3.730472984840526*^9, 3.73047299254502*^9}, {3.7305566873513727`*^9, 
   3.7305567308952975`*^9}, {3.730556886927088*^9, 3.7305569131106553`*^9}, {
   3.730557242621592*^9, 3.7305573606363783`*^9}, {3.73055771430449*^9, 
   3.7305577251351695`*^9}, {3.7305581383665457`*^9, 3.730558152935896*^9}, {
   3.7312602620864716`*^9, 3.7312602825580025`*^9}, {3.731261789181636*^9, 
   3.731261791263114*^9}, {3.731261841258609*^9, 3.7312618424734917`*^9}, {
   3.731261876069353*^9, 3.731261877143103*^9}, 3.7312619427736893`*^9, 
   3.7312622845083046`*^9, {3.851951304211819*^9, 3.8519513854604645`*^9}, {
   3.8519514325748835`*^9, 3.851951573326021*^9}, 3.851951750495144*^9, 
   3.8519517868927164`*^9, 3.8519518211241455`*^9, {3.8519518904364605`*^9, 
   3.851951929163808*^9}, {3.851954184356408*^9, 3.851954186600216*^9}, 
   3.8519545520593014`*^9, {3.851955685562499*^9, 3.851955686589571*^9}, {
   3.851955804082919*^9, 3.8519558044788003`*^9}, {3.8519577154585085`*^9, 
   3.851957729652563*^9}, {3.8519641362793827`*^9, 3.8519641651884627`*^9}, {
   3.85196594916074*^9, 3.851965963635912*^9}, {3.85196687697763*^9, 
   3.851966877659809*^9}, 3.8519669317683754`*^9, {3.851973321742544*^9, 
   3.851973342814912*^9}, {3.851973438888547*^9, 3.85197344222373*^9}, {
   3.8519739080027285`*^9, 3.851973917196357*^9}, {3.8519752368984528`*^9, 
   3.85197524325529*^9}, 3.85197551237716*^9, 3.8519755476779995`*^9, {
   3.851975656873122*^9, 3.851975675602148*^9}, 3.8519759905299845`*^9, {
   3.8519760562328253`*^9, 3.8519760689900723`*^9}, {3.8519761322865453`*^9, 
   3.8519761334904423`*^9}, {3.851976181015073*^9, 3.8519761819541464`*^9}, 
   3.8519762263364277`*^9, 3.851976263770647*^9, {3.851978306172095*^9, 
   3.8519783111176233`*^9}, {3.851984419797775*^9, 3.851984420756149*^9}, 
   3.8519845512146025`*^9, {3.8519845958819304`*^9, 3.851984596430002*^9}, {
   3.8519846265771866`*^9, 3.8519846740034294`*^9}, {3.851984704465914*^9, 
   3.8519847064302616`*^9}, {3.8519847453704987`*^9, 3.8519847458878365`*^9}, 
   3.85198477633648*^9, {3.851984821901883*^9, 3.851984822456086*^9}, 
   3.851984853266609*^9, 3.851984886115674*^9, {3.8519849166319323`*^9, 
   3.8519849172646947`*^9}, {3.8519849493404436`*^9, 3.8519849827257023`*^9}, 
   3.8519850187434587`*^9, {3.851985197683219*^9, 3.851985204612754*^9}, {
   3.8520530265694456`*^9, 3.8520530269888067`*^9}, {3.8521293855265307`*^9, 
   3.8521293866389184`*^9}, 3.8521315889329834`*^9, 3.852136732172714*^9, {
   3.8521367628391895`*^9, 3.8521368040561953`*^9}, 3.8521368552556696`*^9, 
   3.85213691123707*^9, {3.852144104173362*^9, 3.8521441305952597`*^9}, {
   3.8521442037874765`*^9, 3.852144273863139*^9}, {3.852144310862769*^9, 
   3.8521443765012107`*^9}, {3.852144519007715*^9, 3.852144519742633*^9}, {
   3.8521445512993555`*^9, 3.852144566675934*^9}, 3.852152658859212*^9, {
   3.8544662745373645`*^9, 3.854466275553238*^9}, {3.8544664691583815`*^9, 
   3.8544665143589134`*^9}, {3.854467100134525*^9, 3.854467101003753*^9}},
 CellLabel->
  "In[901]:=",ExpressionUUID->"0b482a0a-ab45-49e3-9071-03ce1698f691"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dch", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwVxXk0GwYAB+BQyqypkLjSkASLm6rp9Sb5uasprURMlY4IcQtrVVumT0s8
nTk61qebsbZazENcsc7ZN3OU0Va1pTSLx3Sj5blWz2z743sfU5jEi1QlEAif
/Of/nWf7PZv542w14h/fEQjvOKshH/nPF5BRFPMuKsZxhfPLkKlGttAcY+da
1Y9FrXLo9m/KDvjYQ6DraG52c51jIHypJO84Id0m/uT06Cbne+f8mlduR2Be
nWRYjC1Ofe3k9RZbNn6rs3ET5Gxz6OMP/Ja6XDHAqBsh/r3D4VcOdpBDPaDv
WupaZqeCIbbFUQx7oV9bu0rmrYqrFTV+lBQftO3nusyl7kLmk8uStwtcWLnI
j18rUEP0k/y0EIEfdKodX0kq1DHAjfhSfukU3FKZi+59u3GllBXh1eyPibWy
PNEzDQS6b6tbavKR1ZIu897SxO3A1VuPBQG49mh5dsxQC8W8YjkhXwABj8qW
MD9EZYN7ZdZ0IHKjl8tb2XvA27hFyjUKQl53532JNxFmFRonFImnwUqz5MpE
exFbf+PSrs5gNOS0NR25rA3+vT6H6vUzWK76OEHBJiFEhdj4g08o2vcGjAYP
kqDh8V5OzzkLlZ6w1A2uDqwWNZojf/4MbXkOLumDOjiY/nVHZk4YKNzNXBZf
F5apaaKvzMIRYcOvtHisC2tm1HLfcDguiq14nDNkiHeUG8pzQswXNRZxFWSs
+bf09JIiwOQFyyZDKbghKEweao/AG9ubhz+fpSBruHO25FMRVOhNW3fC9fBj
WsaYx4oIF6pfOG1O6mHuqecd47JITFnbcz3C9JF8N/yo/GAUaAcGRnwn9bHH
Qtqa/joK1fNr9u5hBtikEdZVM8WwYN111pwyAMPrg/oEajS84rof7BYYIohB
81N9GA0Sc0aqnDCEIjGrISgsBna0Urc6fyNcTFzZfK4VC1bvVaHPuBF8K1d+
cpHFQo/Q9NA0kIqUY14Q+cWhOMSaojZCxb2K27XNG3Hwzm1U1JzcB7uEgJd9
JfHo/2uJLe7fh6X4kqyO/QmQ3v/zcDqbhi7j16Tp5wl49s+pb4530qBw+0LY
fT4RFHsq0dPZGGQjVtkjehKmZvoKllqMccX0LLejLwnJ0hnxipMJ6KOrM4cc
JVhYLEo9VG2CHDGHWJUtwbeFC0yGJR367U60808lIFPXegPK6bBX2pq8sEqG
kfu2XEebASVrKaQ+Ixli7XV6nS8DPeanM+aGkkGtPzGxIWXAYqu/UMZIQdoF
uavWrwy0XP89eyYpBYKx8s5RFSbe6ta+3+lKwdg0V+rgwsS/dmaj0Q==
                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$108998#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 8.619503238688965}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwVxXk0GwYAB+BQyqypkLjSkASLm6rp9Sb5uasprURMlY4IcQtrVVumT0s8
nTk61qebsbZazENcsc7ZN3OU0Va1pTSLx3Sj5blWz2z743sfU5jEi1QlEAif
/Of/nWf7PZv542w14h/fEQjvOKshH/nPF5BRFPMuKsZxhfPLkKlGttAcY+da
1Y9FrXLo9m/KDvjYQ6DraG52c51jIHypJO84Id0m/uT06Cbne+f8mlduR2Be
nWRYjC1Ofe3k9RZbNn6rs3ET5Gxz6OMP/Ja6XDHAqBsh/r3D4VcOdpBDPaDv
WupaZqeCIbbFUQx7oV9bu0rmrYqrFTV+lBQftO3nusyl7kLmk8uStwtcWLnI
j18rUEP0k/y0EIEfdKodX0kq1DHAjfhSfukU3FKZi+59u3GllBXh1eyPibWy
PNEzDQS6b6tbavKR1ZIu897SxO3A1VuPBQG49mh5dsxQC8W8YjkhXwABj8qW
MD9EZYN7ZdZ0IHKjl8tb2XvA27hFyjUKQl53532JNxFmFRonFImnwUqz5MpE
exFbf+PSrs5gNOS0NR25rA3+vT6H6vUzWK76OEHBJiFEhdj4g08o2vcGjAYP
kqDh8V5OzzkLlZ6w1A2uDqwWNZojf/4MbXkOLumDOjiY/nVHZk4YKNzNXBZf
F5apaaKvzMIRYcOvtHisC2tm1HLfcDguiq14nDNkiHeUG8pzQswXNRZxFWSs
+bf09JIiwOQFyyZDKbghKEweao/AG9ubhz+fpSBruHO25FMRVOhNW3fC9fBj
WsaYx4oIF6pfOG1O6mHuqecd47JITFnbcz3C9JF8N/yo/GAUaAcGRnwn9bHH
Qtqa/joK1fNr9u5hBtikEdZVM8WwYN111pwyAMPrg/oEajS84rof7BYYIohB
81N9GA0Sc0aqnDCEIjGrISgsBna0Urc6fyNcTFzZfK4VC1bvVaHPuBF8K1d+
cpHFQo/Q9NA0kIqUY14Q+cWhOMSaojZCxb2K27XNG3Hwzm1U1JzcB7uEgJd9
JfHo/2uJLe7fh6X4kqyO/QmQ3v/zcDqbhi7j16Tp5wl49s+pb4530qBw+0LY
fT4RFHsq0dPZGGQjVtkjehKmZvoKllqMccX0LLejLwnJ0hnxipMJ6KOrM4cc
JVhYLEo9VG2CHDGHWJUtwbeFC0yGJR367U60808lIFPXegPK6bBX2pq8sEqG
kfu2XEebASVrKaQ+Ixli7XV6nS8DPeanM+aGkkGtPzGxIWXAYqu/UMZIQdoF
uavWrwy0XP89eyYpBYKx8s5RFSbe6ta+3+lKwdg0V+rgwsS/dmaj0Q==
                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$108998#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 8.619503238688965}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 300.}}, {
       5, 7, 1, {183}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlIk3FAgcx8eQo4RyRbNpTJGrUK7U/H4NUQzlFmHINDkqCm0XJpbKJtPF
q5wxFLktHY6M1aJyRmrDMLmaUCm2HLtvt/f28973fd73H/iQ/Y46MokEAkHk
n1US/od/xND+krcE/GflH9YErc6cb2NxBj++CfTpquyJ5jkBsd8xp7CHAdc0
VSipz1mgGdKfkcA7AskVuW32B46Dall/W4//CUgrVm5nHDwN6oV72sdYUdDx
knfoQTkbkgwraJs6YsHuMpeUMxkPS4XJX1WXJ8DTXRfakrQTod5xu4todhKQ
RYxpNYZXQKfYpvG07zUw9vGxMUu6ASgT9uJrTQrYVp93LP9wE1yCU7tDSanA
WF3qsck2HZ72FShQmzKhr4hwRiC8A1+inYcuynFB2jHPxmBLHlAocyU9bvcg
PciN8GjpfVhdXmqfVl0E9IW4F2haAhezysNLOaXwh9Ugad37MhB/L9tw3bIC
vLxUlscfroSyVnXXn288gKU03fSA2kfAKDca9RitBs+r6au4knUQT19Xvean
J8CuzhxpKauH0xvVVp60aYCI9NvbNPi/Q4icKqvzxFMIZCdzomWagPlJ4bFe
TjNYpVDnniw+Aw3qoW2uHq0g+mkXNfx1G0w3eHnXSnSAIPlYpJRRJ3QFxqc5
+XWBREmEK5XUDWYzTBmt7h4I2u7SKJ/UC6kxlpELu99AW9Nm4zHRt0CUo0x0
VvfBGjPbwu70ATAfj2XyBvjgfquGVEwegnD6bOdtPwFcmTdIuHDnHRQVBtEi
BMMgn1+SJSgZhRO5M0SnqHF4c2f7gSd0IWBGDG+T6gRk326ipI1MQuwzCVrc
6ymgXShYFKN8AoKVQ3VM0GeoJX49RSyfhrO1N03Zc1/A/Ax8XbScgW+mgrLI
S7NwmSNJ4u//BuvHdWMtdOfgIc1BmPN9HvbeCneWbFmEz3/RvY2eE3C7hs+V
4XIR7PBsDRbMEvEgB6wHt4nht8Yi8kD0EkycU5t72yCO6oZJ3W8kJbGSRSjp
pUth5y9VRFOZZTh1J8T5Rqs0Stdv4E4nyaBiyNRpLS05pEQ9y34ltQINEvOe
x4+vwHaJLGK5mjyGsG+ZDDgroNz3a8HSFxWxOCwx07RWCfdMxHf7TyvjJIu9
jKOlgiPH2S/PtqriQBQ7PTCchK8S2AFuq9dgWzJ7s+UTNRS010WmlK1Ffk/d
UGIcGRncG7JBOerYHxZsbt1AQW8LGosytA7frlh1dVFEA/cPfKh5s1YT/yzk
jVfCBpzmLHQ792rh8nAz3sdjOqjhHlaUKK2HVPOiWzrcjagj+8VCoKaPVdEr
H5YK9XHn7Lzx1FJD7Dg6VqantRl9Rrr0g6y3oNC77n4e0whPdudrD8cYo7h9
ci4lywSVwpvP+c+Yosbtea8c+lY04umbDWea487xAwqaM9vQZUXyJItORaZp
c3NeJmDBQkRTSwriev55PR5jB6bxbnIebqChMrfgS8kUDZPO1+y7W2WBUkFt
1RnRlnjObpCcsmsnkvSymPUBVlgp7XdXeNEaHYTkD0oFu1DYwtff8Xw3xuVn
hgVN2CA5wbfquiwdHweS52r17dBPPnii/p49inl7Tvmt3ItupdEB/q17MV+c
O8j81QEXPFo8Wbsd0aFoquuQuBNmiyrZB/KcMMDQNGK02Rk3+nqkHexwwc+X
zzQKel2xsiZtwo/vhmc+1CnxR91xB2mI6jO1D8Vtl7DeznggPyDdm75vPz4+
b+b66KEXJud22mmTfNBs6LesZ1QGcj/FrImdZKAC0eGmeYYvKuh9TH2Q74cK
7pxMk8oDqBhjkFNR74+Khe15m18wUak3tKCk9yAqia0s3vSOhbae/Wt7XQIw
urSAc64xECukThF1TYJxnGF9/GXuYVSrUhBErjqK9yRCta9ZhuBgS6Z73NZQ
/Phur67FfCj+G+u6Y/g3rAanPQ==
       "], {Developer`PackedArrayForm, CompressedData["
1:eJwt0gFH3AEAxuH/kiRJkiTJLUlykiRJkpMkSU6SJOckSWomkyTJTJIkySRJ
kswkM5PMJEmSJDMzMzPJzGQyk5n0pL08X+D1exgfjA48CIJgO7hfAokkkUwK
qaSRTgaZZJFNDrnkESKfAgopopgwJZRSRjkVVFJFNTXUEqGOehpopIlmWojS
ShvtdNBJFzHidNNDL330M8AjHjPEE4YZYZQxxpngKc+YZIppZphljnkWeM4i
SyyzwiprrLPBC16yyRaveM2b/5/v8JZ37LLHPgcccsQxJ5xyxns+8JFPfOYL
X/nGORd85wc/ueQXV/zmD9f85R83BEJIIJEkkkkhlTTSySCTLLLJIZc8QuRT
QCFFFBOmhFLKKKeCSqqopoZaItRRTwONNNFMC1FaaaOdDjrpIkacbnropY9+
7iK/Bfb9Tiw=
        "], CompressedData["
1:eJwd1Hk81dn/B3Bc+5Zd2mixV0RRxOuTUJSS8U2hZrJFfYsmWlQGLVQiLdzt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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], ",", 
    RowBox[{"dih", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T6HosaaS2heP/RcJVHn
jxNAdtW1YYWW0z/FyyIHhWIkQPC/muvC698/Hy7qmjJJLkBtxaUHYQPkPxdi
2uMT/zNAcK7WTsob5z+fNY2q3UI5QBkfWAJ67+k/r6vbi7UsPkDtJonmRUzs
Px/Vu07uv0FAagw6qSyv7j9Tocq9E11EQIZ72epIdfA/yz4nOkDNRkDh9Q/v
InfxP4Ogqk4UcklAfVsUe8mH8j9/03tw7+lLQFjpbGotgfM/aNONeFxVTkAK
Uyx8rnH0P8lLY4y4elBAsHcL6M9y9T+AliZjRrRRQCHbw8GVX/Y/VkP9BSgI
U0DKe0WBKl33P6NW9JvSVVRA9mE8aklT+D+SUpK4AI1VQDP821iBNvk/obBD
oYLeVkB+FrX0mir6P1L3mxCIGVhAm3kvJmMM+z8joAdM4W5ZQDWWF0Dw/vs/
aq+TegO+WkACAdFREuv8P1Onxi+p9ltA0kHihavF/T9cAQ2xokldQDM9Cirt
sP4/B0T6uB+GXkC0tyghA4v/PyntB7RlvF9A7txTMLUvAEA2fJS9f4ZgQPG0
wtsrogBAKHZ4ZI4jYUDb/05lUAwBQCohZvHGzWFA+7wCBKZ+AUBn/+P343Ri
QFVecgw27gFA9VG1wcIQY0CynhkirlUCQJNVkHHLuWNAIBInIUXFAkCCzb7k
lVdkQAOjaNjgLANArHh90UTyZEAyj4OU8JEDQObURaQdmmVAuurgqA3/A0Bx
pWE6uDZmQHY36ihcZARADCeHtnzgZkABzYQUqNEEQPgcAPYCf2dAThdsgzw3
BUAgRgmvbRpoQO4Js8xjmgVAWCAcTgLDaED2wYP8dwUGQOFugrBYYGlAFgQA
jfloBkB5bvL42ApqQFjwP3xZ1AZATaHyuj2yakCO5qZrUT0HQHJIRkBkTmtA
KmtiltieB0CnoKOrtPdrQM25ymsuCAhALW1U2saVbECTf2eMJGoIQO5slYK9
MG1ACaH879TJCEC/HeAQ3thtQEtO9EdFMQlA4UJ+YsB1bkBUjUUBcpEJQBMZ
JprMH29A4CndEFL5CUCAIl5LvcZvQItf8M/uXgpAH9D03zcxcED6cJQwYr0K
QIZnPw2mhXBAlAbjA3sjC0AWuTMcddRwQOs01tF3ggtALuMsHtkpcUCs6j9w
DukLQOMm7lyvfXFAqZrwCHNNDEDBJFl95stxQFDUQbbSqgxAJ/vIkLIgckCk
Ff5Jvw8NQLWL4oXfb3JA1+Gyt7JtDUDvEqv6/79yQEo9iV+BzA1Amje2Pw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$109055#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 3.724856134772982}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAANeTIRbRT1T6HosaaS2heP/RcJVHn
jxNAdtW1YYWW0z/FyyIHhWIkQPC/muvC698/Hy7qmjJJLkBtxaUHYQPkPxdi
2uMT/zNAcK7WTsob5z+fNY2q3UI5QBkfWAJ67+k/r6vbi7UsPkDtJonmRUzs
Px/Vu07uv0FAagw6qSyv7j9Tocq9E11EQIZ72epIdfA/yz4nOkDNRkDh9Q/v
InfxP4Ogqk4UcklAfVsUe8mH8j9/03tw7+lLQFjpbGotgfM/aNONeFxVTkAK
Uyx8rnH0P8lLY4y4elBAsHcL6M9y9T+AliZjRrRRQCHbw8GVX/Y/VkP9BSgI
U0DKe0WBKl33P6NW9JvSVVRA9mE8aklT+D+SUpK4AI1VQDP821iBNvk/obBD
oYLeVkB+FrX0mir6P1L3mxCIGVhAm3kvJmMM+z8joAdM4W5ZQDWWF0Dw/vs/
aq+TegO+WkACAdFREuv8P1Onxi+p9ltA0kHihavF/T9cAQ2xokldQDM9Cirt
sP4/B0T6uB+GXkC0tyghA4v/PyntB7RlvF9A7txTMLUvAEA2fJS9f4ZgQPG0
wtsrogBAKHZ4ZI4jYUDb/05lUAwBQCohZvHGzWFA+7wCBKZ+AUBn/+P343Ri
QFVecgw27gFA9VG1wcIQY0CynhkirlUCQJNVkHHLuWNAIBInIUXFAkCCzb7k
lVdkQAOjaNjgLANArHh90UTyZEAyj4OU8JEDQObURaQdmmVAuurgqA3/A0Bx
pWE6uDZmQHY36ihcZARADCeHtnzgZkABzYQUqNEEQPgcAPYCf2dAThdsgzw3
BUAgRgmvbRpoQO4Js8xjmgVAWCAcTgLDaED2wYP8dwUGQOFugrBYYGlAFgQA
jfloBkB5bvL42ApqQFjwP3xZ1AZATaHyuj2yakCO5qZrUT0HQHJIRkBkTmtA
KmtiltieB0CnoKOrtPdrQM25ymsuCAhALW1U2saVbECTf2eMJGoIQO5slYK9
MG1ACaH879TJCEC/HeAQ3thtQEtO9EdFMQlA4UJ+YsB1bkBUjUUBcpEJQBMZ
JprMH29A4CndEFL5CUCAIl5LvcZvQItf8M/uXgpAH9D03zcxcED6cJQwYr0K
QIZnPw2mhXBAlAbjA3sjC0AWuTMcddRwQOs01tF3ggtALuMsHtkpcUCs6j9w
DukLQOMm7lyvfXFAqZrwCHNNDEDBJFl95stxQFDUQbbSqgxAJ/vIkLIgckCk
Ff5Jvw8NQLWL4oXfb3JA1+Gyt7JtDUDvEqv6/79yQEo9iV+BzA1Amje2Pw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$109055#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 300.}, {0., 3.724856134772982}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "300.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 300.}}, {
       5, 7, 1, {183}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlIk3FAgcx8eQo4RyRbNpTJGrUK7U/H4NUQzlFmHINDkqCm0XJpbKJtPF
q5wxFLktHY6M1aJyRmrDMLmaUCm2HLtvt/f28973fd73H/iQ/Y46MokEAkHk
n1US/od/xND+krcE/GflH9YErc6cb2NxBj++CfTpquyJ5jkBsd8xp7CHAdc0
VSipz1mgGdKfkcA7AskVuW32B46Dall/W4//CUgrVm5nHDwN6oV72sdYUdDx
knfoQTkbkgwraJs6YsHuMpeUMxkPS4XJX1WXJ8DTXRfakrQTod5xu4todhKQ
RYxpNYZXQKfYpvG07zUw9vGxMUu6ASgT9uJrTQrYVp93LP9wE1yCU7tDSanA
WF3qsck2HZ72FShQmzKhr4hwRiC8A1+inYcuynFB2jHPxmBLHlAocyU9bvcg
PciN8GjpfVhdXmqfVl0E9IW4F2haAhezysNLOaXwh9Ugad37MhB/L9tw3bIC
vLxUlscfroSyVnXXn288gKU03fSA2kfAKDca9RitBs+r6au4knUQT19Xvean
J8CuzhxpKauH0xvVVp60aYCI9NvbNPi/Q4icKqvzxFMIZCdzomWagPlJ4bFe
TjNYpVDnniw+Aw3qoW2uHq0g+mkXNfx1G0w3eHnXSnSAIPlYpJRRJ3QFxqc5
+XWBREmEK5XUDWYzTBmt7h4I2u7SKJ/UC6kxlpELu99AW9Nm4zHRt0CUo0x0
VvfBGjPbwu70ATAfj2XyBvjgfquGVEwegnD6bOdtPwFcmTdIuHDnHRQVBtEi
BMMgn1+SJSgZhRO5M0SnqHF4c2f7gSd0IWBGDG+T6gRk326ipI1MQuwzCVrc
6ymgXShYFKN8AoKVQ3VM0GeoJX49RSyfhrO1N03Zc1/A/Ax8XbScgW+mgrLI
S7NwmSNJ4u//BuvHdWMtdOfgIc1BmPN9HvbeCneWbFmEz3/RvY2eE3C7hs+V
4XIR7PBsDRbMEvEgB6wHt4nht8Yi8kD0EkycU5t72yCO6oZJ3W8kJbGSRSjp
pUth5y9VRFOZZTh1J8T5Rqs0Stdv4E4nyaBiyNRpLS05pEQ9y34ltQINEvOe
x4+vwHaJLGK5mjyGsG+ZDDgroNz3a8HSFxWxOCwx07RWCfdMxHf7TyvjJIu9
jKOlgiPH2S/PtqriQBQ7PTCchK8S2AFuq9dgWzJ7s+UTNRS010WmlK1Ffk/d
UGIcGRncG7JBOerYHxZsbt1AQW8LGosytA7frlh1dVFEA/cPfKh5s1YT/yzk
jVfCBpzmLHQ792rh8nAz3sdjOqjhHlaUKK2HVPOiWzrcjagj+8VCoKaPVdEr
H5YK9XHn7Lzx1FJD7Dg6VqantRl9Rrr0g6y3oNC77n4e0whPdudrD8cYo7h9
ci4lywSVwpvP+c+Yosbtea8c+lY04umbDWea487xAwqaM9vQZUXyJItORaZp
c3NeJmDBQkRTSwriev55PR5jB6bxbnIebqChMrfgS8kUDZPO1+y7W2WBUkFt
1RnRlnjObpCcsmsnkvSymPUBVlgp7XdXeNEaHYTkD0oFu1DYwtff8Xw3xuVn
hgVN2CA5wbfquiwdHweS52r17dBPPnii/p49inl7Tvmt3ItupdEB/q17MV+c
O8j81QEXPFo8Wbsd0aFoquuQuBNmiyrZB/KcMMDQNGK02Rk3+nqkHexwwc+X
zzQKel2xsiZtwo/vhmc+1CnxR91xB2mI6jO1D8Vtl7DeznggPyDdm75vPz4+
b+b66KEXJud22mmTfNBs6LesZ1QGcj/FrImdZKAC0eGmeYYvKuh9TH2Q74cK
7pxMk8oDqBhjkFNR74+Khe15m18wUak3tKCk9yAqia0s3vSOhbae/Wt7XQIw
urSAc64xECukThF1TYJxnGF9/GXuYVSrUhBErjqK9yRCta9ZhuBgS6Z73NZQ
/Phur67FfCj+G+u6Y/g3rAanPQ==
       "], {Developer`PackedArrayForm, CompressedData["
1:eJwt0gFH3AEAxuH/kiRJkiTJLUlykiRJkpMkSU6SJOckSWomkyTJTJIkySRJ
kswkM5PMJEmSJDMzMzPJzGQyk5n0pL08X+D1exgfjA48CIJgO7hfAokkkUwK
qaSRTgaZZJFNDrnkESKfAgopopgwJZRSRjkVVFJFNTXUEqGOehpopIlmWojS
ShvtdNBJFzHidNNDL330M8AjHjPEE4YZYZQxxpngKc+YZIppZphljnkWeM4i
SyyzwiprrLPBC16yyRaveM2b/5/v8JZ37LLHPgcccsQxJ5xyxns+8JFPfOYL
X/nGORd85wc/ueQXV/zmD9f85R83BEJIIJEkkkkhlTTSySCTLLLJIZc8QuRT
QCFFFBOmhFLKKKeCSqqopoZaItRRTwONNNFMC1FaaaOdDjrpIkacbnropY9+
7iK/Bfb9Tiw=
        "], CompressedData["
1:eJwNkXc4FQoAR41SZBTJM4oKlYvCk+TV7zbITEpmqBtSipCSloyLa14j2Tt7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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8521289733573065`*^9, 3.8521293904665227`*^9, 3.8521294959956727`*^9, 
   3.8521297046089582`*^9, 3.852131592226951*^9, 3.8521347061846323`*^9, {
   3.8521367474139876`*^9, 3.852136806273043*^9}, 3.8521368568819723`*^9, 
   3.8521369154516397`*^9, 3.8521425043719387`*^9, 3.8521428783540773`*^9, 
   3.852143383165412*^9, 3.8521435736482935`*^9, 3.8521436088904057`*^9, {
   3.8521440975916367`*^9, 3.852144105867482*^9}, {3.852144198466983*^9, 
   3.852144220201835*^9}, {3.8521442531812716`*^9, 3.852144258517273*^9}, {
   3.852144288589091*^9, 3.852144313944848*^9}, {3.8521443454602895`*^9, 
   3.8521443783587503`*^9}, {3.852144504929965*^9, 3.852144522238653*^9}, {
   3.8521445547350073`*^9, 3.85214456801539*^9}, {3.852152647602355*^9, 
   3.8521526601284623`*^9}, 3.854466209546666*^9, 3.854466281362112*^9, {
   3.8544664723891907`*^9, 3.8544665166420813`*^9}, 3.854466776386264*^9, 
   3.8544669453513517`*^9, {3.8544670893179035`*^9, 3.8544671035825467`*^9}, 
   3.8544679264099045`*^9, 3.8544689870382767`*^9, 3.854469724379198*^9, 
   3.8544700680728827`*^9, 3.8544703549512224`*^9, 3.8544703908817787`*^9, 
   3.8545108415538483`*^9, 3.86132018916466*^9, 3.861387111680912*^9, 
   3.861387309395067*^9, 3.861387506187943*^9},
 CellLabel->
  "Out[901]=",ExpressionUUID->"df41b258-8051-4e73-9c33-f06f6eaaf1c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"delta_c", ",", "delta_i"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "delta"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, 
   3.8521288666663456`*^9, {3.852130762064339*^9, 3.8521308332363777`*^9}, {
   3.852130896147086*^9, 3.8521310938494043`*^9}, {3.8521367558250923`*^9, 
   3.8521368397526817`*^9}, 3.8521369198904943`*^9, 3.852144113254361*^9, {
   3.8521442109354515`*^9, 3.852144226900914*^9}, {3.852144264779761*^9, 
   3.8521442651655607`*^9}, {3.8521443842250557`*^9, 3.852144384855301*^9}, {
   3.8521445358839865`*^9, 3.852144536559326*^9}, {3.854466286540778*^9, 
   3.854466287182977*^9}, {3.8544663966997547`*^9, 3.854466398272565*^9}, 
   3.8544664910317187`*^9, {3.8544671095431056`*^9, 3.854467124472703*^9}},
 CellLabel->
  "In[902]:=",ExpressionUUID->"b3beead8-1d69-4713-8ecd-b83d036903b3"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVzX881HcAx/E7ERlGfpxfd91Xk6SktPL78y5NKg91JVN+Jy3G3H0rTR3X
ps647mrc+jW1KNOuThoS6bTtIaMxlCz6sZbmR8X3kF9D2/54PZ5/vqidKVvi
dVgsVsR//W9Z6NTbN+pHfl8NO2lYLIZk343qECgqySfipLvfcRlyovPLQzxF
PVGnT+UrlzJkYOEVvRxVKzGKm3as8WOIslvZpKvoIMtNHO8fCGKI14WMbySi
J0Q3QMnZtJ0hzJJy13TVc/LnsvgeaTxDTvadGx2T95BqQVnfVTFDEupzd1RI
+smwu29PfRZDfIqyNLToDRF6xWz9PpcholKPX1JVWhJSvif2fjFDOEkOMq18
jAj4NTmnWxjC6rL3bZk9QbQFlWvlnQzpX88ZLJFMEofW+H0p3QypcTLamiSa
Jo55KVm64wy5rj0o36tiQyK7ueM8T0s+Vu/aNiDXh+RmS0lGopb81h1bErnB
ALrzDrH79moJ7KP1m2bPwap7z7mCdC1ZJNtedUViCFanS5D9CS2Z2hPMTRAZ
44sAYn25QksEc/OHRCoz3M16cbiFNUTGmo5Wv5ZzINOf3ZR9eoiUWbQaS2UL
oRk5P2q36S0Ruqxoue29HB8smsO3ZI8Tq3VjygZzD2gOPuK5lE+S4ducxMJE
P/SHZIf0FE6To9E861OL1kBylqvatoSFq/LoTP/ojzAufTWhLGTDLi0iafxI
IDxLfpXOGM1C8Q9dTdJ9G9HsFtUrC9dFc1Z25aGLwciUjphV/qyHnPbHRo7N
m+EuWXW100QfLXVtYlP/LfBNfRD2o8AA3UZ/ul3r2Iqg0V+O2qjnICvVtcBL
sA3zJ31eVg8YYmylcltafyic0q+53gs0wnsPOwJ9xGGwtZqM4pw1RsmpiPFX
Q9vxbU7IdH6bCXil46+Cs8NRNdJTWWNmCu6r9m/P60ZCd3HnrlklpugXNx4v
+C4KhP3QPy7UDOrU4FilTQzIYdfhukkzLMEfYc3tMUg3zdwUljcX5hXJQ88L
YpGf7+wwvMocq2/N7/80ZifaLgbm9LSY46fSQLaHXRzUaY2u7rstUCxIq37y
Mg66Bneq9utboj2zsXWicBd+Zts4bD5nicRYJ9lgSjzSrp2bfp9YQeA6HOfk
uRs6ll0XVz6xguTYs7PtI7tBC0e3uAg5sDjZsTfyzifYcJOqGzaxBuPGqMIz
9qC2nWdaVGgN3q0D7HyPBFRY3JgeWm6DMsZwskInEX9Lj5TP+t0Gxys1mwNq
E7ExpmydU4wt2pwz1pfKPoXNXUTOTNkiYknUhRMbkpB6y9x4RmEHD77aqkwv
GZLPF/hUcu1xSKO/9FpLMhbb7p8wv2kPvYEviyjFZxD7/+VWs46L0V/naJLD
UyD2jnw38RcX+Q3vJtPnCiHSrh96e5CH2DHDgMNCIaLyMuMiDebh0aTdzpSH
QtDXu7duLJiHtwG+6jMfitAU8tX+Tg4f1YZWBi9zRVhgGS3PiORj+aURd+64
CB/UnWx8epmPYOkLxYlQGoE+pSsMB/lYt0ERtDKMxj9xoS7+DB8w8TR8vJ2G
609PeWItH8tOKo46RdJYEHFq6s0wHxbfe4o1cTSqHpTmto7z0VV3POG1kEb8
/Ubn0zoU9uj5rA2U0cjj3dObb0UhtuFv9sAxGjNTW86EcyjskH9dm6egEWpW
76y0phBk2eP17GsaT+32r9azo7DUMXdZ6mkaxZ9rN/bMozC6tpd3qYiGdcj1
JpUzhUGDvMfri2mMznVwe7GIQu9vvmcHL9MY0z9y3G4xhUcheZbeV2nsfWD/
0TFXCjW7/IzafqRRWqmSJbtTqFjY13CgnIZxr7q9aAWFktd5WdwbNC43X7J/
+iGFC/v6dBKqaFyZ+awg2IPCGQ/lHZNb//171zyTelLInfLLKK+h0Vb/nm2t
F4WcO33eOzQ0ut40CMa8KWQeUU68q6XhqUqXLvWl8C+z6qRc
          "]]}, Annotation[#, "Charting`Private`Tag$109116#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVlHk81AkfgJGbn9WFfR27JZGiIkfRfL+blCjlyH0N8hop5lcfuzaRFCuM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          "]]}, Annotation[#, "Charting`Private`Tag$109116#2"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {Automatic, Automatic}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox["x", HoldForm], TraditionalForm], 
       FormBox["delta", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"delta_c", "delta_i"}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.852130989856325*^9, {3.852131022693478*^9, 3.852131040583562*^9}, {
   3.8521310737532277`*^9, 3.852131096094097*^9}, 3.852131597225279*^9, 
   3.85213470996019*^9, {3.8521367513295164`*^9, 3.852136861485786*^9}, 
   3.8521369207794785`*^9, 3.8521441150023737`*^9, {3.8521442126845193`*^9, 
   3.8521442282150483`*^9}, {3.852144266300352*^9, 3.852144318533679*^9}, 
   3.852144386025009*^9, {3.852144508665457*^9, 3.8521445727710733`*^9}, {
   3.8521526512109694`*^9, 3.852152664122487*^9}, 3.854466288683798*^9, 
   3.854466401288348*^9, {3.8544664764107766`*^9, 3.854466492122064*^9}, 
   3.854466779739745*^9, 3.854466948985453*^9, 3.854467092307378*^9, 
   3.8544671264423456`*^9, 3.8544679319033365`*^9, 3.854468987177422*^9, 
   3.8544697245398006`*^9, 3.8544700682116613`*^9, 3.8544703550786986`*^9, 
   3.8544703910197906`*^9, 3.854510841727565*^9, 3.8613201893610573`*^9, 
   3.8613871117527847`*^9, 3.8613873094805593`*^9, 3.861387506270795*^9},
 CellLabel->
  "Out[902]=",ExpressionUUID->"d741745a-4ad3-4935-b72d-71acc0cbf6a5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}], "/", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "300"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.0"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "delta_ratio"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, {
   3.852124125642785*^9, 3.852124141635003*^9}, {3.8521311140173144`*^9, 
   3.8521311358455563`*^9}, {3.852136793087507*^9, 3.8521368167286*^9}, {
   3.852137159884965*^9, 3.852137179240376*^9}, {3.854466406179469*^9, 
   3.854466408288206*^9}, {3.854466443997735*^9, 3.854466445776703*^9}, {
   3.854467135796082*^9, 3.854467149193948*^9}},
 CellLabel->
  "In[903]:=",ExpressionUUID->"4be731d4-ecc6-48c2-baf0-f0afbc57742d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13k4Vd0XB3CUQlJJhsqQQoYQkXmte42pvFTmudRrDJeXRkOKZChSESIN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       "]]},
     Annotation[#, "Charting`Private`Tag$109197#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["x", HoldForm], TraditionalForm], 
    FormBox["delta_ratio", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 300}, {0, 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8521241496341267`*^9, 3.8521288800069914`*^9, 3.8521295058238277`*^9, 
   3.8521297161720333`*^9, 3.8521311399580317`*^9, 3.852131601893999*^9, 
   3.8521347148755445`*^9, {3.852136794543645*^9, 3.852136818676442*^9}, 
   3.85213692588529*^9, 3.8521371837472353`*^9, 3.8521445442999954`*^9, 
   3.852144577633812*^9, 3.852152674455408*^9, 3.8544664523059874`*^9, 
   3.8544665245735435`*^9, 3.854466784963599*^9, {3.8544671378713207`*^9, 
   3.854467150126757*^9}, 3.854467940025468*^9, 3.8544679801779585`*^9, 
   3.8544689872643948`*^9, 3.854469724662532*^9, 3.854470068324076*^9, 
   3.8544703551787724`*^9, 3.8544703911164217`*^9, 3.854510841882902*^9, 
   3.861320189415147*^9, 3.86138711188198*^9, 3.861387309557529*^9, 
   3.861387506326517*^9},
 CellLabel->
  "Out[903]=",ExpressionUUID->"c14ec73f-09cb-4722-b762-567b8ce2935d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{"Now", " ", "shear", " ", "stress", " ", 
   RowBox[{"profiles", ".", "  ", "Need"}], " ", "numerical", " ", 
   "formula"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.85239354818289*^9, 3.8523935677337036`*^9}},
 CellLabel->
  "In[904]:=",ExpressionUUID->"8fabd8cb-277e-4339-80d4-546393fe59b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"S1Sol", "[", "x", "]"}], ",", 
   RowBox[{"S2Sol", "[", "x", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.852129834464188*^9, 3.85212986212484*^9}},
 CellLabel->
  "In[905]:=",ExpressionUUID->"8e3dc439-6ea5-45b9-80b5-6403274be7e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "K"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.852129864630492*^9, 3.852144586290086*^9, 
  3.8521526852388124`*^9, 3.854466792848514*^9, 3.854467192371884*^9, 
  3.854467993816263*^9, 3.85446898735896*^9, 3.8544697247871532`*^9, 
  3.8544700684268403`*^9, 3.854470355257098*^9, 3.8544703911479445`*^9, 
  3.854510841931653*^9, 3.86132018946239*^9, 3.861387111929654*^9, 
  3.8613873096034193`*^9, 3.861387506376704*^9},
 CellLabel->
  "Out[905]=",ExpressionUUID->"9bfd614b-91e9-4689-8f15-4425f513af34"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S1SolN", "[", "x_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "K"], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"K", "\[Rule]", "0.384"}], ",", 
     RowBox[{"A", "\[Rule]", "4.17"}], ",", 
     RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.852129900314182*^9, 3.852129945731001*^9}, 
   3.8521299946526856`*^9, {3.8521446076637096`*^9, 3.852144646253935*^9}},
 CellLabel->
  "In[906]:=",ExpressionUUID->"01b3c087-c389-4a55-890f-c3af83944273"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S1SolN", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8521300006387076`*^9, 3.8521300287581463`*^9}},
 CellLabel->
  "In[907]:=",ExpressionUUID->"d94e3c06-3958-4f1e-8bc0-7742642a8eca"],

Cell[BoxData[
 RowBox[{"2.6041666666666665`", " ", 
  RowBox[{"ProductLog", "[", 
   RowBox[{"637340.01023888`", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.8521300297560835`*^9, 3.85214465667334*^9, 
  3.852152696627823*^9, 3.8544668005186944`*^9, 3.8544671925010414`*^9, 
  3.854467993932811*^9, 3.854468987440054*^9, 3.85446972494825*^9, 
  3.8544700685370216`*^9, 3.854470355331519*^9, 3.854470391175081*^9, 
  3.854510841981098*^9, 3.861320189508871*^9, 3.861387111975775*^9, 
  3.861387309656344*^9, 3.861387506424677*^9},
 CellLabel->
  "Out[907]=",ExpressionUUID->"5ed12e67-1dd7-4351-81ed-e6a76b38b940"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2SolN", "[", "x_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}]], "/.", 
   " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z02h", " ", "->", " ", "0.000371"}], ",", 
     RowBox[{"K", "\[Rule]", "0.384"}], ",", 
     RowBox[{"A", "\[Rule]", "4.17"}], ",", 
     RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.852129900314182*^9, 3.852129945731001*^9}, {
  3.852130043049155*^9, 3.8521300740164013`*^9}, {3.8521446729744716`*^9, 
  3.8521446776405983`*^9}},
 CellLabel->
  "In[908]:=",ExpressionUUID->"0d642e2e-a729-4b36-9035-7b16345170b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2SolN", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8521300828358326`*^9, 3.852130087574032*^9}},
 CellLabel->
  "In[909]:=",ExpressionUUID->"de1b85e0-bc45-422c-920b-c02f233be7c5"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2.6041666666666665`", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"2695.4177897574123`", " ", 
     RowBox[{"dih", "[", "x", "]"}]}], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    RowBox[{"637340.01023888`", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
  RowBox[{"1.60128`", "\[VeryThinSpace]", "+", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"128512.128`", " ", 
      RowBox[{"dih", "[", "x", "]"}]}], 
     RowBox[{"ProductLog", "[", 
      RowBox[{"637340.01023888`", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}]]], "Output",
 CellChangeTimes->{3.8521300885465574`*^9, 3.8521446925989*^9, 
  3.85215271181011*^9, 3.8544668072966223`*^9, 3.8544671926342273`*^9, 
  3.8544680003545637`*^9, 3.854468987543959*^9, 3.8544697250797863`*^9, 
  3.854470068663002*^9, 3.8544703554055986`*^9, 3.8544703912025366`*^9, 
  3.854510842029313*^9, 3.8613201895557632`*^9, 3.861387112023944*^9, 
  3.861387309714076*^9, 3.861387506470488*^9},
 CellLabel->
  "Out[909]=",ExpressionUUID->"0e2aa00f-5b50-4856-bffe-568fcbd0e407"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1", " ", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{
          RowBox[{"S1SolN", "[", "x", "]"}], "^", "2"}]}], "/.", "s"}], "]"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "Cf1", "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Cf"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, {
   3.852124125642785*^9, 3.852124141635003*^9}, {3.85213011619508*^9, 
   3.8521301430047703`*^9}, {3.852130217573925*^9, 3.852130225014469*^9}, 
   3.852130336873315*^9, {3.8521313538860645`*^9, 3.852131392479273*^9}, {
   3.8521314540560384`*^9, 3.852131455947811*^9}, {3.852131496570117*^9, 
   3.85213151320859*^9}, {3.852137295378949*^9, 3.852137306004427*^9}, {
   3.854466829157797*^9, 3.8544668357344933`*^9}, {3.8544671641435285`*^9, 
   3.85446716508239*^9}},
 CellLabel->
  "In[910]:=",ExpressionUUID->"4fc82e74-e2e0-4285-ab3d-cdf61f719fd1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{
          RowBox[{"S2SolN", "[", "x", "]"}], "^", "2"}]}], "/.", "s"}], "]"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "300"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Orange"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "Cf2", "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8521302425391626`*^9, 3.852130282037215*^9}, 
   3.85213034376534*^9, {3.8521311848524218`*^9, 3.852131268789968*^9}, {
   3.8521313785130234`*^9, 3.8521314486244793`*^9}, 3.8521315072282715`*^9, {
   3.854466838567319*^9, 3.854466846042708*^9}, {3.854467168638209*^9, 
   3.854467169546732*^9}},
 CellLabel->
  "In[911]:=",ExpressionUUID->"59f641ce-2afd-4c64-8b60-426b9c8fc54f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P1pt5", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"P1", ",", "P2", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "300"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.006"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8521302981332645`*^9, 3.8521303070806866`*^9}, {
   3.8521304328913984`*^9, 3.852130438397482*^9}, {3.8521312504548655`*^9, 
   3.852131285765663*^9}, 3.852131325225462*^9, 3.8521313639917946`*^9, 
   3.8521314322379427`*^9, {3.8521527268428793`*^9, 3.8521527921426654`*^9}, {
   3.854466849816766*^9, 3.854466851877669*^9}, {3.854467178178856*^9, 
   3.8544671790655856`*^9}},
 CellLabel->
  "In[912]:=",ExpressionUUID->"bb3d0b36-a536-46c0-b760-e0cb2a65072b"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVzHs0lAkYBnBEcg2J1I5KR6qtdJWQ9xWl1CqVcvm+ufimy6BlPkWimYqy
YiYxsbkUUUmRXST3LitNudXuJLfaTqyQRhFjtrKzfzznOb9znvPMDwjZtV9D
TU0tQJX/u2Tv1y9Dhe3OLeKwoLAZXIh/zGzzEpeDw8qjtW4GXEjqOB1lKW6A
tC6HFYk6XPi46JbWuYLnYB32ziV4KhckPZImTXEbGF4vj0yfwgWHbMFFIb8b
2O3/olKNC8PLSpefKHgLr2UWmie+U5DanzU2LuoDszCn788mKOA1JPuVCQfA
m1xeJh6nwOlaXC3NH4Is7XQ+6wsF/GL7R+EFn8D6T6cBq08UmAdbJXwSjcOz
DNklg34K1Dp/2NA6dQL8peFK8z4KBraay4uESuhkfA626aWg2kZ/dzD/G+g3
Lnmw+y0Fv306LgorUMeIn/pSX7VTsK+Q6/1RpI2aCQVc9jMKGns4RaTHNDxV
t9MuXUoB/sDSbpqqg/QZ26uyBgqWJPhW3BLqok2ux8jOPyj4esiTweMb4Ezt
rqh9NRR4mWR+5hcYY6Y8ayLtDgXjTWcqP4jM0ZhT4ndLQgEXdO2NR80xx0Px
qjuZghfF4rK1frOQx2COGl2goCglrViw0AKjgtIUx0Sqve/N60Z1s9FyerRy
x1nVvqcxec0wAzO+TWbNOkZB27f4tc6LrfBYpY/SiKCgxPS5wdmERei/kbxb
YU1B6I9rWmscV6HpQ1/dyw0BYOY+LpHOsMes1F7ZlaMBMFJjHng10BnzZIpL
QTYBcIZlOSttyUZ05Z/s0erjwG0RK8aVtQmTpH5RI/kcmBNJBCtit2DEt8HH
fJoDN252Np09sg2teg5eZrlxoDkuvjwq1xNN7/CIp2YcOCfr0rdu3omzpeLM
ajkbWutfRBu57kJ5YlLy5kY29Oj/veJO227cv5tXmpjPhrjw5TkOXt6olxo3
GhnPhnE7iXfkwF4s1w96NMZjg97Lti1O0T64Juix3cR2NhSlEYrBz75o591y
JHo1GyyLFYOe8f6YpJGk8LdgA2NQlnFZk0T17qK4jRpsGIh+ej7nChOLhzfd
mPyLBYXhnhyJBRu7Wg3zCvNZsAxf+TTL2Pi20EfgdIoFM8oOf36bw8Hy27eO
s31Y4FK1YCCIHYChJsHDb1az4EHxFnX7ORQui1MYxBqz4IZXZGV3L4UxgoqK
e0NMkMU8fT5xlYve7odMM5uYEMixSZCH7Echa4xk3GaC1/IRymb9ATR85K8T
kcgEYeKbdNnoAcwfc9o0EcIE09S2MPL+QYx8mCeZt4sJwyuGC/wFh3A0bz65
ch0TLKsi1DPteagn0lqawWBCybCuskwjEPt99cJKNZhwvrx25+a6QBxy9m1k
DpDwYrFga3FCEHae69dsaCWBWMbMTvIIxvWpG9wlFSTYzys0K9E6jDEZMO9o
LglRtdq2d1oPo1zSGzo3kQStj6evzRf/jKMvBSbycBLGnujUHvYPwcvWDUsu
sknIlE4qT5iEYvbRK2oO20jgjOtuPhkaivUOx/Wa15HQrpwTEPIyFLt5gzPd
FpDwZfOGwktr+Zj9vbJabERCpa7ZtN5kPrrqTMm9+p2AVXmjqxkKPtIhtpm5
gwR4nn0nTtpLI5X8xNirgwB3D/F2Ox8aX2XUSTRVRsP1ul2+ND7aYTP3XjsB
K1PFZ2xIGg28XT3mqmx6fX10LUWj0PGXiaE2Ajrrz/M+hNK4sN6iKlFGwCEt
J7ctCTTqvZ/+oKWVAI70H/WPiTTed4yzjVXZT3ShLkVMY1iL2zV7lbfP7HN4
c4HGJqHoek4LAbbWySvDf6Xx1MUVakeaCRhze2+Zd41GmW2G4exGAuTTUrq2
3qAxq6ZjuPkZAe8bN6TL82k0k23riFG5fU/KTMfbND4R1DwcekpANddZ/8Xv
NIa8qex/ICWgbFG/NKKUxoSOAK0IlYs+pMQx7tJovWDVoqUqZx/p1+BV0Fgf
6xKT+oSAS/aS+4ZVNEpMhFXbVE7+6iworVb9tb1Wqql87n6/o18tjbFilsvd
BgJiYiUTk3U07hmZFAep/B+WGuPa
           "]]}, 
         Annotation[#, "Charting`Private`Tag$109248#1"]& ]}}, {}}, {{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0.5, 0]], 
          LineBox[CompressedData["
1:eJwV0Xs41AkXwHEsuTYrhUoUskNFqNGgnFMht1Wub0iu1cy4jPnNBblmcgvD
Iiq2pcLSzixZiSy6EYtkk0r3UCxCQtLaef84z3k+z/M9fx3tQKbrMSkJCYl8
8fx/13oufZ4QPrUqsFeaElDOQnrb0QEXQT20uwXFO8UmQs6zpBgtQTvoJ393
1ON8HEzqX5U5U/UQLEgd5nLLMZA/lN8tLRgAd4UJ+tulk2BREn82gfUCHrxb
yWq1PglThn8YxVW9gbfDUjeK6qPhjmJlrkXxEBzhGBRb2EZDwejPc/NZ7+FW
9Nd16z9EAb0917suYQwiSgX+K85Fwe6y1GaCNQFFfb55F1yjIG2v1apzJlNw
FzsU+KpRwKqm3uFVTYNe9woJ9VeR4L1xB9dD9xNM+Kbc1hRFgrXAkLyzeBbY
92nzVaciwegb+amK6hz4DD1bkvWKBPVQnYzprHkIWvNeomxHJEgMbtjTu+IL
7LExGCKtioQxe/WPooRF+MurzPjDFA/+vrGqNGvhK4TIySsM9fGgiazkFsr6
BoG/7hXcvs6D8oIVMo5j/4JGCWO9czEP7iclDuabSODlS2pWXnwe1EyfzGJX
SaKMLD/xsAcPfjCIGnl7XAoVDfd6kJAHF/y54Kr7HRo2voy9t5UHpx8wp42L
pZHvRNZ4K8OD/wmDPSazZJHp1O+6dJsLXUMBIl8HOTS2Ob65p5YLuMFPtnuF
PLZd9U3RL+PClgyvhqsJCnhj/OCYWzoXlmjOmnTWSpz2N5Fs8OQCq8SR98SQ
hMxyiseSAxdGBuweHBgjYYG8mXQecIF2uRTzTJRRyTdAttKACy4qxTOsqlWY
X/GhnCTJBSXR+l8q5VSwZDXL4NQ8B9rszzu+Oa6CKi8mHLZOcsDiVMGVQ7qr
sTwmrGTDcw5snsrx3F68BlfOdK7Z1ciB+e7kxvEsddzcVL7YFseBYFCgrppV
R05PNtecx4G+akEdxXstNticPNgTzgFRXmF1/A/r0LJVSt/bX9x7VZYrt6xH
csM7mUFrcT/UlbtzShMN3Plh1SocQE8XZS9PLeQPVzQ/UBLft/dnxTVpYYFI
kfqdLAfSq16mtaVtRK1fW92ufGXDJmoU/JazCSUeSe5tHWbDwLd0ipWBDj7M
YJEWmtggMHPiHDqig2+YdPuNN9hgzSTVBmaL/cDqslstG669zjVO/ayDCUXS
nLeV4v5O0dbeW7p4Pvt9WE4hG2zShdqB3nrI5hLesxw21K55uDIlQx9Hn8aS
IszY0MTSGKLc1MfZ+jbJFTvYcLfnWOPwmD5GS6x9WbqdDY/TFo/bOBig+/jB
qTF9Niws6bZKy2/B4Zw3Ey0abLAa5hH8lK34ujpRFCjFhs66DQOJp4xwzmRL
3sq/CehTOSE0rjHCJw8UT1v0EjDIrOG/fm2E/fqShiHdBIwb2Bojbkd90WDk
QDsB319kpi//ux1/6Y2vedZEwJb9bzSh2RidL6X5JFUQELF1Z++flqaoVLmz
RDWBgJe7DixrupkiRfy/a7EE/GjtbRTPMMUBcn67y0nxvW9iptV5Uxyx7blf
yCVgWNBl1zJnijctxwowlADvmeBbrTU7MCrT1k/Cm4D9DWev3SFTkNLxs57q
LgLUDsznd6ymooddeadwjgUz9x0XNhtS8aqcelrRLAu6HUp8Em2pqDu/VSJj
hgWnne11dkVT0bPNYTVzUtx7FP1+5SUVRWkOoY4j4j4YOhMqzbFnG3uv62Nx
n5S6TAFL3FYeR0muZ8GnP9UZlxhWaOCaXPstjgXJflprC7fsw4MUqaQkLRb8
luXH3+9ng+X9qdoVdyNAI/pI6MJpO+wQZu5QjoyAisrB7hSOI1rHMkxtzCKg
JzW9PuayMx4020/Jn2DCmf7nSno9h9DqYp59/Skm9N7ri1Xe74q1vGTPyE1M
GFJ6bfz7gBv6JVD8tFvCIZVnVGrh4oHSTicUvjLCYd4s3yN6zBOFSW/bNdXC
QfHxgN3u2MPofGj5Nfd+GIgKjyz8M+OFc58Cavinw0CreuEf53QfjHscxDWE
MND8p7/oorQveshnsnWlwmAstjO79Jej2DZW2F50JxSEPOeA/HX+mLzYsZCc
HgqG+ORwT78/vuoW6Mh4hsLqurCZN6UBWGCrs/PZplDYe1N3LMQ/EJMMH93g
T4fArWo7SapGELZWkRbV74VAhUt044vhIKz4eOzE54IQ6Od3PvxyKRiTVqpY
1oSFACOAnPGReQzNbxdeuLcvBFyMPgWRzY9jcLPz3+7rQyAh89WF/tnjONE+
XS0zx4A1BQNs39YTaAFke9VeBkwZT1X5xNPwQMtJ60khA7RuRkoWU+mYuTbi
SXYWA2qnFBbrpBg4WeHWVBTCgOz65kO2LQxEdf2SOScG9BnE21dnhOC/Qpzq
3saAI4ZHS3IcQvHM2rac+u8ZQN0kVKuVCcMYS+qQ3CwdYpplt//eG4aVF+vy
hh7TQWYyqUxbEI7HjG9lxzTRYe6+fHOYDxPJ2VQ/YQkdijuWF+NUIvACu8DY
IIUOAfMKtokREXi978oXtXA6PF3UCGQ+jsDGmYMdQnc6fLbdIzxPYSFxOfpy
7h46NCqoyQ3nsrB/38CuaDIdTK/M7tBcYGHNtoWzasp0cE55J8jxJDBM75FZ
1yINDjgInMwOEyjMX3cgXGwkmSs89yKwS1kvQFlskwJBMtmXwIK+lGvuX2iw
ptw8tjmIwCXFfZ0v5mkweC+bPh5BYNyxb39Nz9KAJrPb2i6DQELzoaL2RxoE
dIxITmYSuHrdIZe7kzTwzvqpJU9AoIq2T8kJsZ1U31u8+onADArJRzRBg+16
uSa8cwQGl13ft3ucBnPWH7SulBHY2cl/6jVKg49yec/tKwi8enXy+rcPNPjQ
tefCx18JDHHs+LlU7KfueaqWvxG46m5b6uh7GjQFWyn1XSMQi2q6okdoUKc/
2hH5B4FaLPpnTbFF43mpmtcJrFHgk28P06CEMypFbyBwJO9RhYLY56n5raSb
BOoqyM+JhmiQu2QV/0cTgXYu5350E/tM66ildzOBDcJE0fw7GvBP539ZbiHQ
Lbh1bbHY/wGL3EFZ
           "]]}, Annotation[#, "Charting`Private`Tag$109309#1"]& ]}}, {}}}, {
    PlotRange -> {{0, 300}, {0, 0.006}}, DisplayFunction -> Identity, 
     Ticks -> {Automatic, Automatic}, AxesOrigin -> {Automatic, Automatic}, 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox["x", HoldForm], TraditionalForm], 
       FormBox["Cf", TraditionalForm]}, 
     AxesOrigin -> {0, 0.0017565298439869608`}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"Cf1"}, "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"Cf2"}, "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.8521303080785627`*^9, 3.852130439439432*^9, 3.852131230002668*^9, {
   3.8521312747462187`*^9, 3.8521312878332644`*^9}, 3.8521313263882775`*^9, 
   3.8521314332169776`*^9, 3.8521314659240513`*^9, 3.8521315272034454`*^9, 
   3.852131621708188*^9, 3.8521347285753293`*^9, 3.852137028149008*^9, 
   3.852137319304658*^9, 3.8521447087436476`*^9, {3.852152754928*^9, 
   3.852152762545837*^9}, 3.852152793268535*^9, 3.854466820473281*^9, 
   3.854466862744375*^9, 3.854467193029669*^9, 3.8544680103166523`*^9, 
   3.8544689877735987`*^9, 3.854469725320961*^9, 3.8544700689082613`*^9, 
   3.8544703555917664`*^9, 3.854470391354257*^9, 3.8545108422661247`*^9, 
   3.861320189672696*^9, 3.8613871121847353`*^9, 3.861387309875229*^9, 
   3.861387506615913*^9},
 CellLabel->
  "Out[912]=",ExpressionUUID->"7afd1b51-5acc-4f61-9b34-a919b40d6c22"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
   "Uncorrected", " ", "ODE", " ", "solve", " ", "now", " ", "complete"}], 
   "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**"}], "*****)"}]}]], "Input",
 CellChangeTimes->{{3.854468889703472*^9, 3.8544689097777357`*^9}, {
  3.8544690049235115`*^9, 3.8544690101423225`*^9}, {3.854469373618474*^9, 
  3.854469385254258*^9}},
 CellLabel->
  "In[913]:=",ExpressionUUID->"efef26a1-502a-4541-b629-c6f078407086"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
   "Now", " ", "Try", " ", "corrected", " ", "shear", " ", "stress", " ", 
    "at", " ", 
    RowBox[{"interface", ".", " ", "This"}], " ", "requires", " ", "a", " ", 
    "different", " ", "RHS", " ", "to", " ", 
    RowBox[{"EQB", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"Note", ":", "  ", 
     RowBox[{
     "the", " ", "behavior", " ", "is", " ", "quite", " ", "different", " ", 
      "for", " ", "corrected", " ", 
      RowBox[{"RHS", ".", " ", "ODE"}], " ", "solver", " ", "will", " ", 
      "run", " ", "only", " ", "to", " ", "x"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"22.5", " ", "where", " ", "dei"}], " ", "=", "dhc"}]}], "  ", 
   "*)"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.852153107825353*^9, 3.852153141504816*^9}, 
   3.8544672132853203`*^9, {3.854468020224822*^9, 3.854468135909381*^9}, {
   3.854468437621869*^9, 3.85446844222665*^9}, 3.8544689201344357`*^9, 
   3.8544692374372997`*^9, {3.8544692768816953`*^9, 3.8544692816351457`*^9}, {
   3.8544693194816694`*^9, 3.8544693224620533`*^9}, {3.8544700820206766`*^9, 
   3.854470097580553*^9}, {3.861387200499701*^9, 3.861387200968752*^9}},
 CellLabel->
  "In[914]:=",ExpressionUUID->"66331773-4bb9-421b-9f25-7d98c3622c03"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", " ", "=", " ", "1.9971"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", " ", "=", " ", 
   RowBox[{"-", "3.0789"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"RHS", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"S1Sol", "[", "x", "]"}]}], ")"}], "^", "2"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p1", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dih", "[", "x", "]"}], "/", 
         RowBox[{"dch", "[", "x", "]"}]}], ")"}], "^", "3"}]}], "+", 
     RowBox[{"p2", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dih", "[", "x", "]"}], "/", 
          RowBox[{"dch", "[", "x", "]"}]}], ")"}], ")"}], "^", "2"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "p1", "+", "p2"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dih", "[", "x", "]"}], "/", 
        RowBox[{"dch", "[", "x", "]"}]}], ")"}]}], "+", "1"}], 
    ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.8518774092188787`*^9, 3.8518774683683825`*^9}, {
   3.851969495837837*^9, 3.8519695017834826`*^9}, {3.852123819420309*^9, 
   3.8521238859284735`*^9}, {3.8521285195600414`*^9, 3.85212852318195*^9}, {
   3.8521285791278296`*^9, 3.8521285811838126`*^9}, 3.8521294108153977`*^9, {
   3.8521346807674227`*^9, 3.8521346861725435`*^9}, 3.861387093635703*^9},
 CellLabel->
  "In[915]:=",ExpressionUUID->"7d928bc9-9600-4476-b7c9-5ca2690646e0"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["K", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"0.08179999999999987`", " ", 
       RowBox[{"dih", "[", "x", "]"}]}], 
      RowBox[{"dch", "[", "x", "]"}]], "-", 
     FractionBox[
      RowBox[{"3.0789`", " ", 
       SuperscriptBox[
        RowBox[{"dih", "[", "x", "]"}], "2"]}], 
      SuperscriptBox[
       RowBox[{"dch", "[", "x", "]"}], "2"]], "+", 
     FractionBox[
      RowBox[{"1.9971`", " ", 
       SuperscriptBox[
        RowBox[{"dih", "[", "x", "]"}], "3"]}], 
      SuperscriptBox[
       RowBox[{"dch", "[", "x", "]"}], "3"]]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"ProductLog", "[", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}], "2"]]], "Output",
 CellChangeTimes->{
  3.8518774700267987`*^9, 3.8518813006478653`*^9, 3.851881577084176*^9, 
   3.8519522955458813`*^9, 3.8519539118080473`*^9, 3.851959798526639*^9, 
   3.851969509194504*^9, 3.8519723666097918`*^9, 3.851973128416898*^9, 
   3.851983071699252*^9, 3.8520499341647034`*^9, 3.852071639505766*^9, 
   3.852071861377211*^9, 3.8521238585200663`*^9, 3.852123888534499*^9, 
   3.852128531920142*^9, 3.8521285841553464`*^9, 3.852129414897439*^9, 
   3.8521294591169863`*^9, 3.8521346894177866`*^9, 3.8521414908213716`*^9, 
   3.852142761807107*^9, 3.852144460862179*^9, 3.852152530664609*^9, 
   3.852153223587676*^9, {3.852392949931183*^9, 3.8523929655530005`*^9}, 
   3.8544660472554913`*^9, {3.854466643154942*^9, 3.854466659044355*^9}, {
   3.854466739672195*^9, 3.8544667468106737`*^9}, 3.854467621955298*^9, 
   3.854468187967978*^9, 3.8544682552223587`*^9, 3.854469129888514*^9, 
   3.854469306905365*^9, 3.854469506513418*^9, 3.8544701389252825`*^9, 
   3.8544702009341793`*^9, 3.854470355688326*^9, 3.8544703914042315`*^9, 
   3.854510842320591*^9, 3.8613201897257338`*^9, 3.861387112239067*^9, 
   3.861387309935296*^9, 3.861387506671442*^9},
 CellLabel->
  "Out[917]=",ExpressionUUID->"97279200-80df-458e-83a9-00fe9f409bfa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RHS", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "\[Rule]", "0.384"}], ",", 
    RowBox[{
     RowBox[{"dch", "[", "x", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"dih", "[", "x", "]"}], "\[Rule]", "0.00371"}], ",", 
    RowBox[{"A", "\[Rule]", "4.17"}], ",", 
    RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]], "Input",
 CellChangeTimes->{3.861387488866166*^9},
 CellLabel->
  "In[918]:=",ExpressionUUID->"2f3ef37c-6e75-401c-b0e8-b7f77715b377"],

Cell[BoxData["0.0012256607771085597`"], "Output",
 CellChangeTimes->{3.85446763962276*^9, 3.8544681922960076`*^9, 
  3.8544682586286526`*^9, 3.854469129980458*^9, 3.8544693069978056`*^9, 
  3.854469506624527*^9, 3.8544701420541973`*^9, 3.854470201021313*^9, 
  3.8544703557538233`*^9, 3.85447039141867*^9, 3.854510842361869*^9, 
  3.861320189764304*^9, 3.86138711227566*^9, 3.8613873099785*^9, 
  3.86138750671187*^9},
 CellLabel->
  "Out[918]=",ExpressionUUID->"e4169b88-8432-4f0b-971a-7ad540829087"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Form", " ", "EQB", " ", "for", " ", "corrected", " ", "shear", " ", 
   "stress", " ", "profile"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.851875571700697*^9, 3.8518756062393427`*^9}, {
   3.8518773178590827`*^9, 3.8518773211900396`*^9}, 3.8519695542562656`*^9, {
   3.854470145154855*^9, 3.8544701558867655`*^9}},
 CellLabel->
  "In[919]:=",ExpressionUUID->"3c15c630-c4e8-4e0e-ba20-80143fb084b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQB", " ", "=", " ", 
   RowBox[{"EQB1", "-", "RHS"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8518784786888294`*^9, 3.8518785268044167`*^9}, {
   3.8518785932858458`*^9, 3.851878613330866*^9}, 3.8518816059186444`*^9, {
   3.8519520992953196`*^9, 3.85195210129722*^9}, {3.8519539499965687`*^9, 
   3.851953968503289*^9}, 3.85195400295744*^9, {3.851969527590869*^9, 
   3.8519695396461782`*^9}, 3.8519695791804967`*^9, 3.8519834929355936`*^9, 
   3.8519836243116455`*^9},
 CellLabel->
  "In[920]:=",ExpressionUUID->"a137a26e-7727-4cde-9240-5e6c2fe6e49e"],

Cell[BoxData[
 RowBox[{"(*", "  ", 
  RowBox[{
  "Equation", " ", "EQB", " ", "for", " ", "corrected", " ", "RHS", " ", 
   RowBox[{"complete", "."}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8518757218813744`*^9, 3.8518757365865045`*^9}, 
   3.854467775334635*^9, 3.8544678506291175`*^9},
 CellLabel->
  "In[921]:=",ExpressionUUID->"e5b2cb49-83b6-4a43-85db-68366112a9b5"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
    "**"}], "*****)"}]], "Input",
 CellChangeTimes->{{3.8544678106018944`*^9, 3.854467820434574*^9}, {
  3.8544693466263647`*^9, 3.8544693535446835`*^9}},
 CellLabel->
  "In[922]:=",ExpressionUUID->"bfadd152-9010-4b19-a525-4854e0b99ef2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQBN", " ", "=", 
   RowBox[{"EQB", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z02h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, {3.85197601541241*^9, 
   3.8519760263560867`*^9}, {3.851976151846327*^9, 3.8519761540388584`*^9}, {
   3.851978280184795*^9, 3.8519782818348255`*^9}, {3.8519843947572317`*^9, 
   3.851984395835679*^9}, 3.8519844730078897`*^9, {3.8521424847575073`*^9, 
   3.852142485298045*^9}},
 CellLabel->
  "In[923]:=",ExpressionUUID->"a1a41cb1-e67a-41b4-a44f-d612b0acab6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQCN", " ", "=", " ", 
   RowBox[{"EQC", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z02h", " ", "->", " ", "0.000371"}], ",", 
      RowBox[{"K", "\[Rule]", "0.384"}], ",", 
      RowBox[{"A", "\[Rule]", "4.17"}], ",", 
      RowBox[{"Rec", "\[Rule]", "334667"}]}], " ", "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8519750503237295`*^9, 3.851975051748598*^9}, {
   3.8519754025959206`*^9, 3.851975407831726*^9}, 3.8519754443209496`*^9, {
   3.851976037160728*^9, 3.8519760468379583`*^9}, {3.8519761617038784`*^9, 
   3.8519761639038644`*^9}, {3.8519782909715233`*^9, 
   3.8519782921539507`*^9}, {3.851984403144809*^9, 3.851984403944397*^9}, {
   3.8521424904753866`*^9, 3.8521424909305363`*^9}},
 CellLabel->
  "In[924]:=",ExpressionUUID->"218f279c-a7e8-4d6a-a520-205c8acd2160"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"EQBN", "\[Equal]", "0"}], ",", 
      RowBox[{"EQCN", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"dch", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"dih", "[", "0", "]"}], "\[Equal]", 
       RowBox[{"5", "*", "0.000371"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"dch", ",", "dih"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "22.5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7304707264222374`*^9, 3.7304707626209087`*^9}, {
   3.730471150076991*^9, 3.730471192732275*^9}, {3.7304712331930275`*^9, 
   3.730471241200686*^9}, {3.7304728856991377`*^9, 3.7304729120458727`*^9}, {
   3.730472984840526*^9, 3.73047299254502*^9}, {3.7305566873513727`*^9, 
   3.7305567308952975`*^9}, {3.730556886927088*^9, 3.7305569131106553`*^9}, {
   3.730557242621592*^9, 3.7305573606363783`*^9}, {3.73055771430449*^9, 
   3.7305577251351695`*^9}, {3.7305581383665457`*^9, 3.730558152935896*^9}, {
   3.7312602620864716`*^9, 3.7312602825580025`*^9}, {3.731261789181636*^9, 
   3.731261791263114*^9}, {3.731261841258609*^9, 3.7312618424734917`*^9}, {
   3.731261876069353*^9, 3.731261877143103*^9}, 3.7312619427736893`*^9, 
   3.7312622845083046`*^9, {3.851951304211819*^9, 3.8519513854604645`*^9}, {
   3.8519514325748835`*^9, 3.851951573326021*^9}, 3.851951750495144*^9, 
   3.8519517868927164`*^9, 3.8519518211241455`*^9, {3.8519518904364605`*^9, 
   3.851951929163808*^9}, {3.851954184356408*^9, 3.851954186600216*^9}, 
   3.8519545520593014`*^9, {3.851955685562499*^9, 3.851955686589571*^9}, {
   3.851955804082919*^9, 3.8519558044788003`*^9}, {3.8519577154585085`*^9, 
   3.851957729652563*^9}, {3.8519641362793827`*^9, 3.8519641651884627`*^9}, {
   3.85196594916074*^9, 3.851965963635912*^9}, {3.85196687697763*^9, 
   3.851966877659809*^9}, 3.8519669317683754`*^9, {3.851973321742544*^9, 
   3.851973342814912*^9}, {3.851973438888547*^9, 3.85197344222373*^9}, {
   3.8519739080027285`*^9, 3.851973917196357*^9}, {3.8519752368984528`*^9, 
   3.85197524325529*^9}, 3.85197551237716*^9, 3.8519755476779995`*^9, {
   3.851975656873122*^9, 3.851975675602148*^9}, 3.8519759905299845`*^9, {
   3.8519760562328253`*^9, 3.8519760689900723`*^9}, {3.8519761322865453`*^9, 
   3.8519761334904423`*^9}, {3.851976181015073*^9, 3.8519761819541464`*^9}, 
   3.8519762263364277`*^9, 3.851976263770647*^9, {3.851978306172095*^9, 
   3.8519783111176233`*^9}, {3.851984419797775*^9, 3.851984420756149*^9}, 
   3.8519845512146025`*^9, {3.8519845958819304`*^9, 3.851984596430002*^9}, {
   3.8519846265771866`*^9, 3.8519846740034294`*^9}, {3.851984704465914*^9, 
   3.8519847064302616`*^9}, {3.8519847453704987`*^9, 3.8519847458878365`*^9}, 
   3.85198477633648*^9, {3.851984821901883*^9, 3.851984822456086*^9}, 
   3.851984853266609*^9, 3.851984886115674*^9, {3.8519849166319323`*^9, 
   3.8519849172646947`*^9}, {3.8519849493404436`*^9, 3.8519849827257023`*^9}, 
   3.8519850187434587`*^9, {3.851985197683219*^9, 3.851985204612754*^9}, {
   3.8520530265694456`*^9, 3.8520530269888067`*^9}, {3.8521293855265307`*^9, 
   3.8521293866389184`*^9}, 3.8521315889329834`*^9, 3.852136732172714*^9, {
   3.8521367628391895`*^9, 3.8521368040561953`*^9}, 3.8521368552556696`*^9, 
   3.85213691123707*^9, {3.852144104173362*^9, 3.8521441305952597`*^9}, {
   3.8521442037874765`*^9, 3.852144273863139*^9}, {3.852144310862769*^9, 
   3.8521443765012107`*^9}, {3.852144519007715*^9, 3.852144519742633*^9}, {
   3.8521445512993555`*^9, 3.852144566675934*^9}, 3.852152658859212*^9, {
   3.8544662745373645`*^9, 3.854466275553238*^9}, {3.8544664691583815`*^9, 
   3.8544665143589134`*^9}, {3.854467100134525*^9, 3.854467101003753*^9}, {
   3.8544683249026747`*^9, 3.854468326585354*^9}, 3.8544683929395714`*^9, {
   3.8613871204077663`*^9, 3.861387189978856*^9}},
 CellLabel->
  "In[925]:=",ExpressionUUID->"a51a6646-13a6-4472-969c-ddff8afd4cf1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dch", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAc6uKIKWXmT4T+dULAADwP7+i+fp7
edc/NIgXJ0lM8D/sWsM7OXboP15vOYEGgPA/RbW/Kesr8j83C9QzBqvwP08P
Bqvk/vc/GsIUdbTS8D/y2Q8zPVD+P8Jx/qwC/PA/zzPqU9MaAkCgHD+UaCHx
P/EyrpG3TAVASre7Nv1I8T8wWyZKsW8IQDCyULgTb/E/9OT7eLNcC0Dw+KDK
BpLxPwQnMyvliA5AaahYs1+38T9N5eOpj78QQBN4xjzG2fE/pkuIezczEkCT
0o+7GPvxPyaO3Q53xhNAi509SNQe8j9ogWHduj4VQLNuX/3KP/I/0FCWbZbW
FkCj78qAIGPyP8c0Jbv8ZhhAgFHLMGyF8j+AyeJDZ9wZQHXi7PkPpfI/XzpR
jmlxG0AapqSfAcfyPwFc7hNw6xxAV7Wb/1bm8j/JWTxbDoUeQNQuvC/pB/M/
EDbyr5sLIEBbRtiReyjzP5yX3U8yxyBACbWl5IRG8z87Z6HQlJIhQFwvNsmy
ZvM/O4/8bnlQIkCT6HjsX4TzP4LBBGyjCiNAMo6VAB6h8z/cYeVJmdQjQAlK
k+3lv/M/mFpdRRGRJEBVw5JJPdzzP2fBrSFVXSVA6EsEWof68z99Mqtc3iUm
QBz5BonSF/Q/9Ps/tengJkDAHIR4vTL0P34zre7AqydAA3Y0SXpP9D9qw7FF
GmkoQECWDuDdafQ/nV1j+7giKUCHZAWpUIP0P+Nl7ZEj7ClAc0S3u3Ge9D+K
xg5GEKgqQMZoALBJt/Q/RJUI28hzK0DGTPdlsdH0P1+8mY0DMixAaXs6ytbp
9D/C7deeg+wsQMT4UYwEAfU/OI3ukM+2LUAlOjWelhn1Pw+FnKCdcy5AsLLp
Kfcv9T/56iKRN0AvQBUAqZOWR/U/lS0rcIsEMECIoNJpH171P9+RkCY8YjBA
o/XVq4hy9T8yLWLN0scwQCJn2ID5h/U/tnT/gqomMUBHBzYoUZv1P11B8+ek
gzFAIRMFAp+t9T8ORVM9hegxQCBMaJa2wPU/8PR+oaZGMkADF/cRx9H1P9vb
FvatrDJAfuyYPGvj9T/qRwX61xAzQECzFATV8/U/KWC/DENuM0DO+uwNSwL2
P3Kv5Q+U0zNA9WNKFwIR9j/sqtchJjI0QNqeuQbKHfY/b901JJ6YNEAsMsQJ
iyr2PxaV6tU4/TRAttD2/uU19j/t+GqWFFs1QP1rUGVkP/Y/zpNXR9bANUCc
UX3Zakj2P9/aDwfZHzZATqIez5VP9j+4Fpr5/382QDY7I/KGVfY/DvvNaA==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$109481#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 1.0000000440919095`}, 
                  FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 1.0000000440919095`}, DisplayFunction :> 
                  Identity, Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 22.5}, {1.0000000440919095`, 
                   1.3958806475163335`}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "22.5`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAc6uKIKWXmT4T+dULAADwP7+i+fp7
edc/NIgXJ0lM8D/sWsM7OXboP15vOYEGgPA/RbW/Kesr8j83C9QzBqvwP08P
Bqvk/vc/GsIUdbTS8D/y2Q8zPVD+P8Jx/qwC/PA/zzPqU9MaAkCgHD+UaCHx
P/EyrpG3TAVASre7Nv1I8T8wWyZKsW8IQDCyULgTb/E/9OT7eLNcC0Dw+KDK
BpLxPwQnMyvliA5AaahYs1+38T9N5eOpj78QQBN4xjzG2fE/pkuIezczEkCT
0o+7GPvxPyaO3Q53xhNAi509SNQe8j9ogWHduj4VQLNuX/3KP/I/0FCWbZbW
FkCj78qAIGPyP8c0Jbv8ZhhAgFHLMGyF8j+AyeJDZ9wZQHXi7PkPpfI/XzpR
jmlxG0AapqSfAcfyPwFc7hNw6xxAV7Wb/1bm8j/JWTxbDoUeQNQuvC/pB/M/
EDbyr5sLIEBbRtiReyjzP5yX3U8yxyBACbWl5IRG8z87Z6HQlJIhQFwvNsmy
ZvM/O4/8bnlQIkCT6HjsX4TzP4LBBGyjCiNAMo6VAB6h8z/cYeVJmdQjQAlK
k+3lv/M/mFpdRRGRJEBVw5JJPdzzP2fBrSFVXSVA6EsEWof68z99Mqtc3iUm
QBz5BonSF/Q/9Ps/tengJkDAHIR4vTL0P34zre7AqydAA3Y0SXpP9D9qw7FF
GmkoQECWDuDdafQ/nV1j+7giKUCHZAWpUIP0P+Nl7ZEj7ClAc0S3u3Ge9D+K
xg5GEKgqQMZoALBJt/Q/RJUI28hzK0DGTPdlsdH0P1+8mY0DMixAaXs6ytbp
9D/C7deeg+wsQMT4UYwEAfU/OI3ukM+2LUAlOjWelhn1Pw+FnKCdcy5AsLLp
Kfcv9T/56iKRN0AvQBUAqZOWR/U/lS0rcIsEMECIoNJpH171P9+RkCY8YjBA
o/XVq4hy9T8yLWLN0scwQCJn2ID5h/U/tnT/gqomMUBHBzYoUZv1P11B8+ek
gzFAIRMFAp+t9T8ORVM9hegxQCBMaJa2wPU/8PR+oaZGMkADF/cRx9H1P9vb
FvatrDJAfuyYPGvj9T/qRwX61xAzQECzFATV8/U/KWC/DENuM0DO+uwNSwL2
P3Kv5Q+U0zNA9WNKFwIR9j/sqtchJjI0QNqeuQbKHfY/b901JJ6YNEAsMsQJ
iyr2PxaV6tU4/TRAttD2/uU19j/t+GqWFFs1QP1rUGVkP/Y/zpNXR9bANUCc
UX3Zakj2P9/aDwfZHzZATqIez5VP9j+4Fpr5/382QDY7I/KGVfY/DvvNaA==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$109481#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 1.0000000440919095`}, 
                  FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 1.0000000440919095`}, DisplayFunction :> 
                  Identity, Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 22.5}, {1.0000000440919095`, 
                   1.3958806475163335`}}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "22.5`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 22.5}}, {
       5, 7, 1, {130}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlIszFAgcx4lWltusZJdVi1bay3sLRfP7hTmsqPSikVeouDg5j41OaYlw
lkkZj7x6mCan9Wgvj6y9xKLTVZ6rTh7bYySV7B6rvZu7Zu4z853PfP+Bj0lo
jG/4ChUVFdV/lqbyP3zGcu3QHg34z5SvNod0yRlRZYrt1+8A3urLharCfSAI
2lEhHQgGjx0p8X29x2DYsIVd3xENVjzCjHNoHHwoqKuvOJoIjYV+HPXwZEgo
UsXjEalQ6n1ATdpwDkhaHhmxf3AhtXu75vLsBZhLt8zJ1M6GEFfj1Xrf/gwn
zmqK+6t5YPpn2sVCuwJgALvHK+QSmJWTiSt4l8FcOez56/0iYAZVZEW/K4bN
7cfEDKMysKBba0rY5SDYHj2pI66EoWk3l8aZapDzaJWHdG4A1fmjcpFVA9te
dQdePXQLHEejtp8h1oLDI5J+QFsd0MaHk9Y58qHE/5Y0J78eDJ8m71e8bYDi
Xd6iKLcmsLTGiEMnBSAks4iul+/BvnmzX6zaW0A6SPU1fN0GrWMrl9JWCYHg
o+yTG3XAnCA6s6JBBBKTF64e7AfQme2tfD/eCXc+tzZfSeyC4iCLBCCJIV1c
YvvqWg+w1hoSf1D2wcvgogm5fz94HMx+jqOPgZ7S45mu8QQWKjXvirc8hUdd
Hqak0Gfw2O+d/QxtEJ68yffqGRiCgdP2wTV5IzCkJfkxw1MCo6WpWWFqz2HM
knHVpe0FOFKq3FPLx+EcxQ6PjL+EXorI0clkEvSovrYGoVMQSJ1gyqqmoYZ6
ynRgUgoW+0cFdP5r4Oe5eEf+9Ba29t6aaPSagWbCmiQldRbAJfkbtvQ9TNyP
3dszMgcnclSCjEw/wpx/3vfRkZ8gyXz9aWH9PCjnb1/QXfoMGSKnwjBXGZB4
PVV3s+XAIU553zy8CNPcZfkVpgL2KPWvZcqXoYVjs5vTpYQ1i4zlLb0q6Cng
+9bWq2LrCJ1ssLACrRW5/dxt6li9XpE7l7IS9XdG7goQEjDr6DCxW20VKtK/
E7PcNTHY2Pj8eg0t/K35L2fNLm00P/B04VMGCTsTD/rFbNBBmZtrU5gaGZm6
NrqHJ8nYL7DI79Zfg/FHmDoObD2kqW3Mu35mLXbUmJL0+Pp43IeemzZFQdI8
TfsDxQBzKLMEVrMhEp2EqvEBRpgZWKC4+2UdEtLCZPIKOop8aZyySmM8F8ZN
uH/KBDkuZqdcck0x1vjhyYc3N+DxLxEn2CIGBo9phP8+ZoZ+zTXBvrKNuLvI
M2CQvAl59iGrHxQy8fGzJBHfYDOS43jx5WUWuJdcsynXxAoL6tolp69b45sb
Ue6Nl2ywgMlNNuLYovPt0jruETuctmqanNnJQqHWRZ87SywseR14L65pCyZ0
shgOMVuxZcKgoES2Ff+NwFl7/BubXNhD
       "], {Developer`PackedArrayForm, CompressedData["
1:eJwl0gFHnQEAQNFveZJJkkmSVCaTSZIkSZIkk3lmJkmeJEklSZKkTZIkSZJJ
ksxMJpkkM0mSJEmSJEkykyRJkg67nH9w0yOt4ZYXQRB8Dv4XRYhoYnhJLHHE
k8ArEkkimRRSSSOD12Tyhizekk0OueSRTwGFFFFMCaWUUU4FlbyjiveE+cBH
PlFNDbXUEaGeBhppopkW2ming0666KaHXvro5wsDDDLEMCOMMsY4E0wyxVem
mWGWOeb5xnd+sMBPFlniF8ussMpv/rDGOhtsssU2O+yyxz4HHHLEMSeccsY5
F1zyl39ccc0Nt9xxzwOPPBEYIYoQz0P0QcA=
        "], CompressedData["
1:eJwd1Hk41GsbB3D7NmQpZOukoiJJjpTiqzKiFEU56lVRyJoltCDhbVQiGvuW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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], ",", 
    RowBox[{"dih", "\[Rule]", 
     InterpretationBox[
      RowBox[{
       TagBox["InterpolatingFunction",
        "SummaryHead"], "[", 
       DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
        "Ready"}, 
        TemplateBox[{PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAc6uKIKWXmT7s39guuWReP7+i+fp7
edc/fBGFMxGLpj/sWsM7OXboP7rsQ2cckLM/RbW/Kesr8j8e9bUGjHW6P08P
Bqvk/vc/qrxfq39iwD/y2Q8zPVD+P4jUuRTIosM/zzPqU9MaAkD3fUb4JY3G
P/EyrpG3TAVAqbKvv6acyT8wWyZKsW8IQK0oE4Kdicw/9OT7eLNcC0CiEf+j
tDXPPwQnMyvliA5AKs9/UU4H0T9N5eOpj78QQASuItOTVtI/pkuIezczEkBu
Fw6Vb5vTPyaO3Q53xhNA9bk7e2r41D9ogWHduj4VQN6R4StkO9Y/0FCWbZbW
FkBRpsreM5fXP8c0Jbv8ZhhAUt2gMOLq2D+AyeJDZ9wZQABYZPWEJto/XzpR
jmlxG0AOxQmbBHzbPwFc7hNw6xxAplia5FK63D/JWTxbDoUeQAYNSHkcE94/
EDbyr5sLIEBjWEDT1WXfP5yX3U8yxyBAk2qfyCZR4D87Z6HQlJIhQAWLyw0c
/eA/O4/8bnlQIkD51UwxKZ7hP4LBBGyjCiNANkUkWKE84j/cYeVJmdQjQMr6
he1Q6eI/mFpdRRGRJECm2Yo7TIvjP2fBrSFVXSVAONeez+E75D99Mqtc3iUm
QDw06C9m6uQ/9Ps/tengJkCwvNXFT47lP34zre7AqydAs2//M2tB5j9qw7FF
GmkoQLEdISn86eY/nV1j+7giKUAq9CQtnZDnP+Nl7ZEj7ClAt9ZtdxRH6D+K
xg5GEKgqQD6uBSb78ug/RJUI28hzK0A6CBSYQa/pP1+8mY0DMixA/JGp8Ppg
6j/C7deeg+wsQGJ6qZwfEes/OI3ukM+2LUANNvLZb9LrPw+FnKCdcy5AwWdu
ZxaJ7D/56iKRN0AvQPT3MtaVUe0/lS0rcIsEMEBHR76rKhnuP9+RkCY8YjBA
EfvKc+vV7j8yLWLN0scwQCANgFCLpe8/tnT/gqomMUCBAwryJjXwP11B8+ek
gzFABsD33AmX8D8ORVM9hegxQO21iDzvAvE/8PR+oaZGMkBXrfHHSWnxP9vb
FvatrDJAYmc0MCba8T/qRwX61xAzQK2sWXT+SvI/KWC/DENuM0CX0EOwKbby
P3Kv5Q+U0zNAS7xLuJos8z/sqtchJjI0QCuz1+NYnfM/b901JJ6YNEDoTtbt
BRr0PxaV6tU4/TRAI4BY3h6X9D/t+GqWFFs1QDqSbQ1fDvU/zpNXR9bANUAa
rkOulpL1P9/aDwfZHzZA8hoaUPQQ9j+4Fpr5/382QGGZYrffk/Y/XpPNGw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$109538#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 22.5}, {0., 1.4111020244104895`}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "22.5`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{{{}, {}, 
                    TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAc6uKIKWXmT7s39guuWReP7+i+fp7
edc/fBGFMxGLpj/sWsM7OXboP7rsQ2cckLM/RbW/Kesr8j8e9bUGjHW6P08P
Bqvk/vc/qrxfq39iwD/y2Q8zPVD+P4jUuRTIosM/zzPqU9MaAkD3fUb4JY3G
P/EyrpG3TAVAqbKvv6acyT8wWyZKsW8IQK0oE4Kdicw/9OT7eLNcC0CiEf+j
tDXPPwQnMyvliA5AKs9/UU4H0T9N5eOpj78QQASuItOTVtI/pkuIezczEkBu
Fw6Vb5vTPyaO3Q53xhNA9bk7e2r41D9ogWHduj4VQN6R4StkO9Y/0FCWbZbW
FkBRpsreM5fXP8c0Jbv8ZhhAUt2gMOLq2D+AyeJDZ9wZQABYZPWEJto/XzpR
jmlxG0AOxQmbBHzbPwFc7hNw6xxAplia5FK63D/JWTxbDoUeQAYNSHkcE94/
EDbyr5sLIEBjWEDT1WXfP5yX3U8yxyBAk2qfyCZR4D87Z6HQlJIhQAWLyw0c
/eA/O4/8bnlQIkD51UwxKZ7hP4LBBGyjCiNANkUkWKE84j/cYeVJmdQjQMr6
he1Q6eI/mFpdRRGRJECm2Yo7TIvjP2fBrSFVXSVAONeez+E75D99Mqtc3iUm
QDw06C9m6uQ/9Ps/tengJkCwvNXFT47lP34zre7AqydAs2//M2tB5j9qw7FF
GmkoQLEdISn86eY/nV1j+7giKUAq9CQtnZDnP+Nl7ZEj7ClAt9ZtdxRH6D+K
xg5GEKgqQD6uBSb78ug/RJUI28hzK0A6CBSYQa/pP1+8mY0DMixA/JGp8Ppg
6j/C7deeg+wsQGJ6qZwfEes/OI3ukM+2LUANNvLZb9LrPw+FnKCdcy5AwWdu
ZxaJ7D/56iKRN0AvQPT3MtaVUe0/lS0rcIsEMEBHR76rKhnuP9+RkCY8YjBA
EfvKc+vV7j8yLWLN0scwQCANgFCLpe8/tnT/gqomMUCBAwryJjXwP11B8+ek
gzFABsD33AmX8D8ORVM9hegxQO21iDzvAvE/8PR+oaZGMkBXrfHHSWnxP9vb
FvatrDJAYmc0MCba8T/qRwX61xAzQK2sWXT+SvI/KWC/DENuM0CX0EOwKbby
P3Kv5Q+U0zNAS7xLuJos8z/sqtchJjI0QCuz1+NYnfM/b901JJ6YNEDoTtbt
BRr0PxaV6tU4/TRAI4BY3h6X9D/t+GqWFFs1QDqSbQ1fDvU/zpNXR9bANUAa
rkOulpL1P9/aDwfZHzZA8hoaUPQQ9j+4Fpr5/382QGGZYrffk/Y/XpPNGw==

                    "]]}, 
                    Annotation[#, 
                    "Charting`Private`Tag$109538#1"]& ]}}, {}}, {
                 DisplayFunction -> Identity, Ticks -> {Automatic, Automatic},
                   AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                  GridLines -> {None, None}, DisplayFunction -> Identity, 
                  PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                  All, DisplayFunction -> Identity, AspectRatio -> 1, 
                  Axes -> {False, False}, AxesLabel -> {None, None}, 
                  AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                  Method -> {
                   "DefaultBoundaryStyle" -> Automatic, 
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "DefaultMeshStyle" -> AbsolutePointSize[6], 
                    "ScalingFunctions" -> None, 
                    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                  PlotRange -> {{0., 22.5}, {0., 1.4111020244104895`}}, 
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "22.5`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic]},
         "SummaryPanel"],
        DynamicModuleValues:>{}], "]"}],
      InterpolatingFunction[{{0., 22.5}}, {
       5, 7, 1, {130}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
        False}, CompressedData["
1:eJxFlIszFAgcx4lWltusZJdVi1bay3sLRfP7hTmsqPSikVeouDg5j41OaYlw
lkkZj7x6mCan9Wgvj6y9xKLTVZ6rTh7bYySV7B6rvZu7Zu4z853PfP+Bj0lo
jG/4ChUVFdV/lqbyP3zGcu3QHg34z5SvNod0yRlRZYrt1+8A3urLharCfSAI
2lEhHQgGjx0p8X29x2DYsIVd3xENVjzCjHNoHHwoqKuvOJoIjYV+HPXwZEgo
UsXjEalQ6n1ATdpwDkhaHhmxf3AhtXu75vLsBZhLt8zJ1M6GEFfj1Xrf/gwn
zmqK+6t5YPpn2sVCuwJgALvHK+QSmJWTiSt4l8FcOez56/0iYAZVZEW/K4bN
7cfEDKMysKBba0rY5SDYHj2pI66EoWk3l8aZapDzaJWHdG4A1fmjcpFVA9te
dQdePXQLHEejtp8h1oLDI5J+QFsd0MaHk9Y58qHE/5Y0J78eDJ8m71e8bYDi
Xd6iKLcmsLTGiEMnBSAks4iul+/BvnmzX6zaW0A6SPU1fN0GrWMrl9JWCYHg
o+yTG3XAnCA6s6JBBBKTF64e7AfQme2tfD/eCXc+tzZfSeyC4iCLBCCJIV1c
YvvqWg+w1hoSf1D2wcvgogm5fz94HMx+jqOPgZ7S45mu8QQWKjXvirc8hUdd
Hqak0Gfw2O+d/QxtEJ68yffqGRiCgdP2wTV5IzCkJfkxw1MCo6WpWWFqz2HM
knHVpe0FOFKq3FPLx+EcxQ6PjL+EXorI0clkEvSovrYGoVMQSJ1gyqqmoYZ6
ynRgUgoW+0cFdP5r4Oe5eEf+9Ba29t6aaPSagWbCmiQldRbAJfkbtvQ9TNyP
3dszMgcnclSCjEw/wpx/3vfRkZ8gyXz9aWH9PCjnb1/QXfoMGSKnwjBXGZB4
PVV3s+XAIU553zy8CNPcZfkVpgL2KPWvZcqXoYVjs5vTpYQ1i4zlLb0q6Cng
+9bWq2LrCJ1ssLACrRW5/dxt6li9XpE7l7IS9XdG7goQEjDr6DCxW20VKtK/
E7PcNTHY2Pj8eg0t/K35L2fNLm00P/B04VMGCTsTD/rFbNBBmZtrU5gaGZm6
NrqHJ8nYL7DI79Zfg/FHmDoObD2kqW3Mu35mLXbUmJL0+Pp43IeemzZFQdI8
TfsDxQBzKLMEVrMhEp2EqvEBRpgZWKC4+2UdEtLCZPIKOop8aZyySmM8F8ZN
uH/KBDkuZqdcck0x1vjhyYc3N+DxLxEn2CIGBo9phP8+ZoZ+zTXBvrKNuLvI
M2CQvAl59iGrHxQy8fGzJBHfYDOS43jx5WUWuJdcsynXxAoL6tolp69b45sb
Ue6Nl2ywgMlNNuLYovPt0jruETuctmqanNnJQqHWRZ87SywseR14L65pCyZ0
shgOMVuxZcKgoES2Ff+NwFl7/BubXNhD
       "], {Developer`PackedArrayForm, CompressedData["
1:eJwl0gFHnQEAQNFveZJJkkmSVCaTSZIkSZIkk3lmJkmeJEklSZKkTZIkSZJJ
ksxMJpkkM0mSJEmSJEkykyRJkg67nH9w0yOt4ZYXQRB8Dv4XRYhoYnhJLHHE
k8ArEkkimRRSSSOD12Tyhizekk0OueSRTwGFFFFMCaWUUU4FlbyjiveE+cBH
PlFNDbXUEaGeBhppopkW2ming0666KaHXvro5wsDDDLEMCOMMsY4E0wyxVem
mWGWOeb5xnd+sMBPFlniF8ussMpv/rDGOhtsssU2O+yyxz4HHHLEMSeccsY5
F1zyl39ccc0Nt9xxzwOPPBEYIYoQz0P0QcA=
        "], CompressedData["
1:eJwNlGc4FQoAhq2IhIaMctU1IiXRTYuPlNFQCVeSLaMkDYWOPZK9Rw46FDnn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        "]}, {Automatic}],
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.854468330856037*^9, {3.8544683713509717`*^9, 3.854468394491034*^9}, 
   3.854469164188836*^9, 3.854469307711932*^9, 3.854469507278886*^9, 
   3.854470201658229*^9, 3.8544703563657494`*^9, 3.85447039198269*^9, 
   3.85451084286655*^9, 3.861320190223954*^9, {3.861387112719822*^9, 
   3.861387184411666*^9}, 3.861387310447076*^9, 3.861387507196055*^9},
 CellLabel->
  "Out[925]=",ExpressionUUID->"3860f236-8f19-42ef-8044-a4af50a5c55b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "22.5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"delta_c", ",", "delta_i"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "delta"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, 
   3.8521288666663456`*^9, {3.852130762064339*^9, 3.8521308332363777`*^9}, {
   3.852130896147086*^9, 3.8521310938494043`*^9}, {3.8521367558250923`*^9, 
   3.8521368397526817`*^9}, 3.8521369198904943`*^9, 3.852144113254361*^9, {
   3.8521442109354515`*^9, 3.852144226900914*^9}, {3.852144264779761*^9, 
   3.8521442651655607`*^9}, {3.8521443842250557`*^9, 3.852144384855301*^9}, {
   3.8521445358839865`*^9, 3.852144536559326*^9}, {3.8521533390561695`*^9, 
   3.8521534020496907`*^9}, {3.8613871476507177`*^9, 3.86138719256396*^9}},
 CellLabel->
  "In[926]:=",ExpressionUUID->"3af9b9ca-f47d-4456-9d30-ff3d09f8c2a0"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV0Hs01YkWB3DRUXIUZbzOlOF4F+E4P48re8shb1IaTYkc49lIXveQPCqV
lCKqK0JDY3RwlSLUcKlRHc+4RhHymOLSz3ndlDXu7/6x116f9f2utdfaOiHH
/X6UlZGR+Yma/+8TPWaGjX23HSqCcKOMDAkOixXsEE4qTBklBl6RI2GilCjQ
41yC9vsKdqPyJPiGdsvTWYVw4pXUrUWBhHpeegeNUwxhKWGkK52E7OcabenV
5TAjF3f91kYSHveduL1iWQn0+ZW5dmUStGaYh6ROfJi1ZjfUqJLg8SnVNl5Q
B85piQNpaiQ8XZlT5FXXQ4T51gZ7DRIW5TlzYsuH0Jb6xSObQYI3Q3p30akV
ut6XfSjUISGsTFfNdP1TKNZQuSrLJCFd3ycrWvAb/OyqMhKuR8If6oMWCdXt
sO8/F+5vMyRhva6p8pLlM7h99GSk+w4SIohxwZyTAF79RTv9jk2CmJe4doNB
N8SubHgha01CRouivfH6HrDqrgrXsyHhJtrcCxf0wrqkEZ1gOxJCK7s4cdX9
cMpFNqLVgYSCOh3mJ8sh2LyrzkhrDwmSjtfjH5xGof/ji9MvDpCw2ZOufPLp
KDhzWcm935NgPshBJdsxyHxrFDAYQELU9MMyC7N3MLSSP//mBxJiZQXmu+gT
UDSUsHX0CAkzurVLWdJJKG+0uf4gjIRebly8+qsZUJxysx5KJKFi5kuSXcIC
RPN1xtPzSdgfrmjqPimBXfM5fRmdJDB0r6TnTK+AcE/17B9CEnZUJtC/gixC
ZcacLXMJyuP0fB8KaDif1nKG4bMEfUlgfbZSAR0Hqp7fPLUEOkeGvAOPKeG3
p8+IDlYvwY+rj2q3Jiujv4evatTrJVCfb1qnHrIZU/tcHzivLkECy34030QV
bwV1xdwxFELIwkrXlrlvcH6943idtxBqdsevK+1VR99ejcYMnhAqxFHt/AJN
XE28ypctFcJnR43uznQGlhZlDrK6hDAmI7c0eXQrfjoXdkGNFELMt8evZjK1
cUHT0/WlqghqI7vaCrO+Q2dd3QAlexGkiDT/uz1SB420x4SmwSKQuLsc+D1I
F3UT6Ky2cyKwPZTnOLOXiYZjWhfl+SIY0CyJ6mTpISj9ftGxRwRad8+0Vhnp
45jYYvRfQhE0TZh4eisZYOA/bLV3q4ph2yAZnrRAOeGtyQUrMbAK8/g/Txii
4exlvekDYihZKzLL7zDCT45ON/2SxPDIceebrMfGyAgVdfFviOGm9UWVlWoT
vGwgW3KvUQy9byvPsS5tx3juL6L+QTE89CrWi83YgTTxVGylSAxLP+2TiQk1
xdYch4FfNklA4mIcsehkhmz/vXmBJhKoWhj5HE/sxMONz0aTXSQQUF7JDaSb
Y0y5X9hIkAQe3PcIkjtvjvuT5iOPpkjAljGwnL1sjmd8awIs8yXAnAh/0x9p
gW2ua0uLqiQwrRjtUzxlgaW7+Fe6f5NAX643d4+/JWYXQ8fhQQkU8EoVE/ss
cbcxncb9KIHWp6vLXDcWGtYYpNWtSGDTYTzPamahpLYwKVpJCrbBi1VZVlY4
vEV+VWObFHJbUiOb7lrhmubkZqsdUtgTrxXLV2Oj94ZbOQU2UhjO01dkXmXj
3DKdy+FIoRaUIj7ksXF50SPmGOWzC+LOmmtUv+bakQLKlm6daTY32LgQ/t3i
FOVcGa7Q6zYbp+S4XZnOUnA5XjbC47Nx2suM2+QihQZPRlVPF5VPffhL2U0K
OV9kaQUv2fgo26CETTmkau7oQQEbhxXOav9AWXltM2O6l436JzP77lA+1hJw
ZfnfbHzt2/ze0l0KTJPrSXozbKyDZ+1eHlLIX6finLKGQFqRjXWMlxRahWOH
EuQILNqOutco/zlWHRdDI1D9fPDHRsr2DZyyEAUCc588UVzjLYXZYN5XdxUC
e1R/Lc2j/Lfm8XqGDoF3eu2+3PORwvSx2m1PkMDhXJrJs71S2Bhwkt24m8D7
TYuZM5RtnVw96znUvebMBpof9Q/N98mVrgQejPj7r86UbZ5/M3TZl8DF74P7
Oyhf1j6VcySYwNQ57U2P90mhaYP7nYAQAh0uutCHKb+XqD32CyVQJztoSkzZ
RvDPWZcIAunP7bTN91M5b9pxZyyBY0b+ggrK9ND6AOM4AuVqu2+0U7b2STvO
TCBwcGjU/h3lS/oaJeo8Am125m1R95fCI+WZByopBNac0HZmUZ78Wv9SMZXA
PJ6arw9l+p9pk7Q0Av0FUVbRlIkBj8+r6QRGSZSF5yj/D+DIODI=
          "]]}, Annotation[#, "Charting`Private`Tag$109599#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVjns0lAkchi2JMiaUe9u4RFSuYz6k9fvJoB0aNa2ORZdliqab3FYlI9KN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          "]]}, Annotation[#, "Charting`Private`Tag$109599#2"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {Automatic, Automatic}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox["x", HoldForm], TraditionalForm], 
       FormBox["delta", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"delta_c", "delta_i"}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.852130989856325*^9, {3.852131022693478*^9, 3.852131040583562*^9}, {
   3.8521310737532277`*^9, 3.852131096094097*^9}, 3.852131597225279*^9, 
   3.85213470996019*^9, {3.8521367513295164`*^9, 3.852136861485786*^9}, 
   3.8521369207794785`*^9, 3.8521441150023737`*^9, {3.8521442126845193`*^9, 
   3.8521442282150483`*^9}, {3.852144266300352*^9, 3.852144318533679*^9}, 
   3.852144386025009*^9, {3.852144508665457*^9, 3.8521445727710733`*^9}, {
   3.8521526512109694`*^9, 3.852152664122487*^9}, {3.852153340521995*^9, 
   3.8521534029863386`*^9}, 3.8521534477345223`*^9, 3.852393235672058*^9, 
   3.8544682303161335`*^9, 3.8544683344499636`*^9, {3.8544683748694925`*^9, 
   3.8544683982129107`*^9}, 3.854469164315158*^9, 3.854469312001621*^9, 
   3.8544695074176183`*^9, 3.854470201788704*^9, 3.8544703564810057`*^9, 
   3.8544703921219864`*^9, 3.8545108429633303`*^9, 3.861320190426359*^9, 
   3.861387112787095*^9, {3.861387148683097*^9, 3.861387193115323*^9}, 
   3.86138731051657*^9, 3.8613875073603153`*^9},
 CellLabel->
  "Out[926]=",ExpressionUUID->"5bfca307-0c0f-43a8-9319-617f686f6cad"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Profile", " ", "intersect", " ", "at", " ", 
    RowBox[{"x", "/", "dc0"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"21.9", ".", "  ", "calculation"}], " ", "cannot", " ", 
    "continue"}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8523934089100885`*^9, 3.8523934744118767`*^9}},
 CellLabel->
  "In[927]:=",ExpressionUUID->"f8bf62ab-7a8b-40fc-a8ab-1a73c92c38fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dih", "[", "x", "]"}], "/.", "s"}], "]"}], "/", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"dch", "[", "x", "]"}], "/.", "s"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "21.9"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "21.9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.0"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "delta_ratio"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, {
   3.852124125642785*^9, 3.852124141635003*^9}, {3.8521311140173144`*^9, 
   3.8521311358455563`*^9}, {3.852136793087507*^9, 3.8521368167286*^9}, {
   3.852137159884965*^9, 3.852137179240376*^9}, {3.8521534562534657`*^9, 
   3.8521534577260957`*^9}, {3.8544684035045304`*^9, 3.8544684050673103`*^9}},
 CellLabel->
  "In[928]:=",ExpressionUUID->"264d9d23-999b-475c-8c11-86ee95559d2a"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV0fk71AkcwHGkXcNKRZeSu4jK9c3d5+N4UlFp6km6HCW5smlI7ZQNYyU6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       "]]},
     Annotation[#, "Charting`Private`Tag$109680#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["x", HoldForm], TraditionalForm], 
    FormBox["delta_ratio", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 21.9}, {0, 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8521241496341267`*^9, 3.8521288800069914`*^9, 3.8521295058238277`*^9, 
   3.8521297161720333`*^9, 3.8521311399580317`*^9, 3.852131601893999*^9, 
   3.8521347148755445`*^9, {3.852136794543645*^9, 3.852136818676442*^9}, 
   3.85213692588529*^9, 3.8521371837472353`*^9, 3.8521445442999954`*^9, 
   3.852144577633812*^9, 3.852152674455408*^9, 3.852153463796714*^9, 
   3.852393242448696*^9, 3.852393482585869*^9, {3.8544683786777663`*^9, 
   3.8544684070539103`*^9}, 3.8544691644264746`*^9, 3.8544695075427847`*^9, 
   3.854470201882196*^9, 3.854470356613801*^9, 3.8544703922902784`*^9, 
   3.854510843015266*^9, 3.86132019046172*^9, 3.86138711289397*^9, 
   3.861387310629044*^9, 3.861387507445229*^9},
 CellLabel->
  "Out[928]=",ExpressionUUID->"a4b6be78-b1aa-4ef9-9871-67b9a44db334"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Now", " ", "shear", " ", "stresses", " ", "profiles"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8523934863561687`*^9, 3.8523934975676327`*^9}},
 CellLabel->
  "In[929]:=",ExpressionUUID->"c07ae007-5a1a-40e4-b398-6f3cbcd8c004"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"S1Sol", "[", "x", "]"}], ",", 
   RowBox[{"S2Sol", "[", "x", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.852129834464188*^9, 3.85212986212484*^9}},
 CellLabel->
  "In[930]:=",ExpressionUUID->"a0b9618e-2a4b-4a89-9f93-d07f6133c2a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "K"], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.852129864630492*^9, 3.852144586290086*^9, 
  3.8521526852388124`*^9, 3.8521534765185328`*^9, 3.85239325765287*^9, 
  3.8544684244557667`*^9, 3.854469164560133*^9, 3.8544695076922827`*^9, 
  3.8544702020480638`*^9, 3.8544703567265606`*^9, 3.8544703924207783`*^9, 
  3.854510843055888*^9, 3.861320190488905*^9, 3.861387112946851*^9, 
  3.86138731067796*^9, 3.861387507493536*^9},
 CellLabel->
  "Out[930]=",ExpressionUUID->"fff2b830-f4cb-44f9-a113-5341bbfec2a5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S1SolN", "[", "x_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"ProductLog", "[", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
      RowBox[{"dch", "[", "x", "]"}]}], "]"}], "K"], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"K", "\[Rule]", "0.384"}], ",", 
     RowBox[{"A", "\[Rule]", "4.17"}], ",", 
     RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.852129900314182*^9, 3.852129945731001*^9}, 
   3.8521299946526856`*^9, {3.8521446076637096`*^9, 3.852144646253935*^9}},
 CellLabel->
  "In[931]:=",ExpressionUUID->"1aaaec5b-007e-4c17-97b8-f4c93545e35c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S1SolN", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8521300006387076`*^9, 3.8521300287581463`*^9}},
 CellLabel->
  "In[932]:=",ExpressionUUID->"69f2260d-e485-4215-bb7b-d503288ffe89"],

Cell[BoxData[
 RowBox[{"2.6041666666666665`", " ", 
  RowBox[{"ProductLog", "[", 
   RowBox[{"637340.01023888`", " ", 
    RowBox[{"dch", "[", "x", "]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.8521300297560835`*^9, 3.85214465667334*^9, 
  3.852152696627823*^9, 3.8521534840944643`*^9, 3.8523932577726107`*^9, 
  3.854468424598563*^9, 3.8544691646504536`*^9, 3.8544695078186803`*^9, 
  3.8544702021267877`*^9, 3.8544703568166337`*^9, 3.8544703925108643`*^9, 
  3.854510843093493*^9, 3.861320190509881*^9, 3.86138711299079*^9, 
  3.86138731073597*^9, 3.86138750754568*^9},
 CellLabel->
  "Out[932]=",ExpressionUUID->"0fee1168-e819-430a-b419-4ad7727e824d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2SolN", "[", "x_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"dih", "[", "x", "]"}], "z02h"], "]"}], " ", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
    RowBox[{"K", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", "K"}], "+", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"K", " ", "Rec", " ", 
          RowBox[{"dih", "[", "x", "]"}]}], 
         RowBox[{"ProductLog", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"A", " ", "K"}]], " ", "K", " ", "Rec", " ", 
           RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}], ")"}]}]], "/.", 
   " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z02h", " ", "->", " ", "0.000371"}], ",", 
     RowBox[{"K", "\[Rule]", "0.384"}], ",", 
     RowBox[{"A", "\[Rule]", "4.17"}], ",", 
     RowBox[{"Rec", "\[Rule]", "334667"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.852129900314182*^9, 3.852129945731001*^9}, {
  3.852130043049155*^9, 3.8521300740164013`*^9}, {3.8521446729744716`*^9, 
  3.8521446776405983`*^9}},
 CellLabel->
  "In[933]:=",ExpressionUUID->"2e8e94c3-c4d5-4923-930a-6428d9ff421d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2SolN", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.8521300828358326`*^9, 3.852130087574032*^9}, {
  3.852153957397455*^9, 3.8521539579897165`*^9}, {3.852393520425887*^9, 
  3.8523935264340243`*^9}},
 CellLabel->
  "In[934]:=",ExpressionUUID->"8942b777-a967-48ee-968f-dc810915836d"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2.6041666666666665`", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"2695.4177897574123`", " ", 
     RowBox[{"dih", "[", "x", "]"}]}], "]"}], " ", 
   RowBox[{"ProductLog", "[", 
    RowBox[{"637340.01023888`", " ", 
     RowBox[{"dch", "[", "x", "]"}]}], "]"}]}], 
  RowBox[{"1.60128`", "\[VeryThinSpace]", "+", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"128512.128`", " ", 
      RowBox[{"dih", "[", "x", "]"}]}], 
     RowBox[{"ProductLog", "[", 
      RowBox[{"637340.01023888`", " ", 
       RowBox[{"dch", "[", "x", "]"}]}], "]"}]], "]"}]}]]], "Output",
 CellChangeTimes->{
  3.8521300885465574`*^9, 3.8521446925989*^9, 3.85215271181011*^9, 
   3.8521534934769154`*^9, 3.8523932578780622`*^9, {3.8523935166094627`*^9, 
   3.852393528448537*^9}, 3.8544684246706395`*^9, 3.854469164779998*^9, 
   3.8544695079219666`*^9, 3.8544702022277727`*^9, 3.854470356891765*^9, 
   3.8544703926049976`*^9, 3.8545108431345263`*^9, 3.861320190537272*^9, 
   3.861387113040976*^9, 3.861387310789517*^9, 3.861387507603018*^9},
 CellLabel->
  "Out[934]=",ExpressionUUID->"e229bce1-a10d-4a11-9d74-045ead78fbc3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"P1", " ", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{
          RowBox[{"S1SolN", "[", "x", "]"}], "^", "2"}]}], "/.", "s"}], "]"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "21.9"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "Cf1", "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Cf"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7304708017236705`*^9, 3.7304708122401657`*^9}, {
   3.7304730416168613`*^9, 3.7304730707815638`*^9}, {3.730473814039258*^9, 
   3.730473826796304*^9}, 3.730474078406934*^9, {3.73047653031583*^9, 
   3.730476543922491*^9}, {3.7304766464973187`*^9, 3.7304766615750213`*^9}, {
   3.730476862433628*^9, 3.730476896065502*^9}, {3.7304774941941566`*^9, 
   3.7304775031765327`*^9}, {3.7304816694624643`*^9, 3.730481675169521*^9}, {
   3.7304817798288193`*^9, 3.730481788564022*^9}, {3.7304819928760777`*^9, 
   3.730481993488542*^9}, {3.730482119312874*^9, 3.7304821203565845`*^9}, {
   3.730483211564336*^9, 3.730483212161736*^9}, 3.7304841703260126`*^9, {
   3.7304842742328053`*^9, 3.730484289830879*^9}, {3.7304851440883756`*^9, 
   3.7304851588588357`*^9}, {3.730556696895141*^9, 3.7305567422123394`*^9}, {
   3.730556896694992*^9, 3.7305569386537857`*^9}, {3.730557346763559*^9, 
   3.7305573666756663`*^9}, {3.7305577739448447`*^9, 
   3.7305577755709996`*^9}, {3.7305578613478703`*^9, 
   3.7305578616961155`*^9}, {3.7305579457467904`*^9, 3.730557946457324*^9}, {
   3.730558246032014*^9, 3.7305582468595715`*^9}, {3.7305583795617867`*^9, 
   3.730558379881013*^9}, {3.7312602962847276`*^9, 3.731260336965604*^9}, {
   3.731260371729291*^9, 3.731260378602171*^9}, {3.7312604370716763`*^9, 
   3.731260471952445*^9}, {3.731261923361915*^9, 3.7312619595786343`*^9}, {
   3.731262329272114*^9, 3.7312623329216766`*^9}, {3.8519557182337413`*^9, 
   3.8519558326506815`*^9}, {3.8519641774245214`*^9, 3.8519641827870855`*^9}, 
   3.8519757088954124`*^9, {3.851975794778686*^9, 3.8519759076207895`*^9}, {
   3.8519762075829487`*^9, 3.851976210600333*^9}, {3.851984496694077*^9, 
   3.851984498195173*^9}, {3.852052988475387*^9, 3.852052989045046*^9}, {
   3.852123991945447*^9, 3.8521240142489805`*^9}, 3.852124088513068*^9, {
   3.852124125642785*^9, 3.852124141635003*^9}, {3.85213011619508*^9, 
   3.8521301430047703`*^9}, {3.852130217573925*^9, 3.852130225014469*^9}, 
   3.852130336873315*^9, {3.8521313538860645`*^9, 3.852131392479273*^9}, {
   3.8521314540560384`*^9, 3.852131455947811*^9}, {3.852131496570117*^9, 
   3.85213151320859*^9}, {3.852137295378949*^9, 3.852137306004427*^9}, {
   3.852153511130223*^9, 3.852153512791292*^9}},
 CellLabel->
  "In[935]:=",ExpressionUUID->"d376d377-26a8-419b-b583-d70336a28a72"],

Cell[BoxData[
 RowBox[{
  RowBox[{"P2", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"2", "/", 
         RowBox[{
          RowBox[{"S2SolN", "[", "x", "]"}], "^", "2"}]}], "/.", "s"}], "]"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "21.9"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Orange"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "Cf2", "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8521302425391626`*^9, 3.852130282037215*^9}, 
   3.85213034376534*^9, {3.8521311848524218`*^9, 3.852131268789968*^9}, {
   3.8521313785130234`*^9, 3.8521314486244793`*^9}, 3.8521315072282715`*^9, {
   3.852153517609412*^9, 3.852153519079669*^9}},
 CellLabel->
  "In[936]:=",ExpressionUUID->"dff382a6-412f-4a68-9c58-90593139686b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P1pt5", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"P1", ",", "P2", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "21.9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.006"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8521302981332645`*^9, 3.8521303070806866`*^9}, {
   3.8521304328913984`*^9, 3.852130438397482*^9}, {3.8521312504548655`*^9, 
   3.852131285765663*^9}, 3.852131325225462*^9, 3.8521313639917946`*^9, 
   3.8521314322379427`*^9, {3.8521527268428793`*^9, 3.8521527921426654`*^9}, {
   3.852153539593119*^9, 3.852153542397509*^9}},
 CellLabel->
  "In[937]:=",ExpressionUUID->"3dbbba87-89e1-4f52-bed7-5e442842e288"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0nk01HsUAHDLlLWUilLIVkiF8StD073itCe0L7J8f0poFZW8elnaNxKi
ohmdPCqphKjMy5KUpTBm2jwjS40l1NNUvO/74557Pufcc+49914T/11eASpK
Skr+NP7Pe/Qfxm4Yujr/niTwQug4Fqb2Ceu3Rx8CG/3ErEJdFh609YpnRp8G
vp/bBW1qm88V/qsECSAOlwnCxrIw5Jsk0YlOhcicEp+eMSx0BHMt2+yuQ+2Z
fa5h1J7TU4mbIAO+1Het5FCbXQuSKkVnw+Kygog5Oiyc2fB6gk//HWjjc+3F
o1mI0Lya+cEuF/zuhnYeopaVcVrnCR7Aujt+ljWjWMibV7/xR1QRaLi59cVr
sxBkcOKApfNj2KAqT1xMbTTonLiu/wkct5GVDWux8ExS1yG1E4EopdV1L7XN
JZ45T1AKC1cPjg3QpPNraaR+i6qCkv1aeaHqLDQpWqxG+byE8N1KJx2p73UW
F5g7v4Lq5lz5bzUWtlXsblzVXw2yQN7SU9SBLnJ1iV0dyK9+LcscyULdr1Vu
cwX1sOK6TPUHhwVhqFlRf9RbKHVsrXytzEI1dFm7KN7Co6bYNdeoB7XyU87t
eQeTplw2DKJenrE0wsr3Pcj5Rt4q1AP1e3g+/I8Q8Dg3lFGi+5vcvOnToX+A
e85hMGOIwL7IWVKPOZ8gWJGkKvxJQB+qGqdny4EjdHRVfCNgUZqnIV/2DZoW
n57PkxPISg4pWWH8C44rrEQrZQSObD4wxD5TRu51/QBTKYEbhgm3ZXNHYL5o
q+qXOgL3YxLTdn1Xxwc3Re5elQTyXV96/ynUxr9LHcQWIgLvJDsaM9XHYEK5
k6yokEBta6BxcutYbDEQurfnEljwvPZue/o4tE0+GV+eReDOOq/Mg6snYCCa
y/uEBHScFrnoztTHIWeF8OEVAl0DmaZabROReK9pN0wkUKJy+IZmqQHy4yt1
Tc4TOFsccm755Sloe+Zz744TBJrcnz/tdjfClardBl5RBLRTllVWjZ+KeqOL
TZoOEfhyoHOtR99U3F9aI+0JI+Cm7MKsbzFBA/1qjZxdBFJ8bixUrjbFcqOL
TO52ArOtMVL6lxnqWfuVO7ME4FqCytxkc5T1hHXu20L7Hza+/SzcAuvjKlTt
NxCQOOSf+uoxDa+zeozVagJpCeqFAv50LJ75OqjRnUCG7wWtGANLNOyfLBte
QsCsse5Oh4YVFsauknxyo/UmU2O7B6wwxPjhKXUksFGSccS81hobFptZpTsT
OO8ke/H+8QwUyz93/5pDQFV9vVNFqg0+ut3Pr7Kn98+WvPMMm4nN4lsHa2YR
8B0cX+vjNwv5YhdLgTWB07nH2q/yZ+MLG51/P06j/6EpuTlbzxY9I+SrB0wJ
nPyqsTMz1hYHJ8UpdhsT+OEqevW1zxYrC4uizaYQmBbc0BC53Q6DUnvGF0wk
EPqc02vcZIdDaZO5ORMI/KG4cI/jYY+tS7yj4nUJHEsSjn5UZo/Ro4ev3Neh
9w6qizzO5SJnQne73SgCF3U3X0zM4mLGq7TqbE0Cyb3KxY8nOWCDi5b7UXUC
qbxZh/OOOeCRZZY740YS2LQuv6P7lwOqPRwVlcMh4Jy9KQCDGexyquZZqBKo
Frv8ttnB4OYZC8RG1P4cy0uTdjFYlDf54ETqE94DpX17GfT/znmhRV2vc9b8
RgSDmsFv0vtUCOzc90SmcYrB+55bzUTU6XwT/zeZDJpKkmL8qLlBaoqnWQxW
OY7N3URdntgVd+sWg2oWei1rqOU9haLYuwwWrK3wXErNE3iZOBYwuFGzYxuX
+vXImOYrFdRO1rtHUgdwgw6crGRQ70TnJyXqQR+PMeFVDMbNWeT7U5mAceEU
XFnDYHFIi38vdUhwXpqymEGZS2GalHo4KXVudxOD9pfPODVQx5cerZFKGXxQ
oiatoS4wdB++/4FBY55iWhn1sqUOSenNDKa2hdY/pf4QbjD7bAuDwYYpxx5R
7xUqVRxsZZCjvZOfRz2itm3L1jYGPzT3DuZQ/weaz78C
           "]]}, 
         Annotation[#, "Charting`Private`Tag$109731#1"]& ]}}, {}}, {{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0.5, 0]], 
          LineBox[CompressedData["
1:eJwVy3k8FHgDx3EjiuhwtFrV5qqI5Jrcvj/xsMlqSiIqrY4VSjPDXMYZnrRL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           "]]}, Annotation[#, "Charting`Private`Tag$109792#1"]& ]}}, {}}}, {
    PlotRange -> {{0, 21.9}, {0, 0.006}}, DisplayFunction -> Identity, 
     Ticks -> {Automatic, Automatic}, AxesOrigin -> {Automatic, Automatic}, 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox["x", HoldForm], TraditionalForm], 
       FormBox["Cf", TraditionalForm]}, 
     AxesOrigin -> {0, 0.0023201405488429824`}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"Cf1"}, "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"Cf2"}, "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.8521535327149844`*^9, 3.8521535462639475`*^9}, 
   3.8523932581009827`*^9, 3.854468425005859*^9, 3.854469164980206*^9, 
   3.8544695081444955`*^9, 3.8544702024510293`*^9, 3.8544703571020103`*^9, 
   3.8544703928199234`*^9, 3.8545108433494883`*^9, 3.8613201906125593`*^9, 
   3.8613871132025757`*^9, 3.8613875078301983`*^9},
 CellLabel->
  "Out[937]=",ExpressionUUID->"8fe455d5-b7e2-4d94-a71d-6875c7e1d962"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Calculation", " ", "for", " ", "corrected", " ", "shear", " ", "stress", 
   " ", "profile", " ", "is", " ", "complete"}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.8544702083957186`*^9, 3.8544702339880314`*^9}},
 CellLabel->
  "In[938]:=",ExpressionUUID->"23f29a0b-5462-4023-a561-d994d5243de2"]
},
WindowSize->{1440, 770},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 935, 18, 30, "Input",ExpressionUUID->"cb21c7c6-dc94-4bc3-9476-b0b5d034bbb4"],
Cell[1495, 40, 2442, 58, 94, "Input",ExpressionUUID->"ea60df7e-34a6-4c5b-b260-4c0ba7449a99"],
Cell[3940, 100, 352, 7, 30, "Input",ExpressionUUID->"82978fa8-6d69-43f3-b12c-ab4efd7c3ce1"],
Cell[CellGroupData[{
Cell[4317, 111, 580, 12, 30, "Input",ExpressionUUID->"f6965048-5747-4dd7-8f85-b3a359a09027"],
Cell[4900, 125, 254, 7, 57, "Output",ExpressionUUID->"dc798ac1-555d-4cdb-9cef-e592915bd5f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5191, 137, 768, 18, 30, "Input",ExpressionUUID->"4fa0517e-dfa6-42e8-ae35-99614f1d0edc"],
Cell[5962, 157, 336, 10, 64, "Output",ExpressionUUID->"21c13acf-8582-4ba6-a3ae-fffe571526a2"]
}, Open  ]],
Cell[6313, 170, 506, 12, 30, "Input",ExpressionUUID->"d5d7d418-6488-4e43-8ad8-d7b6e2cb5566"],
Cell[6822, 184, 744, 14, 30, "Input",ExpressionUUID->"25fb845c-9afe-4214-9316-c4d7ec15a13d"],
Cell[7569, 200, 552, 15, 30, "Input",ExpressionUUID->"671d1813-c94e-4f5c-8a63-6b76fadcdda2"],
Cell[CellGroupData[{
Cell[8146, 219, 726, 18, 30, "Input",ExpressionUUID->"e79b034f-0f7f-420c-afd4-b76835fa6bc6"],
Cell[8875, 239, 1024, 21, 66, "Output",ExpressionUUID->"21535c37-4bfc-4a2f-92e7-d72af02ed3b6"]
}, Open  ]],
Cell[9914, 263, 313, 7, 30, "Input",ExpressionUUID->"1624ab0b-1fa2-43b1-9025-174591d960c5"],
Cell[CellGroupData[{
Cell[10252, 274, 322, 7, 30, "Input",ExpressionUUID->"739a9663-a7f8-4d16-9c6b-6869524a3ed2"],
Cell[10577, 283, 755, 20, 66, "Output",ExpressionUUID->"8cf319ae-20f9-4d6b-9237-d17e6b0fe733"]
}, Open  ]],
Cell[11347, 306, 283, 6, 30, "Input",ExpressionUUID->"32d29f4e-9225-4db2-ae76-12b73b64b183"],
Cell[CellGroupData[{
Cell[11655, 316, 459, 14, 55, "Input",ExpressionUUID->"56cf7adb-e33b-4068-9a7f-c9e8eb9dedf2"],
Cell[12117, 332, 508, 12, 59, "Output",ExpressionUUID->"13de4b48-621e-42cb-99b0-268b1db91212"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12662, 349, 344, 8, 57, "Input",ExpressionUUID->"c73886e4-bc1f-4e87-9361-0ab56b188bc1"],
Cell[13009, 359, 413, 9, 59, "Output",ExpressionUUID->"f01ca4ae-62b1-4f46-9629-b3fd35e634ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13459, 373, 466, 12, 57, "Input",ExpressionUUID->"cecdd245-3829-4177-b408-81318d0e9dc8"],
Cell[13928, 387, 625, 15, 66, "Output",ExpressionUUID->"d267be12-39b0-4951-bd1d-e34b5d031332"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14590, 407, 182, 3, 30, "Input",ExpressionUUID->"852e83f0-b591-4995-accb-64d77e1fed5e"],
Cell[14775, 412, 601, 15, 66, "Output",ExpressionUUID->"c0761641-a3ff-480a-ac8d-dafd2468b4e4"]
}, Open  ]],
Cell[15391, 430, 308, 7, 30, "Input",ExpressionUUID->"791a9e83-929d-49bb-9336-e8da1d5c1adc"],
Cell[CellGroupData[{
Cell[15724, 441, 265, 6, 30, "Input",ExpressionUUID->"81561a9f-1ada-481b-8487-c87cd1193c15"],
Cell[15992, 449, 632, 14, 24, "Message",ExpressionUUID->"a25247d4-434e-4232-8ee0-b0a8268ba94f"],
Cell[16627, 465, 626, 16, 62, "Output",ExpressionUUID->"60010109-79ec-4ab9-a9eb-95ca420654f7"]
}, Open  ]],
Cell[17268, 484, 535, 14, 61, "Input",ExpressionUUID->"0b78b01e-d955-43e7-ad0b-88c866000b29"],
Cell[CellGroupData[{
Cell[17828, 502, 373, 8, 30, "Input",ExpressionUUID->"c1a895c8-3ec0-4572-b629-9474bce95644"],
Cell[18204, 512, 1032, 23, 67, "Output",ExpressionUUID->"7ba1a34c-93be-455b-8aab-953c69c3bce1"]
}, Open  ]],
Cell[19251, 538, 308, 7, 30, "Input",ExpressionUUID->"f2727e6a-3e68-4649-80cf-8e21138e53ca"],
Cell[CellGroupData[{
Cell[19584, 549, 619, 17, 49, "Input",ExpressionUUID->"4110c549-54c6-4c26-b4a3-ef900572dfb7"],
Cell[20206, 568, 651, 16, 67, "Output",ExpressionUUID->"304598f0-87ef-42de-ae8a-e63eb55a6a34"]
}, Open  ]],
Cell[20872, 587, 240, 5, 30, "Input",ExpressionUUID->"ab54f21e-2941-49ed-91f2-568487038381"],
Cell[21115, 594, 404, 10, 30, "Input",ExpressionUUID->"7ac1198f-a464-4ae9-b60a-0fa9abb193ba"],
Cell[21522, 606, 582, 13, 33, "Input",ExpressionUUID->"c062a907-3048-4101-b550-1a602178787e"],
Cell[CellGroupData[{
Cell[22129, 623, 211, 4, 30, "Input",ExpressionUUID->"fa47fa05-ec70-4bcf-adaf-4f08f4288ea7"],
Cell[22343, 629, 591, 12, 54, "Output",ExpressionUUID->"91cfffbc-b63c-445c-9e7d-53704a639644"]
}, Open  ]],
Cell[22949, 644, 243, 5, 30, "Input",ExpressionUUID->"19102964-597c-4a97-a3dd-ec5c7adcb088"],
Cell[CellGroupData[{
Cell[23217, 653, 178, 3, 30, "Input",ExpressionUUID->"f7a660d9-1fa9-465b-84b4-9135ee0aa205"],
Cell[23398, 658, 574, 15, 67, "Output",ExpressionUUID->"58b909ca-bd08-4dab-82e1-3db70ef846f2"]
}, Open  ]],
Cell[23987, 676, 719, 20, 50, "Input",ExpressionUUID->"34d944d9-3719-4b8d-8940-c858fbcfb91c"],
Cell[CellGroupData[{
Cell[24731, 700, 209, 4, 30, "Input",ExpressionUUID->"f25969f8-5e8d-4b0a-9069-be4ed7c7f2c8"],
Cell[24943, 706, 1198, 31, 81, "Output",ExpressionUUID->"36078014-3b2b-4609-97f0-ba6de85e8854"]
}, Open  ]],
Cell[26156, 740, 277, 6, 30, "Input",ExpressionUUID->"c03a0ec9-4f52-4dbc-bb8d-cf909ec33d7b"],
Cell[26436, 748, 1018, 29, 78, "Input",ExpressionUUID->"440c160d-5182-4656-9d8f-ed2e976269c7"],
Cell[27457, 779, 273, 6, 30, "Input",ExpressionUUID->"8a2531e4-a929-4184-a325-dc3396178401"],
Cell[CellGroupData[{
Cell[27755, 789, 671, 15, 30, "Input",ExpressionUUID->"0b10577e-4069-4410-aff5-a67f7fe22f40"],
Cell[28429, 806, 707, 10, 34, "Output",ExpressionUUID->"49d681c9-d6de-4e84-b2c0-a232806c3876"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29173, 821, 1033, 22, 30, "Input",ExpressionUUID->"40524fd0-6eab-439f-a425-d9dc2a2cdc82"],
Cell[30209, 845, 540, 8, 34, "Output",ExpressionUUID->"05db6b8f-7b47-4104-9f01-3cc4be6fadf9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30786, 858, 362, 8, 30, "Input",ExpressionUUID->"4f29be76-7bab-497d-827d-76d6240fd6d8"],
Cell[31151, 868, 1591, 40, 81, "Output",ExpressionUUID->"fe780e16-6ee2-4ed0-aa09-ba3eaf1a3d4a"]
}, Open  ]],
Cell[32757, 911, 302, 7, 30, "Input",ExpressionUUID->"d4fbf5f9-1dc1-4e1b-a0ce-980765611ee2"],
Cell[33062, 920, 609, 12, 30, "Input",ExpressionUUID->"292642b2-b58d-4450-805b-067cbe7fdb10"],
Cell[CellGroupData[{
Cell[33696, 936, 592, 11, 30, "Input",ExpressionUUID->"28dc1692-73b7-4e17-b0dc-6228604e3cb4"],
Cell[34291, 949, 1593, 36, 61, "Output",ExpressionUUID->"ef36533b-7c9f-406f-8626-a82bec44c76c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35921, 990, 612, 14, 30, "Input",ExpressionUUID->"2a769c66-0636-43c8-bfb0-1e906775d018"],
Cell[36536, 1006, 1983, 52, 61, "Output",ExpressionUUID->"52a0ca4e-b533-444e-9cc4-3eac2eabc168"]
}, Open  ]],
Cell[38534, 1061, 270, 6, 30, "Input",ExpressionUUID->"074ea169-89cd-43eb-930f-f08e8ba96b09"],
Cell[CellGroupData[{
Cell[38829, 1071, 460, 10, 30, "Input",ExpressionUUID->"eb92df4c-5651-4f54-b289-ba4f93144542"],
Cell[39292, 1083, 740, 14, 58, "Output",ExpressionUUID->"931a3f4f-403d-408d-ae9b-8df0f6ffa5c7"]
}, Open  ]],
Cell[40047, 1100, 208, 4, 30, "Input",ExpressionUUID->"afcb4998-50d5-4bea-a001-d20ddb8ba456"],
Cell[40258, 1106, 407, 9, 30, "Input",ExpressionUUID->"d5c1f21f-9406-4b4f-b671-45c4e6dfe44c"],
Cell[40668, 1117, 535, 13, 55, "Input",ExpressionUUID->"b5b2af8a-821f-4296-9e42-5068ea68075d"],
Cell[CellGroupData[{
Cell[41228, 1134, 209, 4, 30, "Input",ExpressionUUID->"035835b1-ba77-4b28-beac-3e6729f12875"],
Cell[41440, 1140, 1126, 30, 81, "Output",ExpressionUUID->"f409aff8-6b2c-4319-8524-ab1703c101da"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42603, 1175, 206, 4, 30, "Input",ExpressionUUID->"636dc89e-5e09-4596-9bee-2cf1480dd0b2"],
Cell[42812, 1181, 1088, 25, 72, "Output",ExpressionUUID->"dc088538-078a-4f99-8311-9ed83be3b4bd"]
}, Open  ]],
Cell[43915, 1209, 323, 7, 30, "Input",ExpressionUUID->"04528a2a-0bcd-4ced-ac52-3de6bf03cbde"],
Cell[CellGroupData[{
Cell[44263, 1220, 334, 8, 30, "Input",ExpressionUUID->"51f2c909-ae6e-404a-929c-62767e7d10ef"],
Cell[44600, 1230, 825, 17, 58, "Output",ExpressionUUID->"66b5d26e-5ba1-4eab-8477-acc5ba07c768"]
}, Open  ]],
Cell[45440, 1250, 287, 6, 30, "Input",ExpressionUUID->"0df6fc1e-990f-4881-943e-716347f3716f"],
Cell[CellGroupData[{
Cell[45752, 1260, 326, 7, 30, "Input",ExpressionUUID->"0afed7a9-81cf-437a-b834-71056bde53af"],
Cell[46081, 1269, 924, 19, 57, "Output",ExpressionUUID->"5688ff29-b20f-46c2-8fc1-e1d70b508649"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47042, 1293, 519, 13, 30, "Input",ExpressionUUID->"00a7e422-fee2-438c-b3dd-5698e61a2cf6"],
Cell[47564, 1308, 1200, 29, 58, "Output",ExpressionUUID->"83d7c898-3dae-48cd-88ed-549c0e750212"]
}, Open  ]],
Cell[48779, 1340, 298, 7, 30, "Input",ExpressionUUID->"b4ffaa2d-74a5-4ef8-b19d-807a8c4870b4"],
Cell[49080, 1349, 622, 15, 52, "Input",ExpressionUUID->"392de634-aa3b-48db-b7c4-df97c481f97c"],
Cell[49705, 1366, 347, 8, 30, "Input",ExpressionUUID->"cc0d0b27-1416-4008-9a0d-e11081ce93a4"],
Cell[CellGroupData[{
Cell[50077, 1378, 349, 8, 30, "Input",ExpressionUUID->"efa3b49a-cede-4628-8036-e6f750c5a2ef"],
Cell[50429, 1388, 1257, 31, 61, "Output",ExpressionUUID->"2ed06b69-edcf-4a4b-a380-877f3b0e8b58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51723, 1424, 296, 7, 30, "Input",ExpressionUUID->"5f6834f1-12c7-469e-84ad-5dd9e22e3453"],
Cell[52022, 1433, 1001, 23, 61, "Output",ExpressionUUID->"9bcdeffe-27d5-4c85-9b0e-22be60f8d06a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53060, 1461, 264, 6, 30, "Input",ExpressionUUID->"4a9785f5-599d-4826-9263-94a6031e1d07"],
Cell[53327, 1469, 482, 8, 34, "Output",ExpressionUUID->"6481e303-0526-420a-ac06-ebaa8eced435"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53846, 1482, 727, 19, 30, "Input",ExpressionUUID->"c5ba50b8-bb4b-4070-804b-f40c11217fb4"],
Cell[54576, 1503, 2343, 65, 61, "Output",ExpressionUUID->"609c566d-81f3-4ec3-8318-7f7d2d560d91"]
}, Open  ]],
Cell[56934, 1571, 297, 7, 30, "Input",ExpressionUUID->"e8f80b15-c250-4072-9fe8-f3b30801a04b"],
Cell[CellGroupData[{
Cell[57256, 1582, 478, 9, 30, "Input",ExpressionUUID->"e5629228-dd94-46e0-824b-e9b97a37aafd"],
Cell[57737, 1593, 937, 19, 57, "Output",ExpressionUUID->"cf7836f7-d636-4d07-8d7e-840f825813fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58711, 1617, 322, 7, 30, "Input",ExpressionUUID->"b4e6d041-c22c-43c1-aa22-dd6036712378"],
Cell[59036, 1626, 839, 18, 57, "Output",ExpressionUUID->"200fbfb9-8282-46d5-9373-5f51d0cc449d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59912, 1649, 315, 7, 30, "Input",ExpressionUUID->"f6ba5116-ef24-409d-a965-9410a080fa50"],
Cell[60230, 1658, 461, 7, 34, "Output",ExpressionUUID->"17228a99-0c3c-4ed2-8d5a-eeb68dbe4ab4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60728, 1670, 826, 20, 30, "Input",ExpressionUUID->"32960b91-ff19-4920-b5f4-1eed50d60a48"],
Cell[61557, 1692, 1403, 37, 58, "Output",ExpressionUUID->"f334f745-cb27-44c9-b789-7889fb7b26ef"]
}, Open  ]],
Cell[62975, 1732, 609, 15, 52, "Input",ExpressionUUID->"3c7ea884-fcde-4a7e-86d0-941f0be15b46"],
Cell[63587, 1749, 354, 7, 30, "Input",ExpressionUUID->"879748e4-4d70-4dca-9eaf-ed67e218c967"],
Cell[CellGroupData[{
Cell[63966, 1760, 179, 3, 30, "Input",ExpressionUUID->"cddcc760-fb28-4f7b-a9d9-ff3675855cb5"],
Cell[64148, 1765, 1846, 50, 61, "Output",ExpressionUUID->"24bad9a6-441f-4f63-8d55-ce7e55b8ed5a"]
}, Open  ]],
Cell[66009, 1818, 408, 9, 30, "Input",ExpressionUUID->"ccded802-49e4-4be2-83cb-ef9acdff1953"],
Cell[CellGroupData[{
Cell[66442, 1831, 890, 19, 30, "Input",ExpressionUUID->"e8fdf097-19b3-4d5b-a6b6-eb1a04629f89"],
Cell[67335, 1852, 2613, 74, 109, "Output",ExpressionUUID->"23e29179-92d9-49d7-962e-73c877f80593"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69985, 1931, 890, 19, 30, "Input",ExpressionUUID->"594fdd82-c597-4243-80ec-1c64eb5ff193"],
Cell[70878, 1952, 3033, 80, 109, "Output",ExpressionUUID->"b9bab27e-7e07-4a52-8433-bbc8b48c6486"]
}, Open  ]],
Cell[73926, 2035, 861, 17, 30, "Input",ExpressionUUID->"52c36b3f-db34-4e37-8960-5294768c9f68"],
Cell[74790, 2054, 3324, 87, 182, "Input",ExpressionUUID->"91f9d3ac-9ecc-4283-875b-a3575e02ef54"],
Cell[78117, 2143, 287, 6, 30, "Input",ExpressionUUID->"419e9f84-50a1-4abb-a701-5c3258c4c039"],
Cell[CellGroupData[{
Cell[78429, 2153, 629, 15, 30, "Input",ExpressionUUID->"7757e649-1ed4-4103-a35f-6c73de0af9ce"],
Cell[79061, 2170, 407, 6, 34, "Output",ExpressionUUID->"43d106b4-d6a6-443d-b69e-4e8c5fe4c7cb"]
}, Open  ]],
Cell[79483, 2179, 265, 5, 30, "Input",ExpressionUUID->"f5cab13b-2fbf-450c-b2f9-bc30c515c4d8"],
Cell[CellGroupData[{
Cell[79773, 2188, 178, 3, 30, "Input",ExpressionUUID->"9aac8e5a-2bfd-415e-8190-8b01498c086b"],
Cell[79954, 2193, 775, 16, 58, "Output",ExpressionUUID->"96134cda-848c-473e-a2a4-42b9c6c385ac"]
}, Open  ]],
Cell[80744, 2212, 322, 7, 30, "Input",ExpressionUUID->"29f44626-c423-4b6d-a859-8cb2f4394fd4"],
Cell[CellGroupData[{
Cell[81091, 2223, 895, 20, 30, "Input",ExpressionUUID->"7484bbc1-6f60-429b-b7f3-a25db1349d38"],
Cell[81989, 2245, 1599, 40, 81, "Output",ExpressionUUID->"ced305a4-e563-4980-b4ea-9ca57d178764"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83625, 2290, 214, 4, 30, "Input",ExpressionUUID->"b7f1c1ab-272c-4835-8fa8-4d9b087cf72e"],
Cell[83842, 2296, 1281, 35, 81, "Output",ExpressionUUID->"a2a8238a-7666-48ad-8f3a-f6cb13054962"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85160, 2336, 632, 16, 30, "Input",ExpressionUUID->"a83bb409-ad98-4f59-be4e-5c0fcc4f4917"],
Cell[85795, 2354, 451, 8, 34, "Output",ExpressionUUID->"fd6843b8-6661-4df1-9924-66a4173c7084"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86283, 2367, 206, 4, 30, "Input",ExpressionUUID->"a8412832-c458-46a6-9719-912ca37fa949"],
Cell[86492, 2373, 1052, 25, 72, "Output",ExpressionUUID->"496216b9-f8bc-413b-8a29-19600f003345"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87581, 2403, 365, 8, 30, "Input",ExpressionUUID->"764c74de-05c2-44ad-b7fe-c5292f48b0b2"],
Cell[87949, 2413, 1210, 27, 72, "Output",ExpressionUUID->"4d9957ec-bcdf-4822-86d0-505da8d3b02a"]
}, Open  ]],
Cell[89174, 2443, 215, 4, 30, "Input",ExpressionUUID->"9f219e7c-97a5-4e45-acfa-eeada032eee7"],
Cell[89392, 2449, 314, 7, 30, "Input",ExpressionUUID->"015937c6-0dab-432d-a6be-fa79e8e4e004"],
Cell[89709, 2458, 1424, 36, 78, "Input",ExpressionUUID->"7cad23fe-7166-4ce7-9e12-20e5cd1a83a2"],
Cell[CellGroupData[{
Cell[91158, 2498, 209, 4, 30, "Input",ExpressionUUID->"457d3613-54e5-4784-9e11-b576e36eafa0"],
Cell[91370, 2504, 984, 24, 72, "Output",ExpressionUUID->"94ae0adb-03f1-4e27-99c5-ed00e31ea7d7"]
}, Open  ]],
Cell[92369, 2531, 274, 6, 30, "Input",ExpressionUUID->"086ef00e-ec76-4caa-956a-0da262b43879"],
Cell[CellGroupData[{
Cell[92668, 2541, 584, 15, 30, "Input",ExpressionUUID->"c3ab5535-47b6-4a94-aa11-139206ee1ec2"],
Cell[93255, 2558, 384, 6, 34, "Output",ExpressionUUID->"5173f54e-4ac0-47f6-88a9-56a88b368a96"]
}, Open  ]],
Cell[93654, 2567, 240, 5, 30, "Input",ExpressionUUID->"6aa609ae-0de0-41ee-a6fe-9dc700108989"],
Cell[CellGroupData[{
Cell[93919, 2576, 181, 3, 30, "Input",ExpressionUUID->"1cf35150-ebc7-4172-8780-f027f5a055c2"],
Cell[94103, 2581, 881, 25, 58, "Output",ExpressionUUID->"8481251d-d7d2-44c2-a80f-9bbebbba86ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95021, 2611, 739, 19, 30, "Input",ExpressionUUID->"af5e8ca6-a929-44f6-a4ab-51c2b843138f"],
Cell[95763, 2632, 1743, 44, 72, "Output",ExpressionUUID->"a4759076-c398-477d-98a9-7635540c24f3"]
}, Open  ]],
Cell[97521, 2679, 495, 10, 30, "Input",ExpressionUUID->"26a33294-6f31-4464-9388-4ec5eecb5f9a"],
Cell[CellGroupData[{
Cell[98041, 2693, 1835, 47, 70, "Input",ExpressionUUID->"63bf9988-dc69-4d36-8a4a-201c574d52ba"],
Cell[99879, 2742, 1884, 48, 72, "Output",ExpressionUUID->"57b53b59-3739-47a0-808f-53f880ddbea1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101800, 2795, 555, 14, 30, "Input",ExpressionUUID->"5f811457-9063-4a6e-86a2-408ca1ec7d2b"],
Cell[102358, 2811, 439, 7, 34, "Output",ExpressionUUID->"d072e8fc-0761-459b-b332-3a0caf1446f9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102834, 2823, 579, 12, 30, "Input",ExpressionUUID->"985cae73-98cc-4d60-8226-9856fe03dfab"],
Cell[103416, 2837, 6811, 178, 279, "Output",ExpressionUUID->"23713782-d42a-4707-a4f7-ec5145090a50"]
}, Open  ]],
Cell[110242, 3018, 253, 5, 30, "Input",ExpressionUUID->"056ce359-ff69-4d5d-bcbc-b80d003f7526"],
Cell[110498, 3025, 497, 15, 30, "Input",ExpressionUUID->"fe37d8ca-e77a-4a84-83f2-d0b75799e18d"],
Cell[110998, 3042, 1002, 20, 73, "Input",ExpressionUUID->"4ce40572-576e-4635-802f-19c9a666085d"],
Cell[112003, 3064, 771, 13, 52, "Input",ExpressionUUID->"d4f7e667-d918-4a6b-aa14-a56c199dafa2"],
Cell[CellGroupData[{
Cell[112799, 3081, 227, 5, 30, "Input",ExpressionUUID->"2dc65262-3214-427d-a0af-0503579834d3"],
Cell[113029, 3088, 3363, 96, 109, "Output",ExpressionUUID->"cd7c19c7-9aaf-4d10-8cda-b9333d9e75e6"]
}, Open  ]],
Cell[116407, 3187, 427, 10, 30, "Input",ExpressionUUID->"02d0c4fc-a834-42ad-bdb4-2fa1cdf1324b"],
Cell[CellGroupData[{
Cell[116859, 3201, 982, 20, 30, "Input",ExpressionUUID->"9a7f0b89-d7ac-4cac-9789-069bf3908070"],
Cell[117844, 3223, 4050, 110, 182, "Output",ExpressionUUID->"f7344620-df60-4bc3-870f-d02084e61401"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121931, 3338, 1015, 19, 30, "Input",ExpressionUUID->"00857a12-a045-43a5-a092-3f2841f3738c"],
Cell[122949, 3359, 4115, 108, 182, "Output",ExpressionUUID->"ff8136be-6dd3-424a-a02b-53f3bebb52cc"]
}, Open  ]],
Cell[127079, 3470, 457, 9, 30, "Input",ExpressionUUID->"e2c0fdc3-2818-46e3-90bb-ea9a4a772f83"],
Cell[127539, 3481, 4576, 119, 256, "Input",ExpressionUUID->"ebfcc9d9-9090-4e00-95dd-85b5e8e45fe4"],
Cell[132118, 3602, 274, 6, 30, "Input",ExpressionUUID->"e552149b-2708-43f3-acd8-8223cf18da2b"],
Cell[CellGroupData[{
Cell[132417, 3612, 630, 16, 30, "Input",ExpressionUUID->"a001de08-d375-443f-93c3-16325548d64c"],
Cell[133050, 3630, 456, 7, 34, "Output",ExpressionUUID->"a5424c61-d887-49e4-b89c-0304914c77bb"]
}, Open  ]],
Cell[133521, 3640, 264, 5, 30, "Input",ExpressionUUID->"e8074448-2c86-419b-885a-6854976bf757"],
Cell[133788, 3647, 240, 5, 30, "Input",ExpressionUUID->"dd73e1b8-d1ca-4d08-bb15-4a706c3ef535"],
Cell[CellGroupData[{
Cell[134053, 3656, 177, 3, 30, "Input",ExpressionUUID->"fbc0ea47-5dc4-4154-baf0-b92b90320538"],
Cell[134233, 3661, 1352, 36, 58, "Output",ExpressionUUID->"0177afee-d5d7-4135-be72-a7b668b3136e"]
}, Open  ]],
Cell[135600, 3700, 615, 15, 30, "Input",ExpressionUUID->"1f26f63b-cdbd-4d83-945b-ed978fe57cb0"],
Cell[CellGroupData[{
Cell[136240, 3719, 452, 9, 30, "Input",ExpressionUUID->"cd3114b4-7f25-4238-ab30-f1bd94376e00"],
Cell[136695, 3730, 1270, 33, 58, "Output",ExpressionUUID->"0a64d8ec-240d-440c-8ad3-11ee97a6a69e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138002, 3768, 819, 18, 30, "Input",ExpressionUUID->"806ac099-ab93-495c-8edb-4df002ee52a4"],
Cell[138824, 3788, 2685, 71, 81, "Output",ExpressionUUID->"93a1c67e-6d38-4f43-955d-2ddf260c36d2"]
}, Open  ]],
Cell[141524, 3862, 421, 9, 30, "Input",ExpressionUUID->"e7366cdf-3ef7-4a5c-a1f9-d1b8648ed9fc"],
Cell[141948, 3873, 3487, 86, 106, "Input",ExpressionUUID->"633d12df-963c-4d2e-9eea-701ba6efdf89"],
Cell[145438, 3961, 274, 6, 30, "Input",ExpressionUUID->"5c538785-894d-4594-807a-f509a0f01d60"],
Cell[CellGroupData[{
Cell[145737, 3971, 634, 16, 30, "Input",ExpressionUUID->"7b263790-27ec-4789-8f6d-dd4ee6b7df76"],
Cell[146374, 3989, 435, 7, 34, "Output",ExpressionUUID->"0d92e991-4558-4ca5-85ce-c22c1c9b4e5a"]
}, Open  ]],
Cell[146824, 3999, 688, 17, 30, "Input",ExpressionUUID->"4bec4fca-4865-40a8-8188-40bcb53269c1"],
Cell[147515, 4018, 774, 19, 30, "Input",ExpressionUUID->"e87d97c2-fbc4-4eb0-8192-fea5eaf9f7ed"],
Cell[CellGroupData[{
Cell[148314, 4041, 942, 20, 30, "Input",ExpressionUUID->"a8f3c2d3-5e47-4a9b-86ba-5cbc25b56c89"],
Cell[149259, 4063, 711, 11, 34, "Output",ExpressionUUID->"167abe9e-2477-4d63-b10d-30bb6efdcde4"]
}, Open  ]],
Cell[149985, 4077, 531, 10, 30, "Input",ExpressionUUID->"55040b67-3794-4ada-bb1d-6e41b6838669"],
Cell[150519, 4089, 622, 14, 52, "Input",ExpressionUUID->"1c3b2305-8c6b-4458-813f-8dfe6ef6f3ea"],
Cell[CellGroupData[{
Cell[151166, 4107, 651, 13, 30, "Input",ExpressionUUID->"e2e0a281-3aa7-4888-9662-e0b12131aed3"],
Cell[151820, 4122, 774, 16, 59, "Output",ExpressionUUID->"56f4b8a3-6b9d-478d-979e-09ef4975e4d4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152631, 4143, 549, 14, 30, "Input",ExpressionUUID->"5abfcb77-b15b-44c7-b5fd-0918f11fd3f4"],
Cell[153183, 4159, 722, 11, 34, "Output",ExpressionUUID->"9b0ae716-fbf8-49d6-9da7-0148edad22d3"]
}, Open  ]],
Cell[153920, 4173, 411, 8, 30, "Input",ExpressionUUID->"a756a48b-aa86-4571-8aef-9584603dccd7"],
Cell[154334, 4183, 589, 11, 30, "Input",ExpressionUUID->"d10fbdd1-167d-42c2-a552-ed41575b821f"],
Cell[154926, 4196, 758, 15, 52, "Input",ExpressionUUID->"fe134c15-9aa3-47f8-95ac-006c9c717992"],
Cell[155687, 4213, 997, 22, 52, "Input",ExpressionUUID->"03d66728-b880-4634-8cfd-481b246a523b"],
Cell[156687, 4237, 826, 17, 30, "Input",ExpressionUUID->"8ae65aef-7dd1-4f36-aff8-3f748abfe610"],
Cell[157516, 4256, 836, 17, 30, "Input",ExpressionUUID->"2f36a8fc-cdce-4cbf-bad1-7619c056acc3"],
Cell[CellGroupData[{
Cell[158377, 4277, 3867, 61, 30, "Input",ExpressionUUID->"0b482a0a-ab45-49e3-9071-03ce1698f691"],
Cell[162247, 4340, 41797, 773, 62, "Output",ExpressionUUID->"df41b258-8051-4e73-9c33-f06f6eaaf1c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204081, 5118, 3190, 54, 30, "Input",ExpressionUUID->"b3beead8-1d69-4713-8ecd-b83d036903b3"],
Cell[207274, 5174, 17774, 346, 256, "Output",ExpressionUUID->"d741745a-4ad3-4935-b72d-71acc0cbf6a5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[225085, 5525, 2984, 54, 30, "Input",ExpressionUUID->"4be731d4-ecc6-48c2-baf0-f0afbc57742d"],
Cell[228072, 5581, 8228, 153, 253, "Output",ExpressionUUID->"c14ec73f-09cb-4722-b762-567b8ce2935d"]
}, Open  ]],
Cell[236315, 5737, 345, 7, 30, "Input",ExpressionUUID->"8fabd8cb-277e-4339-80d4-546393fe59b0"],
Cell[CellGroupData[{
Cell[236685, 5748, 286, 7, 30, "Input",ExpressionUUID->"8e3dc439-6ea5-45b9-80b5-6403274be7e4"],
Cell[236974, 5757, 1570, 40, 81, "Output",ExpressionUUID->"9bfd614b-91e9-4689-8f15-4425f513af34"]
}, Open  ]],
Cell[238559, 5800, 715, 18, 52, "Input",ExpressionUUID->"01b3c087-c389-4a55-890f-c3af83944273"],
Cell[CellGroupData[{
Cell[239299, 5822, 212, 4, 30, "Input",ExpressionUUID->"d94e3c06-3958-4f1e-8bc0-7742642a8eca"],
Cell[239514, 5828, 652, 12, 34, "Output",ExpressionUUID->"5ed12e67-1dd7-4351-81ed-e6a76b38b940"]
}, Open  ]],
Cell[240181, 5843, 1399, 38, 78, "Input",ExpressionUUID->"0d642e2e-a729-4b36-9035-7b16345170b3"],
Cell[CellGroupData[{
Cell[241605, 5885, 210, 4, 30, "Input",ExpressionUUID->"de1b85e0-bc45-422c-920b-c02f233be7c5"],
Cell[241818, 5891, 1091, 24, 64, "Output",ExpressionUUID->"0e2aa00f-5b50-4856-bffe-568fcbd0e407"]
}, Open  ]],
Cell[242924, 5918, 3032, 53, 30, "Input",ExpressionUUID->"4fc82e74-e2e0-4285-ab3d-cdf61f719fd1"],
Cell[245959, 5973, 991, 24, 30, "Input",ExpressionUUID->"59f641ce-2afd-4c64-8b60-426b9c8fc54f"],
Cell[CellGroupData[{
Cell[246975, 6001, 825, 18, 30, "Input",ExpressionUUID->"bb3d0b36-a536-46c0-b760-e0cb2a65072b"],
Cell[247803, 6021, 20301, 394, 246, "Output",ExpressionUUID->"7afd1b51-5acc-4f61-9b34-a919b40d6c22"]
}, Open  ]],
Cell[268119, 6418, 936, 20, 73, "Input",ExpressionUUID->"efef26a1-502a-4541-b629-c6f078407086"],
Cell[269058, 6440, 1338, 27, 73, "Input",ExpressionUUID->"66331773-4bb9-421b-9f25-7d98c3622c03"],
Cell[CellGroupData[{
Cell[270421, 6471, 1538, 41, 73, "Input",ExpressionUUID->"7d928bc9-9600-4476-b7c9-5ca2690646e0"],
Cell[271962, 6514, 2128, 46, 71, "Output",ExpressionUUID->"97279200-80df-458e-83a9-00fe9f409bfa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[274127, 6565, 500, 13, 30, "Input",ExpressionUUID->"2f3ef37c-6e75-401c-b0e8-b7f77715b377"],
Cell[274630, 6580, 501, 8, 34, "Output",ExpressionUUID->"e4169b88-8432-4f0b-971a-7ad540829087"]
}, Open  ]],
Cell[275146, 6591, 453, 9, 30, "Input",ExpressionUUID->"3c15c630-c4e8-4e0e-ba20-80143fb084b5"],
Cell[275602, 6602, 589, 11, 30, "Input",ExpressionUUID->"a137a26e-7727-4cde-9240-5e6c2fe6e49e"],
Cell[276194, 6615, 379, 8, 30, "Input",ExpressionUUID->"e5b2cb49-83b6-4a43-85db-68366112a9b5"],
Cell[276576, 6625, 440, 9, 30, "Input",ExpressionUUID->"bfadd152-9010-4b19-a525-4854e0b99ef2"],
Cell[277019, 6636, 826, 17, 30, "Input",ExpressionUUID->"a1a41cb1-e67a-41b4-a44f-d612b0acab6a"],
Cell[277848, 6655, 836, 17, 30, "Input",ExpressionUUID->"218f279c-a7e8-4d6a-a520-205c8acd2160"],
Cell[CellGroupData[{
Cell[278709, 6676, 3996, 63, 30, "Input",ExpressionUUID->"a51a6646-13a6-4472-969c-ddff8afd4cf1"],
Cell[282708, 6741, 37624, 710, 62, "Output",ExpressionUUID->"3860f236-8f19-42ef-8044-a4af50a5c55b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[320369, 7456, 3118, 53, 30, "Input",ExpressionUUID->"3af9b9ca-f47d-4456-9d30-ff3d09f8c2a0"],
Cell[323490, 7511, 17770, 346, 252, "Output",ExpressionUUID->"5bfca307-0c0f-43a8-9319-617f686f6cad"]
}, Open  ]],
Cell[341275, 7860, 429, 10, 30, "Input",ExpressionUUID->"f8bf62ab-7a8b-40fc-a8ab-1a73c92c38fc"],
Cell[CellGroupData[{
Cell[341729, 7874, 2944, 53, 30, "Input",ExpressionUUID->"264d9d23-999b-475c-8c11-86ee95559d2a"],
Cell[344676, 7929, 4638, 94, 253, "Output",ExpressionUUID->"a4b6be78-b1aa-4ef9-9871-67b9a44db334"]
}, Open  ]],
Cell[349329, 8026, 281, 6, 30, "Input",ExpressionUUID->"c07ae007-5a1a-40e4-b398-6f3cbcd8c004"],
Cell[CellGroupData[{
Cell[349635, 8036, 286, 7, 30, "Input",ExpressionUUID->"a0b9618e-2a4b-4a89-9f93-d07f6133c2a9"],
Cell[349924, 8045, 1574, 40, 81, "Output",ExpressionUUID->"fff2b830-f4cb-44f9-a113-5341bbfec2a5"]
}, Open  ]],
Cell[351513, 8088, 715, 18, 52, "Input",ExpressionUUID->"1aaaec5b-007e-4c17-97b8-f4c93545e35c"],
Cell[CellGroupData[{
Cell[352253, 8110, 212, 4, 30, "Input",ExpressionUUID->"69f2260d-e485-4215-bb7b-d503288ffe89"],
Cell[352468, 8116, 658, 12, 34, "Output",ExpressionUUID->"0fee1168-e819-430a-b419-4ad7727e824d"]
}, Open  ]],
Cell[353141, 8131, 1399, 38, 78, "Input",ExpressionUUID->"2e8e94c3-c4d5-4923-930a-6428d9ff421d"],
Cell[CellGroupData[{
Cell[354565, 8173, 312, 6, 30, "Input",ExpressionUUID->"8942b777-a967-48ee-968f-dc810915836d"],
Cell[354880, 8181, 1147, 25, 64, "Output",ExpressionUUID->"e229bce1-a10d-4a11-9d74-045ead78fbc3"]
}, Open  ]],
Cell[356042, 8209, 2980, 52, 30, "Input",ExpressionUUID->"d376d377-26a8-419b-b583-d70336a28a72"],
Cell[359025, 8263, 942, 23, 30, "Input",ExpressionUUID->"dff382a6-412f-4a68-9c58-90593139686b"],
Cell[CellGroupData[{
Cell[359992, 8290, 774, 17, 30, "Input",ExpressionUUID->"3dbbba87-89e1-4f52-bed7-5e442842e288"],
Cell[360769, 8309, 20465, 396, 246, "Output",ExpressionUUID->"8fe455d5-b7e2-4d94-a71d-6875c7e1d962"]
}, Open  ]],
Cell[381249, 8708, 348, 7, 30, "Input",ExpressionUUID->"23f29a0b-5462-4023-a561-d994d5243de2"]
}
]
*)

